@@ -1,3 +1,6 @@
+#ifndef MAIN_TEST
+#define MAIN_TEST
+
 //
 //  main.cpp
 //  TestMothur
@@ -8,21 +11,18 @@
 
 
 #include "mothurout.h"
-#include "gtest/gtest.h"
+#include "gtest.h"
 
 #define UNIT_TEST
 
 int main(int argc, char **argv) {
     MothurOut* m; m = MothurOut::getInstance();
+    m->setTestFilePath("/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/");
     string pathname = m->mothurProgramPath;
     if (pathname != "") {
         //add / to name if needed
         string lastChar = pathname.substr(pathname.length()-1);
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
-        if (lastChar != "/") { pathname += "/TestMothur/TestFiles/"; }
-#else
-        if (lastChar != "\\") { pathname += "\\TestMothur\\TestFiles\\"; }
-#endif
+        if (lastChar != PATH_SEPARATOR) { pathname += PATH_SEPARATOR; }
     }
     
     m->setTestFilePath(pathname);
@@ -30,3 +30,5 @@ int main(int argc, char **argv) {
     ::testing::InitGoogleTest(&argc, argv);
     return RUN_ALL_TESTS();
 }
+
+#endif
