@@ -19,23 +19,13 @@ EstOutput JSD::getValues(vector<SharedRAbundVector*> shared) {
         double KLD1 = 0.0;
         double KLD2 = 0.0;
 
-        vector<int> countA = shared[0]->getAbundances();
-        vector<int> countB = shared[1]->getAbundances();
-        double totalA = 0;
-        double totalB = 0;
+        double totalA = shared[0]->getNumSeqs();
+        double totalB = shared[1]->getNumSeqs();
         
-		for (int i = 0; i < shared[0]->getNumBins(); i++) {
-            totalA += countA[i];
-            totalB += countB[i];
-        }
-
         for (int i = 0; i < shared[0]->getNumBins(); i++) {
-            double tempA = countA[i] / totalA;
-            double tempB = countB[i] / totalB;
+            double tempA = shared[0]->get(i) / totalA;
+            double tempB = shared[1]->get(i) / totalB;
             
-            tempA = countA[i] / totalA;
-            tempB = countB[i] / totalB;
-
             if (tempA == 0) { tempA = 0.000001; }
             if (tempB == 0) { tempB = 0.000001; }
 
@@ -43,7 +33,6 @@ EstOutput JSD::getValues(vector<SharedRAbundVector*> shared) {
 
             if (tempA != 0) {  KLD1 += tempA * log(tempA/denom); } //KLD(x,m)
             if (tempB != 0) {  KLD2 += tempB * log(tempB/denom); } //KLD(y,m)
-
         }
 
             
