@@ -23,8 +23,8 @@ EstOutput Lennon::getValues(vector<SharedRAbundVector*> shared) {
 		
 		for (int i = 0; i < shared[0]->getNumBins(); i++) {
 			//store in temps to avoid multiple repetitive function calls
-			tempA = shared[0]->getAbundance(i);
-			tempB = shared[1]->getAbundance(i);
+			tempA = shared[0]->get(i);
+			tempB = shared[1]->get(i);
 			
 			if (tempA != 0) { S1++; }
 			if (tempB != 0) { S2++; } 
