@@ -21,7 +21,7 @@ public:
 	SharedSobsCS() : Calculator("sharedsobs", 1, true) {};
 	EstOutput getValues(SAbundVector* rank){ return data; };
 	EstOutput getValues(vector<SharedRAbundVector*>);
-    EstOutput getValues(vector<SharedRAbundVector*>, vector<string>&);
+    //EstOutput getValues(vector<SharedRAbundVector*>, vector<string>&);
 	string getCitation() { return "http://www.mothur.org/wiki/Sharedsobs"; }
 };
 
