@@ -82,7 +82,7 @@ ChimeraSlayer::ChimeraSlayer(string file, string temp, bool trim, map<string, in
 			
 			//run filter on template copying templateSeqs into filteredTemplateSeqs
 			for (int i = 0; i < templateSeqs.size(); i++) {  
-				if (m->control_pressed) {  break; }
+				if (m->getControl_pressed()) {  break; }
 				
 				Sequence* newSeq = new Sequence(templateSeqs[i]->getName(), templateSeqs[i]->getAligned());
 				runFilter(newSeq);  
@@ -131,7 +131,7 @@ ChimeraSlayer::ChimeraSlayer(string file, string temp, bool trim, map<string, in
 			
 			//run filter on template copying templateSeqs into filteredTemplateSeqs
 			for (int i = 0; i < templateSeqs.size(); i++) {  
-				if (m->control_pressed) {  break; }
+				if (m->getControl_pressed()) {  break; }
 				
 				Sequence* newSeq = new Sequence(templateSeqs[i]->getName(), templateSeqs[i]->getAligned());
 				runFilter(newSeq);  
@@ -158,11 +158,11 @@ int ChimeraSlayer::doPrep() {
 		
 			for (int i = 0; i < tempQuerySeqs.size(); i++) { delete tempQuerySeqs[i];  }
 		
-			if (m->control_pressed) {  return 0; } 
+			if (m->getControl_pressed()) {  return 0; } 
 		
 			//run filter on template copying templateSeqs into filteredTemplateSeqs
 			for (int i = 0; i < templateSeqs.size(); i++) {  
-				if (m->control_pressed) {  return 0; }
+				if (m->getControl_pressed()) {  return 0; }
 				
 				Sequence* newSeq = new Sequence(templateSeqs[i]->getName(), templateSeqs[i]->getAligned());
 				runFilter(newSeq);  
@@ -171,14 +171,14 @@ int ChimeraSlayer::doPrep() {
 		}
 		string 	kmerDBNameLeft;
 		string 	kmerDBNameRight;
-	
+        Utils util;
 		//generate the kmerdb to pass to maligner
 		if (searchMethod == "kmer") { 
-			string templatePath = m->hasPath(templateFileName);
-			string rightTemplateFileName = templatePath + "right." + m->getRootName(m->getSimpleName(templateFileName));
+			string templatePath = util.hasPath(templateFileName);
+			string rightTemplateFileName = templatePath + "right." + util.getRootName(util.getSimpleName(templateFileName));
 			databaseRight = new KmerDB(rightTemplateFileName, kmerSize);
 				
-			string leftTemplateFileName = templatePath + "left." + m->getRootName(m->getSimpleName(templateFileName));
+			string leftTemplateFileName = templatePath + "left." + util.getRootName(util.getSimpleName(templateFileName));
 			databaseLeft = new KmerDB(leftTemplateFileName, kmerSize);	
 		
 			//leftside
@@ -186,8 +186,9 @@ int ChimeraSlayer::doPrep() {
 			ifstream kmerFileTestLeft(kmerDBNameLeft.c_str());
 			bool needToGenerateLeft = true;
 			
-			if(kmerFileTestLeft){	
-				bool GoodFile = m->checkReleaseVersion(kmerFileTestLeft, m->getVersion());
+			if(kmerFileTestLeft){
+                string line = util.getline(kmerFileTestLeft);
+				bool GoodFile = util.checkReleaseVersion(line, current->getVersion());
 				if (GoodFile) {  needToGenerateLeft = false;	}
 			}
 			
@@ -195,7 +196,7 @@ int ChimeraSlayer::doPrep() {
 			
 				for (int i = 0; i < templateSeqs.size(); i++) {
 					
-					if (m->control_pressed) { return 0; } 
+					if (m->getControl_pressed()) { return 0; } 
 					
 					string leftFrag = templateSeqs[i]->getUnaligned();
 					leftFrag = leftFrag.substr(0, int(leftFrag.length() * 0.33));
@@ -217,15 +218,16 @@ int ChimeraSlayer::doPrep() {
 			ifstream kmerFileTestRight(kmerDBNameRight.c_str());
 			bool needToGenerateRight = true;
 			
-			if(kmerFileTestRight){	
-				bool GoodFile = m->checkReleaseVersion(kmerFileTestRight, m->getVersion());
+			if(kmerFileTestRight){
+                string line = util.getline(kmerFileTestRight);
+				bool GoodFile = util.checkReleaseVersion(line, current->getVersion());
 				if (GoodFile) {  needToGenerateRight = false;	}
 			}
 			
 			if(needToGenerateRight){	
 			
 				for (int i = 0; i < templateSeqs.size(); i++) {
-					if (m->control_pressed) { return 0; } 
+					if (m->getControl_pressed()) { return 0; } 
 					
 					string rightFrag = templateSeqs[i]->getUnaligned();
 					rightFrag = rightFrag.substr(int(rightFrag.length() * 0.66));
@@ -245,9 +247,9 @@ int ChimeraSlayer::doPrep() {
 		}else if (searchMethod == "blast") {
 		
 			//generate blastdb
-			databaseLeft = new BlastDB(m->getRootName(m->getSimpleName(fastafile)), -1.0, -1.0, 1, -3, blastlocation, threadID);
+			databaseLeft = new BlastDB(util.getRootName(util.getSimpleName(fastafile)), -1.0, -1.0, 1, -3, blastlocation, threadID);
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 
 			for (int i = 0; i < templateSeqs.size(); i++) { 	databaseLeft->addSequence(*templateSeqs[i]);	}
 			databaseLeft->generateDB();
@@ -274,7 +276,7 @@ vector<Sequence*> ChimeraSlayer::getTemplate(Sequence q, vector<Sequence*>& user
 		
 		for (int i = 0; i < templateSeqs.size(); i++) {
 			
-			if (m->control_pressed) { return userTemplate; } 
+			if (m->getControl_pressed()) { return userTemplate; } 
 			
 			//have I reached a sequence with the same abundance as myself?
 			if (!(priority[templateSeqs[i]->getName()] > myAbund)) { break; }
@@ -295,18 +297,19 @@ vector<Sequence*> ChimeraSlayer::getTemplate(Sequence q, vector<Sequence*>& user
 		string 	kmerDBNameRight;
 		
 		//generate the kmerdb to pass to maligner
-		if (searchMethod == "kmer") { 
-			string templatePath = m->hasPath(templateFileName);
-			string rightTemplateFileName = templatePath + "right." + m->getRootName(m->getSimpleName(templateFileName));
+		if (searchMethod == "kmer") {
+            Utils util;
+			string templatePath = util.hasPath(templateFileName);
+			string rightTemplateFileName = templatePath + "right." + util.getRootName(util.getSimpleName(templateFileName));
 			databaseRight = new KmerDB(rightTemplateFileName, kmerSize);
 			
-			string leftTemplateFileName = templatePath + "left." + m->getRootName(m->getSimpleName(templateFileName));
+			string leftTemplateFileName = templatePath + "left." + util.getRootName(util.getSimpleName(templateFileName));
 			databaseLeft = new KmerDB(leftTemplateFileName, kmerSize);	
 			
 			
 			for (int i = 0; i < userTemplate.size(); i++) {
 				
-				if (m->control_pressed) { return userTemplate; } 
+				if (m->getControl_pressed()) { return userTemplate; } 
 				
 				string leftFrag = userTemplate[i]->getUnaligned();
 				leftFrag = leftFrag.substr(0, int(leftFrag.length() * 0.33));
@@ -318,7 +321,7 @@ vector<Sequence*> ChimeraSlayer::getTemplate(Sequence q, vector<Sequence*>& user
 			databaseLeft->setNumSeqs(userTemplate.size());
 				
 			for (int i = 0; i < userTemplate.size(); i++) {
-				if (m->control_pressed) { return userTemplate; }  
+				if (m->getControl_pressed()) { return userTemplate; }  
 					
 				string rightFrag = userTemplate[i]->getUnaligned();
 				rightFrag = rightFrag.substr(int(rightFrag.length() * 0.66));
@@ -332,11 +335,12 @@ vector<Sequence*> ChimeraSlayer::getTemplate(Sequence q, vector<Sequence*>& user
 		}else if (searchMethod == "blast") {
 			
 			//generate blastdb
-			databaseLeft = new BlastDB(m->getRootName(m->getSimpleName(templateFileName)), -1.0, -1.0, 1, -3, blastlocation, threadID);
+            Utils util;
+			databaseLeft = new BlastDB(util.getRootName(util.getSimpleName(templateFileName)), -1.0, -1.0, 1, -3, blastlocation, threadID);
 			
-			if (m->control_pressed) { return userTemplate; }
+			if (m->getControl_pressed()) { return userTemplate; }
 
-			for (int i = 0; i < userTemplate.size(); i++) { if (m->control_pressed) { return userTemplate; }   databaseLeft->addSequence(*userTemplate[i]);	}
+			for (int i = 0; i < userTemplate.size(); i++) { if (m->getControl_pressed()) { return userTemplate; }   databaseLeft->addSequence(*userTemplate[i]);	}
 			databaseLeft->generateDB();
 			databaseLeft->setNumSeqs(userTemplate.size());
 		}
@@ -535,7 +539,7 @@ int ChimeraSlayer::getChimeras(Sequence* query) {
 		if (templateFileName != "self") { thisTemplate = templateSeqs; thisFilteredTemplate = filteredTemplateSeqs; }
 		else {  thisTemplate = getTemplate(*query, thisFilteredTemplate);  } //fills this template and creates the databases
 		
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		if (thisTemplate.size() == 0) {  return 0; } //not chimeric
 		
 		//moved this out of maligner - 4/29/11
@@ -549,11 +553,11 @@ int ChimeraSlayer::getChimeras(Sequence* query) {
 			else if (searchMethod == "blast") {  delete databaseLeft; }
 		}
 	
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 
 		string chimeraFlag = maligner.getResults(*query, decalc);
 
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		
 		vector<results> Results = maligner.getOutput();
 		
@@ -634,11 +638,11 @@ int ChimeraSlayer::getChimeras(Sequence* query) {
 //				cout << seqs[k].seq->getName() << endl;
 			}
 			
-			if (m->control_pressed) {  return 0;  }
+			if (m->getControl_pressed()) {  return 0;  }
 
 			//send to slayer
 			chimeraFlags = slayer.getResults(*query, seqsForSlayer);
-			if (m->control_pressed) {  return 0;  }
+			if (m->getControl_pressed()) {  return 0;  }
 			chimeraResults = slayer.getOutput();
 			
 			printResults.flag = chimeraFlags;
@@ -817,6 +821,7 @@ vector<Sequence> ChimeraSlayer::getBlastSeqs(Sequence q, vector<Sequence*>& db,
 		Sequence* queryLeft = new Sequence(q.getName(), leftQuery);
 		Sequence* queryRight = new Sequence(q.getName(), rightQuery);
 		
+        
 		vector<int> tempIndexesLeft = databaseLeft->findClosestMegaBlast(queryLeft, num+1, minSim);
 		vector<int> tempIndexesRight = databaseLeft->findClosestMegaBlast(queryRight, num+1, minSim);
 				
@@ -837,7 +842,7 @@ vector<Sequence> ChimeraSlayer::getBlastSeqs(Sequence q, vector<Sequence*>& db,
 //		for (int i = 0; i < smaller.size(); i++) {
 		while(index < tempIndexesLeft.size() && index < tempIndexesRight.size()){
 			
-			if (m->control_pressed) { delete queryRight; delete queryLeft; return refResults; }
+			if (m->getControl_pressed()) { delete queryRight; delete queryLeft; return refResults; }
 	
 			//add left if you havent already
 			it = seen.find(tempIndexesLeft[index]);
@@ -857,7 +862,7 @@ vector<Sequence> ChimeraSlayer::getBlastSeqs(Sequence q, vector<Sequence*>& db,
 
 		
 		for (int i = index; i < tempIndexesLeft.size(); i++) {
-			if (m->control_pressed) { delete queryRight; delete queryLeft; return refResults; }
+			if (m->getControl_pressed()) { delete queryRight; delete queryLeft; return refResults; }
 			
 			//add right if you havent already
 			it = seen.find(tempIndexesLeft[i]);
@@ -868,7 +873,7 @@ vector<Sequence> ChimeraSlayer::getBlastSeqs(Sequence q, vector<Sequence*>& db,
 		}
 
 		for (int i = index; i < tempIndexesRight.size(); i++) {
-			if (m->control_pressed) { delete queryRight; delete queryLeft; return refResults; }
+			if (m->getControl_pressed()) { delete queryRight; delete queryLeft; return refResults; }
 			
 			//add right if you havent already
 			it = seen.find(tempIndexesRight[i]);
@@ -914,8 +919,9 @@ vector<Sequence> ChimeraSlayer::getKmerSeqs(Sequence q, vector<Sequence*>& db, i
 		Sequence* queryLeft = new Sequence(q.getName(), leftQuery);
 		Sequence* queryRight = new Sequence(q.getName(), rightQuery);
 		
-		vector<int> tempIndexesLeft = databaseLeft->findClosestSequences(queryLeft, num);
-		vector<int> tempIndexesRight = databaseRight->findClosestSequences(queryRight, num);
+        vector<float> Scores;
+		vector<int> tempIndexesLeft = databaseLeft->findClosestSequences(queryLeft, num, Scores);
+		vector<int> tempIndexesRight = databaseRight->findClosestSequences(queryRight, num, Scores);
 		
 		//merge results		
 		map<int, int> seen;
@@ -926,7 +932,7 @@ vector<Sequence> ChimeraSlayer::getKmerSeqs(Sequence q, vector<Sequence*>& db, i
 		//		for (int i = 0; i < smaller.size(); i++) {
 		while(index < tempIndexesLeft.size() && index < tempIndexesRight.size()){
 			
-			if (m->control_pressed) { delete queryRight; delete queryLeft; return refResults; }
+			if (m->getControl_pressed()) { delete queryRight; delete queryLeft; return refResults; }
 			
 			//add left if you havent already
 			it = seen.find(tempIndexesLeft[index]);
@@ -946,7 +952,7 @@ vector<Sequence> ChimeraSlayer::getKmerSeqs(Sequence q, vector<Sequence*>& db, i
 		
 		
 		for (int i = index; i < tempIndexesLeft.size(); i++) {
-			if (m->control_pressed) { delete queryRight; delete queryLeft; return refResults; }
+			if (m->getControl_pressed()) { delete queryRight; delete queryLeft; return refResults; }
 			
 			//add right if you havent already
 			it = seen.find(tempIndexesLeft[i]);
@@ -957,7 +963,7 @@ vector<Sequence> ChimeraSlayer::getKmerSeqs(Sequence q, vector<Sequence*>& db, i
 		}
 		
 		for (int i = index; i < tempIndexesRight.size(); i++) {
-			if (m->control_pressed) { delete queryRight; delete queryLeft; return refResults; }
+			if (m->getControl_pressed()) { delete queryRight; delete queryLeft; return refResults; }
 			
 			//add right if you havent already
 			it = seen.find(tempIndexesRight[i]);
