@@ -9,7 +9,7 @@
 
 #include "decalc.h"
 #include "mothurchimera.h"
-#include "dist.h"
+#include "calculator.h"
 #include "eachgapdist.h"
 #include "ignoregaps.h"
 #include "eachgapdist.h"
@@ -286,16 +286,17 @@ float DeCalculator::calcDE(vector<float> obs, vector<float> exp) {
 
 //***************************************************************************************************************
 
-vector<float> DeCalculator::calcFreq(vector<Sequence*> seqs, string filename) {
+vector<float> DeCalculator::calcFreq(vector<Sequence*> seqs, string filename, string version) {
 	try {
 
 		vector<float> prob;
-		string freqfile = m->getRootName(filename) + "freq";
+        Utils util;
+		string freqfile = util.getRootName(filename) + "freq";
 		ofstream outFreq;
 		
-		m->openOutputFile(freqfile, outFreq);
+		util.openOutputFile(freqfile, outFreq);
 		
-		outFreq << "#" << m->getVersion() << endl;
+		outFreq << "#" << version << endl;
 		
 		string length = toString(seqs.size());  //if there are 5000 seqs in the template then set precision to 3
 		int precision = length.length() - 1;
@@ -401,7 +402,7 @@ vector< vector<float> > DeCalculator::getQuantiles(vector<Sequence*> seqs, vecto
 				
 				Sequence* subject = new Sequence(seqs[j]->getName(), seqs[j]->getAligned());
 				
-				if (m->control_pressed) { delete query; delete subject; return quan; }
+				if (m->getControl_pressed()) { delete query; delete subject; return quan; }
 				
 				map<int, int> trim;
 				map<int, int>::iterator it;
@@ -692,7 +693,7 @@ vector<Sequence> DeCalculator::findClosest(Sequence querySeq, vector<Sequence*>&
 		vector<SeqDist> distsLeft;
 		vector<SeqDist> distsRight;
 		
-		Dist* distcalculator = new eachGapDist();
+		DistCalc* distcalculator = new eachGapDist();
 		
 		string queryUnAligned = querySeq.getUnaligned();
 		int numBases = int(queryUnAligned.length() * 0.33);
@@ -743,8 +744,6 @@ vector<Sequence> DeCalculator::findClosest(Sequence querySeq, vector<Sequence*>&
 		Sequence queryLeft(querySeq.getName(), leftQuery);
 		Sequence queryRight(querySeq.getName(), rightQuery);
 		
-//cout << querySeq->getName() << '\t' << leftSpot << '\t' << rightSpot << '\t' << firstBaseSpot << '\t' << lastBaseSpot << endl;
-//cout << queryUnAligned.length() << '\t' << queryLeft.getUnaligned().length() << '\t' << queryRight.getUnaligned().length() << endl;
 		for(int j = 0; j < thisFilteredTemplate.size(); j++){
 			
 			string dbAligned = thisFilteredTemplate[j]->getAligned();
@@ -754,11 +753,8 @@ vector<Sequence> DeCalculator::findClosest(Sequence querySeq, vector<Sequence*>&
 			Sequence dbLeft(thisFilteredTemplate[j]->getName(), leftDB);
 			Sequence dbRight(thisFilteredTemplate[j]->getName(), rightDB);
 
-			distcalculator->calcDist(queryLeft, dbLeft);
-			float distLeft = distcalculator->getDist();
-			
-			distcalculator->calcDist(queryRight, dbRight);
-			float distRight = distcalculator->getDist();
+			double distLeft = distcalculator->calcDist(queryLeft, dbLeft);
+			double distRight = distcalculator->calcDist(queryRight, dbRight);
 
 			SeqDist subjectLeft;
 			subjectLeft.seq = NULL;
@@ -794,7 +790,7 @@ vector<Sequence> DeCalculator::findClosest(Sequence querySeq, vector<Sequence*>&
 		float maxDist = 1.0 - (minSim / 100.0);
 
 		for (int i = 0; i < numWanted+1; i++) {
-			if (m->control_pressed) { return seqsMatches; }
+			if (m->getControl_pressed()) { return seqsMatches; }
 			
 			//add left if you havent already
 			it = seen.find(thisTemplate[distsLeft[i].index]->getName());
@@ -862,14 +858,13 @@ Sequence* DeCalculator::findClosest(Sequence* querySeq, vector<Sequence*> db) {
 		
 		Sequence* seqsMatch;  
 		
-		Dist* distcalculator = new eachGapDist();
+		DistCalc* distcalculator = new eachGapDist();
 		int index = 0;
 		int smallest = 1000000;
 		
 		for(int j = 0; j < db.size(); j++){
 			
-			distcalculator->calcDist(*querySeq, *db[j]);
-			float dist = distcalculator->getDist();
+			double dist = distcalculator->calcDist(*querySeq, *db[j]);
 			
 			if (dist < smallest) { 
 				smallest = dist;
