@@ -12,7 +12,7 @@
 #include "phylosummary.h"
 
 /**************************************************************************************************/
-Bayesian::Bayesian(string tfile, string tempFile, string method, int ksize, int cutoff, int i, int tid, bool f, bool sh) : 
+Bayesian::Bayesian(string tfile, string tempFile, string method, int ksize, int cutoff, int i, int tid, bool f, bool sh, string version) :
 Classify(), kmerSize(ksize), confidenceThreshold(cutoff), iters(i) {
 	try {
 		
@@ -21,10 +21,11 @@ Classify(), kmerSize(ksize), confidenceThreshold(cutoff), iters(i) {
         shortcuts = sh;
 		string baseName = tempFile;
 		string baseTName = tfile;
+        Utils util;
 
 		/************calculate the probablity that each word will be in a specific taxonomy*************/
-		string tfileroot = m->getFullPathName(baseTName.substr(0,baseTName.find_last_of(".")+1));
-		string tempfileroot = m->getRootName(m->getSimpleName(baseName));
+		string tfileroot = util.getFullPathName(baseTName.substr(0,baseTName.find_last_of(".")+1));
+		string tempfileroot = util.getRootName(util.getSimpleName(baseName));
 		string phyloTreeName = tfileroot + "tree.train";
 		string phyloTreeSumName = tfileroot + "tree.sum";
 		string probFileName = tfileroot + tempfileroot + char('0'+ kmerSize) + "mer.prob";
@@ -38,13 +39,11 @@ Classify(), kmerSize(ksize), confidenceThreshold(cutoff), iters(i) {
 		ifstream probFileTest(probFileName.c_str());
 		ifstream probFileTest3(phyloTreeSumName.c_str());
 		
-		int start = time(NULL);
+		long start = time(NULL);
 		
 		//if they are there make sure they were created after this release date
 		bool FilesGood = false;
-		if(probFileTest && probFileTest2 && phyloTreeTest && probFileTest3){
-			FilesGood = checkReleaseDate(probFileTest, probFileTest2, phyloTreeTest, probFileTest3);
-		}
+		if(probFileTest && probFileTest2 && phyloTreeTest && probFileTest3){ FilesGood = checkReleaseDate(probFileTest, probFileTest2, phyloTreeTest, probFileTest3, version); }
 
 		if(probFileTest && probFileTest2 && phyloTreeTest && probFileTest3 && FilesGood){
 			
@@ -64,10 +63,10 @@ Classify(), kmerSize(ksize), confidenceThreshold(cutoff), iters(i) {
         }else{
 		
 			//create search database and names vector
-			generateDatabaseAndNames(tfile, tempFile, method, ksize, 0.0, 0.0, 0.0, 0.0);
+			generateDatabaseAndNames(tfile, tempFile, method, ksize, 0.0, 0.0, 0.0, 0.0, version);
 			
 			//prevents errors caused by creating shortcut files if you had an error in the sanity check.
-			if (m->control_pressed) {  m->mothurRemove(phyloTreeName);  m->mothurRemove(probFileName); m->mothurRemove(probFileName2); }
+			if (m->getControl_pressed()) {  util.mothurRemove(phyloTreeName);  util.mothurRemove(probFileName); util.mothurRemove(probFileName2); }
 			else{ 
 				genusNodes = phyloTree->getGenusNodes(); 
 				genusTotals = phyloTree->getGenusTotals();
@@ -91,26 +90,24 @@ Classify(), kmerSize(ksize), confidenceThreshold(cutoff), iters(i) {
 				ofstream out2;
 
                 if (shortcuts) { 
-                    m->openOutputFile(probFileName, out); 
+                    util.openOutputFile(probFileName, out); 
 				
                     //output mothur version
-                    out << "#" << m->getVersion() << endl;
+                    out << "#" << version << endl;
 				
                     out << numKmers << endl;
 				
-                    m->openOutputFile(probFileName2, out2);
+                    util.openOutputFile(probFileName2, out2);
 				
                     //output mothur version
-                    out2 << "#" << m->getVersion() << endl;
+                    out2 << "#" << version << endl;
                 }
-				
-				
 
 				//for each word
 				for (int i = 0; i < numKmers; i++) {
                     //m->mothurOut("[DEBUG]: kmer = " + toString(i) + "\n");
                     
-					if (m->control_pressed) {  break; }
+					if (m->getControl_pressed()) {  break; }
 
                     if (shortcuts) {  out << i << '\t'; }
 					
@@ -162,9 +159,9 @@ Classify(), kmerSize(ksize), confidenceThreshold(cutoff), iters(i) {
 			}
 		}
 		
-        if (m->debug) { m->mothurOut("[DEBUG]: about to generateWordPairDiffArr\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: about to generateWordPairDiffArr\n"); }
 		generateWordPairDiffArr();
-        if (m->debug) { m->mothurOut("[DEBUG]: done generateWordPairDiffArr\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: done generateWordPairDiffArr\n"); }
 			
 		m->mothurOut("DONE."); m->mothurOutEndLine();
 		m->mothurOut("It took " + toString(time(NULL) - start) + " seconds get probabilities. "); m->mothurOutEndLine();
@@ -187,9 +184,10 @@ Bayesian::~Bayesian() {
 }
 
 /**************************************************************************************************/
-string Bayesian::getTaxonomy(Sequence* seq) {
+string Bayesian::getTaxonomy(Sequence* seq, string& simpleTax, bool& flipped) {
 	try {
 		string tax = "";
+        simpleTax = "";
 		Kmer kmer(kmerSize);
 		flipped = false;
 		
@@ -225,16 +223,16 @@ string Bayesian::getTaxonomy(Sequence* seq) {
 		
 		int index = getMostProbableTaxonomy(queryKmers);
 		
-		if (m->control_pressed) { return tax; }
+		if (m->getControl_pressed()) { return tax; }
 					
 		//bootstrap - to set confidenceScore
 		int numToSelect = queryKmers.size() / 8;
 	
-        if (m->debug) {  m->mothurOut(seq->getName() + "\t"); }
+        if (m->getDebug()) {  m->mothurOut(seq->getName() + "\t"); }
         
-		tax = bootstrapResults(queryKmers, index, numToSelect);
+		tax = bootstrapResults(queryKmers, index, numToSelect, simpleTax);
         
-        if (m->debug) {  m->mothurOut("\n"); }
+        if (m->getDebug()) {  m->mothurOut("\n"); }
 		
 		return tax;	
 	}
@@ -244,7 +242,7 @@ string Bayesian::getTaxonomy(Sequence* seq) {
 	}
 }
 /**************************************************************************************************/
-string Bayesian::bootstrapResults(vector<int> kmers, int tax, int numToSelect) {
+string Bayesian::bootstrapResults(vector<int> kmers, int tax, int numToSelect, string& simpleTax) {
 	try {
 				
 		map<int, int> confidenceScores; 
@@ -263,18 +261,20 @@ string Bayesian::bootstrapResults(vector<int> kmers, int tax, int numToSelect) {
 		map<int, int>::iterator itBoot;
 		map<int, int>::iterator itBoot2;
 		map<int, int>::iterator itConvert;
-			
+        
+        int numKmers = kmers.size()-1;
+        Utils util;
 		for (int i = 0; i < iters; i++) {
-			if (m->control_pressed) { return "control"; }
+			if (m->getControl_pressed()) { return "control"; }
 			
-			vector<int> temp;
+            vector<int> temp;
 			for (int j = 0; j < numToSelect; j++) {
-				int index = m->getRandomIndex(kmers.size()-1);
-				
+				int index = util.getRandomIndex(numKmers);
+                
 				//add word to temp
 				temp.push_back(kmers[index]);
 			}
-			
+            
 			//get taxonomy
 			int newTax = getMostProbableTaxonomy(temp);
 			//int newTax = 1;
@@ -310,7 +310,7 @@ string Bayesian::bootstrapResults(vector<int> kmers, int tax, int numToSelect) {
 					confidence = itBoot2->second;
 				}
 				
-                if (m->debug) { m->mothurOut(seqTax.name + "(" + toString(((confidence/(float)iters) * 100)) + ");"); }
+                if (m->getDebug()) { m->mothurOut(seqTax.name + "(" + toString(((confidence/(float)iters) * 100)) + ");"); }
             
 				if (((confidence/(float)iters) * 100) >= confidenceThreshold) {
 					confidenceTax = seqTax.name + "(" + toString(((confidence/(float)iters) * 100)) + ");" + confidenceTax;
@@ -338,20 +338,12 @@ int Bayesian::getMostProbableTaxonomy(vector<int> queryKmer) {
 		
 		double maxProbability = -1000000.0;
 		//find taxonomy with highest probability that this sequence is from it
-		
-		
-//		cout << genusNodes.size() << endl;
-		
-		
-		for (int k = 0; k < genusNodes.size(); k++) {
+
+        for (int k = 0; k < genusNodes.size(); k++) {
 			//for each taxonomy calc its probability
 			
 			double prob = 0.0000;
-			for (int i = 0; i < queryKmer.size(); i++) {
-				prob += wordGenusProb[queryKmer[i]][k];
-			}
-			
-//			cout << phyloTree->get(genusNodes[k]).name << '\t' << prob << endl;
+			for (int i = 0; i < queryKmer.size(); i++) { prob += wordGenusProb[queryKmer[i]][k]; }
 
 			//is this the taxonomy with the greatest probability?
 			if (prob > maxProbability) { 
@@ -359,7 +351,6 @@ int Bayesian::getMostProbableTaxonomy(vector<int> queryKmer) {
 				maxProbability = prob;
 			}
 		}
-		
 			
 		return indexofGenus;
 	}
@@ -411,11 +402,11 @@ int Bayesian::generateWordPairDiffArr(){
 /**************************************************************************************************/
 void Bayesian::readProbFile(ifstream& in, ifstream& inNum, string inName, string inNumName) {
 	try{
-		
+		Utils util;
         //read version
-        string line = m->getline(in); m->gobble(in);
+        string line = util.getline(in); util.gobble(in);
         
-        in >> numKmers; m->gobble(in);
+        in >> numKmers; util.gobble(in);
         //initialze probabilities
         wordGenusProb.resize(numKmers);
         
@@ -428,14 +419,14 @@ void Bayesian::readProbFile(ifstream& in, ifstream& inNum, string inName, string
         for (int j = 0; j < numKmers; j++) {  diffPair tempDiffPair; WordPairDiffArr.push_back(tempDiffPair); }
         
         //read version
-        string line2 = m->getline(inNum); m->gobble(inNum);
+        string line2 = util.getline(inNum); util.gobble(inNum);
         float probTemp;
         
         while (inNum) {
             inNum >> zeroCountProb[count] >> num[count] >> probTemp;
             WordPairDiffArr[count].prob = probTemp;
             count++;
-            m->gobble(inNum);
+            util.gobble(inNum);
             
         }
         inNum.close();
@@ -454,7 +445,7 @@ void Bayesian::readProbFile(ifstream& in, ifstream& inNum, string inName, string
                 wordGenusProb[kmer][name] = prob;
             }
             
-            m->gobble(in);
+            util.gobble(in);
         }
         in.close();
         
@@ -466,33 +457,31 @@ void Bayesian::readProbFile(ifstream& in, ifstream& inNum, string inName, string
 	}
 }
 /**************************************************************************************************/
-bool Bayesian::checkReleaseDate(ifstream& file1, ifstream& file2, ifstream& file3, ifstream& file4) {
+bool Bayesian::checkReleaseDate(ifstream& file1, ifstream& file2, ifstream& file3, ifstream& file4, string version) {
 	try {
 		
 		bool good = true;
 		
 		vector<string> lines;
-		lines.push_back(m->getline(file1));  
-		lines.push_back(m->getline(file2)); 
-		lines.push_back(m->getline(file3)); 
-		lines.push_back(m->getline(file4)); 
+        Utils util;
+		lines.push_back(util.getline(file1));  
+		lines.push_back(util.getline(file2)); 
+		lines.push_back(util.getline(file3)); 
+		lines.push_back(util.getline(file4)); 
 
 		//before we added this check
 		if ((lines[0][0] != '#') || (lines[1][0] != '#') || (lines[2][0] != '#') || (lines[3][0] != '#')) {  good = false;  }
 		else {
 			//rip off #
 			for (int i = 0; i < lines.size(); i++) { lines[i] = lines[i].substr(1);  }
-			
-			//get mothurs current version
-			string version = m->getVersion();
-			
+
 			vector<string> versionVector;
-			m->splitAtChar(version, versionVector, '.');
+			util.splitAtChar(version, versionVector, '.');
 			
 			//check each files version
 			for (int i = 0; i < lines.size(); i++) { 
 				vector<string> linesVector;
-				m->splitAtChar(lines[i], linesVector, '.');
+				util.splitAtChar(lines[i], linesVector, '.');
 			
 				if (versionVector.size() != linesVector.size()) { good = false; break; }
 				else {
