@@ -14,6 +14,7 @@
 PhyloTree::PhyloTree(){
 	try {
 		m = MothurOut::getInstance();
+        current = CurrentFile::getInstance();
 		numNodes = 1;
 		numSeqs = 0;
 		tree.push_back(TaxNode("Root"));
@@ -34,32 +35,33 @@ PhyloTree::PhyloTree(){
 PhyloTree::PhyloTree(ifstream& in, string filename){
 	try {
 		m = MothurOut::getInstance();
+        current = CurrentFile::getInstance();
 		calcTotals = false;
 		numNodes = 0;
 		numSeqs = 0;
 		
         //read version
-        string line = m->getline(in); m->gobble(in);
+        string line = util.getline(in); util.gobble(in);
         
-        in >> numNodes; m->gobble(in);
+        in >> numNodes; util.gobble(in);
         
         tree.resize(numNodes);
         
-        in >> maxLevel; m->gobble(in);
+        in >> maxLevel; util.gobble(in);
         
         for (int i = 0; i < tree.size(); i++) {
-            tree[i].name = m->getline(in); m->gobble(in);
-            in >> tree[i].level >> tree[i].parent; m->gobble(in);
+            tree[i].name = util.getline(in); util.gobble(in);
+            in >> tree[i].level >> tree[i].parent; util.gobble(in);
         }
         
         //read genus nodes
         int numGenus = 0;
-        in >> numGenus; m->gobble(in);
+        in >> numGenus; util.gobble(in);
         
         int gnode, gsize;
         totals.clear();
         for (int i = 0; i < numGenus; i++) {
-            in >> gnode >> gsize; m->gobble(in);
+            in >> gnode >> gsize; util.gobble(in);
             
             uniqueTaxonomies.insert(gnode);
             totals.push_back(gsize);
@@ -76,6 +78,7 @@ PhyloTree::PhyloTree(ifstream& in, string filename){
 PhyloTree::PhyloTree(string tfile){
 	try {
 		m = MothurOut::getInstance();
+        current = CurrentFile::getInstance();
 		numNodes = 1;
 		numSeqs = 0;
 		tree.push_back(TaxNode("Root"));
@@ -86,7 +89,7 @@ PhyloTree::PhyloTree(string tfile){
 		string name, tax;
 		
         map<string, string> temp;
-        m->readTax(tfile, temp, true);
+        util.readTax(tfile, temp, true);
         
         for (map<string, string>::iterator itTemp = temp.begin(); itTemp != temp.end();) {
             addSeqToTree(itTemp->first, itTemp->second);
@@ -147,16 +150,16 @@ vector<string> PhyloTree::getSeqs(string seqTaxonomy){
 		
 		int currentNode = 0;
 
-        m->removeConfidences(seqTaxonomy);
+        util.removeConfidences(seqTaxonomy);
         
         string taxon;
         while(seqTaxonomy != ""){
 			
-			if (m->control_pressed) { return names; }
+			if (m->getControl_pressed()) { return names; }
 			
 			taxon = getNextTaxon(seqTaxonomy, "");
             
-            if (m->debug) { m->mothurOut(taxon +'\n'); }
+            if (m->getDebug()) { m->mothurOut(taxon +'\n'); }
 			
 			if (taxon == "") {  m->mothurOut(taxCopy + " has an error in the taxonomy.  This may be due to a ;;"); m->mothurOutEndLine(); break;  }
 			
@@ -166,7 +169,7 @@ vector<string> PhyloTree::getSeqs(string seqTaxonomy){
 				currentNode = childPointer->second;
 			}
 			else{											//otherwise, error this taxonomy is not in tree
-				m->mothurOut("[ERROR]: " + taxCopy + " is not in taxonomy tree, please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
+				m->mothurOut("[ERROR]: " + taxCopy + " is not in taxonomy tree, please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return names;
 			}
             
 			if (seqTaxonomy == "") {   names = tree[currentNode].accessions;	}
@@ -192,20 +195,20 @@ int PhyloTree::addSeqToTree(string seqName, string seqTaxonomy){
 		int level = 0;
 		
 		tree[0].accessions.push_back(seqName);
-		m->removeConfidences(seqTaxonomy);
+		util.removeConfidences(seqTaxonomy);
         string taxon;// = getNextTaxon(seqTaxonomy);
 	
 		while(seqTaxonomy != ""){
 			
 			level++;
 		
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			//somehow the parent is getting one too many accnos
 			//use print to reassign the taxa id
 			taxon = getNextTaxon(seqTaxonomy, seqName);
             
-            if (m->debug) { m->mothurOut(seqName +'\t' + taxon +'\n'); }
+            if (m->getDebug()) { m->mothurOut(seqName +'\t' + taxon +'\n'); }
 			
 			if (taxon == "") {  m->mothurOut(seqName + " has an error in the taxonomy.  This may be due to a ;;"); m->mothurOutEndLine(); if (currentNode != 0) {  uniqueTaxonomies.insert(currentNode); } break;  }
 			
@@ -255,7 +258,7 @@ vector<int> PhyloTree::getGenusNodes()	{
         for (map<string, int>::iterator itName = name2Taxonomy.begin(); itName != name2Taxonomy.end(); itName++) {
             map<int, int>::iterator itTemp = temp.find(itName->second);
             if (itTemp != temp.end()) { name2GenusNodeIndex[itName->first] = itTemp->second; }
-            else {  m->mothurOut("[ERROR]: trouble making name2GenusNodeIndex, aborting.\n"); m->control_pressed = true; }
+            else {  m->mothurOut("[ERROR]: trouble making name2GenusNodeIndex, aborting.\n"); m->setControl_pressed(true); }
         }
         
 		return genusIndex;
@@ -295,7 +298,7 @@ void PhyloTree::assignHeirarchyIDs(int index){
         
 		for(it=tree[index].children.begin();it!=tree[index].children.end();it++){
             
-            if (m->debug) { m->mothurOut(toString(index) +'\t' + tree[it->second].name +'\n'); }
+            if (m->getDebug()) { m->mothurOut(toString(index) +'\t' + tree[it->second].name +'\n'); }
                 
 			tree[it->second].heirarchyID = tree[index].heirarchyID + '.' + toString(counter);
 			counter++;
@@ -328,7 +331,7 @@ void PhyloTree::binUnclassified(string file){
 	try {
 	
 		ofstream out;
-		m->openOutputFile(file, out);
+		util.openOutputFile(file, out);
 		
 		map<string, int>::iterator itBin;
 		map<string, int>::iterator childPointer;
@@ -346,7 +349,7 @@ void PhyloTree::binUnclassified(string file){
 			}
 		}
 		
-        if (m->debug) { m->mothurOut("maxLevel = " + toString(maxLevel) +'\n'); }
+        if (m->getDebug()) { m->mothurOut("maxLevel = " + toString(maxLevel) +'\n'); }
         
 		int copyNodes = copy.size();
 	
@@ -354,18 +357,18 @@ void PhyloTree::binUnclassified(string file){
 		map<int, int>::iterator itLeaf;
 		for (itLeaf = leafNodes.begin(); itLeaf != leafNodes.end(); itLeaf++) {
 			
-			if (m->control_pressed) {  out.close(); break;  }
+			if (m->getControl_pressed()) {  out.close(); break;  }
 			
 			int level = copy[itLeaf->second].level;
 			int currentNode = itLeaf->second;
             
-            if (m->debug) { m->mothurOut(copy[currentNode].name +'\n'); }
+            if (m->getDebug()) { m->mothurOut(copy[currentNode].name +'\n'); }
 			
 			//this sequence is unclassified at some levels
 			while(level < maxLevel){
 		
 				level++;
-                if (m->debug) { m->mothurOut("level = " + toString(level) +'\n'); }
+                if (m->getDebug()) { m->mothurOut("level = " + toString(level) +'\n'); }
 			
 				string taxon = "unclassified";	
 				
@@ -387,7 +390,7 @@ void PhyloTree::binUnclassified(string file){
 			}
 		}
 		
-		if (!m->control_pressed) {
+		if (!m->getControl_pressed()) {
 			//print copy tree
 			print(out, copy);
 		}
@@ -450,7 +453,7 @@ void PhyloTree::print(ofstream& out, vector<TaxNode>& copy){
 	try {
 		
 		//output mothur version
-		out << "#" << m->getVersion() << endl;
+		out << "#" << current->getVersion() << endl;
 		
 		out << copy.size() << endl;
 		
@@ -479,10 +482,10 @@ void PhyloTree::print(ofstream& out, vector<TaxNode>& copy){
 void PhyloTree::printTreeNodes(string treefilename) {
 	try {
         ofstream outTree;
-        m->openOutputFile(treefilename, outTree);
+        util.openOutputFile(treefilename, outTree);
         
         //output mothur version
-        outTree << "#" << m->getVersion() << endl;
+        outTree << "#" << current->getVersion() << endl;
         
         //print treenodes
         outTree << tree.size() << endl;
@@ -566,7 +569,7 @@ bool PhyloTree::ErrorCheck(vector<string> templateFileNames){
 		map<string, int>::iterator itFind;
 		map<string, int> taxonomyFileNames = name2Taxonomy;
 		
-        if (m->debug) { m->mothurOut("[DEBUG]: in error check. Numseqs in template = " + toString(templateFileNames.size()) + ". Numseqs in taxonomy = " + toString(taxonomyFileNames.size()) + ".\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: in error check. Numseqs in template = " + toString(templateFileNames.size()) + ". Numseqs in taxonomy = " + toString(taxonomyFileNames.size()) + ".\n"); }
         
 		for (int i = 0; i < templateFileNames.size(); i++) {
 			itFind = taxonomyFileNames.find(templateFileNames[i]);
