@@ -9,6 +9,7 @@
 
 #include "clusterclassic.h"
 #include "progress.hpp"
+#include "utils.hpp"
 
 /***********************************************************************/
 ClusterClassic::ClusterClassic(float c, string f, bool s) : method(f), smallDist(1e6), nseqs(0), sim(s) {
@@ -38,12 +39,12 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 		vector<string> matrixNames;
 		
 		ifstream fileHandle;
-		m->openInputFile(filename, fileHandle);
+        Utils util; util.openInputFile(filename, fileHandle);
 		
         string numTest;
 		fileHandle >> numTest >> name;
         
-        if (!m->isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting."); m->mothurOutEndLine(); exit(1); }
+        if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting."); m->mothurOutEndLine(); exit(1); }
         else { convert(numTest, nseqs); }
 
 
@@ -93,7 +94,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 				int        index = 0;
 
 				for(int i=1;i<nseqs;i++){
-						if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+						if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
 						
 						fileHandle >> name;
 						matrixNames.push_back(name);
@@ -105,7 +106,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 						
 								for(int j=0;j<i;j++){
 								
-										if (m->control_pressed) { delete reading; fileHandle.close(); return 0;  }
+										if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
 										
 										fileHandle >> distance;
 							
@@ -129,7 +130,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 								for(int j=0;j<i;j++){
 										fileHandle >> distance;
 										
-										if (m->control_pressed) { delete reading; fileHandle.close(); return 0;  }
+										if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
 				
 										if (distance == -1) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -167,7 +168,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 								for(int j=0;j<nseqs;j++){
 										fileHandle >> distance;
 										
-										if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+										if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
 										
 										if (distance == -1) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -190,7 +191,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 								for(int j=0;j<nseqs;j++){
 										fileHandle >> distance;
 										
-										if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+										if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
 										
 									   if (distance == -1) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.                                                        
@@ -214,7 +215,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 				}
 		}
 		
-		if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
 		
 		reading->finish();
 		delete reading;
@@ -241,12 +242,12 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
 		vector<string> matrixNames;
 		
 		ifstream fileHandle;
-		m->openInputFile(filename, fileHandle);
+		Utils util; util.openInputFile(filename, fileHandle);
 		
         string numTest;
 		fileHandle >> numTest >> name;
         
-        if (!m->isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting."); m->mothurOutEndLine(); exit(1); }
+        if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting."); m->mothurOutEndLine(); exit(1); }
         else { convert(numTest, nseqs); }
         
         
@@ -293,7 +294,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
             int        index = 0;
             
             for(int i=1;i<nseqs;i++){
-                if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+                if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
                 
                 fileHandle >> name;
                 matrixNames.push_back(name);
@@ -305,7 +306,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     
                     for(int j=0;j<i;j++){
                         
-                        if (m->control_pressed) { delete reading; fileHandle.close(); return 0;  }
+                        if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
                         
                         fileHandle >> distance;
                         
@@ -327,7 +328,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<i;j++){
                         fileHandle >> distance;
                         
-                        if (m->control_pressed) { delete reading; fileHandle.close(); return 0;  }
+                        if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
                         
                         if (distance == -1) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -361,7 +362,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<nseqs;j++){
                         fileHandle >> distance;
                         
-                        if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+                        if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
                         
                         if (distance == -1) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -381,7 +382,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<nseqs;j++){
                         fileHandle >> distance;
                         
-                        if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+                        if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
                         
                         if (distance == -1) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.                                                        
@@ -402,7 +403,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
             }
 		}
 		
-		if (m->control_pressed) {  fileHandle.close();  delete reading; return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
 		
 		reading->finish();
 		delete reading;
@@ -412,10 +413,10 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
         rabund->setLabel(list->getLabel());  
         
         for(int i = 0; i < list->getNumBins(); i++) { 
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             vector<string> binNames;
             string bin = list->get(i);
-            m->splitAtComma(bin, binNames);
+            util.splitAtComma(bin, binNames);
             int total = 0;
             for (int j = 0; j < binNames.size(); j++) { total += countTable->getNumSeqs(binNames[j]);  }
             rabund->push_back(total);   
@@ -456,12 +457,12 @@ double ClusterClassic::getSmallCell() {
 				}
 			}
 		}
-		
+		Utils util;
 		if (mins.size() > 0) {
 			int zrand = 0;
 			if (mins.size() > 1) {
 				//pick random number between 0 and mins.size()
-				zrand = m->getRandomIndex(mins.size()-1);
+				zrand = util.getRandomIndex(mins.size()-1);
 			}
 			
 			smallRow = mins[zrand].row;
@@ -591,6 +592,7 @@ void ClusterClassic::update(double& cutOFF){
 void ClusterClassic::setMapWanted(bool f)  {  
 	try {
 		mapWanted = f;
+        Utils util;
 		
 		//initialize map
 		for (int i = 0; i < list->getNumBins(); i++) {
@@ -598,7 +600,7 @@ void ClusterClassic::setMapWanted(bool f)  {
 			//parse bin 
 			string names = list->get(i);
 			vector<string> binnames;
-            m->splitAtComma(names, binnames);
+            util.splitAtComma(names, binnames);
             for (int j = 0; j < binnames.size(); j++) {
 				//save name and bin number
 				seq2Bin[binnames[j]] = i;
@@ -617,7 +619,7 @@ try {
 		//update location of seqs in smallRow since they move to smallCol now
         string names = list->get(smallRow);
         vector<string> binnames;
-        m->splitAtComma(names, binnames);
+        Utils util; util.splitAtComma(names, binnames);
         for (int j = 0; j < binnames.size(); j++) {
             //save name and bin number
             seq2Bin[binnames[j]] = smallCol;
