@@ -153,6 +153,7 @@
 #include "renamefilecommand.h"
 #include "chimeravsearchcommand.h"
 #include "mergecountcommand.hpp"
+#include "clusterfitcommand.hpp"
 
 //needed for testing project
 //CommandFactory* CommandFactory::_uniqueInstance;
@@ -172,13 +173,13 @@ CommandFactory* CommandFactory::getInstance() {
 CommandFactory::CommandFactory(){
 	string s = "";
 	m = MothurOut::getInstance();
+    current = CurrentFile::getInstance();
 
 	command = new NoCommand(s);
 	shellcommand = new NoCommand(s);
 	pipecommand = new NoCommand(s);
 
-	outputDir = ""; inputDir = "";
-	logFileName = "";
+	current->setOutputDir(""); current->setInputDir("");
 	append = false;
 
 	//initialize list of valid commands
@@ -329,6 +330,7 @@ CommandFactory::CommandFactory(){
     commands["set.seed"]            = "set.seed";
     commands["rename.file"]         = "rename.file";
     commands["merge.count"]         = "merge.count";
+    commands["cluster.fit"]         = "cluster.fit";
 
 
 }
@@ -345,7 +347,7 @@ CommandFactory::~CommandFactory(){
 /***********************************************************/
 int CommandFactory::checkForRedirects(string optionString) {
     try {
-
+        Utils util;
         int pos = optionString.find("outputdir");
         if (pos != string::npos) { //user has set outputdir in command option string
             string outputOption = "";
@@ -356,8 +358,8 @@ int CommandFactory::checkForRedirects(string optionString) {
                 if (foundEquals)       {   outputOption += optionString[i]; }
             }
             if (outputOption[0] == '=') { outputOption = outputOption.substr(1); }
-            if(m->mkDir(outputOption)){
-                setOutputDirectory(outputOption); 
+            if(util.mkDir(outputOption)){
+                current->setOutputDir(outputOption);
                 m->mothurOut("Setting output directory to: " + outputOption); m->mothurOutEndLine();
             }
         }
@@ -372,8 +374,8 @@ int CommandFactory::checkForRedirects(string optionString) {
                 if (foundEquals)       {   intputOption += optionString[i]; }
             }
             if (intputOption[0] == '=') { intputOption = intputOption.substr(1); }
-            if(m->dirCheck(intputOption)){
-                setInputDirectory(intputOption); 
+            if(util.dirCheck(intputOption)){
+                current->setInputDir(intputOption); 
                 m->mothurOut("Setting input directory to: " + intputOption); m->mothurOutEndLine();
             }
         }
@@ -393,16 +395,17 @@ int CommandFactory::checkForRedirects(string optionString) {
                 random = time(NULL);
                 seed = true;
             }else {
-                if (m->isNumeric1(intputOption)) { m->mothurConvert(intputOption, random); seed=true; }
-                else { m->mothurOut("[ERROR]: Seed must be an integer."); m->mothurOutEndLine(); seed = false;}
+                if (util.isNumeric1(intputOption)) { util.mothurConvert(intputOption, random); seed=true; }
+                else { m->mothurOut("[ERROR]: Seed must be an integer.\n"); seed = false;}
             }
 
-            if (seed)  {
-                m->setRandomSeed(random);
-                m->mothurOut("Setting random seed to " + toString(random) + ".\n\n");
-            }
+            if (seed)  { m->mothurOut("Setting random seed to " + toString(random) + ".\n\n"); m->setRandomSeed(random); }
         }
-
+        
+        pos = optionString.find("mothurcalling=true");
+        if (pos != string::npos) { //user has set seed in command option string
+            current->setMothurCalling(true);
+        }else { current->setMothurCalling(false);  }
 
         return 0;
 	}
@@ -419,21 +422,23 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 	try {
 
 		delete command;   //delete the old command
-
-        checkForRedirects(optionString);
-
-		//user has opted to redirect output from dir where input files are located to some other place
-		if (outputDir != "") {
-			if (optionString != "") { optionString += ", outputdir=" + outputDir; }
-			else { optionString += "outputdir=" + outputDir; }
-		}
-
-		//user has opted to redirect input from dir where mothur.exe is located to some other place
-		if (inputDir != "") {
-			if (optionString != "") { optionString += ", inputdir=" + inputDir; }
-			else { optionString += "inputdir=" + inputDir; }
-		}
-
+        
+        if (commandName != "help") {
+            checkForRedirects(optionString);
+            
+            //user has opted to redirect output from dir where input files are located to some other place
+            if (current->getOutputDir() != "") {
+                if (optionString != "") { optionString += ", outputdir=" + current->getOutputDir(); }
+                else { optionString += "outputdir=" + current->getOutputDir(); }
+            }
+            
+            //user has opted to redirect input from dir where mothur.exe is located to some other place
+            if (current->getInputDir() != "") {
+                if (optionString != "") { optionString += ", inputdir=" + current->getInputDir(); }
+                else { optionString += "inputdir=" + current->getInputDir(); }
+            }
+        }
+        
 		if(commandName == "cluster")                    {	command = new ClusterCommand(optionString);					}
 		else if(commandName == "unique.seqs")			{	command = new DeconvoluteCommand(optionString);				}
 		else if(commandName == "parsimony")				{	command = new ParsimonyCommand(optionString);				}
@@ -577,6 +582,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
         else if(commandName == "make.file")             {	command = new MakeFileCommand(optionString);                }
         else if(commandName == "biom.info")             {	command = new BiomInfoCommand(optionString);                }
         else if(commandName == "rename.file")           {	command = new RenameFileCommand(optionString);              }
+        else if(commandName == "cluster.fit")           {	command = new ClusterFitCommand(optionString);              }
 		else											{	command = new NoCommand(optionString);						}
 
 		return command;
@@ -593,21 +599,22 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 Command* CommandFactory::getCommand(string commandName, string optionString, string mode){
 	try {
 		delete pipecommand;   //delete the old command
-
-        checkForRedirects(optionString);
-
-		//user has opted to redirect output from dir where input files are located to some other place
-		if (outputDir != "") {
-			if (optionString != "") { optionString += ", outputdir=" + outputDir; }
-			else { optionString += "outputdir=" + outputDir; }
-		}
-
-		//user has opted to redirect input from dir where mothur.exe is located to some other place
-		if (inputDir != "") {
-			if (optionString != "") { optionString += ", inputdir=" + inputDir; }
-			else { optionString += "inputdir=" + inputDir; }
-		}
-
+        
+        if (commandName != "help") {
+            checkForRedirects(optionString);
+            
+            //user has opted to redirect output from dir where input files are located to some other place
+            if (current->getOutputDir() != "") {
+                if (optionString != "") { optionString += ", outputdir=" + current->getOutputDir(); }
+                else { optionString += "outputdir=" + current->getOutputDir(); }
+            }
+            
+            //user has opted to redirect input from dir where mothur.exe is located to some other place
+            if (current->getInputDir() != "") {
+                if (optionString != "") { optionString += ", inputdir=" + current->getInputDir(); }
+                else { optionString += "inputdir=" + current->getInputDir(); }
+            }
+        }
 		if(commandName == "cluster")				{	pipecommand = new ClusterCommand(optionString);					}
 		else if(commandName == "unique.seqs")			{	pipecommand = new DeconvoluteCommand(optionString);				}
 		else if(commandName == "parsimony")				{	pipecommand = new ParsimonyCommand(optionString);				}
@@ -751,6 +758,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
         else if(commandName == "make.file")             {	pipecommand = new MakeFileCommand(optionString);                }
         else if(commandName == "biom.info")             {	pipecommand = new BiomInfoCommand(optionString);                }
         else if(commandName == "rename.file")           {	pipecommand = new RenameFileCommand(optionString);              }
+        else if(commandName == "cluster.fit")           {	pipecommand = new ClusterFitCommand(optionString);              }
 		else											{	pipecommand = new NoCommand(optionString);						}
 
 		return pipecommand;
@@ -910,7 +918,8 @@ Command* CommandFactory::getCommand(string commandName){
         else if(commandName == "set.seed")              {	shellcommand = new SetSeedCommand();                }
         else if(commandName == "make.file")             {	shellcommand = new MakeFileCommand();               }
         else if(commandName == "biom.info")             {	shellcommand = new BiomInfoCommand();               }
-        else if(commandName == "rename.file")           {	pipecommand = new RenameFileCommand();              }
+        else if(commandName == "rename.file")           {	shellcommand = new RenameFileCommand();             }
+        else if(commandName == "cluster.fit")           {	shellcommand = new ClusterFitCommand();             }
 		else											{	shellcommand = new NoCommand();						}
 
 		return shellcommand;
@@ -920,23 +929,7 @@ Command* CommandFactory::getCommand(string commandName){
 		exit(1);
 	}
 }
-/***********************************************************
-//This function is used to interrupt a command
-Command* CommandFactory::getCommand(){
-	try {
-		delete command;   //delete the old command
-
-		string s = "";
-	    command = new NoCommand(s);
-
-		return command;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "CommandFactory", "getCommand");
-		exit(1);
-	}
-}
-***********************************************************************/
+/***********************************************************************/
 bool CommandFactory::isValidCommand(string command) {
 	try {
 
@@ -961,14 +954,9 @@ bool CommandFactory::isValidCommand(string command) {
 /***********************************************************************/
 bool CommandFactory::isValidCommand(string command, string noError) {
 	try {
-
 		//is the command in the map
-		if ((commands.find(command)) != (commands.end())) {
-			return true;
-		}else{
-			return false;
-		}
-
+		if ((commands.find(command)) != (commands.end())) { return true;  }
+		else{ return false; }
 	}
 	catch(exception& e) {
 		m->errorOut(e, "CommandFactory", "isValidCommand");
@@ -983,9 +971,7 @@ void CommandFactory::printCommands(ostream& out) {
         it++;
         out << it->first;
         it++;
-		for (; it != commands.end(); it++) {
-			out << ", " << it->first;
-		}
+		for (; it != commands.end(); it++) { out << ", " << it->first; }
 		out <<  "." << endl;
 	}
 	catch(exception& e) {
@@ -1027,5 +1013,4 @@ void CommandFactory::printCommandsCategories(ostream& out) {
 		exit(1);
 	}
 }
-
 /***********************************************************************/
