@@ -43,7 +43,6 @@ string AnosimCommand::getHelpString(){
 		helpString += "The design file looks like the group file.  It is a 2 column tab delimited file, where the first column is the sample name and the second column is the group the sample belongs to.\n";
 		helpString += "The iters parameter allows you to set number of randomization for the P value.  The default is 1000. \n";
 		helpString += "The anosim command should be in the following format: anosim(phylip=file.dist, design=file.design).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. iters), '=' and parameters (i.e. 1000).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -57,7 +56,7 @@ string AnosimCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "anosim") {  pattern = "[filename],anosim"; } //makes file like: amazon.align
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -108,17 +107,17 @@ AnosimCommand::AnosimCommand(string option) {
 			outputTypes["anosim"] = tempOutNames;
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("design");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["design"] = inputDir + it->second;		}
 				}
@@ -126,39 +125,39 @@ AnosimCommand::AnosimCommand(string option) {
 				it = parameters.find("phylip");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["phylip"] = inputDir + it->second;		}
 				}
 			}
 			
-			phylipFileName = validParameter.validFile(parameters, "phylip", true);
+			phylipFileName = validParameter.validFile(parameters, "phylip");
 			if (phylipFileName == "not open") { phylipFileName = ""; abort = true; }
 			else if (phylipFileName == "not found") { 
 				//if there is a current phylip file, use it
-				phylipFileName = m->getPhylipFile(); 
+				phylipFileName = current->getPhylipFile(); 
 				if (phylipFileName != "") { m->mothurOut("Using " + phylipFileName + " as input file for the phylip parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current phylip file and the phylip parameter is required."); m->mothurOutEndLine(); abort = true; }
 				
-			}else { m->setPhylipFile(phylipFileName); }	
+			}else { current->setPhylipFile(phylipFileName); }	
 			
 			//check for required parameters
-			designFileName = validParameter.validFile(parameters, "design", true);
+			designFileName = validParameter.validFile(parameters, "design");
 			if (designFileName == "not open") { designFileName = ""; abort = true; }
 			else if (designFileName == "not found") {
 				//if there is a current design file, use it
-				designFileName = m->getDesignFile(); 
+				designFileName = current->getDesignFile(); 
 				if (designFileName != "") { m->mothurOut("Using " + designFileName + " as input file for the design parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current design file and the design parameter is required."); m->mothurOutEndLine(); abort = true; }								
-			}else { m->setDesignFile(designFileName); }	
+			}else { current->setDesignFile(designFileName); }	
 			
-			string temp = validParameter.validFile(parameters, "iters", false);
+			string temp = validParameter.valid(parameters, "iters");
 			if (temp == "not found") { temp = "1000"; }
-			m->mothurConvert(temp, iters); 
+			util.mothurConvert(temp, iters); 
 			
-			temp = validParameter.validFile(parameters, "alpha", false);
+			temp = validParameter.valid(parameters, "alpha");
 			if (temp == "not found") { temp = "0.05"; }
-			m->mothurConvert(temp, experimentwiseAlpha); 
+			util.mothurConvert(temp, experimentwiseAlpha); 
 		}
 		
 	}
@@ -171,12 +170,12 @@ AnosimCommand::AnosimCommand(string option) {
 int AnosimCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		//read design file
 		designMap = new DesignMap(designFileName);
 		
-		if (outputDir == "") { outputDir = m->hasPath(phylipFileName); }
+		if (outputDir == "") { outputDir = util.hasPath(phylipFileName); }
 		
 		//read in distance matrix and square it
 		ReadPhylipVector readMatrix(phylipFileName);
@@ -194,19 +193,19 @@ int AnosimCommand::execute(){
 			string group = designMap->get(sampleNames[i]);
 			
 			if (group == "not found") {
-				m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct."); m->mothurOutEndLine(); m->control_pressed = true;
+				m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
 			}else { origGroupSampleMap[group].push_back(i); }
 		}
 		int numGroups = origGroupSampleMap.size();
 		
-		if (m->control_pressed) { delete designMap; return 0; }
+		if (m->getControl_pressed()) { delete designMap; return 0; }
 		
 		//create a new filename
 		ofstream ANOSIMFile;
-        map<string, string> variables; variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(phylipFileName));
+        map<string, string> variables; variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipFileName));
 		string ANOSIMFileName = getOutputFileName("anosim", variables);	
         
-		m->openOutputFile(ANOSIMFileName, ANOSIMFile);
+		util.openOutputFile(ANOSIMFileName, ANOSIMFile);
 		outputNames.push_back(ANOSIMFileName); outputTypes["anosim"].push_back(ANOSIMFileName);
 		m->mothurOut("\ncomparison\tR-value\tP-value\n");
 		ANOSIMFile << "comparison\tR-value\tP-value\n";
@@ -263,13 +262,10 @@ int AnosimCommand::execute(){
 		m->mothurOut("If you have borderline P-values, you should try increasing the number of iterations\n");
 		ANOSIMFile.close();
 		
-			
 		delete designMap;
 				
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 	}
@@ -283,7 +279,6 @@ int AnosimCommand::execute(){
 double AnosimCommand::runANOSIM(ofstream& ANOSIMFile, vector<vector<double> > dMatrix, map<string, vector<int> > groupSampleMap, double alpha) {
 	try {
 
-		
 		vector<vector<double> > rankMatrix = convertToRanks(dMatrix);
 		double RValue = calcR(rankMatrix, groupSampleMap);
 		
@@ -300,17 +295,13 @@ double AnosimCommand::runANOSIM(ofstream& ANOSIMFile, vector<vector<double> > dM
 		else						{	pString = toString(pValue);					}
 		
 		
-		map<string, vector<int> >::iterator it=groupSampleMap.begin();
-		m->mothurOut(it->first);
-		ANOSIMFile << it->first;
-		it++;
-		for(it;it!=groupSampleMap.end();it++){
-			m->mothurOut('-' + it->first);
-			ANOSIMFile << '-' << it->first;
-		
-		}
-		m->mothurOut('\t' + toString(RValue) + '\t' + pString);
-		ANOSIMFile << '\t' << RValue << '\t' << pString;
+		//map<string, vector<int> >::iterator it=groupSampleMap.begin();
+        vector<string> sampleNames;
+        for(map<string, vector<int> >::iterator it = groupSampleMap.begin();it!=groupSampleMap.end();it++){ sampleNames.push_back(it->first); }
+        string output = util.getStringFromVector(sampleNames, "-");
+        
+		m->mothurOut(output + '\t' + toString(RValue) + '\t' + pString);
+		ANOSIMFile << output << '\t' << RValue << '\t' << pString;
 
 		if(pValue < alpha){
 			ANOSIMFile << "*";
@@ -373,11 +364,9 @@ double AnosimCommand::calcR(vector<vector<double> > rankMatrix, map<string, vect
 						numBetweenComps++;
 					}					
 				}
-				
 			}
 		}
 		
-		
 		between /= (float) numBetweenComps;
 		
 		double Rvalue = (between - within)/(numSamples * (numSamples-1) / 4.0);
@@ -406,7 +395,6 @@ vector<vector<double> > AnosimCommand::convertToRanks(vector<vector<double> > di
 			}
 		}
 		
-		
 		//sort distances
 		sort(cells.begin(), cells.end(), compareSequenceDistance); 	
 
@@ -460,7 +448,7 @@ map<string, vector<int> > AnosimCommand::getRandomizedGroups(map<string, vector<
 			sampleIndices.insert(sampleIndices.end(), indices.begin(), indices.end());
 		}
 		
-		m->mothurRandomShuffle(sampleIndices);
+		util.mothurRandomShuffle(sampleIndices);
 		
 		int index = 0;
 		map<string, vector<int> > randomizedGroups = origMapping;
