@@ -43,7 +43,7 @@ string BinSeqCommand::getHelpString(){
 		helpString += "The default value for label is all lines in your inputfile.\n";
 		helpString += "The bin.seqs command outputs a .fasta file for each distance you specify appending the OTU number to each name.\n";
 		helpString += "If you provide a groupfile, then it also appends the sequences group to the name.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. fasta), '=' and parameters (i.e.yourFastaFile).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -57,7 +57,7 @@ string BinSeqCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "fasta") {  pattern = "[filename],[distance],fasta"; } //makes file like: amazon.0.03.fasta
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -109,14 +109,14 @@ BinSeqCommand::BinSeqCommand(string option) {
 			outputTypes["fasta"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("fasta");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
 				}
@@ -124,7 +124,7 @@ BinSeqCommand::BinSeqCommand(string option) {
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -132,7 +132,7 @@ BinSeqCommand::BinSeqCommand(string option) {
 				it = parameters.find("name");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["name"] = inputDir + it->second;		}
 				}
@@ -140,7 +140,7 @@ BinSeqCommand::BinSeqCommand(string option) {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -148,7 +148,7 @@ BinSeqCommand::BinSeqCommand(string option) {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
@@ -156,55 +156,55 @@ BinSeqCommand::BinSeqCommand(string option) {
 
 			
 			//check for required parameters
-			fastafile = validParameter.validFile(parameters, "fasta", true);
+			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not found") { 				//if there is a current phylip file, use it
-				fastafile = m->getFastaFile(); 
+				fastafile = current->getFastaFile(); 
 				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current fasta file and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
 			}
 			else if (fastafile == "not open") { abort = true; }	
-			else { m->setFastaFile(fastafile); }
+			else { current->setFastaFile(fastafile); }
 			
-			listfile = validParameter.validFile(parameters, "list", true);
+			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not found") { 			
-				listfile = m->getListFile(); 
+				listfile = current->getListFile(); 
 				if (listfile != "") { m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current list file and the list parameter is required."); m->mothurOutEndLine(); abort = true; }
 			}
 			else if (listfile == "not open") { listfile = ""; abort = true; }	
-			else { m->setListFile(listfile); }
+			else { current->setListFile(listfile); }
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){
 				outputDir = "";	
-				outputDir += m->hasPath(listfile); //if user entered a file with a path then preserve it	
+				outputDir += util.hasPath(listfile); //if user entered a file with a path then preserve it	
 			}
 			
 		
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
 			
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
-			namesfile = validParameter.validFile(parameters, "name", true);
+			namesfile = validParameter.validFile(parameters, "name");
 			if (namesfile == "not open") { namesfile = ""; abort = true; }	
 			else if (namesfile == "not found") { namesfile = ""; }
-			else {  m->setNameFile(namesfile); }
+			else {  current->setNameFile(namesfile); }
 
-			groupfile = validParameter.validFile(parameters, "group", true);
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not open") { abort = true; }
 			else if (groupfile == "not found") { groupfile = ""; }
-			else { m->setGroupFile(groupfile); }
+			else { current->setGroupFile(groupfile); }
             
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
 			if (countfile == "not open") { countfile = ""; abort = true; }
 			else if (countfile == "not found") { countfile = "";  }	
-			else { m->setCountTableFile(countfile); }
+			else { current->setCountFile(countfile); }
             
             if ((namesfile != "") && (countfile != "")) {
                 m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
@@ -217,7 +217,7 @@ BinSeqCommand::BinSeqCommand(string option) {
             if (countfile == "") {
                 if (namesfile == ""){
                     vector<string> files; files.push_back(fastafile); 
-                    parser.getNameFile(files);
+                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
                 }
             }
 			
@@ -235,28 +235,23 @@ BinSeqCommand::~BinSeqCommand(){}
 
 int BinSeqCommand::execute(){
 	try {
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 	
 		int error = 0;
 		
-		fasta = new FastaMap();
-		if (groupfile != "") {
-			groupMap = new GroupMap(groupfile);
-			groupMap->readMap();
-		}
-		
-		//read fastafile
-		fasta->readFastaFile(fastafile);
-		
+		FastaMap fasta; fasta.readFastaFile(fastafile);
+        GroupMap groupMap;
+		if (groupfile != "") { groupMap.readMap(groupfile); }
+				
 		//if user gave a namesfile then use it
-		if (namesfile != "") {  readNamesFile();  }
+		if (namesfile != "") {  readNamesFile(fasta);  }
         if (countfile != "") {  ct.readTable(countfile, true, false);  }
 		
-		input = new InputData(listfile, "list");
-		list = input->getListVector();
+		InputData input(listfile, "list", nullVector);
+		ListVector* list = input.getListVector();
 		string lastLabel = list->getLabel();
 		
-		if (m->control_pressed) {  delete input;  delete fasta; if (groupfile != "") {  delete groupMap;   } return 0; }
+		if (m->getControl_pressed()) {  return 0; }
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		set<string> processedLabels;
@@ -265,25 +260,25 @@ int BinSeqCommand::execute(){
 				
 		while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if(m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);		} delete input;  delete fasta; if (groupfile != "") {  delete groupMap;   } return 0; }	
+			if(m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}   return 0; }
 			
 			if(allLines == 1 || labels.count(list->getLabel()) == 1){
 				
-				error = process(list);	
-				if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);		} delete input;  delete fasta; if (groupfile != "") {  delete groupMap;   } return 0; }	
+				error = process(list, fasta, groupMap);
+				if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }
 							
 				processedLabels.insert(list->getLabel());
 				userLabels.erase(list->getLabel());
 			}
 			
-			if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+			if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 				string saveLabel = list->getLabel();
 				
 				delete list;
-				list = input->getListVector(lastLabel);
+				list = input.getListVector(lastLabel);
 				
-				error = process(list);	
-				if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);		} delete input;  delete fasta; if (groupfile != "") {  delete groupMap;   } return 0; }
+				error = process(list, fasta, groupMap);
+				if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }
 													
 				processedLabels.insert(list->getLabel());
 				userLabels.erase(list->getLabel());
@@ -295,10 +290,10 @@ int BinSeqCommand::execute(){
 			lastLabel = list->getLabel();			
 			
 			delete list;
-			list = input->getListVector();
+			list = input.getListVector();
 		}
 		
-		if(m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);		} delete input;  delete fasta; if (groupfile != "") {  delete groupMap;   } return 0; }	
+		if(m->getControl_pressed())  { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }
 
 		//output error messages about any remaining user labels
 		set<string>::iterator it;
@@ -314,33 +309,27 @@ int BinSeqCommand::execute(){
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
+		if (needToRun )  {
 			if (list != NULL) {		delete list;	}
-			list = input->getListVector(lastLabel);
+			list = input.getListVector(lastLabel);
 				
-			error = process(list);	
-			if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);		} delete input;  delete fasta; if (groupfile != "") {  delete groupMap;   } return 0; }
+			error = process(list, fasta, groupMap);	
+			if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}   return 0; }
 			
 			delete list;  
 		}
 		
-		delete input;  
-		delete fasta; 
-		if (groupfile != "") {  delete groupMap;   } 
-		
-		if(m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);		}  return 0; }	
+		if(m->getControl_pressed())  { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }	
         
         //set align file as new current fastafile
 		string currentFasta = "";
 		itTypes = outputTypes.find("fasta");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { currentFasta = (itTypes->second)[0]; m->setFastaFile(currentFasta); }
+			if ((itTypes->second).size() != 0) { currentFasta = (itTypes->second)[0]; current->setFastaFile(currentFasta); }
 		}
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 
 		
 		return 0;
@@ -352,32 +341,25 @@ int BinSeqCommand::execute(){
 }
 
 //**********************************************************************************************************************
-void BinSeqCommand::readNamesFile() {
+void BinSeqCommand::readNamesFile(FastaMap& fasta) {
 	try {
-		vector<string> dupNames;
-		m->openInputFile(namesfile, inNames);
+		ifstream inNames;
+		util.openInputFile(namesfile, inNames);
 		
 		string name, names, sequence;
 	
 		while(inNames){
-			inNames >> name;			//read from first column  A
-			inNames >> names;		//read from second column  A,B,C,D
-			
-			dupNames.clear();
-			
-			//parse names into vector
-			m->splitAtComma(names, dupNames);
+			inNames >> name;	util.gobble(inNames);		//read from first column  A
+			inNames >> names;	util.gobble(inNames);	//read from second column  A,B,C,D
+            
+            //parse names into vector
+			vector<string> dupNames; util.splitAtComma(names, dupNames);
 			
 			//store names in fasta map
-			sequence = fasta->getSequence(name);
-			for (int i = 0; i < dupNames.size(); i++) {
-				fasta->push_back(dupNames[i], sequence);
-			}
-		
-			m->gobble(inNames);
+			sequence = fasta.getSequence(name);
+			for (int i = 0; i < dupNames.size(); i++) { fasta.push_back(dupNames[i], sequence); }
 		}
 		inNames.close();
-
 	}
 	catch(exception& e) {
 		m->errorOut(e, "BinSeqCommand", "readNamesFile");
@@ -386,14 +368,14 @@ void BinSeqCommand::readNamesFile() {
 }
 //**********************************************************************************************************************
 //return 1 if error, 0 otherwise
-int BinSeqCommand::process(ListVector* list) {
+int BinSeqCommand::process(ListVector* list, FastaMap& fasta, GroupMap& groupMap) {
 	try {
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(listfile));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile));
         variables["[distance]"] = list->getLabel();
         string outputFileName = getOutputFileName("fasta", variables);
         
-        m->openOutputFile(outputFileName, out);
+        ofstream out; util.openOutputFile(outputFileName, out);
         outputNames.push_back(outputFileName);  outputTypes["fasta"].push_back(outputFileName);
         
         m->mothurOut(list->getLabel()); m->mothurOutEndLine();
@@ -402,16 +384,16 @@ int BinSeqCommand::process(ListVector* list) {
         vector<string> binLabels = list->getLabels();
         for (int i = 0; i < list->size(); i++) {
             
-            if (m->control_pressed) {  return 1; }
+            if (m->getControl_pressed()) {  return 1; }
             
             string binnames = list->get(i);
             vector<string> names;
-            m->splitAtComma(binnames, names);
+            util.splitAtComma(binnames, names);
             for (int j = 0; j < names.size(); j++) {
                 string name = names[j];
                 
                 //do work for that name
-                string sequence = fasta->getSequence(name);
+                string sequence = fasta.getSequence(name);
                 
                 if (countfile != "") {
                     if (sequence != "not found") {
@@ -432,7 +414,7 @@ int BinSeqCommand::process(ListVector* list) {
                             out << sequence << endl;
                         }
                         
-                    }else { m->mothurOut(name + " is missing from your fasta. Does your list file contain all sequence names or just the uniques?"); m->mothurOutEndLine(); return 1; }
+                    }else { m->mothurOut(name + " is missing from your fasta. Does your list file contain all sequence names or just the uniques?\n"); return 1; }
                 }else {
                     if (sequence != "not found") {
                         //if you don't have groups
@@ -441,9 +423,9 @@ int BinSeqCommand::process(ListVector* list) {
                             out << ">" << name << endl;
                             out << sequence << endl;
                         }else {//if you do have groups
-                            string group = groupMap->getGroup(name);
+                            string group = groupMap.getGroup(name);
                             if (group == "not found") {  
-                                m->mothurOut(name + " is missing from your group file. Please correct. ");  m->mothurOutEndLine();
+                                m->mothurOut(name + " is missing from your group file. Please correct. \n");
                                 return 1;
                             }else{
                                 name = name + "\t" + group + "\t" + binLabels[i];
@@ -451,7 +433,7 @@ int BinSeqCommand::process(ListVector* list) {
                                 out << sequence << endl;
                             }
                         }
-                    }else { m->mothurOut(name + " is missing from your fasta or name file. Please correct. "); m->mothurOutEndLine(); return 1; }
+                    }else { m->mothurOut(name + " is missing from your fasta or name file. Please correct. \n");  return 1; }
                 }
             }
         }
