@@ -7,7 +7,7 @@
 //
 
 #include "biominfocommand.h"
-#include "sharedutilities.h"
+
 
 
 //**********************************************************************************************************************
@@ -46,7 +46,7 @@ string BiomInfoCommand::getHelpString(){
         helpString += "For example consider the following basis=sequence could give Clostridiales	3	105, where 105 is the total number of sequences whose otu classified to Clostridiales.\n";
         helpString += "Now for basis=otu could give Clostridiales	3	7, where 7 is the number of otus that classified to Clostridiales.\n";
         helpString += "The biom.info command should be in the following format: biom.info(biom=test.biom, label=0.03).\n";
-        helpString += "Note: No spaces between parameter labels (i.e. label), '=' and parameters (i.e. 0.03).\n";
+        
         return helpString;
     }
     catch(exception& e) {
@@ -63,7 +63,7 @@ string BiomInfoCommand::getOutputPattern(string type) {
         else if (type == "constaxonomy") {  pattern = "[filename],[tag],cons.taxonomy"; }
         else if (type == "taxonomy") {  pattern = "[filename],[tag],taxonomy"; }
         else if (type == "taxsummary") {  pattern = "[filename],[tag],[tag2],tax.summary"; } //tag2 = "" for taxonomy tag2 = cons for constaxonomy
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -113,14 +113,14 @@ BiomInfoCommand::BiomInfoCommand(string option)  {
             }
             
             //if the user changes the input directory command factory will send this info to us in the output parameter
-            string inputDir = validParameter.validFile(parameters, "inputdir", false);
+            string inputDir = validParameter.valid(parameters, "inputdir");
             if (inputDir == "not found"){	inputDir = "";		}
             else {
                 string path;
                 it = parameters.find("biom");
                 //user has given a template file
                 if(it != parameters.end()){
-                    path = m->hasPath(it->second);
+                    path = util.hasPath(it->second);
                     //if the user has not given a path then, add inputdir. else leave path alone.
                     if (path == "") {	parameters["biom"] = inputDir + it->second;		}
                 }
@@ -133,27 +133,27 @@ BiomInfoCommand::BiomInfoCommand(string option)  {
             outputTypes["taxsummary"] = tempOutNames;
             
             //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";	}
+            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
             
             //check for required parameters
-            biomfile = validParameter.validFile(parameters, "biom", true);
+            biomfile = validParameter.validFile(parameters, "biom");
             if (biomfile == "not open") { biomfile = ""; abort = true; }
             else if (biomfile == "not found") { biomfile = ""; m->mothurOut("[ERROR]: You must provide a biom file, please correct.\n");  abort = true;}
-            else { m->setBiomFile(biomfile); }
+            else { current->setBiomFile(biomfile); }
             
-            label = validParameter.validFile(parameters, "label", false);
+            label = validParameter.valid(parameters, "label");
             if (label == "not found") { label = "userLabel"; }
             
-            output = validParameter.validFile(parameters, "output", false);		if(output == "not found"){	output = "detail"; }
+            output = validParameter.valid(parameters, "output");		if(output == "not found"){	output = "detail"; }
             if ((output != "simple") && (output != "detail")) { m->mothurOut(output + " is not a valid output form. Options are simple and detail. I will use detail."); m->mothurOutEndLine(); output = "detail"; }
             
-            string temp = validParameter.validFile(parameters, "relabund", false);		if (temp == "not found"){	temp = "false";			}
-            relabund = m->isTrue(temp);
+            string temp = validParameter.valid(parameters, "relabund");		if (temp == "not found"){	temp = "false";			}
+            relabund = util.isTrue(temp);
             
-            temp = validParameter.validFile(parameters, "printlevel", false);		if (temp == "not found"){	temp = "-1";		}
-            m->mothurConvert(temp, printlevel);
+            temp = validParameter.valid(parameters, "printlevel");		if (temp == "not found"){	temp = "-1";		}
+            util.mothurConvert(temp, printlevel);
             
-            basis = validParameter.validFile(parameters, "basis", false);
+            basis = validParameter.valid(parameters, "basis");
             if (basis == "not found") { basis = "otu"; }
             
             if ((basis != "otu") && (basis != "sequence")) { m->mothurOut("Invalid option for basis. basis options are otu and sequence, using otu."); m->mothurOutEndLine(); }
@@ -170,32 +170,32 @@ BiomInfoCommand::BiomInfoCommand(string option)  {
 int BiomInfoCommand::execute(){
     try {
         
-        if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+        if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
-        int start = time(NULL);
+        long start = time(NULL);
         
         createFilesFromBiom();
         
         m->mothurOutEndLine(); m->mothurOut("It took " + toString(time(NULL) - start) + " create mothur files from your biom file.\n");	m->mothurOutEndLine();
         
-        if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); } }
+        if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); } }
         
-        string current = "";
+        string currentName = "";
         itTypes = outputTypes.find("shared");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSharedFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setSharedFile(currentName); }
         }
         
         //set taxonomy file as new current taxonomyfile
         itTypes = outputTypes.find("taxonomy");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setTaxonomyFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setTaxonomyFile(currentName); }
         }
         
         //set constaxonomy file as new current constaxonomyfile
         itTypes = outputTypes.find("constaxonomy");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setConsTaxonomyFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setConsTaxonomyFile(currentName); }
         }
         
         m->mothurOutEndLine();
@@ -215,16 +215,16 @@ int BiomInfoCommand::createFilesFromBiom() {
     try {
         //getting output filename
         string filename = biomfile;
-        if (outputDir == "") { outputDir += m->hasPath(filename); }
+        if (outputDir == "") { outputDir += util.hasPath(filename); }
         
         map<string, string> variables;
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(filename));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
         variables["[tag]"] = label;
         string sharedFilename = getOutputFileName("shared",variables);
         outputNames.push_back(sharedFilename); outputTypes["shared"].push_back(sharedFilename);
         
         ofstream out;
-        m->openOutputFile(sharedFilename, out);
+        util.openOutputFile(sharedFilename, out);
         
         /*{
          "id":"/Users/SarahsWork/Desktop/release/temp.job2.shared-unique",
@@ -235,7 +235,7 @@ int BiomInfoCommand::createFilesFromBiom() {
          "date": "Tue Apr 17 13:12:07 2012", */
         
         ifstream in;
-        m->openInputFile(biomfile, in);
+        util.openInputFile(biomfile, in);
         
         string matrixFormat = "";
         int numRows = 0;
@@ -256,9 +256,9 @@ int BiomInfoCommand::createFilesFromBiom() {
         string matrixElementType = "";
         
         while (!in.eof()) { //split file by tags, so each "line" will have something like "id":"/Users/SarahsWork/Desktop/release/final.tx.1.subsample.1.pick.shared-1"
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            char c = in.get(); m->gobble(in);
+            char c = in.get(); util.gobble(in);
             
             if (c == '[')               { countOpenBrace++;     }
             else if (c == ']')          { countClosedBrace++;   }
@@ -297,31 +297,31 @@ int BiomInfoCommand::createFilesFromBiom() {
         else {
             string thisLine = it->second;
             biomType = getTag(thisLine);
-            //            if ((biomType != "OTU table") && (biomType != "OTUtable") && (biomType != "Taxon table") && (biomType != "Taxontable")) { m->mothurOut("[ERROR]: " + biomType + " is not a valid biom type for mothur. Only types allowed are OTU table and Taxon table.\n"); m->control_pressed = true;  }
+            //            if ((biomType != "OTU table") && (biomType != "OTUtable") && (biomType != "Taxon table") && (biomType != "Taxontable")) { m->mothurOut("[ERROR]: " + biomType + " is not a valid biom type for mothur. Only types allowed are OTU table and Taxon table.\n"); m->setControl_pressed(true);  }
         }
         
-        if (m->control_pressed) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} return 0; }
+        if (m->getControl_pressed()) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
         
         it = fileLines.find("matrix_type");
         if (it == fileLines.end()) { m->mothurOut("[ERROR]: you file does not have a matrix_type provided.\n"); }
         else {
             string thisLine = it->second;
             matrixFormat = getTag(thisLine);
-            if ((matrixFormat != "sparse") && (matrixFormat != "dense")) { m->mothurOut("[ERROR]: " + matrixFormat + " is not a valid biom matrix_type for mothur. Types allowed are sparse and dense.\n"); m->control_pressed = true; }
+            if ((matrixFormat != "sparse") && (matrixFormat != "dense")) { m->mothurOut("[ERROR]: " + matrixFormat + " is not a valid biom matrix_type for mothur. Types allowed are sparse and dense.\n"); m->setControl_pressed(true); }
         }
         
-        if (m->control_pressed) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} return 0; }
+        if (m->getControl_pressed()) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
         
         it = fileLines.find("matrix_element_type");
         if (it == fileLines.end()) { m->mothurOut("[ERROR]: you file does not have a matrix_element_type provided.\n"); }
         else {
             string thisLine = it->second;
             matrixElementType = getTag(thisLine);
-            if ((matrixElementType != "int") && (matrixElementType != "float")) { m->mothurOut("[ERROR]: " + matrixElementType + " is not a valid biom matrix_element_type for mothur. Types allowed are int and float.\n"); m->control_pressed = true; }
+            if ((matrixElementType != "int") && (matrixElementType != "float")) { m->mothurOut("[ERROR]: " + matrixElementType + " is not a valid biom matrix_element_type for mothur. Types allowed are int and float.\n"); m->setControl_pressed(true); }
             if (matrixElementType == "float") { m->mothurOut("[WARNING]: the shared file only uses integers, any float values will be rounded down to the nearest integer.\n"); }
         }
         
-        if (m->control_pressed) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} return 0; }
+        if (m->getControl_pressed()) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
         
         vector<string> conTaxonomy;
         it = fileLines.find("rows");
@@ -333,7 +333,7 @@ int BiomInfoCommand::createFilesFromBiom() {
                 string mapFilename = getOutputFileName("map",variables);
                 outputNames.push_back(mapFilename); outputTypes["map"].push_back(mapFilename);
                 ofstream outMap;
-                m->openOutputFile(mapFilename, outMap);
+                util.openOutputFile(mapFilename, outMap);
                 
                 bool hasTaxonomy = false;
                 vector< vector<string> > results = readRows(thisLine, numRows, hasTaxonomy);
@@ -363,7 +363,7 @@ int BiomInfoCommand::createFilesFromBiom() {
             }
         }
         
-        if (m->control_pressed) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} return 0; }
+        if (m->getControl_pressed()) { out.close(); for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
         
         it = fileLines.find("columns");
         if (it == fileLines.end()) { m->mothurOut("[ERROR]: you file does not have a columns provided.\n"); }
@@ -378,20 +378,20 @@ int BiomInfoCommand::createFilesFromBiom() {
             if (hasTaxonomy) {
                 //write taxonomy file
                 map<string, string> variables;
-                variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(filename));
+                variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
                 variables["[tag]"] = label;
                 string taxFilename = getOutputFileName("taxonomy",variables);
                 outputNames.push_back(taxFilename); outputTypes["taxonomy"].push_back(taxFilename);
                 ofstream outTax;
-                m->openOutputFile(taxFilename, outTax);
+                util.openOutputFile(taxFilename, outTax);
                 
                 GroupMap* g = NULL;
                 PhyloSummary taxaSum(g, relabund, printlevel);
                 
                 for (int i = 0; i < results[1].size(); i++) {
-                    if (m->control_pressed) { break; }
+                    if (m->getControl_pressed()) { break; }
                     
-                    string newTax = m->addUnclassifieds(results[1][i], maxLevel, false);
+                    string newTax = util.addUnclassifieds(results[1][i], maxLevel, false);
                     outTax << results[0][i] << '\t' << newTax << endl;
                     
                     taxaSum.addSeqToTree(results[0][i], newTax);
@@ -399,13 +399,13 @@ int BiomInfoCommand::createFilesFromBiom() {
                 outTax.close();
                 
                 //write taxonomy file
-                variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(filename));
+                variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
                 variables["[tag]"] = label;
                 variables["[tag2]"] = "";
                 string taxSumFilename = getOutputFileName("taxsummary",variables);
                 outputNames.push_back(taxSumFilename); outputTypes["taxsummary"].push_back(taxSumFilename);
                 ofstream outTaxSum;
-                m->openOutputFile(taxSumFilename, outTaxSum);
+                util.openOutputFile(taxSumFilename, outTaxSum);
                 
                 //write tax.summary
                 if (relabund)   {   taxaSum.print(outTaxSum, relabund);     }
@@ -413,13 +413,12 @@ int BiomInfoCommand::createFilesFromBiom() {
                 
                 outTaxSum.close();
             }
-            m->setGroups(groupNames);
             
             //set fileroot
-            fileroot = outputDir + m->getRootName(m->getSimpleName(biomfile));
+            fileroot = outputDir + util.getRootName(util.getSimpleName(biomfile));
         }
         
-        if (m->control_pressed) {  out.close(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} return 0; }
+        if (m->getControl_pressed()) {  out.close(); for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
         
         it = fileLines.find("shape");
         if (it == fileLines.end()) { m->mothurOut("[ERROR]: you file does not have a shape provided.\n"); }
@@ -428,50 +427,47 @@ int BiomInfoCommand::createFilesFromBiom() {
             getDims(thisLine, shapeNumRows, shapeNumCols);
             
             //check shape
-            if (shapeNumCols != numCols) { m->mothurOut("[ERROR]: shape indicates " + toString(shapeNumCols) + " columns, but I only read " + toString(numCols) + " columns.\n"); m->control_pressed = true; }
+            if (shapeNumCols != numCols) { m->mothurOut("[ERROR]: shape indicates " + toString(shapeNumCols) + " columns, but I only read " + toString(numCols) + " columns.\n"); m->setControl_pressed(true); }
             
-            if (shapeNumRows != numRows) { m->mothurOut("[ERROR]: shape indicates " + toString(shapeNumRows) + " rows, but I only read " + toString(numRows) + " rows.\n"); m->control_pressed = true; }
+            if (shapeNumRows != numRows) { m->mothurOut("[ERROR]: shape indicates " + toString(shapeNumRows) + " rows, but I only read " + toString(numRows) + " rows.\n"); m->setControl_pressed(true); }
         }
         
-        if (m->control_pressed) {  out.close(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} return 0; }
+        if (m->getControl_pressed()) {  out.close(); for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
         
         it = fileLines.find("data");
         if (it == fileLines.end()) { m->mothurOut("[ERROR]: you file does not have a data provided.\n"); }
         else {
             string thisLine = it->second;
-            m->currentSharedBinLabels = otuNames;
-            
-            //read data
-            vector<SharedRAbundVector*> lookup = readData(matrixFormat, thisLine, matrixElementType, groupNames, otuNames.size());
-            
-            m->mothurOutEndLine(); m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-            lookup[0]->printHeaders(out);
-            printSharedData(lookup, out);
+            SharedRAbundVectors* lookup = readData(matrixFormat, thisLine, matrixElementType, groupNames, otuNames.size());
+            lookup->setOTUNames(otuNames);
+            m->mothurOutEndLine(); m->mothurOut(lookup->getLabel()+"\n"); 
+            lookup->print(out);
             
             if (conTaxonomy.size() != 0) {
                 //sanity check
-                if ((lookup[0]->getNumBins() == conTaxonomy.size()) && (lookup[0]->getNumBins() == otuNames.size())) {
+                if ((lookup->getNumBins() == conTaxonomy.size()) && (lookup->getNumBins() == otuNames.size())) {
                     //write taxonomy file
                     map<string, string> variables;
-                    variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(filename));
+                    variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
                     variables["[tag]"] = label;
                     string taxFilename = getOutputFileName("constaxonomy",variables);
                     outputNames.push_back(taxFilename); outputTypes["constaxonomy"].push_back(taxFilename);
                     ofstream outTax;
-                    m->openOutputFile(taxFilename, outTax);
+                    util.openOutputFile(taxFilename, outTax);
                     outTax << "OTU\tSize\tTaxonomy\n";
                     
                     CountTable* ct = NULL;
                     if (basis == "otu") {
                         ct = new CountTable();
-                        for (int j = 0; j < lookup.size(); j++) {  ct->addGroup(lookup[j]->getGroup()); }
+                        vector<string> groupNames = lookup->getNamesGroups();
+                        for (int j = 0; j < groupNames.size(); j++) {  ct->addGroup(groupNames[j]); }
                         
-                        int numBins = lookup[0]->getNumBins();
+                        int numBins = lookup->getNumBins();
                         for (int i = 0; i < numBins; i++) {
                             vector<int> abunds;
-                            for (int j = 0; j < lookup.size(); j++) {
-                                if (m->control_pressed) { break; }
-                                abunds.push_back(lookup[j]->getAbundance(i));
+                            for (int j = 0; j < lookup->size(); j++) {
+                                if (m->getControl_pressed()) { break; }
+                                abunds.push_back(lookup->get(i, groupNames[j]));
                             }
                             ct->push_back(otuNames[i], abunds);
                         }
@@ -479,17 +475,18 @@ int BiomInfoCommand::createFilesFromBiom() {
                     
                     PhyloSummary taxaSum(ct, relabund, printlevel);
                     
-                    for (int i = 0; i < lookup[0]->getNumBins(); i++) {
-                        if (m->control_pressed) { break; }
+                    for (int i = 0; i < lookup->getNumBins(); i++) {
+                        if (m->getControl_pressed()) { break; }
                         
                         int total = 0;
                         map<string, bool> containsGroup;
-                        for (int j = 0; j < lookup.size(); j++) {
-                            total += lookup[j]->getAbundance(i);
-                            containsGroup[lookup[j]->getGroup()] = lookup[j]->getAbundance(i);
+                        for (int j = 0; j < lookup->size(); j++) {
+                            int abund = lookup->get(i, groupNames[j]);
+                            total += abund;
+                            containsGroup[groupNames[j]] = abund;
                         }
                         
-                        string newTax = m->addUnclassifieds(conTaxonomy[i], maxLevel, false);
+                        string newTax = util.addUnclassifieds(conTaxonomy[i], maxLevel, false);
                         outTax << otuNames[i] << '\t' << total << '\t' << newTax << endl;
                         
                         if (basis == "sequence") {
@@ -501,13 +498,13 @@ int BiomInfoCommand::createFilesFromBiom() {
                     outTax.close();
                     
                     //write taxonomy file
-                    variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(filename));
+                    variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
                     variables["[tag]"] = label;
                     variables["[tag2]"] = "cons";
                     string taxSumFilename = getOutputFileName("taxsummary",variables);
                     outputNames.push_back(taxSumFilename); outputTypes["taxsummary"].push_back(taxSumFilename);
                     ofstream outTaxSum;
-                    m->openOutputFile(taxSumFilename, outTaxSum);
+                    util.openOutputFile(taxSumFilename, outTaxSum);
                     taxaSum.print(outTaxSum, output);
                     outTaxSum.close();
                     
@@ -516,7 +513,7 @@ int BiomInfoCommand::createFilesFromBiom() {
                 }
             }
             
-            for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+            delete lookup;
         }
         
         return 0;
@@ -527,17 +524,16 @@ int BiomInfoCommand::createFilesFromBiom() {
     }
 }
 //**********************************************************************************************************************
-vector<SharedRAbundVector*> BiomInfoCommand::readData(string matrixFormat, string line, string matrixElementType, vector<string>& groupNames, int numOTUs) {
+SharedRAbundVectors* BiomInfoCommand::readData(string matrixFormat, string line, string matrixElementType, vector<string>& groupNames, int numOTUs) {
     try {
-        
-        vector<SharedRAbundVector*> lookup;
+        SharedRAbundVectors* lookup = new SharedRAbundVectors();
         
         //creates new sharedRAbunds
         for (int i = 0; i < groupNames.size(); i++) {
             SharedRAbundVector* temp = new SharedRAbundVector(numOTUs); //sets all abunds to 0
             temp->setLabel(label);
             temp->setGroup(groupNames[i]);
-            lookup.push_back(temp);
+            lookup->push_back(temp);
         }
         
         bool dataStart = false;
@@ -547,7 +543,7 @@ vector<SharedRAbundVector*> BiomInfoCommand::readData(string matrixFormat, strin
         int otuCount = 0;
         for (int i = 0; i < line.length(); i++) {
             
-            if (m->control_pressed) { return lookup; }
+            if (m->getControl_pressed()) { return lookup; }
             
             //look for opening [ to indicate data is starting
             if ((line[i] == '[') && (!dataStart)) { dataStart = true; i++;  if (!(i < line.length())) { break; } }
@@ -559,8 +555,8 @@ vector<SharedRAbundVector*> BiomInfoCommand::readData(string matrixFormat, strin
                     inBrackets = false;
                     int temp;
                     float temp2;
-                    if (matrixElementType == "float") { m->mothurConvert(num, temp2); temp = (int)temp2; }
-                    else { m->mothurConvert(num, temp); }
+                    if (matrixElementType == "float") { util.mothurConvert(num, temp2); temp = (int)temp2; }
+                    else { util.mothurConvert(num, temp); }
                     nums.push_back(temp);
                     num = "";
                     
@@ -568,19 +564,19 @@ vector<SharedRAbundVector*> BiomInfoCommand::readData(string matrixFormat, strin
                     if (matrixFormat == "dense") {
                         
                         //sanity check
-                        if (nums.size() != lookup.size()) { m->mothurOut("[ERROR]: trouble parsing OTU data.  OTU " + toString(otuCount) + " causing errors.\n"); m->control_pressed = true; }
+                        if (nums.size() != lookup->size()) { m->mothurOut("[ERROR]: trouble parsing OTU data.  OTU " + toString(otuCount) + " causing errors.\n"); m->setControl_pressed(true); }
                         
                         //set abundances for this otu
                         //nums contains [abundSample0, abundSample1, abundSample2, ...] for current OTU
-                        for (int j = 0; j < lookup.size(); j++) { lookup[j]->set(otuCount, nums[j], groupNames[j]); }
+                        for (int j = 0; j < groupNames.size(); j++) { lookup->set(otuCount, nums[j], groupNames[j]); }
                         
                         otuCount++;
                     }else {
                         //sanity check
-                        if (nums.size() != 3) { m->mothurOut("[ERROR]: trouble parsing OTU data.\n"); m->control_pressed = true; }
+                        if (nums.size() != 3) { m->mothurOut("[ERROR]: trouble parsing OTU data.\n"); m->setControl_pressed(true); }
                         
                         //nums contains [otuNum, sampleNum, abundance]
-                        lookup[nums[1]]->set(nums[0], nums[2], groupNames[nums[1]]);
+                        lookup->set(nums[0], nums[2], groupNames[nums[1]]);
                     }
                     nums.clear();
                 }
@@ -588,7 +584,7 @@ vector<SharedRAbundVector*> BiomInfoCommand::readData(string matrixFormat, strin
                 if (inBrackets) {
                     if (line[i] == ',') {
                         int temp;
-                        m->mothurConvert(num, temp);
+                        util.mothurConvert(num, temp);
                         nums.push_back(temp);
                         num = "";
                     }else { if (!isspace(line[i])) { num += line[i]; }  }
@@ -616,13 +612,13 @@ int BiomInfoCommand::getDims(string line, int& shapeNumRows, int& shapeNumCols)
             if ((line[i] == '[') && (!inBar)) {  inBar = true; i++;  if (!(i < line.length())) { break; } }
             else if ((line[i] == ']') && (inBar)) {
                 inBar= false;
-                m->mothurConvert(num, shapeNumCols);
+                util.mothurConvert(num, shapeNumCols);
                 break;
             }
             
             if (inBar) {
                 if (line[i] == ',') {
-                    m->mothurConvert(num, shapeNumRows);
+                    util.mothurConvert(num, shapeNumRows);
                     num = "";
                 }else { if (!isspace(line[i])) { num += line[i]; }  }
             }
@@ -663,7 +659,7 @@ vector< vector<string> > BiomInfoCommand::readRows(string line, int& numRows, bo
         
         for (int i = 0; i < line.length(); i++) {
             
-            if (m->control_pressed) { return results; }
+            if (m->getControl_pressed()) { return results; }
             
             if (line[i] == '[')         { countOpenBrace++;     }
             else if (line[i] == ']')    { countClosedBrace++;   }
@@ -721,7 +717,7 @@ vector<string> BiomInfoCommand::getNamesAndTaxonomies(string line) {
             results.push_back(getName(line)); results.push_back("");
         }else {
             string value;
-            m->splitAtComma(value, line);  //value hold name portion ("id":"Otu01") line holds rest
+            util.splitAtComma(value, line);  //value hold name portion ("id":"Otu01") line holds rest
             results.push_back(getName(value));
             
             string taxonomy = ""; string bootstrap = "";
@@ -751,7 +747,7 @@ vector<string> BiomInfoCommand::getNamesAndTaxonomies(string line) {
 string BiomInfoCommand::getName(string line) {
     try {
         vector<string> nameItems;
-        m->splitAtChar(line, nameItems, ':'); //split part we want containing the ids
+        util.splitAtChar(line, nameItems, ':'); //split part we want containing the ids
         string name = nameItems[1];
         
         //remove "" if needed
@@ -780,37 +776,37 @@ string BiomInfoCommand::getTaxonomy(string taxonomy, string bootstrap) {
         
         if (taxonomy != "") {
             vector<string> taxItems;
-            m->splitAtChar(taxonomy, taxItems, ':'); //split part we want containing the ids
+            util.splitAtChar(taxonomy, taxItems, ':'); //split part we want containing the ids
             string taxons = taxItems[1];
             
             string taxon;
             while((taxons.find_first_of(',') != -1)) {
-                if (m->control_pressed) {break;}
-                m->splitAtComma(taxon, taxons);
+                if (m->getControl_pressed()) {break;}
+                util.splitAtComma(taxon, taxons);
                 results.push_back(taxon);
             }
-            if (!m->stringBlank(taxons)) { results.push_back(taxons); }
+            if (!util.stringBlank(taxons)) { results.push_back(taxons); }
         }
         
         if (bootstrap != "") {
             vector<string> bootItems;
-            m->splitAtChar(bootstrap, bootItems, ':'); //split part we want containing the ids
+            util.splitAtChar(bootstrap, bootItems, ':'); //split part we want containing the ids
             string bootValues = bootItems[1];
             
             string bootValue;
             int i = 0;
             while((bootValues.find_first_of(',') != -1)) {
-                if (m->control_pressed) {break;}
-                m->splitAtComma(bootValue, bootValues);
+                if (m->getControl_pressed()) {break;}
+                util.splitAtComma(bootValue, bootValues);
                 results[i]+="("+bootValue+")";
                 i++;
             }
-            if (!m->stringBlank(bootValues)) { results[i]+="("+bootValues+")"; }
+            if (!util.stringBlank(bootValues)) { results[i]+="("+bootValues+")"; }
         }
         
         string result = "";
         for (int i = 0; i < results.size(); i++) {
-            if (m->control_pressed) {result = ""; break;}
+            if (m->getControl_pressed()) {result = ""; break;}
             result += results[i] + ";";
         }
         
@@ -851,30 +847,6 @@ string BiomInfoCommand::getTag(string& line) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-void BiomInfoCommand::printSharedData(vector<SharedRAbundVector*> thislookup, ofstream& out) {
-    try {
-        
-        //sorts alphabetically
-        m->clearGroups();
-        vector<string> Groups;
-        map<string, SharedRAbundVector*> Ovectors;
-        for (int i = 0; i < thislookup.size(); i++) { Ovectors[thislookup[i]->getGroup()] = thislookup[i]; }
-        
-        //initialize bin values
-        for (map<string, SharedRAbundVector*>::iterator it = Ovectors.begin(); it != Ovectors.end(); it++) {
-            out << (it->second)->getLabel() << '\t' << it->first << '\t';
-            (it->second)->print(out);
-                
-            Groups.push_back(it->first);
-        }
-        m->setGroups(Groups);
-        
-    }
-    catch(exception& e) {
-        m->errorOut(e, "BiomInfoCommand", "printSharedData");
-        exit(1);
-    }
-}
+//**********************************************************************************************************************/
+
 
-//**********************************************************************************************************************
