@@ -16,6 +16,7 @@ vector<string> CatchAllCommand::setParameters(){
 		//can choose shared or sabund not both, so put them in the same chooseOnlyOneGroup
 		CommandParameter pshared("shared", "InputTypes", "", "", "catchallInputs", "catchallInputs", "none","analysis-bestanalysis-models-bubble-summary",false,false,true); parameters.push_back(pshared);
 		CommandParameter psabund("sabund", "InputTypes", "", "", "catchallInputs", "catchallInputs", "none","analysis-bestanalysis-models-bubble-summary",false,false,true); parameters.push_back(psabund);
+        CommandParameter pgroups("groups", "String", "", "", "", "", "","",false,false); parameters.push_back(pgroups);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
@@ -37,7 +38,7 @@ string CatchAllCommand::getHelpString(){
 		helpString += "For more information about catchall refer to http://www.northeastern.edu/catchall/index.html \n";
 		helpString += "The catchall executable must be in the same folder as your mothur executable. \n";
 		helpString += "If you are a MAC or Linux user you must also have installed mono, a link to mono is on the webpage. \n";
-		helpString += "The catchall command parameters are shared, sabund and label.  shared or sabund is required. \n";
+		helpString += "The catchall command parameters are shared, sabund, groups and label.  shared or sabund is required. \n";
 		helpString += "The label parameter is used to analyze specific labels in your input.\n";
 		helpString += "The catchall command should be in the following format: \n";
 		helpString += "catchall(sabund=yourSabundFile) \n";
@@ -60,7 +61,7 @@ string CatchAllCommand::getOutputPattern(string type) {
         else if (type == "bubble") {  pattern = "[filename],_BubblePlot.csv"; }
         else if (type == "summary") {  pattern =  "[filename],catchall.summary"; }
         else if (type == "sabund") {  pattern =  "[filename],[distance],csv"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -124,14 +125,14 @@ CatchAllCommand::CatchAllCommand(string option)  {
 
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("sabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["sabund"] = inputDir + it->second;		}
 				}
@@ -139,27 +140,27 @@ CatchAllCommand::CatchAllCommand(string option)  {
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
 			}
 
 			//check for required parameters
-			sabundfile = validParameter.validFile(parameters, "sabund", true);
+			sabundfile = validParameter.validFile(parameters, "sabund");
 			if (sabundfile == "not open") { sabundfile = ""; abort = true; }
 			else if (sabundfile == "not found") { sabundfile = "";  }
-			else { m->setSabundFile(sabundfile); }
+			else { current->setSabundFile(sabundfile); }
 			
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }
 			else if (sharedfile == "not found") { sharedfile = "";   }
-			else { m->setSharedFile(sharedfile); }
+			else { current->setSharedFile(sharedfile); }
 			
-			string label = validParameter.validFile(parameters, "label", false);			
+			string label = validParameter.valid(parameters, "label");
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 		
@@ -167,10 +168,10 @@ CatchAllCommand::CatchAllCommand(string option)  {
 				//is there are current file available for either of these?
 				//give priority to shared, then sabund
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
-					sabundfile = m->getSabundFile(); 
+					sabundfile = current->getSabundFile(); 
 					if (sabundfile != "") {  m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("No valid current files. You must provide a sabund or shared file before you can use the catchall command."); m->mothurOutEndLine(); 
@@ -180,11 +181,17 @@ CatchAllCommand::CatchAllCommand(string option)  {
 			}
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		
+			outputDir = validParameter.valid(parameters, "outputdir");
 			if (outputDir == "not found"){	
-				if (sabundfile != "") {  outputDir = m->hasPath(sabundfile); }
-				else { outputDir = m->hasPath(sharedfile); }
+				if (sabundfile != "") {  outputDir = util.hasPath(sabundfile); }
+				else { outputDir = util.hasPath(sharedfile); }
 			}
+            
+            string groups = validParameter.valid(parameters, "groups");
+            if (groups == "not found") { groups = ""; }
+            else { util.splitAtDash(groups, Groups);
+                    if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }  }
+
 		}
 
 	}
@@ -197,20 +204,18 @@ CatchAllCommand::CatchAllCommand(string option)  {
 int CatchAllCommand::execute() {	
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		//get location of catchall
-		path = m->mothurProgramPath;
-		//path = path.substr(0, (path.find_last_of("othur")-5));
-		path = m->getFullPathName(path);
+		path = current->getProgramPath();
 		
-        if (m->debug) { m->mothurOut("[DEBUG]: mothur's path = " + path + "\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: mothur's path = " + path + "\n"); }
        
 		savedOutputDir = outputDir;
 		string catchAllCommandExe = "";
         string catchAllTest = "";
         string programName = "";
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
+		#if defined NON_WINDOWS
 			if (outputDir == "") { outputDir = "./"; } //force full pathname to be created for catchall, this is necessary because if catchall is in the path it will look for input file whereever the exe is and not the cwd.
             catchAllTest = path + "CatchAllcmdL.exe";
 		#else
@@ -220,35 +225,27 @@ int CatchAllCommand::execute() {
 		
         //test to make sure formatdb exists
 		ifstream in;
-		catchAllTest = m->getFullPathName(catchAllTest);
-		int ableToOpen = m->openInputFile(catchAllTest, in, "no error"); in.close();
-		if(ableToOpen == 1) {	
+		catchAllTest = util.getFullPathName(catchAllTest);
+		bool ableToOpen = util.openInputFile(catchAllTest, in, "no error"); in.close();
+		if(!ableToOpen) {	
             m->mothurOut(catchAllTest + " file does not exist. Checking path... \n");
             
             programName = "CatchAllcmdW.exe";
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
+#if defined NON_WINDOWS
             programName = "CatchAllcmdL.exe";
 #endif
-            string cLocation = m->findProgramPath(programName);
+            Utils util;
+            string cLocation = util.findProgramPath(programName);
             
             ifstream in2;
-            ableToOpen = m->openInputFile(cLocation, in2, "no error"); in2.close();
+            ableToOpen = util.openInputFile(cLocation+programName, in2, "no error"); in2.close();
 
-            if(ableToOpen == 1) {
-                programName = "catchall";
-                
-                string cLocation = m->findProgramPath(programName);
-                
-                ifstream in3;
-                ableToOpen = m->openInputFile(cLocation, in3, "no error"); in3.close();
-                
-                if(ableToOpen == 1) { m->mothurOut("[ERROR]: " + cLocation + " file does not exist. mothur requires the catchall executable."); m->mothurOutEndLine();  return 0; }else {  m->mothurOut("Found catchall in your path, using " + cLocation + "\n"); catchAllTest = cLocation; }
-            }
-            else {  m->mothurOut("Found catchall in your path, using " + cLocation + "\n"); catchAllTest = cLocation; }
+            if(!ableToOpen) { m->mothurOut("[ERROR]: " + cLocation + " file does not exist. mothur requires the catchall executable.\n"); return 0; }
+            else            {  m->mothurOut("Found catchall in your path, using " + cLocation + "\n"); catchAllTest = cLocation+programName; }
         }
-        catchAllTest = m->getFullPathName(catchAllTest);
+        catchAllTest = util.getFullPathName(catchAllTest);
         
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
+#if defined NON_WINDOWS
         if (programName == "catchall") { catchAllCommandExe += "catchall "; }
         else {  catchAllCommandExe += "mono \"" + catchAllTest + "\" ";  }
 #else
@@ -256,9 +253,9 @@ int CatchAllCommand::execute() {
 #endif
         
 		//prepare full output directory
-		outputDir = m->getFullPathName(outputDir);
+		outputDir = util.getFullPathName(outputDir);
 		
-        if (m->debug) { m->mothurOut("[DEBUG]: catchall location = " + catchAllCommandExe + "\n[DEBUG]: outputDir = " + outputDir + "\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: catchall location = " + catchAllCommandExe + "\n[DEBUG]: outputDir = " + outputDir + "\n"); }
         
 		vector<string> inputFileNames;
 		if (sharedfile != "") { inputFileNames = parseSharedFile(sharedfile);   }
@@ -266,10 +263,10 @@ int CatchAllCommand::execute() {
 		
 		for (int p = 0; p < inputFileNames.size(); p++) {
 			if (inputFileNames.size() > 1) {
-				m->mothurOutEndLine(); m->mothurOut("Processing group " + groups[p]); m->mothurOutEndLine(); m->mothurOutEndLine();
+				m->mothurOutEndLine(); m->mothurOut("Processing group " + Groups[p]); m->mothurOutEndLine(); m->mothurOutEndLine();
 			}
 			
-			InputData input(inputFileNames[p], "sabund");
+			InputData input(inputFileNames[p], "sabund", nullVector);
 			SAbundVector* sabund = input.getSAbundVector();
 			string lastLabel = sabund->getLabel();
 							
@@ -277,18 +274,18 @@ int CatchAllCommand::execute() {
 			set<string> userLabels = labels;
 			
             map<string, string> variables;
-            variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileNames[p]));
+            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileNames[p]));
 			string summaryfilename = getOutputFileName("summary", variables);
-			summaryfilename = m->getFullPathName(summaryfilename);
+			summaryfilename = util.getFullPathName(summaryfilename);
 			
-            if (m->debug) { m->mothurOut("[DEBUG]: Input File = " + inputFileNames[p] + ".\n[DEBUG]: inputdata address = " + toString(&input) + ".\n[DEBUG]: sabund address = " + toString(&sabund) + ".\n"); } 
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: Input File = " + inputFileNames[p] + ".\n[DEBUG]: inputdata address = " + toString(&input) + ".\n[DEBUG]: sabund address = " + toString(&sabund) + ".\n"); } 
             
 			ofstream out;
-			m->openOutputFile(summaryfilename, out);	
+			util.openOutputFile(summaryfilename, out);	
 			
 			out << "label\tmodel\testimate\tlci\tuci" << endl;
             
-            if (m->debug) { string open = "no"; if (out.is_open()) { open = "yes"; } m->mothurOut("[DEBUG]: output stream is open = " + open + ".\n"); }
+            if (m->getDebug()) { string open = "no"; if (out.is_open()) { open = "yes"; } m->mothurOut("[DEBUG]: output stream is open = " + open + ".\n"); }
 			
 			//for each label the user selected
 			while((sabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
@@ -299,39 +296,39 @@ int CatchAllCommand::execute() {
 						
 						//create catchall input file from mothur's inputfile
 						string filename = process(sabund, inputFileNames[p]);
-						string outputPath = m->getPathName(filename);
+						string outputPath = util.getPathName(filename);
 											
 						//create system command
 						string catchAllCommand = "";
-						#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
+						#if defined NON_WINDOWS
 							catchAllCommand += catchAllCommandExe + "\"" + filename + "\" \""  + outputPath + + "\" 1";
 						#else
                             //removes extra '\\' catchall doesnt like that
                             vector<string> tempNames;
                             string tempFilename = filename;
-                            m->splitAtDash(tempFilename, tempNames);
+                            util.splitAtDash(tempFilename, tempNames);
                             tempFilename = tempNames[0];
                             tempNames.clear();
                             string tempOutputPath = outputPath;
-                            m->splitAtDash(tempOutputPath, tempNames);
+                            util.splitAtDash(tempOutputPath, tempNames);
                             tempOutputPath = tempNames[0];
                             if (tempOutputPath.length() > 0) { tempOutputPath = tempOutputPath.substr(0, tempOutputPath.length()-1); }
                             catchAllCommand += catchAllCommandExe + "\"" + tempFilename + "\" \""  + tempOutputPath + "\" 1";
                             catchAllCommand = "\"" + catchAllCommand + "\"";
 						#endif
                         
-                        if (m->debug) {  m->mothurOut("[DEBUG]: catchall command = " + catchAllCommand + ". About to call system.\n"); }
+                        if (m->getDebug()) {  m->mothurOut("[DEBUG]: catchall command = " + catchAllCommand + ". About to call system.\n"); }
                     
 						//run catchall
 						system(catchAllCommand.c_str());
                     
-                        if (m->debug) { m->mothurOut("[DEBUG]: back from system call. Keeping file: " + filename + ".\n"); }
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: back from system call. Keeping file: " + filename + ".\n"); }
                     
-                        if (!m->debug) { m->mothurRemove(filename); }
+                        if (!m->getDebug()) { util.mothurRemove(filename); }
 
 					
-						filename = m->getRootName(filename); filename = filename.substr(0, filename.length()-1); //rip off extra .
-						if (savedOutputDir == "") { filename = m->getSimpleName(filename); }
+						filename = util.getRootName(filename); filename = filename.substr(0, filename.length()-1); //rip off extra .
+						if (savedOutputDir == "") { filename = util.getSimpleName(filename); }
 					
                         variables["[filename]"] = filename;
 						outputNames.push_back(getOutputFileName("analysis", variables)); outputTypes["analysis"].push_back(getOutputFileName("analysis", variables));
@@ -339,19 +336,19 @@ int CatchAllCommand::execute() {
                         outputNames.push_back(getOutputFileName("models", variables)); outputTypes["models"].push_back(getOutputFileName("models", variables));
                         outputNames.push_back(getOutputFileName("bubble", variables)); outputTypes["bubble"].push_back(getOutputFileName("bubble", variables));
                         
-                        if (m->debug) { m->mothurOut("[DEBUG]: About to create summary file for: " + filename + ".\n[DEBUG]: sabund label = " + sabund->getLabel() + ".\n"); }
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: About to create summary file for: " + filename + ".\n[DEBUG]: sabund label = " + sabund->getLabel() + ".\n"); }
                     
 						createSummaryFile(filename + "_BestModelsAnalysis.csv", sabund->getLabel(), out);
                     
-                        if (m->debug) { m->mothurOut("[DEBUG]: Done creating summary file.\n"); }
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: Done creating summary file.\n"); }
 											
-						if (m->control_pressed) { out.close(); for (int i = 0; i < outputNames.size(); i++) {m->mothurRemove(outputNames[i]);	}  delete sabund;  return 0; }
+						if (m->getControl_pressed()) { out.close(); for (int i = 0; i < outputNames.size(); i++) {util.mothurRemove(outputNames[i]);	}  delete sabund;  return 0; }
 
 						processedLabels.insert(sabund->getLabel());
 						userLabels.erase(sabund->getLabel());
 				}
 				
-				if ((m->anyLabelsToProcess(sabund->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+				if ((util.anyLabelsToProcess(sabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 						string saveLabel = sabund->getLabel();
 						
 						delete sabund;		
@@ -362,39 +359,39 @@ int CatchAllCommand::execute() {
 
 						//create catchall input file from mothur's inputfile
 						string filename = process(sabund, inputFileNames[p]);
-						string outputPath = m->getPathName(filename);
+						string outputPath = util.getPathName(filename);
 											
 						//create system command
 						string catchAllCommand = "";
-						#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
+						#if defined NON_WINDOWS
                             catchAllCommand += catchAllCommandExe + "\"" + filename + "\" \""  + outputPath + + "\" 1";
 						#else
                             //removes extra '\\' catchall doesnt like that
                             vector<string> tempNames;
                             string tempFilename = filename;
-                            m->splitAtDash(tempFilename, tempNames);
+                            util.splitAtDash(tempFilename, tempNames);
                             tempFilename = tempNames[0];
                             tempNames.clear();
                             string tempOutputPath = outputPath;
-                            m->splitAtDash(tempOutputPath, tempNames);
+                            util.splitAtDash(tempOutputPath, tempNames);
                             tempOutputPath = tempNames[0];
 							if (tempOutputPath.length() > 0) { tempOutputPath = tempOutputPath.substr(0, tempOutputPath.length()-1); }
 							catchAllCommand += catchAllCommandExe + "\"" + tempFilename + "\" \""  + tempOutputPath + "\" 1";
 							catchAllCommand = "\"" + catchAllCommand + "\"";
 						#endif
                         
-                        if (m->debug) {  m->mothurOut("[DEBUG]: catchall command = " + catchAllCommand + ". About to call system.\n"); }
+                        if (m->getDebug()) {  m->mothurOut("[DEBUG]: catchall command = " + catchAllCommand + ". About to call system.\n"); }
                     
 						//run catchall
 						system(catchAllCommand.c_str());
                     
-                        if (m->debug) { m->mothurOut("[DEBUG]: back from system call. Keeping file: " + filename + ".\n"); }
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: back from system call. Keeping file: " + filename + ".\n"); }
                     
-                        if (!m->debug) { m->mothurRemove(filename); }
+                        if (!m->getDebug()) { util.mothurRemove(filename); }
 
 					
-						filename = m->getRootName(filename); filename = filename.substr(0, filename.length()-1); //rip off extra .
-						if (savedOutputDir == "") { filename = m->getSimpleName(filename); }
+						filename = util.getRootName(filename); filename = filename.substr(0, filename.length()-1); //rip off extra .
+						if (savedOutputDir == "") { filename = util.getSimpleName(filename); }
 					
                         variables["[filename]"] = filename;
                         outputNames.push_back(getOutputFileName("analysis", variables)); outputTypes["analysis"].push_back(getOutputFileName("analysis", variables));
@@ -403,13 +400,13 @@ int CatchAllCommand::execute() {
                         outputNames.push_back(getOutputFileName("bubble", variables)); outputTypes["bubble"].push_back(getOutputFileName("bubble", variables));
                         
                     
-                        if (m->debug) { m->mothurOut("[DEBUG]: About to create summary file for: " + filename + ".\n[DEBUG]: sabund label = " + sabund->getLabel() + ".\n"); }
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: About to create summary file for: " + filename + ".\n[DEBUG]: sabund label = " + sabund->getLabel() + ".\n"); }
                     
 						createSummaryFile(filename + "_BestModelsAnalysis.csv", sabund->getLabel(), out);
                     
-                        if (m->debug) { m->mothurOut("[DEBUG]: Done creating summary file.\n"); }
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: Done creating summary file.\n"); }
 					
-						if (m->control_pressed) { out.close(); for (int i = 0; i < outputNames.size(); i++) {m->mothurRemove(outputNames[i]);	}   delete sabund;  return 0; }
+						if (m->getControl_pressed()) { out.close(); for (int i = 0; i < outputNames.size(); i++) {util.mothurRemove(outputNames[i]);	}   delete sabund;  return 0; }
 
 						processedLabels.insert(sabund->getLabel());
 						userLabels.erase(sabund->getLabel());
@@ -439,7 +436,7 @@ int CatchAllCommand::execute() {
 			}
 			
 			//run last label if you need to
-			if (needToRun == true)  {
+			if (needToRun )  {
 				if (sabund != NULL) {	delete sabund;	}
 				sabund = (input.getSAbundVector(lastLabel));
 				
@@ -447,74 +444,73 @@ int CatchAllCommand::execute() {
 				
 				//create catchall input file from mothur's inputfile
 				string filename = process(sabund, inputFileNames[p]);
-				string outputPath = m->getPathName(filename);
+				string outputPath = util.getPathName(filename);
 				
 				//create system command
 				string catchAllCommand = "";
-				#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
+				#if defined NON_WINDOWS
                     catchAllCommand += catchAllCommandExe + "\"" + filename + "\" \""  + outputPath + + "\" 1";
 				#else
                     //removes extra '\\' catchall doesnt like that
                     vector<string> tempNames;
                     string tempFilename = filename;
-                    m->splitAtDash(tempFilename, tempNames);
+                    util.splitAtDash(tempFilename, tempNames);
                     tempFilename = tempNames[0];
                     tempNames.clear();
                     string tempOutputPath = outputPath;
-                    m->splitAtDash(tempOutputPath, tempNames);
+                    util.splitAtDash(tempOutputPath, tempNames);
                     tempOutputPath = tempNames[0];
                     if (tempOutputPath.length() > 0) { tempOutputPath = tempOutputPath.substr(0, tempOutputPath.length()-1); }
                     catchAllCommand += catchAllCommandExe + "\"" + tempFilename + "\" \""  + tempOutputPath + "\" 1";
                     catchAllCommand = "\"" + catchAllCommand + "\"";
 				#endif
                 
-                if (m->debug) {  m->mothurOut("[DEBUG]: catchall command = " + catchAllCommand + ". About to call system.\n"); }
+                if (m->getDebug()) {  m->mothurOut("[DEBUG]: catchall command = " + catchAllCommand + ". About to call system.\n"); }
 				
 				//run catchall
 				system(catchAllCommand.c_str());
                 
-                if (m->debug) { m->mothurOut("[DEBUG]: back from system call. Keeping file: " + filename + ".\n"); }
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: back from system call. Keeping file: " + filename + ".\n"); }
 				
-				if (!m->debug) { m->mothurRemove(filename); }
+				if (!m->getDebug()) { util.mothurRemove(filename); }
 				
-				filename = m->getRootName(filename); filename = filename.substr(0, filename.length()-1); //rip off extra .
-				if (savedOutputDir == "") { filename = m->getSimpleName(filename); }
+				filename = util.getRootName(filename); filename = filename.substr(0, filename.length()-1); //rip off extra .
+				if (savedOutputDir == "") { filename = util.getSimpleName(filename); }
 				
 				variables["[filename]"] = filename;
                 outputNames.push_back(getOutputFileName("analysis", variables)); outputTypes["analysis"].push_back(getOutputFileName("analysis", variables));
                 outputNames.push_back(getOutputFileName("bestanalysis", variables)); outputTypes["bestanalysis"].push_back(getOutputFileName("bestanalysis", variables));
                 outputNames.push_back(getOutputFileName("models", variables)); outputTypes["models"].push_back(getOutputFileName("models", variables));
                 outputNames.push_back(getOutputFileName("bubble", variables)); outputTypes["bubble"].push_back(getOutputFileName("bubble", variables));
-                if (m->debug) { m->mothurOut("[DEBUG]: About to create summary file for: " + filename + ".\n[DEBUG]: sabund label = " + sabund->getLabel() + ".\n"); }
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: About to create summary file for: " + filename + ".\n[DEBUG]: sabund label = " + sabund->getLabel() + ".\n"); }
                 
 				createSummaryFile(filename + "_BestModelsAnalysis.csv", sabund->getLabel(), out);
                 
-                if (m->debug) { m->mothurOut("[DEBUG]: Done creating summary file.\n"); }
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: Done creating summary file.\n"); }
 				
 				delete sabund;
 			}
 			
 			out.close();
 			
-			if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {m->mothurRemove(outputNames[i]);	} return 0; }
+			if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {util.mothurRemove(outputNames[i]);	} return 0; }
 				
 		}
 		
 		if (sharedfile == "") {  
-			string summaryfilename = savedOutputDir + m->getRootName(m->getSimpleName(inputFileNames[0])) + "catchall.summary";
-			summaryfilename = m->getFullPathName(summaryfilename);
+			string summaryfilename = savedOutputDir + util.getRootName(util.getSimpleName(inputFileNames[0])) + "catchall.summary";
+			summaryfilename = util.getFullPathName(summaryfilename);
 			outputNames.push_back(summaryfilename); outputTypes["summary"].push_back(summaryfilename);
 		}else { //combine summaries
 			vector<string> sumNames;
 			for (int i = 0; i < inputFileNames.size(); i++) {
-				sumNames.push_back(m->getFullPathName(outputDir + m->getRootName(m->getSimpleName(inputFileNames[i])) + "catchall.summary"));
+				sumNames.push_back(util.getFullPathName(outputDir + util.getRootName(util.getSimpleName(inputFileNames[i])) + "catchall.summary"));
 			}
 			string summaryfilename = combineSummmary(sumNames);
 			outputNames.push_back(summaryfilename); outputTypes["summary"].push_back(summaryfilename);
 		}
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}	
 		m->mothurOutEndLine();
 		
@@ -530,27 +526,27 @@ int CatchAllCommand::execute() {
 string CatchAllCommand::process(SAbundVector* sabund, string file1) {
 	try {
         map<string, string> variables;
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(file1));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(file1));
         variables["[distance]"] = sabund->getLabel();
         string filename = getOutputFileName("sabund", variables);
-		filename = m->getFullPathName(filename);
+		filename = util.getFullPathName(filename);
 	
 		ofstream out;
-		m->openOutputFile(filename, out);
+		util.openOutputFile(filename, out);
 		
-        if (m->debug) { m->mothurOut("[DEBUG]: Creating " + filename + " file for catchall, shown below.\n\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: Creating " + filename + " file for catchall, shown below.\n\n"); }
         
 		for (int i = 1; i <= sabund->getMaxRank(); i++) {
 			int temp = sabund->get(i);
 			
 			if (temp != 0) {
 				out << i << "," << temp << endl;
-                if (m->debug) { m->mothurOut(toString(i) + "," + toString(temp) + "\n"); }
+                if (m->getDebug()) { m->mothurOut(toString(i) + "," + toString(temp) + "\n"); }
 			}
 		}
 		out.close();
         
-        if (m->debug) { m->mothurOut("[DEBUG]: Done creating " + filename + " file for catchall, shown above.\n\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: Done creating " + filename + " file for catchall, shown above.\n\n"); }
 		
 		return filename;
 	
@@ -566,11 +562,11 @@ string CatchAllCommand::combineSummmary(vector<string>& outputNames) {
 		
 		ofstream out;
         map<string, string> variables;
-        variables["[filename]"] = savedOutputDir + m->getRootName(m->getSimpleName(sharedfile));
+        variables["[filename]"] = savedOutputDir + util.getRootName(util.getSimpleName(sharedfile));
         string combineFileName = getOutputFileName("summary", variables);
 		
 		//open combined file
-		m->openOutputFile(combineFileName, out);
+		util.openOutputFile(combineFileName, out);
 		
 		out << "label\tgroup\tmodel\testimate\tlci\tuci" << endl;
 		
@@ -582,11 +578,11 @@ string CatchAllCommand::combineSummmary(vector<string>& outputNames) {
 			vector<string> thisFilesLines;
 			
 			ifstream temp;
-			m->openInputFile(outputNames[i], temp);
+			util.openInputFile(outputNames[i], temp);
 			
 			//read through first line - labels
-			m->getline(temp);			
-			m->gobble(temp);
+			util.getline(temp);			
+			util.gobble(temp);
 			
 			//for each label
 			while (!temp.eof()) {
@@ -598,7 +594,7 @@ string CatchAllCommand::combineSummmary(vector<string>& outputNames) {
 					temp >> tempLabel; 
 					
 					//save for later
-					if (j == 1) { thisLine += groups[i] + "\t" + tempLabel + "\t";	}
+					if (j == 1) { thisLine += Groups[i] + "\t" + tempLabel + "\t";	}
 					else{  thisLine += tempLabel + "\t";	}
 				}
 				
@@ -606,7 +602,7 @@ string CatchAllCommand::combineSummmary(vector<string>& outputNames) {
 				
 				thisFilesLines.push_back(thisLine);
 				
-				m->gobble(temp);
+				util.gobble(temp);
 			}
 			
 			files[outputNames[i]] = thisFilesLines;
@@ -614,7 +610,7 @@ string CatchAllCommand::combineSummmary(vector<string>& outputNames) {
 			numLines = thisFilesLines.size();
 			
 			temp.close();
-			m->mothurRemove(outputNames[i]);
+			util.mothurRemove(outputNames[i]);
 		}
 		
 		//for each label
@@ -643,13 +639,13 @@ int CatchAllCommand::createSummaryFile(string file1, string label, ofstream& out
 	try {
 		
 		ifstream in;
-		int able = m->openInputFile(file1, in, "noerror");
+		bool able = util.openInputFile(file1, in, "noerror");
 		
-		if (able == 1) {  m->mothurOut("[ERROR]: the catchall program did not run properly. Please check to make sure it is located in the same folder as your mothur executable.");m->mothurOutEndLine();  m->control_pressed = true; return 0; }
+		if (!able) {  m->mothurOut("[ERROR]: the catchall program did not run properly. Please check to make sure it is located in the same folder as your mothur executable.");m->mothurOutEndLine();  m->setControl_pressed(true);  return 0; }
 			
 		if (!in.eof()) {
 			
-			string header = m->getline(in); m->gobble(in);
+			string header = util.getline(in); util.gobble(in);
 			
 			int pos = header.find("Total Number of Observed Species =");
 			string numString = "";
@@ -672,16 +668,16 @@ int CatchAllCommand::createSummaryFile(string file1, string label, ofstream& out
 				}
 			}
 															  
-			string firstline = m->getline(in); m->gobble(in);
+			string firstline = util.getline(in); util.gobble(in);
 			vector<string> values;
-			m->splitAtComma(firstline, values);
+			util.splitAtComma(firstline, values);
 			
 			values.pop_back(); //last value is always a blank string since the last character in the line is always a ','
 			
 			if (values.size() == 1) { //grab next line if firstline didn't have what you wanted
-				string secondline = m->getline(in); m->gobble(in);
+				string secondline = util.getline(in); util.gobble(in);
 				values.clear();
-				m->splitAtComma(secondline, values);
+				util.splitAtComma(secondline, values);
 				
 				values.pop_back(); //last value is always a blank string since the last character in the line is always a ','
 			}
@@ -715,30 +711,29 @@ vector<string> CatchAllCommand::parseSharedFile(string filename) {
 		vector<string> filenames;
 		
 		//read first line
-		InputData input(filename, "sharedfile");
-		vector<SharedRAbundVector*> lookup = input.getSharedRAbundVectors();
-		
-		string sharedFileRoot = outputDir + m->getRootName(m->getSimpleName(filename));
+		InputData input(filename, "sharedfile", Groups);
+		SharedRAbundVectors* shared = input.getSharedRAbundVectors();
+        Groups = shared->getNamesGroups();
+		string sharedFileRoot = outputDir + util.getRootName(util.getSimpleName(filename));
 		
 		//clears file before we start to write to it below
-		for (int i=0; i<lookup.size(); i++) {
-			m->mothurRemove((sharedFileRoot + lookup[i]->getGroup() + ".sabund"));
-			filenames.push_back((sharedFileRoot + lookup[i]->getGroup() + ".sabund"));
-			groups.push_back(lookup[i]->getGroup());
+		for (int i=0; i<Groups.size(); i++) {
+			util.mothurRemove((sharedFileRoot + Groups[i] + ".sabund"));
+			filenames.push_back((sharedFileRoot + Groups[i] + ".sabund"));
 		}
-		
-		while(lookup[0] != NULL) {
-			
+    
+		while(shared != NULL) {
+            vector<SharedRAbundVector*> lookup = shared->getSharedRAbundVectors();
 			for (int i = 0; i < lookup.size(); i++) {
 				SAbundVector sav = lookup[i]->getSAbundVector();
 				ofstream out;
-				m->openOutputFileAppend(sharedFileRoot + lookup[i]->getGroup() + ".sabund", out);
+				util.openOutputFileAppend(sharedFileRoot + Groups[i] + ".sabund", out);
 				sav.print(out);
 				out.close();
 			}
 			
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
-			lookup = input.getSharedRAbundVectors();
+            for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) { delete lookup[i]; } lookup[i] = NULL; }
+			shared = input.getSharedRAbundVectors();
 		}
 		
 		return filenames;
