@@ -19,6 +19,7 @@
 #include "clusterdoturcommand.h"
 #include "opticluster.h"
 #include "optimatrix.h"
+#include "calculator.h"
 
 
 /* The cluster() command:
@@ -61,7 +62,7 @@ private:
 	string method, fileroot, tag, outputDir, phylipfile, columnfile, namefile, format, distfile, countfile, fastafile, inputDir, vsearchLocation, metric, initialize;
 	double cutoff, stableMetric;
     float adjust;
-	string showabund, timing;
+	string showabund, timing, metricName;
 	int precision, length, maxIters, processors;
 	ofstream sabundFile, rabundFile, listFile;
 
@@ -69,7 +70,7 @@ private:
 	time_t start;
 	unsigned long loops;
 	
-	void printData(string label, map<string, int>&);
+	void printData(string label, map<string, int>&, bool&);
 	vector<string> outputNames;
     
     int createRabund(CountTable*&, ListVector*&, RAbundVector*&);
@@ -77,6 +78,7 @@ private:
     int runVsearchCluster();
     int runOptiCluster();
     int runMothurCluster();
+    int runUniqueCluster();
 };
 
 #endif
