@@ -18,12 +18,13 @@
 #include "validparameter.h"
 #include "mothurout.h"
 #include "commandparameter.h"
-
+#include "currentfile.h"
+#include "utils.hpp"
 
 class Command {
 	
 	public:
-		Command() {  m = MothurOut::getInstance();   } 
+		Command() {  m = MothurOut::getInstance();  current = CurrentFile::getInstance(); }
 		
 		//needed by gui
 		virtual string getCommandName() = 0;
@@ -45,7 +46,7 @@ class Command {
                         
                         string patternTemp = getOutputPattern(type);
                         vector<string> patterns;
-                        m->splitAtDash(patternTemp, patterns);
+                        util.splitAtDash(patternTemp, patterns);
                         
                         //find pattern to use based on number of variables passed in
                         string pattern = "";
@@ -64,7 +65,7 @@ class Command {
                             for (int i = 0; i < numVariablesPerPattern.size(); i++) {
                                 if (numVariablesPerPattern[i] < variableParts.size()) { pattern = patterns[i]; foundPattern = true; break; }
                             }
-                            if (!foundPattern) {  m->mothurOut("[ERROR]: Not enough variable pieces for " + type + ".\n"); m->control_pressed = true; }
+                            if (!foundPattern) {  m->mothurOut("[ERROR]: Not enough variable pieces for " + type + ".\n"); m->setControl_pressed(true); }
                         }
                         
                         if (pattern != "") {
@@ -72,14 +73,14 @@ class Command {
                             for (int i = 0; i < pattern.length(); i++) { if (pattern[i] == '[') { numVariables++; } }
                             
                             vector<string> pieces;
-                            m->splitAtComma(pattern, pieces);
+                            util.splitAtComma(pattern, pieces);
                             
                         
                             for (int i = 0; i < pieces.size(); i++) {
                                 if (pieces[i][0] == '[') {
                                     map<string, string>::iterator it = variableParts.find(pieces[i]);
                                     if (it == variableParts.end()) {
-                                        m->mothurOut("[ERROR]: Did not provide variable for " + pieces[i] + ".\n"); m->control_pressed = true;
+                                        m->mothurOut("[ERROR]: Did not provide variable for " + pieces[i] + ".\n"); m->setControl_pressed(true);
                                     }else {
                                         if (it->second != "") {
                                             if (it->first == "[filename]") { filename += it->second; }
@@ -125,6 +126,8 @@ class Command {
 	
 	protected:
 		MothurOut* m;
+        Utils util;
+        CurrentFile* current;
 		bool calledHelp;
 			
 		map<string, vector<string> > outputTypes;
