@@ -43,7 +43,6 @@ string CooccurrenceCommand::getHelpString(){
         helpString += "The cooccurrence command should be in the following format: \n";
 		helpString += "cooccurrence(shared=yourSharedFile) \n";
 		helpString += "Example cooccurrence(shared=final.an.shared).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. shared), '=' and parameters (i.e.yourShared).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -57,7 +56,7 @@ string CooccurrenceCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "summary") {  pattern = "[filename],cooccurence.summary"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -106,14 +105,14 @@ CooccurrenceCommand::CooccurrenceCommand(string option) {
 
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -124,49 +123,49 @@ CooccurrenceCommand::CooccurrenceCommand(string option) {
 		
 	        //check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
 			//get shared file
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { 
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}else { m->setSharedFile(sharedfile); }
+			}else { current->setSharedFile(sharedfile); }
 			
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(sharedfile);		}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(sharedfile);		}
 
 			
-			metric = validParameter.validFile(parameters, "metric", false);				if (metric == "not found") { metric = "cscore"; }
+			metric = validParameter.validFile(parameters, "metric");				if (metric == "not found") { metric = "cscore"; }
 			
 			if ((metric != "cscore") && (metric != "checker") && (metric != "combo") && (metric != "vratio")) {
 				m->mothurOut("[ERROR]: " + metric + " is not a valid metric option for the cooccurrence command. Choices are cscore, checker, combo, vratio."); m->mothurOutEndLine(); abort = true; 
 			}
 			
-			matrix = validParameter.validFile(parameters, "matrixmodel", false);				if (matrix == "not found") { matrix = "sim2"; }
+			matrix = validParameter.valid(parameters, "matrixmodel");				if (matrix == "not found") { matrix = "sim2"; }
 			
 			if ((matrix != "sim1") && (matrix != "sim2") && (matrix != "sim3") && (matrix != "sim4") && (matrix != "sim5" ) && (matrix != "sim6" ) && (matrix != "sim7" ) && (matrix != "sim8" ) && (matrix != "sim9" )) {
 				m->mothurOut("[ERROR]: " + matrix + " is not a valid matrix option for the cooccurrence command. Choices are sim1, sim2, sim3, sim4, sim5, sim6, sim7, sim8, sim9."); m->mothurOutEndLine(); abort = true; 
 			}
             
-            groups = validParameter.validFile(parameters, "groups", false);			
+            groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = "";   }
 			else { 
-				m->splitAtDash(groups, Groups);	
-			}			
-			m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
+			}
             
-            string temp = validParameter.validFile(parameters, "iters", false);			if (temp == "not found") { temp = "1000"; }
-			m->mothurConvert(temp, runs); 
+            string temp = validParameter.valid(parameters, "iters");			if (temp == "not found") { temp = "1000"; }
+			util.mothurConvert(temp, runs); 
 
 		}
 
@@ -181,11 +180,12 @@ CooccurrenceCommand::CooccurrenceCommand(string option) {
 int CooccurrenceCommand::execute(){
 	try {
 	
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-		InputData* input = new InputData(sharedfile, "sharedfile");
-		vector<SharedRAbundVector*> lookup = input->getSharedRAbundVectors();
-		string lastLabel = lookup[0]->getLabel();
+		InputData input(sharedfile, "sharedfile", Groups);
+		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+        Groups = lookup->getNamesGroups();
+		string lastLabel = lookup->getLabel();
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		set<string> processedLabels;
@@ -193,88 +193,78 @@ int CooccurrenceCommand::execute(){
 
         ofstream out;
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(sharedfile));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
 		string outputFileName = getOutputFileName("summary", variables);
-        m->openOutputFile(outputFileName, out);
+        util.openOutputFile(outputFileName, out);
         outputNames.push_back(outputFileName);  outputTypes["summary"].push_back(outputFileName);
         out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
         out << "metric\tlabel\tScore\tzScore\tstandardDeviation\tnp_Pvalue\n";
 
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } delete input; out.close(); m->mothurRemove(outputFileName); return 0; }
+            if (m->getControl_pressed()) { delete lookup; out.close(); util.mothurRemove(outputFileName); return 0; }
 	
-			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
+			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
 
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				
 				getCooccurrence(lookup, out);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 			}
 			
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 			
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  
-				lookup = input->getSharedRAbundVectors(lastLabel);
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				delete lookup;
+				lookup = input.getSharedRAbundVectors(lastLabel);
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				getCooccurrence(lookup, out);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 			}
 			
-			lastLabel = lookup[0]->getLabel();
-			//prevent memory leak
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }
+			lastLabel = lookup->getLabel();
+			delete lookup;
 			
-			if (m->control_pressed) {  outputTypes.clear(); delete input; out.close(); m->mothurRemove(outputFileName); return 0; }
+			if (m->getControl_pressed()) {  outputTypes.clear(); out.close(); util.mothurRemove(outputFileName); return 0; }
 
 			//get next line to process
-			lookup = input->getSharedRAbundVectors();				
+			lookup = input.getSharedRAbundVectors();
 		}
 		
-		if (m->control_pressed) { delete input; out.close(); m->mothurRemove(outputFileName); return 0; }
+		if (m->getControl_pressed()) { out.close(); util.mothurRemove(outputFileName); return 0; }
 
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 	
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) { if (lookup[i] != NULL) { delete lookup[i]; } }  
-			lookup = input->getSharedRAbundVectors(lastLabel);
+		if (needToRun )  {
+			delete lookup;
+			lookup = input.getSharedRAbundVectors(lastLabel);
 			
-			m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+			m->mothurOut(lookup->getLabel()+"\n"); 
 			
 			getCooccurrence(lookup, out);
 			
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+			delete lookup;
 		}
 	
         out.close(); 
         
-		//reset groups parameter 
-		delete input; 
-        m->clearGroups(); 
+		//reset groups parameter
+         
 
-        m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+        m->mothurOut("\nOutput File Names: \n"); 
 		m->mothurOut(outputFileName); m->mothurOutEndLine();	
 		m->mothurOutEndLine();
         
@@ -287,25 +277,27 @@ int CooccurrenceCommand::execute(){
 }
 //**********************************************************************************************************************
 
-int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp, ofstream& out){
+int CooccurrenceCommand::getCooccurrence(SharedRAbundVectors*& thisLookUp, ofstream& out){
     try {
-        int numOTUS = thisLookUp[0]->getNumBins();
+        int numOTUS = thisLookUp->getNumBins();
         
         if(numOTUS < 2) {
             m->mothurOut("Not enough OTUs for co-occurrence analysis, skipping"); m->mothurOutEndLine();
             return 0;
         }
         
-        vector< vector<int> > co_matrix; co_matrix.resize(thisLookUp[0]->getNumBins());
-        for (int i = 0; i < thisLookUp[0]->getNumBins(); i++) { co_matrix[i].resize((thisLookUp.size()), 0); }
-        vector<int> columntotal; columntotal.resize(thisLookUp.size(), 0);
+        vector< vector<int> > co_matrix; co_matrix.resize(thisLookUp->getNumBins());
+        for (int i = 0; i < thisLookUp->getNumBins(); i++) { co_matrix[i].resize((thisLookUp->size()), 0); }
+        vector<int> columntotal; columntotal.resize(thisLookUp->size(), 0);
         vector<int> rowtotal; rowtotal.resize(numOTUS, 0);
         
-        for (int i = 0; i < thisLookUp.size(); i++) { //nrows in the shared file
-            for (int j = 0; j < thisLookUp[i]->getNumBins(); j++) { //cols of original shared file
-                if (m->control_pressed) { return 0; }
-                int abund = thisLookUp[i]->getAbundance(j);
-                
+        for (int j = 0; j < thisLookUp->getNumBins(); j++) { //cols of original shared file
+            vector<int> abunds = thisLookUp->getOTU(j);
+        for (int i = 0; i < abunds.size(); i++) { //nrows in the shared file
+            
+                if (m->getControl_pressed()) { return 0; }
+            int abund = abunds[i];
+            
                 if(abund > 0) {
                     co_matrix[j][i] = 1;
                     rowtotal[j]++;
@@ -314,10 +306,11 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
             }
         }
         
+        
         //nrows is ncols of inital matrix. All the functions need this value. They assume the transposition has already taken place and nrows and ncols refer to that matrix.
         //comatrix and initmatrix are still vectors of vectors of ints as in the original script. The abundancevector is only what was read in ie not a co-occurrence matrix!
         int nrows = numOTUS;//rows of inital matrix
-        int ncols = thisLookUp.size();//groups
+        int ncols = thisLookUp->size();//groups
         double initscore = 0.0;
        
         vector<double> stats;
@@ -412,7 +405,7 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
         else if (matrix == "sim9" || matrix == "sim2") { }
         else {
             m->mothurOut("[ERROR]: No model selected! \n");
-            m->control_pressed = true;
+            m->setControl_pressed(true);
         }
         
         
@@ -421,7 +414,7 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
         else if (metric == "checker") { initscore = trial.calc_checker(co_matrix, rowtotal, ncols, nrows); }
         else if (metric == "vratio") { initscore = trial.calc_vratio(nrows, ncols, rowtotal, columntotal); }
         else if (metric == "combo") { initscore = trial.calc_combo(nrows, ncols, co_matrix); }
-        else { m->mothurOut("[ERROR]: No metric selected!\n"); m->control_pressed = true; return 1; }
+        else { m->mothurOut("[ERROR]: No metric selected!\n"); m->setControl_pressed(true); return 1; }
         
         m->mothurOut("Initial c score: " + toString(initscore)); m->mothurOutEndLine();
         
@@ -444,10 +437,10 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
             if(matrix == "sim1" || matrix == "sim6" || matrix == "sim8" || matrix == "sim7") {
                 count = 0;
                 while(count < n) {
-                    if (m->control_pressed) { return 0; }
+                    if (m->getControl_pressed()) { return 0; }
                 nextnum2:
                     previous = 0.0;
-                    randnum = m->getRandomDouble0to1();
+                    randnum = util.getRandomDouble0to1();
                     for(int i=0;i<nrows;i++) {
                         for(int j=0;j<ncols;j++) {
                             current = probabilityMatrix[ncols * i + j];
@@ -466,7 +459,7 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
             
             else if (matrix == "sim2") {
                 for(int i=0;i<nrows;i++) {
-                    m->mothurRandomShuffle(co_matrix[i]);
+                    util.mothurRandomShuffle(co_matrix[i]);
                 }
                 //do this for the scoring since those all have nullmatrix as a parameter
                 //nullmatrix gets cleared at the begining of each run
@@ -478,8 +471,8 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
                     count = 0;
                     while(count < rowtotal[i]) {
                         previous = 0.0;
-                        if (m->control_pressed) { return 0; }
-                        randnum = m->getRandomDouble0to1();
+                        if (m->getControl_pressed()) { return 0; }
+                        randnum = util.getRandomDouble0to1();
                         for(int j=0;j<ncols;j++) {
                             current = probabilityMatrix[ncols * i + j];
                             if(randnum <= current && randnum > previous && nullmatrix[i][j] != 1) {
@@ -499,8 +492,8 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
                 for(int j=0;j<ncols;j++) {
                     count = 0;
                     while(count < columntotal[j]) {
-                        if (m->control_pressed) { return 0; }
-                        randnum = m->getRandomDouble0to1();
+                        if (m->getControl_pressed()) { return 0; }
+                        randnum = util.getRandomDouble0to1();
                         for(int i=0;i<nrows;i++) {
                             current = probabilityMatrix[ncols * i + j];
                             if(randnum <= current && randnum > previous && nullmatrix[i][j] != 1) {
@@ -521,7 +514,7 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
                 nullmatrix = co_matrix;
             }
             else {
-                m->mothurOut("[ERROR]: No null model selected!\n\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: No null model selected!\n\n"); m->setControl_pressed(true);
                 return 1;
             }
             
@@ -539,7 +532,7 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
                 stats.push_back(trial.calc_combo(nrows, ncols, nullmatrix));
             }
             else {
-                m->mothurOut("[ERROR]: No metric selected!\n\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: No metric selected!\n\n"); m->setControl_pressed(true);
                 return 1;
             }
             
@@ -568,7 +561,7 @@ int CooccurrenceCommand::getCooccurrence(vector<SharedRAbundVector*>& thisLookUp
         m->mothurOut("zscore: " + toString(zscore)); m->mothurOutEndLine();
         m->mothurOut("standard deviation: " + toString(sd)); m->mothurOutEndLine();
         m->mothurOut("non-parametric p-value: " + toString(pvalue)); m->mothurOutEndLine();
-        out << metric << '\t' << thisLookUp[0]->getLabel() << '\t' << nullMean << '\t' << zscore << '\t' << sd << '\t' << pvalue << endl;
+        out << metric << '\t' << thisLookUp->getLabel() << '\t' << nullMean << '\t' << zscore << '\t' << sd << '\t' << pvalue << endl;
         
         return 0;
     }
