@@ -8,7 +8,7 @@
  */
 
 #include "corraxescommand.h"
-#include "sharedutilities.h"
+
 #include "linearalgebra.h"
 
 //**********************************************************************************************************************
@@ -48,7 +48,7 @@ string CorrAxesCommand::getHelpString(){
 		helpString += "The corr.axes command should be in the following format: corr.axes(axes=yourPcoaFile, shared=yourSharedFile, method=yourMethod).\n";
 		helpString += "Example corr.axes(axes=genus.pool.thetayc.genus.lt.pcoa, shared=genus.pool.shared, method=kendall).\n";
 		helpString += "The corr.axes command outputs a .corr.axes file.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. groups), '=' and parameters (i.e.yourGroups).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -62,7 +62,7 @@ string CorrAxesCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "corraxes") {  pattern = "[filename],[tag],corr.axes"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -112,14 +112,14 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 			outputTypes["corraxes"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("axes");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["axes"] = inputDir + it->second;		}
 				}
@@ -127,7 +127,7 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -135,7 +135,7 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 				it = parameters.find("relabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["relabund"] = inputDir + it->second;		}
 				}
@@ -143,7 +143,7 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 				it = parameters.find("metadata");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["metadata"] = inputDir + it->second;		}
 				}
@@ -151,46 +151,46 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 			
 			
 			//check for required parameters
-			axesfile = validParameter.validFile(parameters, "axes", true);
+			axesfile = validParameter.validFile(parameters, "axes");
 			if (axesfile == "not open") { abort = true; }
 			else if (axesfile == "not found") { axesfile = ""; m->mothurOut("axes is a required parameter for the corr.axes command."); m->mothurOutEndLine(); abort = true;  }	
 			
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { abort = true; }
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else { inputFileName = sharedfile; m->setSharedFile(sharedfile); }
+			else { inputFileName = sharedfile; current->setSharedFile(sharedfile); }
 			
-			relabundfile = validParameter.validFile(parameters, "relabund", true);
+			relabundfile = validParameter.validFile(parameters, "relabund");
 			if (relabundfile == "not open") { abort = true; }
 			else if (relabundfile == "not found") { relabundfile = ""; }
-			else { inputFileName = relabundfile; m->setRelAbundFile(relabundfile); }
+			else { inputFileName = relabundfile; current->setRelAbundFile(relabundfile); }
 			
-			metadatafile = validParameter.validFile(parameters, "metadata", true);
+			metadatafile = validParameter.validFile(parameters, "metadata");
 			if (metadatafile == "not open") { abort = true; }
 			else if (metadatafile == "not found") { metadatafile = ""; }
 			else { inputFileName = metadatafile; }
 			
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = "";  pickedGroups = false;  }
 			else { 
 				pickedGroups = true;
-				m->splitAtDash(groups, Groups);	
+				util.splitAtDash(groups, Groups);
+                    if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }	
 			}			
-			m->setGroups(Groups);
 			
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(inputFileName);	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputFileName);	}
 			
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; m->mothurOut("You did not provide a label, I will use the first label in your inputfile."); m->mothurOutEndLine(); label=""; }	
 			
 			if ((relabundfile == "") && (sharedfile == "") && (metadatafile == "")) { 
 				//is there are current file available for any of these?
 				//give priority to shared, then relabund
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") { inputFileName = sharedfile; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
-					relabundfile = m->getRelAbundFile(); 
+					relabundfile = current->getRelAbundFile(); 
 					if (relabundfile != "") { inputFileName = relabundfile;  m->mothurOut("Using " + relabundfile + " as input file for the relabund parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("You must provide either a shared, relabund, or metadata file."); m->mothurOutEndLine(); abort = true; 
@@ -204,10 +204,10 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 				if ((relabundfile != "") && (sharedfile != "")) { m->mothurOut("You may only use one of the following : shared, relabund or metadata file."); m->mothurOutEndLine(); abort = true;  }
 			}
 			string temp;
-			temp = validParameter.validFile(parameters, "numaxes", false);		if (temp == "not found"){	temp = "3";				}
-			m->mothurConvert(temp, numaxes); 
+			temp = validParameter.valid(parameters, "numaxes");		if (temp == "not found"){	temp = "3";				}
+			util.mothurConvert(temp, numaxes); 
 			
-			method = validParameter.validFile(parameters, "method", false);		if (method == "not found"){	method = "pearson";		}
+			method = validParameter.valid(parameters, "method");		if (method == "not found"){	method = "pearson";		}
 			
 			if ((method != "pearson") && (method != "spearman") && (method != "kendall")) { m->mothurOut(method + " is not a valid method. Valid methods are pearson, spearman, and kendall."); m->mothurOutEndLine(); abort = true; }
 			
@@ -223,40 +223,38 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 int CorrAxesCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		/*************************************************************************************/
 		// use smart distancing to get right sharedRabund and convert to relabund if needed  //
 		/************************************************************************************/
 		if (sharedfile != "") {  
-			InputData* input = new InputData(sharedfile, "sharedfile");
+			InputData* input = new InputData(sharedfile, "sharedfile", Groups);
 			getSharedFloat(input); 
 			delete input;
 			
-			if (m->control_pressed) {  for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } return 0; }
-			if (lookupFloat[0] == NULL) { m->mothurOut("[ERROR] reading relabund file."); m->mothurOutEndLine(); return 0; }
+            if (m->getControl_pressed()) {  delete lookupFloat; return 0; }
+			if (lookupFloat == NULL) { m->mothurOut("[ERROR] reading relabund file."); m->mothurOutEndLine(); return 0; }
 			
 		}else if (relabundfile != "") { 
-			InputData* input = new InputData(relabundfile, "relabund");
+			InputData* input = new InputData(relabundfile, "relabund", Groups);
 			getSharedFloat(input); 
 			delete input;
 			
-			if (m->control_pressed) {  for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } return 0; }
-			if (lookupFloat[0] == NULL) { m->mothurOut("[ERROR] reading relabund file."); m->mothurOutEndLine(); return 0; }
+			if (m->getControl_pressed()) {  delete lookupFloat; return 0; }
+			if (lookupFloat == NULL) { m->mothurOut("[ERROR] reading relabund file."); m->mothurOutEndLine(); return 0; }
 			
 		}else if (metadatafile != "") { 
 			getMetadata();  //reads metadata file and store in lookupFloat, saves column headings in metadataLabels for later
-			if (m->control_pressed) {  for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } return 0; }
-			if (lookupFloat[0] == NULL) { m->mothurOut("[ERROR] reading metadata file."); m->mothurOutEndLine(); return 0; }
-			
-			if (pickedGroups) { eliminateZeroOTUS(lookupFloat); }
-			
+			if (m->getControl_pressed()) {  delete lookupFloat; return 0; }
+			if (lookupFloat == NULL) { m->mothurOut("[ERROR] reading metadata file."); m->mothurOutEndLine(); return 0; }
 		}else {	m->mothurOut("[ERROR]: no file given."); m->mothurOutEndLine(); return 0; }
 		
-		if (m->control_pressed) {  for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } return 0; }
+		if (m->getControl_pressed()) {  delete lookupFloat; return 0; }
 		
 		//this is for a sanity check to make sure the axes file and shared file match
-		for (int i = 0; i < lookupFloat.size(); i++) { names.insert(lookupFloat[i]->getGroup()); }
+        vector<string> lookupGroups = lookupFloat->getNamesGroups();
+        for (int i = 0; i < lookupGroups.size(); i++) { names.insert(lookupGroups[i]); }
 		
 		/*************************************************************************************/
 		// read axes file and check for file mismatches with shared or relabund file         //
@@ -265,30 +263,30 @@ int CorrAxesCommand::execute(){
 		//read axes file
 		map<string, vector<float> > axes = readAxes();
 		
-		if (m->control_pressed) {  for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } return 0; }
+		if (m->getControl_pressed()) {  delete lookupFloat; return 0; }
 		
 		//sanity check, the read only adds groups that are in the shared or relabund file, but we want to make sure the axes file isn't missing anyone
-		if (axes.size() != lookupFloat.size()) { 
+		if (axes.size() != lookupGroups.size()) {
 			map<string, vector<float> >::iterator it;
-			for (int i = 0; i < lookupFloat.size(); i++) {
-				it = axes.find(lookupFloat[i]->getGroup());
-				if (it == axes.end()) { m->mothurOut(lookupFloat[i]->getGroup() + " is in your shared of relabund file but not in your axes file, please correct."); m->mothurOutEndLine(); }
+			for (int i = 0; i < lookupGroups.size(); i++) {
+				it = axes.find(lookupGroups[i]);
+				if (it == axes.end()) { m->mothurOut(lookupGroups[i] + " is in your shared of relabund file but not in your axes file, please correct."); m->mothurOutEndLine(); }
 			}
-			m->control_pressed = true;
+			m->setControl_pressed(true);
 		}
 		
-		if (m->control_pressed) {  for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } return 0; }
+		if (m->getControl_pressed()) {  delete lookupFloat; return 0; }
 		
 		/*************************************************************************************/
 		// calc the r values																//
 		/************************************************************************************/
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileName));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileName));
         variables["[tag]"] = method;
 		string outputFileName = getOutputFileName("corraxes", variables);
 		outputNames.push_back(outputFileName); outputTypes["corraxes"].push_back(outputFileName);	
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
 		
 		//output headings
@@ -304,14 +302,12 @@ int CorrAxesCommand::execute(){
 		else { m->mothurOut("[ERROR]: Invalid method."); m->mothurOutEndLine(); }
 		
 		out.close();
-		for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  }
+		delete lookupFloat;
 		
-		if (m->control_pressed) {  return 0; }
+		if (m->getControl_pressed()) {  return 0; }
 
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 	}
@@ -325,6 +321,7 @@ int CorrAxesCommand::calcPearson(map<string, vector<float> >& axes, ofstream& ou
    try {
 	   
        LinearAlgebra linear;
+       vector<string> lookupGroups = lookupFloat->getNamesGroups();
        
 	   //find average of each axis - X
 	   vector<float> averageAxes; averageAxes.resize(numaxes, 0.0);
@@ -337,18 +334,16 @@ int CorrAxesCommand::calcPearson(map<string, vector<float> >& axes, ofstream& ou
 	   
 	   for (int i = 0; i < averageAxes.size(); i++) {  averageAxes[i] = averageAxes[i] / (float) axes.size(); }
 	   
+       vector<string> currentLabels = lookupFloat->getOTUNames();
 	   //for each otu
-	   for (int i = 0; i < lookupFloat[0]->getNumBins(); i++) {
+	   for (int i = 0; i < lookupFloat->getNumBins(); i++) {
 		   
-		   if (metadatafile == "") {  out << m->currentSharedBinLabels[i];	}
+		   if (metadatafile == "") {  out << currentLabels[i];	}
 		   else {  out << metadataLabels[i];		}
 		   		   
 		   //find the averages this otu - Y
-		   float sumOtu = 0.0;
-		   for (int j = 0; j < lookupFloat.size(); j++) {
-			   sumOtu += lookupFloat[j]->getAbundance(i);
-		   }
-		   float Ybar = sumOtu / (float) lookupFloat.size();
+		   float sumOtu = lookupFloat->getOTUTotal(i);
+		   float Ybar = sumOtu / (float) lookupFloat->size();
 		   
 		   vector<float> rValues(averageAxes.size());
 
@@ -359,9 +354,9 @@ int CorrAxesCommand::calcPearson(map<string, vector<float> >& axes, ofstream& ou
 			   double numerator = 0.0;
 			   double denomTerm1 = 0.0;
 			   double denomTerm2 = 0.0;
-			   for (int j = 0; j < lookupFloat.size(); j++) {
-				   float Yi = lookupFloat[j]->getAbundance(i);
-				   float Xi = axes[lookupFloat[j]->getGroup()][k];
+			   for (int j = 0; j < lookupFloat->size(); j++) {
+				   float Yi = lookupFloat->get(i, lookupGroups[j]);
+				   float Xi = axes[lookupGroups[j]][k];
 				   
 				   numerator += ((Xi - averageAxes[k]) * (Yi - Ybar));
 				   denomTerm1 += ((Xi - averageAxes[k]) * (Xi - averageAxes[k]));
@@ -377,7 +372,7 @@ int CorrAxesCommand::calcPearson(map<string, vector<float> >& axes, ofstream& ou
 			   rValues[k] = r;
 			   out << '\t' << r; 
                
-               double sig = linear.calcPearsonSig(lookupFloat.size(), r);
+               double sig = linear.calcPearsonSig(lookupFloat->size(), r);
                
                out << '\t' << sig;
 		   }
@@ -401,6 +396,7 @@ int CorrAxesCommand::calcSpearman(map<string, vector<float> >& axes, ofstream& o
 	try {
 		
         LinearAlgebra linear;
+        vector<string> lookupGroups = lookupFloat->getNamesGroups();
         vector<double> sf; 
         
 		//format data
@@ -471,18 +467,19 @@ int CorrAxesCommand::calcSpearman(map<string, vector<float> >& axes, ofstream& o
             sf.push_back(sfTemp);
 		}
 		
-				
+		vector<string> currentLabels = lookupFloat->getOTUNames();
+        
 		//for each otu
-		for (int i = 0; i < lookupFloat[0]->getNumBins(); i++) {
+		for (int i = 0; i < lookupFloat->getNumBins(); i++) {
 			
-			if (metadatafile == "") {  out << m->currentSharedBinLabels[i];	}
+			if (metadatafile == "") {  out << currentLabels[i];	}
 			else {  out << metadataLabels[i];		}
 			
 			//find the ranks of this otu - Y
 			vector<spearmanRank> otuScores;
 			map<float, int> tableY;
-			for (int j = 0; j < lookupFloat.size(); j++) {
-				spearmanRank member(lookupFloat[j]->getGroup(), lookupFloat[j]->getAbundance(i));
+			for (int j = 0; j < lookupFloat->size(); j++) {
+				spearmanRank member(lookupGroups[j], lookupFloat->get(i, lookupGroups[j]));
 				otuScores.push_back(member);
 				
 				itTable = tableY.find(member.score);
@@ -537,17 +534,17 @@ int CorrAxesCommand::calcSpearman(map<string, vector<float> >& axes, ofstream& o
 			for (int j = 0; j < numaxes; j++) {
 				
 				double di = 0.0;
-				for (int k = 0; k < lookupFloat.size(); k++) {
+				for (int k = 0; k < lookupFloat->size(); k++) {
 					
-					float xi = rankAxes[lookupFloat[k]->getGroup()][j];
-					float yi = rankOtus[lookupFloat[k]->getGroup()];
+					float xi = rankAxes[lookupGroups[k]][j];
+					float yi = rankOtus[lookupGroups[k]];
 					
 					di += ((xi - yi) * (xi - yi));
 				}
 				
 				double p = 0.0;
 				
-				double n = (double) lookupFloat.size();
+				double n = (double) lookupFloat->size();
 				
 				double SX2 = ((pow(n, 3.0) - n) / 12.0) - Lx[j];
 				double SY2 = ((pow(n, 3.0) - n) / 12.0) - Ly;
@@ -584,6 +581,7 @@ int CorrAxesCommand::calcKendall(map<string, vector<float> >& axes, ofstream& ou
 	try {
 		
         LinearAlgebra linear;
+        vector<string> lookupGroups = lookupFloat->getNamesGroups();
         
 		//format data
 		vector< vector<spearmanRank> > scores; scores.resize(numaxes);
@@ -625,16 +623,18 @@ int CorrAxesCommand::calcKendall(map<string, vector<float> >& axes, ofstream& ou
 			}
 		}
 		
+        vector<string> currentLabels = lookupFloat->getOTUNames();
+        
 		//for each otu
-		for (int i = 0; i < lookupFloat[0]->getNumBins(); i++) {
+		for (int i = 0; i < lookupFloat->getNumBins(); i++) {
 		
-			if (metadatafile == "") {  out << m->currentSharedBinLabels[i];	}
+			if (metadatafile == "") {  out << currentLabels[i];	}
 			else {  out << metadataLabels[i];		}
 			
 			//find the ranks of this otu - Y
 			vector<spearmanRank> otuScores;
-			for (int j = 0; j < lookupFloat.size(); j++) {
-				spearmanRank member(lookupFloat[j]->getGroup(), lookupFloat[j]->getAbundance(i));
+			for (int j = 0; j < lookupFloat->size(); j++) {
+				spearmanRank member(lookupGroups[j], lookupFloat->get(i, lookupGroups[j]));
 				otuScores.push_back(member);
 			}
 						
@@ -726,7 +726,7 @@ int CorrAxesCommand::calcKendall(map<string, vector<float> >& axes, ofstream& ou
 int CorrAxesCommand::getSharedFloat(InputData* input){
 	try {
 		lookupFloat = input->getSharedRAbundFloatVectors();
-		string lastLabel = lookupFloat[0]->getLabel();
+		string lastLabel = lookupFloat->getLabel();
 		
 		if (label == "") { label = lastLabel;  return 0; }
 		
@@ -736,58 +736,53 @@ int CorrAxesCommand::getSharedFloat(InputData* input){
 		set<string> userLabels = labels;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookupFloat[0] != NULL) && (userLabels.size() != 0)) {
+		while((lookupFloat != NULL) && (userLabels.size() != 0)) {
 			
-			if (m->control_pressed) {  return 0;  }
+			if (m->getControl_pressed()) {  return 0;  }
 			
-			if(labels.count(lookupFloat[0]->getLabel()) == 1){
-				processedLabels.insert(lookupFloat[0]->getLabel());
-				userLabels.erase(lookupFloat[0]->getLabel());
+			if(labels.count(lookupFloat->getLabel()) == 1){
+				processedLabels.insert(lookupFloat->getLabel());
+				userLabels.erase(lookupFloat->getLabel());
 				break;
 			}
 			
-			if ((m->anyLabelsToProcess(lookupFloat[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookupFloat[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookupFloat->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookupFloat->getLabel();
 				
-				for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } 
+				delete lookupFloat;
 				lookupFloat = input->getSharedRAbundFloatVectors(lastLabel);
 				
-				processedLabels.insert(lookupFloat[0]->getLabel());
-				userLabels.erase(lookupFloat[0]->getLabel());
+				processedLabels.insert(lookupFloat->getLabel());
+				userLabels.erase(lookupFloat->getLabel());
 				
 				//restore real lastlabel to save below
-				lookupFloat[0]->setLabel(saveLabel);
+				lookupFloat->setLabels(saveLabel);
 				break;
 			}
 			
-			lastLabel = lookupFloat[0]->getLabel();			
+			lastLabel = lookupFloat->getLabel();
 			
 			//get next line to process
 			//prevent memory leak
-			for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  } 
+			delete lookupFloat;
 			lookupFloat = input->getSharedRAbundFloatVectors();
 		}
 		
 		
-		if (m->control_pressed) { return 0;  }
+		if (m->getControl_pressed()) { return 0;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookupFloat.size(); i++) {  if (lookupFloat[i] != NULL) {	delete lookupFloat[i];	} } 
-			lookupFloat = input->getSharedRAbundFloatVectors(lastLabel);
+		if (needToRun )  {
+            delete lookupFloat;
+			lookupFloat = input->getSharedRAbundFloatVectors();
 		}	
 		
 		return 0;
@@ -797,72 +792,15 @@ int CorrAxesCommand::getSharedFloat(InputData* input){
 		exit(1);
 	}
 }
-//**********************************************************************************************************************
-int CorrAxesCommand::eliminateZeroOTUS(vector<SharedRAbundFloatVector*>& thislookup) {
-	try {
-		
-		vector<SharedRAbundFloatVector*> newLookup;
-		for (int i = 0; i < thislookup.size(); i++) {
-			SharedRAbundFloatVector* temp = new SharedRAbundFloatVector();
-			temp->setLabel(thislookup[i]->getLabel());
-			temp->setGroup(thislookup[i]->getGroup());
-			newLookup.push_back(temp);
-		}
-		
-		//for each bin
-		vector<string> newBinLabels;
-		string snumBins = toString(thislookup[0]->getNumBins());
-		for (int i = 0; i < thislookup[0]->getNumBins(); i++) {
-			if (m->control_pressed) { for (int j = 0; j < newLookup.size(); j++) {  delete newLookup[j];  } return 0; }
-			
-			//look at each sharedRabund and make sure they are not all zero
-			bool allZero = true;
-			for (int j = 0; j < thislookup.size(); j++) {
-				if (thislookup[j]->getAbundance(i) != 0) { allZero = false;  break;  }
-			}
-			
-			//if they are not all zero add this bin
-			if (!allZero) {
-				for (int j = 0; j < thislookup.size(); j++) {
-					newLookup[j]->push_back(thislookup[j]->getAbundance(i), thislookup[j]->getGroup());
-				}
-				
-				//if there is a bin label use it otherwise make one
-				string binLabel = "Otu";
-				string sbinNumber = toString(i+1);
-				if (sbinNumber.length() < snumBins.length()) { 
-					int diff = snumBins.length() - sbinNumber.length();
-					for (int h = 0; h < diff; h++) { binLabel += "0"; }
-				}
-				binLabel += sbinNumber; 
-				if (i < m->currentSharedBinLabels.size()) {  binLabel = m->currentSharedBinLabels[i]; }
-				
-				newBinLabels.push_back(binLabel);
-			}
-		}
-		
-		for (int j = 0; j < thislookup.size(); j++) {  delete thislookup[j];  }
-		
-		thislookup = newLookup;
-		m->currentSharedBinLabels = newBinLabels;
-		
-		return 0;
-		
-	}
-	catch(exception& e) {
-		m->errorOut(e, "CorrAxesCommand", "eliminateZeroOTUS");
-		exit(1);
-	}
-}
 /*****************************************************************/
 map<string, vector<float> > CorrAxesCommand::readAxes(){
 	try {
 		map<string, vector<float> > axes;
 		
 		ifstream in;
-		m->openInputFile(axesfile, in);
+		util.openInputFile(axesfile, in);
 		
-		string headerLine = m->getline(in); m->gobble(in);
+		string headerLine = util.getline(in); util.gobble(in);
 		
 		//count the number of axis you are reading
 		bool done = false;
@@ -879,10 +817,10 @@ map<string, vector<float> > CorrAxesCommand::readAxes(){
 		
 		while (!in.eof()) {
 			
-			if (m->control_pressed) { in.close(); return axes; }
+			if (m->getControl_pressed()) { in.close(); return axes; }
 			
 			string group = "";
-			in >> group; m->gobble(in);
+			in >> group; util.gobble(in);
 			
 			vector<float> thisGroupsAxes;
 			for (int i = 0; i < count; i++) {
@@ -904,7 +842,7 @@ map<string, vector<float> > CorrAxesCommand::readAxes(){
 				}
 			}
 			
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
 		
@@ -921,10 +859,10 @@ int CorrAxesCommand::getMetadata(){
 		vector<string> groupNames;
 		
 		ifstream in;
-		m->openInputFile(metadatafile, in);
+		util.openInputFile(metadatafile, in);
 		
-		string headerLine = m->getline(in); m->gobble(in);
-		vector<string> pieces = m->splitWhiteSpace(headerLine);
+		string headerLine = util.getline(in); util.gobble(in);
+		vector<string> pieces = util.splitWhiteSpace(headerLine);
 		
 		//save names of columns you are reading
 		for (int i = 1; i < pieces.size(); i++) {
@@ -933,48 +871,34 @@ int CorrAxesCommand::getMetadata(){
 		int count = metadataLabels.size();
 			
 		//read rest of file
+        lookupFloat = new SharedRAbundFloatVectors();
 		while (!in.eof()) {
 			
-			if (m->control_pressed) { in.close(); return 0; }
+			if (m->getControl_pressed()) { in.close(); return 0; }
 			
 			string group = "";
-			in >> group; m->gobble(in);
+			in >> group; util.gobble(in);
 			groupNames.push_back(group);
 				
 			SharedRAbundFloatVector* tempLookup = new SharedRAbundFloatVector();
-			tempLookup->setGroup(group);
 			tempLookup->setLabel("1");
-			
+            tempLookup->setGroup(group);
+        
 			for (int i = 0; i < count; i++) {
 				float temp = 0.0;
 				in >> temp; 
-				tempLookup->push_back(temp, group);
+				tempLookup->push_back(temp);
 			}
+            lookupFloat->push_back(tempLookup);
 			
-			lookupFloat.push_back(tempLookup);
-			
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
 		
-		//remove any groups the user does not want, and set globaldata->groups with only valid groups
-		SharedUtil* util;
-		util = new SharedUtil();
-		Groups = m->getGroups();
-		util->setGroups(Groups, groupNames);
-		m->setGroups(Groups);
-		
-		for (int i = 0; i < lookupFloat.size(); i++) {
-			//if this sharedrabund is not from a group the user wants then delete it.
-			if (util->isValidGroup(lookupFloat[i]->getGroup(), m->getGroups()) == false) { 
-				delete lookupFloat[i]; lookupFloat[i] = NULL;
-				lookupFloat.erase(lookupFloat.begin()+i); 
-				i--; 
-			}
-		}
-		
-		delete util;
-		
+        lookupFloat->setLabels("1");
+        lookupFloat->eliminateZeroOTUS();
+        
+        
 		return 0;
 	}
 	catch(exception& e) {
