@@ -8,7 +8,7 @@
  */
 
 #include "countseqscommand.h"
-#include "sharedutilities.h"
+
 #include "counttable.h"
 #include "inputdata.h"
 
@@ -18,7 +18,6 @@ vector<string> CountSeqsCommand::setParameters(){
         CommandParameter pshared("shared", "InputTypes", "", "", "NameSHared-sharedGroup", "NameSHared", "none","count",false,false,true); parameters.push_back(pshared);
 		CommandParameter pname("name", "InputTypes", "", "", "NameSHared", "NameSHared", "none","count",false,false,true); parameters.push_back(pname);
 		CommandParameter pgroup("group", "InputTypes", "", "", "sharedGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
-        CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
 		CommandParameter pgroups("groups", "String", "", "", "", "", "","",false,false); parameters.push_back(pgroups);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
@@ -40,10 +39,8 @@ string CountSeqsCommand::getHelpString(){
 		helpString += "The count.seqs aka. make.table command reads a name or shared file and outputs a .count_table file.  You may also provide a group with the names file to get the counts broken down by group.\n";
 		helpString += "The groups parameter allows you to indicate which groups you want to include in the counts, by default all groups in your groupfile are used.\n";
 		helpString += "When you use the groups parameter and a sequence does not represent any sequences from the groups you specify it is not included in the .count.summary file.\n";
-        helpString += "The processors parameter allows you to specify the number of processors to use. The default is 1.\n";
 		helpString += "The count.seqs command should be in the following format: count.seqs(name=yourNameFile).\n";
 		helpString += "Example count.seqs(name=amazon.names) or make.table(name=amazon.names).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. name), '=' and parameters (i.e.yourNameFile).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -56,7 +53,7 @@ string CountSeqsCommand::getOutputPattern(string type) {
     try {
         string pattern = "";
         if (type == "count") {  pattern = "[filename],count_table-[filename],[distance],count_table"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -108,14 +105,14 @@ CountSeqsCommand::CountSeqsCommand(string option)  {
 			
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("name");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["name"] = inputDir + it->second;		}
 				}
@@ -123,7 +120,7 @@ CountSeqsCommand::CountSeqsCommand(string option)  {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -131,33 +128,33 @@ CountSeqsCommand::CountSeqsCommand(string option)  {
                 it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
 			}
 			
 			//check for required parameters
-			namefile = validParameter.validFile(parameters, "name", true);
+			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not open") { namefile = ""; abort = true; }
 			else if (namefile == "not found"){	namefile = ""; }
-            else { m->setNameFile(namefile); }
+            else { current->setNameFile(namefile); }
             
-            sharedfile = validParameter.validFile(parameters, "shared", true);
+            sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }
 			else if (sharedfile == "not found"){	sharedfile = ""; }
-            else { m->setSharedFile(sharedfile); }
+            else { current->setSharedFile(sharedfile); }
             
-			groupfile = validParameter.validFile(parameters, "group", true);
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not open") { abort = true; }
 			else if (groupfile == "not found") {  groupfile = "";  }	
-			else { m->setGroupFile(groupfile); }
+			else { current->setGroupFile(groupfile); }
             
             if ((namefile == "") && (sharedfile == "")) {
-                namefile = m->getNameFile();
+                namefile = current->getNameFile();
 				if (namefile != "") { m->mothurOut("Using " + namefile + " as input file for the name parameter."); m->mothurOutEndLine(); }
 				else {
-                    sharedfile = m->getSharedFile();
+                    sharedfile = current->getSharedFile();
                     if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
                     else {
                         m->mothurOut("You have no current namefile or sharedfile and the name or shared parameter is required."); m->mothurOutEndLine(); abort = true;
@@ -165,18 +162,13 @@ CountSeqsCommand::CountSeqsCommand(string option)  {
                 }
 			}
 
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = "all"; }
-			m->splitAtDash(groups, Groups);
-            m->setGroups(Groups);
-            
-            string temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
-			m->setProcessors(temp);
-			m->mothurConvert(temp, processors);
+			util.splitAtDash(groups, Groups);
+            if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";		}
-
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
 		}
 		
 	}
@@ -190,86 +182,81 @@ CountSeqsCommand::CountSeqsCommand(string option)  {
 int CountSeqsCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
-#else
-        processors=1;
-#endif
-		
         map<string, string> variables;
 
         if (namefile != "") {
-            unsigned long long total = 0;
-            int start = time(NULL);
-            if (outputDir == "") { outputDir = m->hasPath(namefile); }
-            variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(namefile));
+            if (outputDir == "") { outputDir = util.hasPath(namefile); }
+            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(namefile));
             string outputFileName = getOutputFileName("count", variables);
             
-            total = process(outputFileName);
+            long start = time(NULL);
+            unsigned long long total = process(outputFileName);
             
-            if (m->control_pressed) { m->mothurRemove(outputFileName); return 0; }
+            if (m->getControl_pressed()) { util.mothurRemove(outputFileName); return 0; }
             
-            m->mothurOut("It took " + toString(time(NULL) - start) + " secs to create a table for " + toString(total) + " sequences.");
-            m->mothurOutEndLine(); m->mothurOutEndLine();
-            
-            m->mothurOutEndLine();
-            m->mothurOut("Total number of sequences: " + toString(total)); m->mothurOutEndLine();
- 
+            m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to create a table for " + toString(total) + " sequences.\n\n");
+            m->mothurOut("Total number of sequences: " + toString(total) + "\n");
         }else {
-            if (outputDir == "") { outputDir = m->hasPath(sharedfile); }
-            variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(sharedfile));
+            if (outputDir == "") { outputDir = util.hasPath(sharedfile); }
+            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
             
-            InputData input(sharedfile, "sharedfile");
-            vector<SharedRAbundVector*> lookup = input.getSharedRAbundVectors();
-            string lastLabel = lookup[0]->getLabel();
+            InputData input(sharedfile, "sharedfile", Groups);
+            SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+            Groups = lookup->getNamesGroups();
+            string lastLabel = lookup->getLabel();
+            vector<string> currentLabels = lookup->getOTUNames();
             
             //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
             set<string> processedLabels;
             set<string> userLabels = labels;
             
             //as long as you are not at the end of the file or done wih the lines you want
-            while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+            while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
                 
-                if (m->control_pressed) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+                if (m->getControl_pressed()) { delete lookup; for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
                 
-                if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){
+                if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
                     
-                    m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                    m->mothurOut(lookup->getLabel()+"\n"); 
+                    vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+                    processShared(data, variables, currentLabels);
+                    for(int i = 0; i < data.size(); i++) {  delete data[i]; } data.clear();
                     
-                    processShared(lookup, variables);
-                    
-                    processedLabels.insert(lookup[0]->getLabel());
-                    userLabels.erase(lookup[0]->getLabel());
+                    processedLabels.insert(lookup->getLabel());
+                    userLabels.erase(lookup->getLabel());
                 }
                 
-                if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-                    string saveLabel = lookup[0]->getLabel();
+                if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+                    string saveLabel = lookup->getLabel();
                     
-                    for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+                    delete lookup;
                     lookup = input.getSharedRAbundVectors(lastLabel);
-                    m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                    m->mothurOut(lookup->getLabel()+"\n"); 
                     
-                    processShared(lookup, variables);
+                    vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+                    processShared(data, variables, currentLabels);
+                    for(int i = 0; i < data.size(); i++) {  delete data[i]; } data.clear();
                     
-                    processedLabels.insert(lookup[0]->getLabel());
-                    userLabels.erase(lookup[0]->getLabel());
+                    processedLabels.insert(lookup->getLabel());
+                    userLabels.erase(lookup->getLabel());
                     
                     //restore real lastlabel to save below
-                    lookup[0]->setLabel(saveLabel);
+                    lookup->setLabels(saveLabel);
                 }
                 
-                lastLabel = lookup[0]->getLabel();
+                lastLabel = lookup->getLabel();
                 //prevent memory leak
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }
+                delete lookup;
                 
-                if (m->control_pressed) { return 0; }
+                if (m->getControl_pressed()) { return 0; }
                 
                 //get next line to process
                 lookup = input.getSharedRAbundVectors();
             }
             
-            if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); }  return 0; }
+            if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); }  return 0; }
             
             //output error messages about any remaining user labels
             set<string>::iterator it;
@@ -285,15 +272,17 @@ int CountSeqsCommand::execute(){
             }
             
             //run last label if you need to
-            if (needToRun == true)  {
-                for (int i = 0; i < lookup.size(); i++) { if (lookup[i] != NULL) { delete lookup[i]; } }
+            if (needToRun )  {
+                delete lookup;
                 lookup = input.getSharedRAbundVectors(lastLabel);
                 
-                m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                m->mothurOut(lookup->getLabel()+"\n"); 
                 
-                processShared(lookup, variables);
+                vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+                processShared(data, variables, currentLabels);
+                for(int i = 0; i < data.size(); i++) {  delete data[i]; } data.clear();
                 
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+               delete lookup;
             }
             
         }
@@ -301,11 +290,10 @@ int CountSeqsCommand::execute(){
         //set rabund file as new current rabundfile
 		itTypes = outputTypes.find("count");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { string current = (itTypes->second)[0]; m->setCountTableFile(current); }
+			if ((itTypes->second).size() != 0) { string currentName = (itTypes->second)[0]; current->setCountFile(currentName); }
 		}
         
-        m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+        m->mothurOut("\nOutput File Names: \n"); 
 		for(int i = 0; i < outputNames.size(); i++) {  m->mothurOut(outputNames[i]); m->mothurOutEndLine();	 }
 		m->mothurOutEndLine();
         
@@ -319,28 +307,28 @@ int CountSeqsCommand::execute(){
 }
 //**********************************************************************************************************************
 
-unsigned long long CountSeqsCommand::processShared(vector<SharedRAbundVector*>& lookup, map<string, string> variables){
+unsigned long long CountSeqsCommand::processShared(vector<SharedRAbundVector*>& lookup, map<string, string> variables, vector<string> currentLabels){
     try {
         variables["[distance]"] = lookup[0]->getLabel();
         string outputFileName = getOutputFileName("count", variables);
         outputNames.push_back(outputFileName); outputTypes["count"].push_back(outputFileName);
         
         ofstream out;
-        m->openOutputFile(outputFileName, out);
+        util.openOutputFile(outputFileName, out);
         
         out << "OTU_Label\ttotal";
         for (int i = 0; i < lookup.size(); i++) { out << '\t' << lookup[i]->getGroup(); } out << endl;
         
         for (int j = 0; j < lookup[0]->getNumBins(); j++) {
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             int total = 0;
             string output = "";
             for (int i = 0; i < lookup.size(); i++) {
-                total += lookup[i]->getAbundance(j);
-                output += '\t' + toString(lookup[i]->getAbundance(j));
+                total += lookup[i]->get(j);
+                output += '\t' + toString(lookup[i]->get(j));
             }
-            out << m->currentSharedBinLabels[j] << '\t' << total << output << endl;
+            out << currentLabels[j] << '\t' << total << output << endl;
         }
         out.close();
         
@@ -356,32 +344,26 @@ unsigned long long CountSeqsCommand::processShared(vector<SharedRAbundVector*>&
 unsigned long long CountSeqsCommand::process(string outputFileName){
 	try {
         ofstream out;
-        m->openOutputFile(outputFileName, out); outputTypes["count"].push_back(outputFileName);
+        util.openOutputFile(outputFileName, out); outputTypes["count"].push_back(outputFileName);
         outputNames.push_back(outputFileName); outputTypes["count"].push_back(outputFileName);
 		out << "Representative_Sequence\ttotal";
         
-        GroupMap* groupMap;
+        GroupMap* groupMap = NULL;
 		if (groupfile != "") { 
 			groupMap = new GroupMap(groupfile); groupMap->readMap(); 
 			
-			//make sure groups are valid. takes care of user setting groupNames that are invalid or setting groups=all
-			SharedUtil* util = new SharedUtil();
 			vector<string> nameGroups = groupMap->getNamesOfGroups();
-			util->setGroups(Groups, nameGroups);
-			delete util;
-			
+            if (Groups.size() == 0) { Groups = nameGroups; }
+            
 			//sort groupNames so that the group title match the counts below, this is needed because the map object automatically sorts
 			sort(Groups.begin(), Groups.end());
 			
 			//print groupNames
-			for (int i = 0; i < Groups.size(); i++) {
-				out << '\t' << Groups[i];
-			}
+			for (int i = 0; i < Groups.size(); i++) { out << '\t' << Groups[i]; }
 		}
 		out << endl;
-        out.close();
         
-        unsigned long long total = createProcesses(groupMap, outputFileName);
+        unsigned long long total = driver(out, groupMap);
         
         if (groupfile != "") { delete groupMap; }
         
@@ -393,225 +375,23 @@ unsigned long long CountSeqsCommand::process(string outputFileName){
 	}
 }
 /**************************************************************************************************/
-unsigned long long CountSeqsCommand::createProcesses(GroupMap*& groupMap, string outputFileName) {
+unsigned long long CountSeqsCommand::driver(ofstream& out, GroupMap*& groupMap) {
 	try {
-		
-		vector<int> processIDS;
-		int process = 0;
-        vector<unsigned long long> positions;
-        vector<linePair> lines;
-        unsigned long long numSeqs = 0;
-        bool recalc = false;
-        
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
-		positions = m->divideFilePerLine(namefile, processors);
-		for (int i = 0; i < (positions.size()-1); i++) { lines.push_back(linePair(positions[i], positions[(i+1)])); }
-#else
-		if(processors == 1){ lines.push_back(linePair(0, 1000));  }
-        else {
-            unsigned long long numSeqs = 0;
-            positions = m->setFilePosEachLine(namefile, numSeqs);
-            if (positions.size() < processors) { processors = positions.size(); }
-            
-            //figure out how many sequences you have to process
-            int numSeqsPerProcessor = numSeqs / processors;
-            for (int i = 0; i < processors; i++) {
-                int startIndex =  i * numSeqsPerProcessor;
-                if(i == (processors - 1)){	numSeqsPerProcessor = numSeqs - i * numSeqsPerProcessor; 	}
-                lines.push_back(linePair(positions[startIndex], numSeqsPerProcessor));
-            }
-        }
-#endif
-
-        		
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
-		
-		//loop through and create all the processes you want
-		while (process != processors-1) {
-			pid_t pid = fork();
-			
-			if (pid > 0) {
-				processIDS.push_back(pid);  //create map from line number to pid so you can append files in correct order later
-				process++;
-			}else if (pid == 0){
-                string filename = m->mothurGetpid(process) + ".temp";
-				numSeqs = driver(lines[process].start, lines[process].end, filename, groupMap);
-                
-                string tempFile = m->mothurGetpid(process) + ".num.temp";
-                ofstream outTemp;
-                m->openOutputFile(tempFile, outTemp);
-                
-                outTemp << numSeqs << endl;
-                outTemp.close();
-                
-				exit(0);
-            }else {
-                m->mothurOut("[ERROR]: unable to spawn the number of processes you requested, reducing number to " + toString(process) + "\n"); processors = process;
-                for (int i = 0; i < processIDS.size(); i++) { kill (processIDS[i], SIGINT); }
-                //wait to die
-                for (int i=0;i<processIDS.size();i++) {
-                    int temp = processIDS[i];
-                    wait(&temp);
-                }
-                for (int i=0;i<processIDS.size();i++) {
-                    m->mothurRemove((toString(processIDS[i]) + ".temp"));
-                    m->mothurRemove((toString(processIDS[i]) + ".num.temp"));
-                }
-                m->control_pressed = false;
-                recalc = true;
-                break;
-            }
-		}
-		
-        
-        if (recalc) {
-            //test line, also set recalc to true.
-            //for (int i = 0; i < processIDS.size(); i++) { kill (processIDS[i], SIGINT); } for (int i=0;i<processIDS.size();i++) { int temp = processIDS[i]; wait(&temp); } for (int i=0;i<processIDS.size();i++) {m->mothurRemove((toString(processIDS[i]) + ".temp"));m->mothurRemove((toString(processIDS[i]) + ".num.temp"));}m->control_pressed = false;  processors=3; m->mothurOut("[ERROR]: unable to spawn the number of processes you requested, reducing number to " + toString(processors) + "\n");
-            
-            positions.clear();
-            lines.clear();
-            positions = m->divideFilePerLine(namefile, processors);
-            for (int i = 0; i < (positions.size()-1); i++) { lines.push_back(linePair(positions[i], positions[(i+1)])); }
-            
-            numSeqs = 0;
-            processIDS.resize(0);
-            process = 0;
-            
-            while (process != processors-1) {
-                pid_t pid = fork();
-                
-                if (pid > 0) {
-                    processIDS.push_back(pid);  //create map from line number to pid so you can append files in correct order later
-                    process++;
-                }else if (pid == 0){
-                    string filename = m->mothurGetpid(process) + ".temp";
-                    numSeqs = driver(lines[process].start, lines[process].end, filename, groupMap);
-                    
-                    string tempFile = m->mothurGetpid(process) + ".num.temp";
-                    ofstream outTemp;
-                    m->openOutputFile(tempFile, outTemp);
-                    
-                    outTemp << numSeqs << endl;
-                    outTemp.close();
-                    
-                    exit(0);
-                }else {
-                    m->mothurOut("[ERROR]: unable to spawn the necessary processes."); m->mothurOutEndLine();
-                    for (int i = 0; i < processIDS.size(); i++) { kill (processIDS[i], SIGINT); }
-                    exit(0);
-                }
-            }
-        }
-
-        
-		string filename = m->mothurGetpid(process) + ".temp";
-        numSeqs = driver(lines[processors-1].start, lines[processors-1].end, filename, groupMap);
-        
-		//force parent to wait until all the processes are done
-		for (int i=0;i<processIDS.size();i++) {
-			int temp = processIDS[i];
-			wait(&temp);
-		}
-        
-        for (int i = 0; i < processIDS.size(); i++) {
-            string tempFile = toString(processIDS[i]) +  ".num.temp";
-            ifstream intemp;
-            m->openInputFile(tempFile, intemp);
-            
-            int num;
-            intemp >> num; intemp.close();
-            numSeqs += num;
-            m->mothurRemove(tempFile);
-        }
-#else		
-		vector<countData*> pDataArray;
-		DWORD   dwThreadIdArray[processors-1];
-		HANDLE  hThreadArray[processors-1];
-        vector<GroupMap*> copies;
-		
-		//Create processor worker threads.
-		for( int i=0; i<processors-1; i++ ){
-			string filename = toString(i) + ".temp";
-            
-            GroupMap* copyGroup = new GroupMap();
-            copyGroup->getCopy(groupMap);
-            copies.push_back(copyGroup);
-            vector<string> cGroups = Groups;
-           
-			countData* temp = new countData(filename, copyGroup, m, lines[i].start, lines[i].end, groupfile, namefile, cGroups);
-			pDataArray.push_back(temp);
-			processIDS.push_back(i);
-			
-			hThreadArray[i] = CreateThread(NULL, 0, MyCountThreadFunction, pDataArray[i], 0, &dwThreadIdArray[i]);
-		}
-		
-		string filename = toString(processors-1) + ".temp";
-        numSeqs = driver(lines[processors-1].start, lines[processors-1].end, filename, groupMap);
-        		
-		//Wait until all threads have terminated.
-		WaitForMultipleObjects(processors-1, hThreadArray, TRUE, INFINITE);
-		
-		//Close all thread handles and free memory allocations.
-		for(int i=0; i < pDataArray.size(); i++){
-            numSeqs += pDataArray[i]->total;
-            delete copies[i];
-			CloseHandle(hThreadArray[i]);
-			delete pDataArray[i];
-		}
-#endif
-		
-		//append output files
-		for(int i=0;i<processIDS.size();i++){
-			m->appendFiles((toString(processIDS[i]) + ".temp"), outputFileName);
-			m->mothurRemove((toString(processIDS[i]) + ".temp"));
-		}
-        m->appendFiles(filename, outputFileName);
-        m->mothurRemove(filename);
-
-        
-        //sanity check
-        if (groupfile != "") {
-            if (numSeqs != groupMap->getNumSeqs()) {
-                m->mothurOut("[ERROR]: processes reported processing " + toString(numSeqs) + " sequences, but group file indicates you have " + toString(groupMap->getNumSeqs()) + " sequences.");
-                if (processors == 1) { m->mothurOut(" Could you have a file mismatch?\n"); }
-                else { m->mothurOut(" Either you have a file mismatch or a process failed to complete the task assigned to it.\n"); m->control_pressed = true; }
-            }
-		}
-		return numSeqs;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "CountSeqsCommand", "createProcesses");
-		exit(1);
-	}
-}
-/**************************************************************************************************/
-unsigned long long CountSeqsCommand::driver(unsigned long long start, unsigned long long end, string outputFileName, GroupMap*& groupMap) {
-	try {
-        
-        ofstream out;
-        m->openOutputFile(outputFileName, out);
-        
         ifstream in;
-		m->openInputFile(namefile, in);
-		in.seekg(start);
-        
-        //adjust start if null strings
-        if (start == 0) {  m->zapGremlins(in); m->gobble(in);  }
-
-		bool done = false;
+		util.openInputFile(namefile, in);
+		
         unsigned long long total = 0;
-		while (!done) {
-			if (m->control_pressed) { break; }
+		while (!in.eof()) {
+			if (m->getControl_pressed()) { break; }
 			
 			string firstCol, secondCol;
-			in >> firstCol; m->gobble(in); in >> secondCol; m->gobble(in);
-            //cout << firstCol << '\t' << secondCol << endl;
-            m->checkName(firstCol);
-            m->checkName(secondCol);
-			//cout << firstCol << '\t' << secondCol << endl;
+			in >> firstCol; util.gobble(in); in >> secondCol; util.gobble(in);
+            
+            util.checkName(firstCol);
+            util.checkName(secondCol);
             
 			vector<string> names;
-			m->splitAtChar(secondCol, names, ',');
+			util.splitAtChar(secondCol, names, ',');
 			
 			if (groupfile != "") {
 				//set to 0
@@ -647,20 +427,11 @@ unsigned long long CountSeqsCommand::driver(unsigned long long start, unsigned l
 			}
 			
 			total += names.size();
-            
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
-            unsigned long long pos = in.tellg();
-            if ((pos == -1) || (pos >= end)) { break; }
-#else
-            if (in.eof()) { break; }
-#endif
-
-		}
+        }
 		in.close();
         out.close();
         
         return total;
-
     }
 	catch(exception& e) {
 		m->errorOut(e, "CountSeqsCommand", "driver");
@@ -673,11 +444,11 @@ map<int, string> CountSeqsCommand::processNameFile(string name) {
         map<int, string> indexToNames;
         
         ofstream out;
-        m->openOutputFile(name, out);
+        util.openOutputFile(name, out);
         
         //open input file
 		ifstream in;
-		m->openInputFile(namefile, in);
+		util.openInputFile(namefile, in);
         
         string rest = "";
         char buffer[4096];
@@ -687,21 +458,21 @@ map<int, string> CountSeqsCommand::processNameFile(string name) {
         int count = 0;
         
 		while (!in.eof()) {
-			if (m->control_pressed) { break; }
+			if (m->getControl_pressed()) { break; }
 			
             in.read(buffer, 4096);
-            vector<string> pieces = m->splitWhiteSpace(rest, buffer, in.gcount());
+            vector<string> pieces = util.splitWhiteSpace(rest, buffer, in.gcount());
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  firstCol = pieces[i]; columnOne=false; }
                 else  { secondCol = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) { 
-                    m->checkName(firstCol);
-                    m->checkName(secondCol);
+                    util.checkName(firstCol);
+                    util.checkName(secondCol);
                     //parse names into vector
                     vector<string> theseNames;
-                    m->splitAtComma(secondCol, theseNames);
+                    util.splitAtComma(secondCol, theseNames);
                     for (int i = 0; i < theseNames.size(); i++) {  out << theseNames[i] << '\t' << count << endl;  }
                     indexToNames[count] = firstCol;
                     pairDone = false; 
@@ -713,18 +484,18 @@ map<int, string> CountSeqsCommand::processNameFile(string name) {
        
 		
         if (rest != "") {
-            vector<string> pieces = m->splitWhiteSpace(rest);
+            vector<string> pieces = util.splitWhiteSpace(rest);
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  firstCol = pieces[i]; columnOne=false; }
                 else  { secondCol = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) { 
-                    m->checkName(firstCol);
-                    m->checkName(secondCol);
+                    util.checkName(firstCol);
+                    util.checkName(secondCol);
                     //parse names into vector
                     vector<string> theseNames;
-                    m->splitAtComma(secondCol, theseNames);
+                    util.splitAtComma(secondCol, theseNames);
                     for (int i = 0; i < theseNames.size(); i++) {  out << theseNames[i] << '\t' << count << endl;  }
                     indexToNames[count] = firstCol;
                     pairDone = false; 
@@ -750,11 +521,11 @@ map<int, string> CountSeqsCommand::getGroupNames(string filename, set<string>& n
         map<string, int>::iterator it;
         
         ofstream out;
-        m->openOutputFile(filename, out);
+        util.openOutputFile(filename, out);
         
         //open input file
 		ifstream in;
-		m->openInputFile(groupfile, in);
+		util.openInputFile(groupfile, in);
         
         string rest = "";
         char buffer[4096];
@@ -764,17 +535,17 @@ map<int, string> CountSeqsCommand::getGroupNames(string filename, set<string>& n
         int count = 0;
         
 		while (!in.eof()) {
-			if (m->control_pressed) { break; }
+			if (m->getControl_pressed()) { break; }
 			
             in.read(buffer, 4096);
-            vector<string> pieces = m->splitWhiteSpace(rest, buffer, in.gcount());
+            vector<string> pieces = util.splitWhiteSpace(rest, buffer, in.gcount());
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  firstCol = pieces[i]; columnOne=false; }
                 else  { secondCol = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) { 
-                    m->checkName(firstCol);
+                    util.checkName(firstCol);
                     it = groupIndex.find(secondCol);
                     if (it == groupIndex.end()) { //add group, assigning the group and number so we can use vectors above
                         groupIndex[secondCol] = count;
@@ -790,14 +561,14 @@ map<int, string> CountSeqsCommand::getGroupNames(string filename, set<string>& n
         
         
         if (rest != "") {
-            vector<string> pieces = m->splitWhiteSpace(rest);
+            vector<string> pieces = util.splitWhiteSpace(rest);
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  firstCol = pieces[i]; columnOne=false; }
                 else  { secondCol = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) { 
-                    m->checkName(firstCol);
+                    util.checkName(firstCol);
                     it = groupIndex.find(secondCol);
                     if (it == groupIndex.end()) { //add group, assigning the group and number so we can use vectors above
                         groupIndex[secondCol] = count;
