@@ -49,7 +49,6 @@ string CreateDatabaseCommand::getHelpString(){
         helpString += "The create.database command should be in the following format: \n";
 		helpString += "create.database(repfasta=yourFastaFileFromGetOTURep, repname=yourNameFileFromGetOTURep, contaxonomy=yourConTaxFileFromClassifyOTU, list=yourListFile) \n";	
 		helpString += "Example: create.database(repfasta=final.an.0.03.rep.fasta, repname=final.an.0.03.rep.names, list=final.an.list, label=0.03, contaxonomy=final.an.0.03.cons.taxonomy) \n";
-		helpString += "Note: No spaces between parameter labels (i.e. repfasta), '=' and parameters (i.e.yourFastaFileFromGetOTURep).\n";	
 		return helpString;
 	}
 	catch(exception& e) {
@@ -63,7 +62,7 @@ string CreateDatabaseCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "database") {  pattern = "[filename],database"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -114,14 +113,14 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
 			outputTypes["database"] = tempOutNames;
             
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -129,7 +128,7 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
 				it = parameters.find("repname");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["repname"] = inputDir + it->second;		}
 				}
@@ -137,7 +136,7 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
 				it = parameters.find("constaxonomy");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["constaxonomy"] = inputDir + it->second;		}
 				}
@@ -145,7 +144,7 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
 				it = parameters.find("repfasta");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["repfasta"] = inputDir + it->second;		}
 				}
@@ -153,7 +152,7 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -161,7 +160,7 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
@@ -169,7 +168,7 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
                 it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -177,26 +176,26 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
             
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";		}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
 			
 			//check for required parameters
-			listfile = validParameter.validFile(parameters, "list", true);
+			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not found") {	listfile = "";			}
 			else if (listfile == "not open") { listfile = ""; abort = true; }	
-			else { m->setListFile(listfile); }
+			else { current->setListFile(listfile); }
             
-            sharedfile = validParameter.validFile(parameters, "shared", true);
+            sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not found") {	sharedfile = "";			}
 			else if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
-			else { m->setSharedFile(sharedfile); }
+			else { current->setSharedFile(sharedfile); }
             
             if ((sharedfile == "") && (listfile == "")) { 
 				//is there are current file available for either of these?
 				//give priority to list, then shared
-				listfile = m->getListFile(); 
+				listfile = current->getListFile(); 
 				if (listfile != "") {  m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
 				else { 
-					sharedfile = m->getSharedFile(); 
+					sharedfile = current->getSharedFile(); 
 					if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("[ERROR]: No valid current files. You must provide a shared or list file before you can use the create.database command."); m->mothurOutEndLine();
@@ -206,38 +205,38 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
 			}
 			else if ((sharedfile != "") && (listfile != "")) { m->mothurOut("When executing a create.database command you must enter ONLY ONE of the following: shared or list."); m->mothurOutEndLine(); abort = true; }
             
-            if (sharedfile != "") { if (outputDir == "") { outputDir = m->hasPath(sharedfile); } }
-            else { if (outputDir == "") { outputDir = m->hasPath(listfile); } }
+            if (sharedfile != "") { if (outputDir == "") { outputDir = util.hasPath(sharedfile); } }
+            else { if (outputDir == "") { outputDir = util.hasPath(listfile); } }
 			
-			contaxonomyfile = validParameter.validFile(parameters, "constaxonomy", true);
+			contaxonomyfile = validParameter.validFile(parameters, "constaxonomy");
 			if (contaxonomyfile == "not found") {  //if there is a current list file, use it
                contaxonomyfile = "";  m->mothurOut("The constaxonomy parameter is required, aborting."); m->mothurOutEndLine(); abort = true;
 			}
 			else if (contaxonomyfile == "not open") { contaxonomyfile = ""; abort = true; }
 
-            repfastafile = validParameter.validFile(parameters, "repfasta", true);
+            repfastafile = validParameter.validFile(parameters, "repfasta");
 			if (repfastafile == "not found") { repfastafile = ""; }
 			else if (repfastafile == "not open") { repfastafile = ""; abort = true; }
 
-            repnamesfile = validParameter.validFile(parameters, "repname", true);
+            repnamesfile = validParameter.validFile(parameters, "repname");
 			if (repnamesfile == "not found") {  repnamesfile = "";  			}
 			else if (repnamesfile == "not open") { repnamesfile = ""; abort = true; }
             
             if ((repnamesfile != "") && (repfastafile == "")) { m->mothurOut("[ERROR]: You must provide a repfasta file if you are using a repnames file."); m->mothurOutEndLine();
                 abort = true; }
             
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
 			if (countfile == "not found") {  countfile = "";  			}
 			else if (countfile == "not open") { countfile = ""; abort = true; }
             
-			groupfile = validParameter.validFile(parameters, "group", true);
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not open") { groupfile = ""; abort = true; }	
 			else if (groupfile == "not found") { groupfile = ""; }
-			else { m->setGroupFile(groupfile); }
+			else { current->setGroupFile(groupfile); }
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-            label = validParameter.validFile(parameters, "label", false);			
+            label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; m->mothurOut("You did not provide a label, I will use the first label in your listfile.\n");}
         }
 	}
@@ -250,7 +249,7 @@ CreateDatabaseCommand::CreateDatabaseCommand(string option)  {
 int CreateDatabaseCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
         //taxonomies holds the taxonomy info for each Otu
         //classifyOtuSizes holds the size info of each Otu to help with error checking
@@ -258,13 +257,13 @@ int CreateDatabaseCommand::execute(){
         vector<string> otuLabels;
         vector<int> classifyOtuSizes = readTax(taxonomies, otuLabels);
         
-        if (m->control_pressed) { return 0; }
+        if (m->getControl_pressed()) { return 0; }
         
         vector<Sequence> seqs;
         vector<int> repOtusSizes;
         if (repfastafile != "") { repOtusSizes = readFasta(seqs); }
         
-        if (m->control_pressed) { return 0; }
+        if (m->getControl_pressed()) { return 0; }
         
         //names redundants to uniques. backwards to how we normally do it, but each bin is the list file will be a key entry in the map.
         map<string, string> repNames;
@@ -272,13 +271,13 @@ int CreateDatabaseCommand::execute(){
         int numUniqueNamesFile = 0;
         CountTable ct;
         if (repnamesfile != "") {
-            numUniqueNamesFile = m->readNames(repnamesfile, repNames, 1);
+            numUniqueNamesFile = util.readNames(repnamesfile, repNames, 1);
             //the repnames file does not have the same order as the list file bins so we need to sort and reassemble for the search below
             map<string, string> tempRepNames;
             for (map<string, string>::iterator it = repNames.begin(); it != repNames.end();) {
                 string bin = it->first;
                 vector<string> temp;
-                m->splitAtChar(bin, temp, ',');
+                util.splitAtChar(bin, temp, ',');
                 sort(temp.begin(), temp.end());
                 bin = "";
                 for (int i = 0; i < temp.size()-1; i++) {
@@ -295,37 +294,37 @@ int CreateDatabaseCommand::execute(){
             nameMap = ct.getNameMap();
         }
         
-        if (m->control_pressed) { return 0; }
+        if (m->getControl_pressed()) { return 0; }
         
         if (repfastafile != "") {
             
             //are there the same number of otus in the fasta and name files
-            if (repOtusSizes.size() != numUniqueNamesFile) { m->mothurOut("[ERROR]: you have " + toString(numUniqueNamesFile) + " unique seqs in your repname file, but " + toString(repOtusSizes.size()) + " seqs in your repfasta file.  These should match.\n"); m->control_pressed = true; }
+            if (repOtusSizes.size() != numUniqueNamesFile) { m->mothurOut("[ERROR]: you have " + toString(numUniqueNamesFile) + " unique seqs in your repname file, but " + toString(repOtusSizes.size()) + " seqs in your repfasta file.  These should match.\n"); m->setControl_pressed(true); }
             
             //are there the same number of OTUs in the tax and fasta file
-            if (classifyOtuSizes.size() != repOtusSizes.size()) { m->mothurOut("[ERROR]: you have " + toString(classifyOtuSizes.size()) + " taxonomies in your contaxonomy file, but " + toString(repOtusSizes.size()) + " seqs in your repfasta file.  These should match.\n"); m->control_pressed = true; }
+            if (classifyOtuSizes.size() != repOtusSizes.size()) { m->mothurOut("[ERROR]: you have " + toString(classifyOtuSizes.size()) + " taxonomies in your contaxonomy file, but " + toString(repOtusSizes.size()) + " seqs in your repfasta file.  These should match.\n"); m->setControl_pressed(true); }
             
-            if (m->control_pressed) { return 0; }
+            if (m->getControl_pressed()) { return 0; }
             
             //at this point we have the same number of OTUs. Are the sizes we have found so far accurate?
             for (int i = 0; i < classifyOtuSizes.size(); i++) {
                 if (classifyOtuSizes[i] != repOtusSizes[i]) {
-                    m->mothurOut("[ERROR]: OTU size info does not match for bin " + toString(i+1) + ". The contaxonomy file indicated the OTU represented " + toString(classifyOtuSizes[i]) + " sequences, but the repfasta file had " + toString(repOtusSizes[i]) + ".  These should match. Make sure you are using files for the same distance.\n"); m->control_pressed = true;
+                    m->mothurOut("[ERROR]: OTU size info does not match for bin " + toString(i+1) + ". The contaxonomy file indicated the OTU represented " + toString(classifyOtuSizes[i]) + " sequences, but the repfasta file had " + toString(repOtusSizes[i]) + ".  These should match. Make sure you are using files for the same distance.\n"); m->setControl_pressed(true);
                 }
             }
         }
         
-        if (m->control_pressed) { return 0; }
+        if (m->getControl_pressed()) { return 0; }
         
         
         map<string, string> variables; 
-        if (listfile != "") {  variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(listfile)); }
-        else { variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(sharedfile)); }
+        if (listfile != "") {  variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile)); }
+        else { variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile)); }
         string outputFileName = getOutputFileName("database", variables); 
         outputNames.push_back(outputFileName); outputTypes["database"].push_back(outputFileName);
         
         ofstream out;
-        m->openOutputFile(outputFileName, out);
+        util.openOutputFile(outputFileName, out);
         
         string header = "OTUNumber\tAbundance";
 
@@ -335,9 +334,9 @@ int CreateDatabaseCommand::execute(){
             ListVector* list = getList();
             
             if (otuLabels.size() != list->getNumBins()) { 
-                m->mothurOut("[ERROR]: you have " + toString(otuLabels.size()) + " otus in your contaxonomy file, but your list file has " + toString(list->getNumBins()) + " otus. These should match. Make sure you are using files for the same distance.\n"); m->control_pressed = true;  }
+                m->mothurOut("[ERROR]: you have " + toString(otuLabels.size()) + " otus in your contaxonomy file, but your list file has " + toString(list->getNumBins()) + " otus. These should match. Make sure you are using files for the same distance.\n"); m->setControl_pressed(true);  }
             
-            if (m->control_pressed) { delete list; return 0; }
+            if (m->getControl_pressed()) { delete list; return 0; }
             
             GroupMap* groupmap = NULL;
             if (groupfile != "") {
@@ -345,7 +344,7 @@ int CreateDatabaseCommand::execute(){
                 groupmap->readMap();
             }
             
-            if (m->control_pressed) { delete list; if (groupfile != "") { delete groupmap; } return 0; }
+            if (m->getControl_pressed()) { delete list; if (groupfile != "") { delete groupmap; } return 0; }
             
             if (groupfile != "") { 
                 header = "OTUNumber";
@@ -365,15 +364,15 @@ int CreateDatabaseCommand::execute(){
             for (int i = 0; i < list->getNumBins(); i++) {
                 
                 int index = findIndex(otuLabels, binLabels[i]);
-                if (index == -1) {  m->mothurOut("[ERROR]: " + binLabels[i] + " is not in your constaxonomy file, aborting.\n"); m->control_pressed = true; }
+                if (index == -1) {  m->mothurOut("[ERROR]: " + binLabels[i] + " is not in your constaxonomy file, aborting.\n"); m->setControl_pressed(true); }
                 
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
                 out << otuLabels[index];
                 
                 vector<string> binNames;
                 string bin = list->get(i);
-                m->splitAtComma(bin, binNames);
+                util.splitAtComma(bin, binNames);
                 
                 string seqRepName = "";
                 int numSeqsRep = binNames.size();
@@ -388,12 +387,12 @@ int CreateDatabaseCommand::execute(){
                     map<string, string>::iterator it = repNames.find(bin);
                     
                     if (it == repNames.end()) {
-                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " is not in the repnames file. Make sure you are using files for the same distance.\n"); m->control_pressed = true;   break;
+                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " is not in the repnames file. Make sure you are using files for the same distance.\n"); m->setControl_pressed(true);   break;
                     }else { seqRepName = it->second;  numSeqsRep = binNames.size(); }
                     
                     //sanity check
                     if (binNames.size() != classifyOtuSizes[index]) {
-                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " contains " + toString(binNames.size()) + " sequence, but the rep and taxonomy files indicated this OTU should have " + toString(classifyOtuSizes[index]) + ". Make sure you are using files for the same distance.\n"); m->control_pressed = true;   break;
+                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " contains " + toString(binNames.size()) + " sequence, but the rep and taxonomy files indicated this OTU should have " + toString(classifyOtuSizes[index]) + ". Make sure you are using files for the same distance.\n"); m->setControl_pressed(true);   break;
                     }
                 }else if ((countfile != "") && (repfastafile != "")) {
                     //find rep sequence in bin
@@ -407,11 +406,11 @@ int CreateDatabaseCommand::execute(){
                     }
                     
                     if (seqRepName == "") {
-                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " is not in the count file. Make sure you are using files for the same distance.\n"); m->control_pressed = true;   break;
+                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " is not in the count file. Make sure you are using files for the same distance.\n"); m->setControl_pressed(true);   break;
                     }
                     
                     if (numSeqsRep != classifyOtuSizes[i]) {
-                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " contains " + toString(numSeqsRep) + " sequence, but the rep and taxonomy files indicated this OTU should have " + toString(classifyOtuSizes[index]) + ". Make sure you are using files for the same distance.\n"); m->control_pressed = true;   break;
+                        m->mothurOut("[ERROR: OTU " + otuLabels[index] + " contains " + toString(numSeqsRep) + " sequence, but the rep and taxonomy files indicated this OTU should have " + toString(classifyOtuSizes[index]) + ". Make sure you are using files for the same distance.\n"); m->setControl_pressed(true);   break;
                     }
                 }
                 
@@ -435,7 +434,7 @@ int CreateDatabaseCommand::execute(){
                     //output counts
                     for (int j = 0; j < groupmap->getNamesOfGroups().size(); j++) { out << '\t' << counts[(groupmap->getNamesOfGroups())[j]];  }
                     
-                    if (error) { m->control_pressed = true; }
+                    if (error) { m->setControl_pressed(true); }
                 }else if ((countfile != "") && (repfastafile != "")) {
                     if (ct.hasGroupInfo()) {
                         vector<int> groupCounts = ct.getGroupCounts(seqRepName);
@@ -462,35 +461,37 @@ int CreateDatabaseCommand::execute(){
             if (groupfile != "") { delete groupmap; }
            
         }else {
-            vector<SharedRAbundVector*> lookup = getShared();
+            SharedRAbundVectors* lookup = getShared();
+            vector<string> namesOfGroups = lookup->getNamesGroups();
             
             header = "OTUNumber";
-            for (int i = 0; i < lookup.size(); i++) { header += '\t' + lookup[i]->getGroup(); }
+            for (int i = 0; i < namesOfGroups.size(); i++) { header += '\t' + namesOfGroups[i]; }
             if (repfastafile != "") {  header += "\trepSeqName\trepSeq";  }
             header += "\tOTUConTaxonomy";
             out << header << endl;
             
-            for (int h = 0; h < lookup[0]->getNumBins(); h++) {
+            vector<string> currentLabels = lookup->getOTUNames();
+            for (int h = 0; h < lookup->getNumBins(); h++) {
                 
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
-                int index = findIndex(otuLabels, m->currentSharedBinLabels[h]);
-                if (index == -1) {  m->mothurOut("[ERROR]: " + m->currentSharedBinLabels[h] + " is not in your constaxonomy file, aborting.\n"); m->control_pressed = true; }
+                int index = findIndex(otuLabels, currentLabels[h]);
+                if (index == -1) {  m->mothurOut("[ERROR]: " + currentLabels[h] + " is not in your constaxonomy file, aborting.\n"); m->setControl_pressed(true); }
                 
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
                 out << otuLabels[index];
                 
                 int totalAbund = 0;
-                for (int i = 0; i < lookup.size(); i++) { 
-                    int abund = lookup[i]->getAbundance(h);
+                for (int i = 0; i < lookup->size(); i++) {
+                    int abund = lookup->get(h, namesOfGroups[i]);
                     totalAbund += abund; 
                     out  << '\t' << abund;
                 }
                 
                 //sanity check
                 if (totalAbund != classifyOtuSizes[index]) {
-                    m->mothurOut("[WARNING]: OTU " + m->currentSharedBinLabels[h] + " contains " + toString(totalAbund) + " sequence, but the rep and taxonomy files indicated this OTU should have " + toString(classifyOtuSizes[index]) + ". Make sure you are using files for the same distance.\n"); //m->control_pressed = true;   break;
+                    m->mothurOut("[WARNING]: OTU " + currentLabels[h] + " contains " + toString(totalAbund) + " sequence, but the rep and taxonomy files indicated this OTU should have " + toString(classifyOtuSizes[index]) + ". Make sure you are using files for the same distance.\n"); //m->setControl_pressed(true);   break;
                 }
                 
                 //output repSeq
@@ -499,10 +500,9 @@ int CreateDatabaseCommand::execute(){
             }
         }
         out.close();
-        if (m->control_pressed) { m->mothurRemove(outputFileName); return 0; }
+        if (m->getControl_pressed()) { util.mothurRemove(outputFileName); return 0; }
         
-        m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+        m->mothurOut("\nOutput File Names: \n"); 
 		m->mothurOut(outputFileName); m->mothurOutEndLine();	
 		m->mothurOutEndLine();
         
@@ -519,7 +519,7 @@ int CreateDatabaseCommand::findIndex(vector<string>& otuLabels, string label){
 	try {
         int index = -1;
         for (int i = 0; i < otuLabels.size(); i++) {
-            if (m->isLabelEquivalent(otuLabels[i],label)) { index = i; break; }
+            if (util.isLabelEquivalent(otuLabels[i],label)) { index = i; break; }
         }
 		return index;
     }
@@ -535,20 +535,20 @@ vector<int> CreateDatabaseCommand::readTax(vector<string>& taxonomies, vector<st
         vector<int> sizes; 
         
         ifstream in;
-        m->openInputFile(contaxonomyfile, in);
+        util.openInputFile(contaxonomyfile, in);
         
         //read headers
-        m->getline(in);
+        util.getline(in);
         
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             string otu = ""; string tax = "unknown";
             int size = 0;
             
-            in >> otu >> size; m->gobble(in);
-            tax = m->getline(in); m->gobble(in);
+            in >> otu >> size; util.gobble(in);
+            tax = util.getline(in); util.gobble(in);
             
             sizes.push_back(size);
             taxonomies.push_back(tax);
@@ -570,31 +570,31 @@ vector<int> CreateDatabaseCommand::readFasta(vector<Sequence>& seqs){
         vector<int> sizes; 
         
         ifstream in;
-        m->openInputFile(repfastafile, in);
+        util.openInputFile(repfastafile, in);
         
         set<int> sanity;
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             string binInfo;
-            Sequence seq(in, binInfo, true);  m->gobble(in);
+            Sequence seq(in, binInfo, true);  util.gobble(in);
             
             //the binInfo should look like - binNumber|size ie. 1|200 if it is binNumber|size|group then the user gave us the wrong repfasta file
             vector<string> info;
-            m->splitAtChar(binInfo, info, '|');
-            //if (info.size() != 2) { m->mothurOut("[ERROR]: your repfasta file is not the right format.  The create database command is designed to be used with the output from get.oturep.  When running get.oturep you can not use a group file, because mothur is only expecting one representative sequence per OTU and when you use a group file with get.oturep a representative is found for each group.\n");  m->control_pressed = true; break;}
+            util.splitAtChar(binInfo, info, '|');
+            //if (info.size() != 2) { m->mothurOut("[ERROR]: your repfasta file is not the right format.  The create database command is designed to be used with the output from get.oturep.  When running get.oturep you can not use a group file, because mothur is only expecting one representative sequence per OTU and when you use a group file with get.oturep a representative is found for each group.\n");  m->setControl_pressed(true); break;}
             
             int size = 0;
-            m->mothurConvert(info[1], size);
+            util.mothurConvert(info[1], size);
             
             int binNumber = 0;
             string temp = "";
             for (int i = 0; i < info[0].size(); i++) { if (isspace(info[0][i])) {;}else{temp +=info[0][i]; } }
-            m->mothurConvert(m->getSimpleLabel(temp), binNumber);
+            util.mothurConvert(util.getSimpleLabel(temp), binNumber);
             set<int>::iterator it = sanity.find(binNumber);
             if (it != sanity.end()) {
-                m->mothurOut("[ERROR]: your repfasta file is not the right format.  The create database command is designed to be used with the output from get.oturep.  When running get.oturep you can not use a group file, because mothur is only expecting one representative sequence per OTU and when you use a group file with get.oturep a representative is found for each group.\n");  m->control_pressed = true; break;
+                m->mothurOut("[ERROR]: your repfasta file is not the right format.  The create database command is designed to be used with the output from get.oturep.  When running get.oturep you can not use a group file, because mothur is only expecting one representative sequence per OTU and when you use a group file with get.oturep a representative is found for each group.\n");  m->setControl_pressed(true); break;
             }else { sanity.insert(binNumber); }
             
             sizes.push_back(size);
@@ -612,7 +612,7 @@ vector<int> CreateDatabaseCommand::readFasta(vector<Sequence>& seqs){
 //**********************************************************************************************************************
 ListVector* CreateDatabaseCommand::getList(){
 	try {
-		InputData* input = new InputData(listfile, "list");
+		InputData* input = new InputData(listfile, "list", nullVector);
 		ListVector* list = input->getListVector();
 		string lastLabel = list->getLabel();
 		
@@ -625,7 +625,7 @@ ListVector* CreateDatabaseCommand::getList(){
 		
 		//as long as you are not at the end of the file or done wih the lines you want
 		while((list != NULL) && (userLabels.size() != 0)) {
-			if (m->control_pressed) {  delete input; return list;  }
+			if (m->getControl_pressed()) {  delete input; return list;  }
 			
 			if(labels.count(list->getLabel()) == 1){
 				processedLabels.insert(list->getLabel());
@@ -633,7 +633,7 @@ ListVector* CreateDatabaseCommand::getList(){
 				break;
 			}
 			
-			if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+			if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 				string saveLabel = list->getLabel();
 				
 				delete list;
@@ -656,23 +656,18 @@ ListVector* CreateDatabaseCommand::getList(){
 		}
 		
 		
-		if (m->control_pressed) { delete input; return list;  }
+		if (m->getControl_pressed()) { delete input; return list;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
+		if (needToRun )  {
 			delete list;
 			list = input->getListVector(lastLabel);
 		}	
@@ -687,11 +682,11 @@ ListVector* CreateDatabaseCommand::getList(){
 	}
 }
 //**********************************************************************************************************************
-vector<SharedRAbundVector*> CreateDatabaseCommand::getShared(){
+SharedRAbundVectors* CreateDatabaseCommand::getShared(){
 	try {
-		InputData input(sharedfile, "sharedfile");
-		vector<SharedRAbundVector*> lookup = input.getSharedRAbundVectors();
-		string lastLabel = lookup[0]->getLabel();
+		InputData input(sharedfile, "sharedfile", nullVector);
+		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+		string lastLabel = lookup->getLabel();
 		
 		if (label == "") { label = lastLabel; return lookup; }
 		
@@ -701,56 +696,49 @@ vector<SharedRAbundVector*> CreateDatabaseCommand::getShared(){
 		set<string> userLabels = labels;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup[0] != NULL) && (userLabels.size() != 0)) {
-			if (m->control_pressed) {  return lookup;  }
+		while((lookup != NULL) && (userLabels.size() != 0)) {
+			if (m->getControl_pressed()) {  return lookup;  }
 			
-			if(labels.count(lookup[0]->getLabel()) == 1){
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+			if(labels.count(lookup->getLabel()) == 1){
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				break;
 			}
 			
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 				
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+                delete lookup;
 				lookup = input.getSharedRAbundVectors(lastLabel);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 				break;
 			}
 			
-			lastLabel = lookup[0]->getLabel();			
+			lastLabel = lookup->getLabel();
 			
 			//get next line to process
 			//prevent memory leak
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+			delete lookup;
 			lookup = input.getSharedRAbundVectors();
 		}
 		
 		
-		if (m->control_pressed) { return lookup;  }
+		if (m->getControl_pressed()) { return lookup;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+		if (needToRun )  {
+			delete lookup;
 			lookup = input.getSharedRAbundVectors(lastLabel);
 		}	
         
