@@ -57,7 +57,7 @@ string FilterSharedCommand::getHelpString(){
 		helpString += "Example filter.shared(shared=final.an.shared, minabund=10).\n";
 		helpString += "The default value for groups is all the groups in your sharedfile, and all labels in your inputfile will be used.\n";
 		helpString += "The filter.shared command outputs a .filter.shared file.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. groups), '=' and parameters (i.e.yourGroups).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -71,7 +71,7 @@ string FilterSharedCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "shared")      {   pattern = "[filename],[distance],filter,[extension]";    }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -122,93 +122,93 @@ FilterSharedCommand::FilterSharedCommand(string option) {
 			outputTypes["shared"] = tempOutNames;
 			            
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
                 it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
             }
 					
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { 
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}else { m->setSharedFile(sharedfile); }
+			}else { current->setSharedFile(sharedfile); }
 			
             //if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(sharedfile);	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(sharedfile);	}
             
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; pickedGroups = false; }
 			else { 
 				pickedGroups = true;
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
 			
             bool setSomething = false;
-			string temp = validParameter.validFile(parameters, "minabund", false);		
+			string temp = validParameter.valid(parameters, "minabund");
             if (temp == "not found"){	temp = "-1";		}
             else { setSomething = true; }
-			m->mothurConvert(temp, minAbund);  
+			util.mothurConvert(temp, minAbund);  
             
-            temp = validParameter.validFile(parameters, "mintotal", false);		
+            temp = validParameter.valid(parameters, "mintotal");
             if (temp == "not found"){	temp = "-1";		}
             else { setSomething = true; }
-			m->mothurConvert(temp, minTotal);
+			util.mothurConvert(temp, minTotal);
             
-            temp = validParameter.validFile(parameters, "minnumsamples", false);		
+            temp = validParameter.valid(parameters, "minnumsamples");
             if (temp == "not found"){	temp = "-1";		}
             else { setSomething = true; }
-			m->mothurConvert(temp, minSamples);
+			util.mothurConvert(temp, minSamples);
             
-            temp = validParameter.validFile(parameters, "minpercent", false);		
+            temp = validParameter.valid(parameters, "minpercent");
             if (temp == "not found"){	temp = "-1";		}
             else { setSomething = true; }
             
-			m->mothurConvert(temp, minPercent);
+			util.mothurConvert(temp, minPercent);
             if (minPercent < 1) {} //already in percent form
             else {  minPercent = minPercent / 100.0; } //user gave us a whole number version so convert to %
             
-            temp = validParameter.validFile(parameters, "rarepercent", false);
+            temp = validParameter.valid(parameters, "rarepercent");
             if (temp == "not found"){	temp = "-1";		}
             else { setSomething = true; }
             
-			m->mothurConvert(temp, rarePercent);
+			util.mothurConvert(temp, rarePercent);
             if (rarePercent < 1) {} //already in percent form
             else {  rarePercent = rarePercent / 100.0; } //user gave us a whole number version so convert to %
             
-            temp = validParameter.validFile(parameters, "minpercentsamples", false);		
+            temp = validParameter.valid(parameters, "minpercentsamples");
             if (temp == "not found"){	temp = "-1";		}
             else { setSomething = true; }
             
-			m->mothurConvert(temp, minPercentSamples);
+			util.mothurConvert(temp, minPercentSamples);
             if (minPercentSamples < 1) {} //already in percent form
             else {  minPercentSamples = minPercentSamples / 100.0; } //user gave us a whole number version so convert to %
 			
-			temp = validParameter.validFile(parameters, "makerare", false);		if (temp == "not found"){	temp = "T";		}
-			makeRare = m->isTrue(temp);
+			temp = validParameter.valid(parameters, "makerare");		if (temp == "not found"){	temp = "T";		}
+			makeRare = util.isTrue(temp);
             
-            temp = validParameter.validFile(parameters, "keepties", false);		if (temp == "not found"){	temp = "T";		}
-			keepties = m->isTrue(temp);
+            temp = validParameter.valid(parameters, "keepties");		if (temp == "not found"){	temp = "T";		}
+			keepties = util.isTrue(temp);
             
             if (!setSomething) { m->mothurOut("\nYou did not set any parameters. I will filter using minabund=1.\n\n"); minAbund = 1; }
         }
@@ -224,95 +224,86 @@ FilterSharedCommand::FilterSharedCommand(string option) {
 int FilterSharedCommand::execute(){
 	try {
         
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-        InputData input(sharedfile, "sharedfile");
-		vector<SharedRAbundVector*> lookup = input.getSharedRAbundVectors();
-		string lastLabel = lookup[0]->getLabel();
+        InputData input(sharedfile, "sharedfile", Groups);
+		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+        Groups = lookup->getNamesGroups();
+		string lastLabel = lookup->getLabel();
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		set<string> processedLabels;
 		set<string> userLabels = labels;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			if (m->control_pressed) {   for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }  
-                for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0;  }
+		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+            if (m->getControl_pressed()) {   delete lookup; for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0;  }
 			
-			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
+			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
 				
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				
 				processShared(lookup);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 			}
 			
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 				
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  
+				delete lookup;
 				
 				lookup = input.getSharedRAbundVectors(lastLabel);
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				
 				processShared(lookup);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 			}
 			
-			lastLabel = lookup[0]->getLabel();
+			lastLabel = lookup->getLabel();
 			//prevent memory leak
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }
+			delete lookup;
 			
 			//get next line to process
 			lookup = input.getSharedRAbundVectors();				
 		}
 		
 		
-		if (m->control_pressed) {   return 0;  }
+		if (m->getControl_pressed()) {   return 0;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) { if (lookup[i] != NULL) { delete lookup[i]; } }  
+		if (needToRun )  {
+			delete lookup;
 			lookup = input.getSharedRAbundVectors(lastLabel);
 			
-			m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+			m->mothurOut(lookup->getLabel()+"\n"); 
 			
 			processShared(lookup);
 			
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+			delete lookup;
 		}
         
 		//set shared file as new current sharedfile
-		string current = "";
+		string currentName = "";
         itTypes = outputTypes.find("shared");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSharedFile(current); }
+			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setSharedFile(currentName); }
 		}
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 	}
@@ -322,44 +313,33 @@ int FilterSharedCommand::execute(){
 	}
 }
 //**********************************************************************************************************************
-int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup) {
+int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
 	try {
-		
-		//save mothurOut's binLabels to restore for next label
-		vector<string> saveBinLabels = m->currentSharedBinLabels;
-		
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(sharedfile));
-        variables["[extension]"] = m->getExtension(sharedfile);
-        variables["[distance]"] = thislookup[0]->getLabel();
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+        variables["[extension]"] = util.getExtension(sharedfile);
+        variables["[distance]"] = sharedLookup->getLabel();
 		string outputFileName = getOutputFileName("shared", variables);        
         
-        if (m->control_pressed) {  return 0; }
+        if (m->getControl_pressed()) {  return 0; }
         
         map<string, int> labelsForRare;
         vector<string> filteredLabels;
-        vector<int> rareCounts; rareCounts.resize(m->getGroups().size(), 0);
         
-        //create new "filtered" lookup
-        vector<SharedRAbundVector*> filteredLookup;
-        for (int i = 0; i < thislookup.size(); i++) {
-            SharedRAbundVector* temp = new SharedRAbundVector();
-			temp->setLabel(thislookup[i]->getLabel());
-			temp->setGroup(thislookup[i]->getGroup());
-			filteredLookup.push_back(temp);
-        }
+        vector<SharedRAbundVector*> data = sharedLookup->getSharedRAbundVectors();
+        vector<int> rareCounts; rareCounts.resize(Groups.size(), 0);
         
         //you want to remove a percentage of OTUs
         set<string> removeLabels;
         if (rarePercent != -0.01) {
             vector<spearmanRank> otus;
             //rank otus by abundance
-            for (int i = 0; i < thislookup[0]->getNumBins(); i++) {
+            for (int i = 0; i < sharedLookup->getNumBins(); i++) {
                 float otuTotal = 0.0;
-                for (int j = 0; j < thislookup.size(); j++) {
-                    otuTotal += thislookup[j]->getAbundance(i);
+                for (int j = 0; j < data.size(); j++) {
+                    otuTotal += data[j]->get(i);
                 }
-                spearmanRank temp(saveBinLabels[i], otuTotal);
+                spearmanRank temp(sharedLookup->getOTUName(i), otuTotal);
                 otus.push_back(temp);
             }
             
@@ -367,7 +347,7 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
             sort(otus.begin(), otus.end(), compareSpearman);
             
             //find index of cutoff
-            int indexFirstNotRare = ceil(rarePercent * (float)thislookup[0]->getNumBins());
+            int indexFirstNotRare = ceil(rarePercent * (float)data[0]->getNumBins());
             
             //handle ties
             if (keepties) { //adjust indexFirstNotRare if needed
@@ -379,7 +359,7 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
                                 indexFirstNotRare = i+1; tie = false; break;
                             }
                         }
-                        if (tie) { if (m->debug) { m->mothurOut("For distance " + thislookup[0]->getLabel() + " all rare OTUs abundance tie with first 'non rare' OTU, not removing any for rarepercent parameter.\n"); }indexFirstNotRare = 0; }
+                        if (tie) { if (m->getDebug()) { m->mothurOut("For distance " + sharedLookup->getLabel() + " all rare OTUs abundance tie with first 'non rare' OTU, not removing any for rarepercent parameter.\n"); }indexFirstNotRare = 0; }
                     }
                 }
             }
@@ -390,21 +370,21 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
         
         bool filteredSomething = false;
         int numRemoved = 0;
-        for (int i = 0; i < thislookup[0]->getNumBins(); i++) {
+        for (int i = 0; i < sharedLookup->getNumBins();) {
             
-            if (m->control_pressed) { for (int j = 0; j < filteredLookup.size(); j++) { delete filteredLookup[j]; } return 0; }
+            if (m->getControl_pressed()) { for (int j = 0; j < data.size(); j++) { delete data[j]; } return 0; }
             
             bool okay = true; //innocent until proven guilty
             if (minAbund != -1) {
-                for (int j = 0; j < thislookup.size(); j++) { 
-                    if (thislookup[j]->getAbundance(i) < minAbund) { okay = false; break; }
+                for (int j = 0; j < data.size(); j++) {
+                    if (data[j]->get(i) < minAbund) { okay = false; break; }
                 }
             }
             
             if (okay && (minTotal != -1)) {
                 int otuTotal = 0;
-                for (int j = 0; j < thislookup.size(); j++) { 
-                    otuTotal += thislookup[j]->getAbundance(i);
+                for (int j = 0; j < data.size(); j++) {
+                    otuTotal += data[j]->get(i);
                 }
                 if (otuTotal < minTotal) { okay = false; }
             }
@@ -412,9 +392,9 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
             if (okay && (minPercent != -0.01)) {
                 double otuTotal = 0;
                 double total = 0;
-                for (int j = 0; j < thislookup.size(); j++) { 
-                    otuTotal += thislookup[j]->getAbundance(i);
-                    total += thislookup[j]->getNumSeqs();
+                for (int j = 0; j < data.size(); j++) {
+                    otuTotal += data[j]->get(i);
+                    total += data[j]->getNumSeqs();
                 }
                 double percent = otuTotal / total; 
                 if (percent < minPercent) { okay = false; }
@@ -423,40 +403,39 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
             
             if (okay && (minSamples != -1)) {
                 int samples = 0;
-                for (int j = 0; j < thislookup.size(); j++) { 
-                    if (thislookup[j]->getAbundance(i) != 0) { samples++; }
+                for (int j = 0; j < data.size(); j++) {
+                    if (data[j]->get(i) != 0) { samples++; }
                 }
                 if (samples < minSamples) { okay = false; }
             }
             
             if (okay && (minPercentSamples != -0.01)) {
                 double samples = 0;
-                double total = thislookup.size();
-                for (int j = 0; j < thislookup.size(); j++) { 
-                    if (thislookup[j]->getAbundance(i) != 0) { samples++; }
+                double total = data.size();
+                for (int j = 0; j < data.size(); j++) {
+                    if (data[j]->get(i) != 0) { samples++; }
                 }
                 double percent = samples / total; 
                 if (percent < minPercentSamples) { okay = false; }
             }
             
             if (okay && (rarePercent != -0.01)) {
-                if (removeLabels.count(saveBinLabels[i]) != 0) { //are we on the 'bad' list
+                if (removeLabels.count(sharedLookup->getOTUName(i)) != 0) { //are we on the 'bad' list
                     okay = false;
                 }
             }
             
             //did this OTU pass the filter criteria
             if (okay) {
-                filteredLabels.push_back(saveBinLabels[i]);
-                labelsForRare[m->getSimpleLabel(saveBinLabels[i])] = i;
-                for (int j = 0; j < filteredLookup.size(); j++) { //add this OTU to the filtered lookup
-                    filteredLookup[j]->push_back(thislookup[j]->getAbundance(i), thislookup[j]->getGroup());
-                }
+                //filteredLabels.push_back(saveBinLabels[i]);
+                //labelsForRare[util.getSimpleLabel(saveBinLabels[i])] = i;
+                ++i;
             }else { //if not, do we want to save the counts
                 filteredSomething = true;
                 if (makeRare) {
-                    for (int j = 0; j < rareCounts.size(); j++) {  rareCounts[j] += thislookup[j]->getAbundance(i); }
+                    for (int j = 0; j < rareCounts.size(); j++) {  rareCounts[j] += data[j]->get(i); }
                 }
+                sharedLookup->removeOTU(i);
                 numRemoved++;
             }
             
@@ -465,9 +444,6 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
         //if we are saving the counts add a "rare" OTU if anything was filtered
         if (makeRare) {
             if (filteredSomething) {
-                for (int j = 0; j < rareCounts.size(); j++) { //add "rare" OTU to the filtered lookup
-                    filteredLookup[j]->push_back(rareCounts[j], thislookup[j]->getGroup());
-                }
                 //create label for rare OTUs
                 map<string, int>::iterator it;
                 int otuNum = 0; bool notDone = true;
@@ -477,10 +453,10 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
                 if (filteredLabels[filteredLabels.size()-1][0] == 'P') { prefix = "PhyloType"; }
                 
                 string tempLabel = filteredLabels[filteredLabels.size()-1];
-                string simpleLastLabel = m->getSimpleLabel(tempLabel);
-                m->mothurConvert(simpleLastLabel, otuNum); otuNum++;
+                string simpleLastLabel = util.getSimpleLabel(tempLabel);
+                util.mothurConvert(simpleLastLabel, otuNum); otuNum++;
                 while (notDone) {
-                    if (m->control_pressed) { notDone = false; break; }
+                    if (m->getControl_pressed()) { notDone = false; break; }
                     
                     string potentialLabel = toString(otuNum);
                     it = labelsForRare.find(potentialLabel);
@@ -493,34 +469,20 @@ int FilterSharedCommand::processShared(vector<SharedRAbundVector*>& thislookup)
                     }
                     otuNum++;
                 }
-                filteredLabels.push_back("rareOTUs" + toString(otuNum));
+                sharedLookup->push_back(rareCounts, "rareOTUs" + toString(otuNum));
+                //filteredLabels.push_back("rareOTUs" + toString(otuNum));
             }
         }
         
         ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
-		
-        m->currentSharedBinLabels = filteredLabels;
-        
-		filteredLookup[0]->printHeaders(out);
-		
-		for (int i = 0; i < filteredLookup.size(); i++) {
-			out << filteredLookup[i]->getLabel() << '\t' << filteredLookup[i]->getGroup() << '\t';
-			filteredLookup[i]->print(out);
-		}
+        sharedLookup->print(out);
 		out.close();
         
-        
-        //save mothurOut's binLabels to restore for next label
-		m->currentSharedBinLabels = saveBinLabels;
-        
-        for (int j = 0; j < filteredLookup.size(); j++) { delete filteredLookup[j]; }
-		
         m->mothurOut("\nRemoved " + toString(numRemoved) + " OTUs.\n");
         
 		return 0;
-		
 	}
 	catch(exception& e) {
 		m->errorOut(e, "FilterSharedCommand", "processShared");
