@@ -7,6 +7,7 @@
 //
 
 #include "getcoremicrobiomecommand.h"
+#include "getrelabundcommand.h"
 
 
 //**********************************************************************************************************************
@@ -58,7 +59,7 @@ string GetCoreMicroBiomeCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "coremicrobiome") {  pattern = "[filename],[tag],core.microbiome"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -105,7 +106,7 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
 			
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
                 
@@ -113,7 +114,7 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
 				it = parameters.find("relabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["relabund"] = inputDir + it->second;		}
 				}
@@ -121,7 +122,7 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
                 it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -131,23 +132,23 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
             outputTypes["coremicrobiome"] = tempOutNames; 
 
 			//check for parameters
-            sharedfile = validParameter.validFile(parameters, "shared", true);
+            sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { abort = true; }
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else { inputFileName = sharedfile; format = "sharedfile"; m->setSharedFile(sharedfile); }
+			else { inputFileName = sharedfile; format = "sharedfile"; current->setSharedFile(sharedfile); }
 			
-			relabundfile = validParameter.validFile(parameters, "relabund", true);
+			relabundfile = validParameter.validFile(parameters, "relabund");
 			if (relabundfile == "not open") { abort = true; }
 			else if (relabundfile == "not found") { relabundfile = ""; }
-			else { inputFileName = relabundfile; format = "relabund"; m->setRelAbundFile(relabundfile); }
+			else { inputFileName = relabundfile; format = "relabund"; current->setRelAbundFile(relabundfile); }
             
             if ((relabundfile == "") && (sharedfile == "")) { 
 				//is there are current file available for either of these?
 				//give priority to shared, then relabund
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") {  inputFileName = sharedfile; format="sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
-					relabundfile = m->getRelAbundFile(); 
+					relabundfile = current->getRelAbundFile(); 
 					if (relabundfile != "") {  inputFileName = relabundfile; format="relabund"; m->mothurOut("Using " + relabundfile + " as input file for the relabund parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("No valid current files. You must provide a shared or relabund."); m->mothurOutEndLine(); 
@@ -157,28 +158,27 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
 			}
             
             //if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	
-				outputDir = m->hasPath(inputFileName); //if user entered a file with a path then preserve it	
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
+				outputDir = util.hasPath(inputFileName); //if user entered a file with a path then preserve it	
 			}
             
-            string groups = validParameter.validFile(parameters, "groups", false);			
+            string groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; }
-			else { m->splitAtDash(groups, Groups); }
-			m->setGroups(Groups);
+			else { util.splitAtDash(groups, Groups); if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } } }
             
-            string label = validParameter.validFile(parameters, "label", false);			
+            string label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
             
-            output = validParameter.validFile(parameters, "output", false);		if(output == "not found"){	output = "fraction"; }
+            output = validParameter.valid(parameters, "output");		if(output == "not found"){	output = "fraction"; }
 						
 			if ((output != "fraction") && (output != "count")) { m->mothurOut(output + " is not a valid output form. Options are fraction and count. I will use fraction."); m->mothurOutEndLine(); output = "fraction"; }
             
-            string temp = validParameter.validFile(parameters, "abundance", false);	if (temp == "not found"){	temp = "-1";	}
-			m->mothurConvert(temp, abund);
+            string temp = validParameter.valid(parameters, "abundance");	if (temp == "not found"){	temp = "-1";	}
+			util.mothurConvert(temp, abund);
             
             if (abund != -1) { 
                 if ((abund < 0) || (abund > 100)) { m->mothurOut(toString(abund) + " is not a valid number for abund. Must be between 0 and 100.\n"); }
@@ -191,8 +191,7 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
                             if (found) { factorString += "0"; }
                         }
                     }
-                    cout << factorString << endl;
-                    m->mothurConvert(factorString, factor);
+                    util.mothurConvert(factorString, factor);
                 }else {
                     factor = 100;
                     abund /= 100;
@@ -201,8 +200,8 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
                 factor = 100;
             }
             
-            temp = validParameter.validFile(parameters, "samples", false);	if (temp == "not found"){	temp = "-1";	}
-			m->mothurConvert(temp, samples);
+            temp = validParameter.valid(parameters, "samples");	if (temp == "not found"){	temp = "-1";	}
+			util.mothurConvert(temp, samples);
 
 		}
 		
@@ -217,14 +216,34 @@ GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
 int GetCoreMicroBiomeCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
-        InputData input(inputFileName, format);
-        vector<SharedRAbundFloatVector*> lookup = input.getSharedRAbundFloatVectors();
-        string lastLabel = lookup[0]->getLabel();
+        if (format == "sharedfile") { //convert to relabund
+            string options = "shared=" + sharedfile;
+            if (outputDir != "")                            { options += ", outputdir=" + outputDir;    }
+            
+            //calc dists for fastafile
+            m->mothurOut("/******************************************/\n");
+            m->mothurOut("Running command: get.relabund(" + options + ")\n");
+            Command* relabundCommand = new GetRelAbundCommand(options);
+            
+            relabundCommand->execute();
+            map<string, vector<string> > filenames = relabundCommand->getOutputFiles();
+            relabundfile = filenames["relabund"][0];
+            inputFileName = relabundfile; format="relabund";
+            
+            delete relabundCommand;
+            current->setMothurCalling(false);
+            m->mothurOut("/******************************************/\n");
+        }
+        
+        InputData input(inputFileName, format, Groups);
+        SharedRAbundFloatVectors* lookup = input.getSharedRAbundFloatVectors();
+        Groups = lookup->getNamesGroups();
+        string lastLabel = lookup->getLabel();
         
         if (samples != -1) { 
-            if ((samples < 1) || (samples > lookup.size())) { m->mothurOut(toString(samples) + " is not a valid number for samples. Must be an integer between 1 and the number of samples in your file. Your file contains " + toString(lookup.size()) + " samples, so I will use that.\n"); samples = lookup.size(); }
+            if ((samples < 1) || (samples > lookup->size())) { m->mothurOut(toString(samples) + " is not a valid number for samples. Must be an integer between 1 and the number of samples in your file. Your file contains " + toString(lookup->size()) + " samples, so I will use that.\n"); samples = lookup->size(); }
         }
 
         
@@ -233,47 +252,47 @@ int GetCoreMicroBiomeCommand::execute(){
         set<string> userLabels = labels;
         
         //as long as you are not at the end of the file or done wih the lines you want
-        while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+        while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
             
-            if (m->control_pressed) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); } return 0; }
+            if (m->getControl_pressed()) { delete lookup;  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); } return 0; }
             
-            if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
+            if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
                 
-                m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                m->mothurOut(lookup->getLabel()+"\n"); 
                 
                 createTable(lookup);
                 
-                processedLabels.insert(lookup[0]->getLabel());
-                userLabels.erase(lookup[0]->getLabel());
+                processedLabels.insert(lookup->getLabel());
+                userLabels.erase(lookup->getLabel());
             }
             
-            if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-                string saveLabel = lookup[0]->getLabel();
+            if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+                string saveLabel = lookup->getLabel();
                 
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  
+                delete lookup;
                 lookup = input.getSharedRAbundFloatVectors(lastLabel);
-                m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                m->mothurOut(lookup->getLabel()+"\n"); 
                 
                 createTable(lookup);
                 
-                processedLabels.insert(lookup[0]->getLabel());
-                userLabels.erase(lookup[0]->getLabel());
+                processedLabels.insert(lookup->getLabel());
+                userLabels.erase(lookup->getLabel());
                 
                 //restore real lastlabel to save below
-                lookup[0]->setLabel(saveLabel);
+                lookup->setLabels(saveLabel);
             }
             
-            lastLabel = lookup[0]->getLabel();
+            lastLabel = lookup->getLabel();
             //prevent memory leak
-            for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }
+            delete lookup;
             
-            if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+            if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
             
             //get next line to process
             lookup = input.getSharedRAbundFloatVectors();				
         }
         
-        if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+        if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
         
         //output error messages about any remaining user labels
         set<string>::iterator it;
@@ -289,24 +308,24 @@ int GetCoreMicroBiomeCommand::execute(){
         }
         
         //run last label if you need to
-        if (needToRun == true)  {
-            for (int i = 0; i < lookup.size(); i++) { if (lookup[i] != NULL) { delete lookup[i]; } }  
+        if (needToRun )  {
+            delete lookup;
+ 
             lookup = input.getSharedRAbundFloatVectors(lastLabel);
             
-            m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+            m->mothurOut(lookup->getLabel()+"\n"); 
             
             createTable(lookup);
             
-            for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+            delete lookup;
+
         }
         
-        if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+        if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
         
         //output files created by command
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
         return 0;
 		
     }
@@ -317,18 +336,18 @@ int GetCoreMicroBiomeCommand::execute(){
 }
 //**********************************************************************************************************************
 
-int GetCoreMicroBiomeCommand::createTable(vector<SharedRAbundFloatVector*>& lookup){
+int GetCoreMicroBiomeCommand::createTable(SharedRAbundFloatVectors*& lookup){
 	try {
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileName));
-        variables["[tag]"] = lookup[0]->getLabel();
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileName));
+        variables["[tag]"] = lookup->getLabel();
         string outputFileName = getOutputFileName("coremicrobiome", variables);
         outputNames.push_back(outputFileName);  outputTypes["coremicrobiome"].push_back(outputFileName);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
         
-        int numSamples = lookup.size();
-        int numOtus = lookup[0]->getNumBins();
+        int numSamples = lookup->size();
+        int numOtus = lookup->getNumBins();
         
         //table is 100 by numsamples
         //question we are answering is: what fraction of OTUs in a study have a relative abundance at or above %X
@@ -353,15 +372,17 @@ int GetCoreMicroBiomeCommand::createTable(vector<SharedRAbundFloatVector*>& look
             otuNames[thisAbund] = temp;
         }
         
+        vector<string> sampleNames = lookup->getNamesGroups();
+        vector<string> currentLabels = lookup->getOTUNames();
         for (int i = 0; i < numOtus; i++) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             //count number of samples in this otu with a relabund >= spot in count
             vector<int> counts; counts.resize(factor+1, 0);
             
-            for (int j = 0; j < lookup.size(); j++) {
-                double relabund = lookup[j]->getAbundance(i);
+            for (int j = 0; j < sampleNames.size(); j++) {
+                double relabund = lookup->get(i, sampleNames[j]);
                 int wholeRelabund = (int) (floor(relabund*factor));
                 for (int k = 0; k < wholeRelabund+1; k++) { counts[k]++; }
             }
@@ -371,14 +392,14 @@ int GetCoreMicroBiomeCommand::createTable(vector<SharedRAbundFloatVector*>& look
                 for (int k = 0; k < counts[j]; k++) { table[j][k]++; }
                 
                 if ((abund == -1) && (samples != -1)) { //we want all OTUs with this number of samples
-                    if (counts[j] >= samples) { otuNames[j].push_back(m->currentSharedBinLabels[i]); }
+                    if (counts[j] >= samples) { otuNames[j].push_back(currentLabels[i]); }
                 }else if ((abund != -1) && (samples == -1)) { //we want all OTUs with this relabund
                     if (j == (abund*factor)) {
-                        for (int k = 0; k < counts[j]; k++) {  otuNames[k+1].push_back(m->currentSharedBinLabels[i]); }
+                        for (int k = 0; k < counts[j]; k++) {  otuNames[k+1].push_back(currentLabels[i]); }
                     }
                 }else if ((abund != -1) && (samples != -1)) { //we want only OTUs with this relabund for this number of samples
                     if ((j == (abund*factor)) && (counts[j] >= samples)) {
-                        otuNames[j].push_back(m->currentSharedBinLabels[i]); 
+                        otuNames[j].push_back(currentLabels[i]);
                     }
                 }
             }
@@ -392,13 +413,13 @@ int GetCoreMicroBiomeCommand::createTable(vector<SharedRAbundFloatVector*>& look
         int precisionLength = (toString(factor)).length();
         for (int i = 0; i < table.size(); i++) {
             out << "Relabund-" << setprecision(precisionLength-1)<< (float)(i/(float)factor) << "\t";
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             for (int j = 0; j < table[i].size(); j++) {  if (output == "fraction") { table[i][j] /= (double) numOtus; } }
         }
         out << endl;
         
         for (int i = 0; i < numSamples; i++) {
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             out << i+1;
             for (int j = 0; j < table.size(); j++) {  out << setprecision(6) << '\t' << table[j][i]; }
             out << endl;
@@ -406,13 +427,13 @@ int GetCoreMicroBiomeCommand::createTable(vector<SharedRAbundFloatVector*>& look
 
         out.close();
         
-        if (m->control_pressed) { return 0; }
+        if (m->getControl_pressed()) { return 0; }
         
         if ((samples != -1) || (abund != -1))  {
-            string outputFileName2 = outputDir + m->getRootName(m->getSimpleName(inputFileName)) + lookup[0]->getLabel() + ".core.microbiomelist";
+            string outputFileName2 = outputDir + util.getRootName(util.getSimpleName(inputFileName)) + lookup->getLabel() + ".core.microbiomelist";
             outputNames.push_back(outputFileName2);  outputTypes["coremicrobiome"].push_back(outputFileName2);
             ofstream out2;
-            m->openOutputFile(outputFileName2, out2);
+            util.openOutputFile(outputFileName2, out2);
             
             if ((abund == -1) && (samples != -1)) { //we want all OTUs with this number of samples
                 out2 << "Relabund\tOTUList_for_samples=" << samples << "\n";
@@ -423,10 +444,10 @@ int GetCoreMicroBiomeCommand::createTable(vector<SharedRAbundFloatVector*>& look
             }
 
             for (map<int, vector<string> >::iterator it = otuNames.begin(); it != otuNames.end(); it++) {
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
                 vector<string> temp = it->second;
-                string list = m->makeList(temp);
+                string list = util.makeList(temp);
                 
                 if ((abund != -1) && (samples == -1)) { //fill with all samples
                     out2 << it->first << '\t' << list << endl;
