@@ -60,7 +60,7 @@ string GetOtuLabelsCommand::getOutputPattern(string type) {
         else if (type == "corraxes")        {   pattern = "[filename],pick,[extension]";    }
         else if (type == "list")            {   pattern = "[filename],[distance],pick,[extension]";    }
         else if (type == "shared")          {   pattern = "[filename],[distance],pick,[extension]";    }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -112,7 +112,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
 			
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
                 
@@ -122,7 +122,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
                 it = parameters.find("constaxonomy");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["constaxonomy"] = inputDir + it->second;		}
 				}
@@ -130,7 +130,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
                 it = parameters.find("accnos");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["accnos"] = inputDir + it->second;		}
 				}
@@ -138,7 +138,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
                 it = parameters.find("corraxes");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["corraxes"] = inputDir + it->second;		}
 				}
@@ -146,7 +146,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
                 it = parameters.find("otucorr");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["otucorr"] = inputDir + it->second;		}
 				}
@@ -154,7 +154,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
                 it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -162,7 +162,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
                 it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -176,46 +176,46 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
             outputTypes["list"] = tempOutNames;
             
  			//check for parameters
-            accnosfile = validParameter.validFile(parameters, "accnos", true);
+            accnosfile = validParameter.validFile(parameters, "accnos");
 			if (accnosfile == "not open") { abort = true; }
 			else if (accnosfile == "not found") {  
-				accnosfile = m->getAccnosFile(); 
+				accnosfile = current->getAccnosFile(); 
 				if (accnosfile != "") {  m->mothurOut("Using " + accnosfile + " as input file for the accnos parameter."); m->mothurOutEndLine(); }
 				else { 
 					m->mothurOut("You have no valid accnos file and accnos is required."); m->mothurOutEndLine(); 
 					abort = true;
 				} 
-			}else { m->setAccnosFile(accnosfile); }	
+			}else { current->setAccnosFile(accnosfile); }	
 			
-			constaxonomyfile = validParameter.validFile(parameters, "constaxonomy", true);
+			constaxonomyfile = validParameter.validFile(parameters, "constaxonomy");
 			if (constaxonomyfile == "not open") { constaxonomyfile = ""; abort = true; }
 			else if (constaxonomyfile == "not found") {  constaxonomyfile = "";  }
             
-            corraxesfile = validParameter.validFile(parameters, "corraxes", true);
+            corraxesfile = validParameter.validFile(parameters, "corraxes");
 			if (corraxesfile == "not open") { corraxesfile = ""; abort = true; }
 			else if (corraxesfile == "not found") {  corraxesfile = "";  }
             
-            otucorrfile = validParameter.validFile(parameters, "otucorr", true);
+            otucorrfile = validParameter.validFile(parameters, "otucorr");
 			if (otucorrfile == "not open") { otucorrfile = ""; abort = true; }
 			else if (otucorrfile == "not found") {  otucorrfile = "";  }
             
-            listfile = validParameter.validFile(parameters, "list", true);
+            listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") {  listfile = "";  }
-            else { m->setListFile(listfile); }
+            else { current->setListFile(listfile); }
             
-            sharedfile = validParameter.validFile(parameters, "shared", true);
+            sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }
 			else if (sharedfile == "not found") {  sharedfile = "";  }
-            else { m->setSharedFile(sharedfile); }
+            else { current->setSharedFile(sharedfile); }
             
             //if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	 outputDir = ""; 	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	 outputDir = ""; 	}
             
             if ((constaxonomyfile == "") && (corraxesfile == "") && (otucorrfile == "") && (sharedfile == "") && (listfile == ""))  { m->mothurOut("You must provide one of the following: constaxonomy, corraxes, otucorr, shared or list."); m->mothurOutEndLine(); abort = true; }
             
             if ((sharedfile != "") || (listfile != "")) {
-                label = validParameter.validFile(parameters, "label", false);			
+                label = validParameter.valid(parameters, "label");			
                 if (label == "not found") { label = ""; m->mothurOut("You did not provide a label, I will use the first label in your inputfile."); m->mothurOutEndLine(); label=""; }
             }
 		}
@@ -231,16 +231,16 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
 int GetOtuLabelsCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
         //get labels you want to keep
-		labels = m->readAccnos(accnosfile);
+		labels = util.readAccnos(accnosfile);
         //simplfy labels
         set<string> newLabels;
-        for (set<string>::iterator it = labels.begin(); it != labels.end(); it++) {  newLabels.insert(m->getSimpleLabel(*it)); }
+        for (set<string>::iterator it = labels.begin(); it != labels.end(); it++) {  newLabels.insert(util.getSimpleLabel(*it)); }
         labels = newLabels;
         
-		if (m->control_pressed) { return 0; }
+		if (m->getControl_pressed()) { return 0; }
 		
 		//read through the correct file and output lines you want to keep
 		if (constaxonomyfile != "")	{		readClassifyOtu();      }
@@ -249,29 +249,27 @@ int GetOtuLabelsCommand::execute(){
         if (listfile != "")         {		readList();             }
         if (sharedfile != "")		{		readShared();           }
         
-        if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+        if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
         
         //output files created by command
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
         
-        string current = "";
+        string currentName = "";
         itTypes = outputTypes.find("list");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setListFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setListFile(currentName); }
         }
         
         itTypes = outputTypes.find("shared");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSharedFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setSharedFile(currentName); }
         }
         
         //set constaxonomy file as new current constaxonomyfile
         itTypes = outputTypes.find("constaxonomy");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setConsTaxonomyFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setConsTaxonomyFile(currentName); }
         }
         
         return 0;
@@ -285,38 +283,38 @@ int GetOtuLabelsCommand::execute(){
 int GetOtuLabelsCommand::readClassifyOtu(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(constaxonomyfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(constaxonomyfile);  }
         map<string, string> variables; 
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(constaxonomyfile));
-        variables["[extension]"] = m->getExtension(constaxonomyfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(constaxonomyfile));
+        variables["[extension]"] = util.getExtension(constaxonomyfile);
 		string outputFileName = getOutputFileName("constaxonomy", variables);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		ifstream in;
-		m->openInputFile(constaxonomyfile, in);
+		util.openInputFile(constaxonomyfile, in);
 		
 		bool wroteSomething = false;
 		int selectedCount = 0;
 		
         //read headers
-        string headers = m->getline(in);
+        string headers = util.getline(in);
         out << headers << endl;
         
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             string otu = ""; string tax = "unknown";
             int size = 0;
             
-            in >> otu >> size; m->gobble(in);
-            tax = m->getline(in); m->gobble(in);
+            in >> otu >> size; util.gobble(in);
+            tax = util.getline(in); util.gobble(in);
             
-            if (m->debug) { m->mothurOut("Otu=" + otu + ", size=" + toString(size) + ", tax=" + tax + "\n"); }
+            if (m->getDebug()) { m->mothurOut("Otu=" + otu + ", size=" + toString(size) + ", tax=" + tax + "\n"); }
             
-            if (labels.count(m->getSimpleLabel(otu)) != 0) {
+            if (labels.count(util.getSimpleLabel(otu)) != 0) {
 				wroteSomething = true;
 				selectedCount++;
                 
@@ -343,35 +341,35 @@ int GetOtuLabelsCommand::readClassifyOtu(){
 int GetOtuLabelsCommand::readOtuAssociation(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(otucorrfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(otucorrfile);  }
         map<string, string> variables; 
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(otucorrfile));
-        variables["[extension]"] = m->getExtension(otucorrfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(otucorrfile));
+        variables["[extension]"] = util.getExtension(otucorrfile);
 		string outputFileName = getOutputFileName("otucorr", variables);
 
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		ifstream in;
-		m->openInputFile(otucorrfile, in);
+		util.openInputFile(otucorrfile, in);
 		
 		bool wroteSomething = false;
 		int selectedCount = 0;
 		
         //read headers
-        string headers = m->getline(in);
+        string headers = util.getline(in);
         out << headers << endl;
         
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             string otu1 = ""; 
             string otu2 = ""; 
             in >> otu1 >> otu2;
-            string line = m->getline(in); m->gobble(in);
+            string line = util.getline(in); util.gobble(in);
             
-            if ((labels.count(m->getSimpleLabel(otu1)) != 0) && (labels.count(m->getSimpleLabel(otu2)) != 0)){
+            if ((labels.count(util.getSimpleLabel(otu1)) != 0) && (labels.count(util.getSimpleLabel(otu2)) != 0)){
 				wroteSomething = true;
 				selectedCount++;
                 
@@ -398,35 +396,35 @@ int GetOtuLabelsCommand::readOtuAssociation(){
 int GetOtuLabelsCommand::readCorrAxes(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(corraxesfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(corraxesfile);  }
         map<string, string> variables; 
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(corraxesfile));
-        variables["[extension]"] = m->getExtension(corraxesfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(corraxesfile));
+        variables["[extension]"] = util.getExtension(corraxesfile);
 		string outputFileName = getOutputFileName("corraxes", variables);
 
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
         
 		ifstream in;
-		m->openInputFile(corraxesfile, in);
+		util.openInputFile(corraxesfile, in);
 		
 		bool wroteSomething = false;
 		int selectedCount = 0;
 		
         //read headers
-        string headers = m->getline(in);
+        string headers = util.getline(in);
         out << headers << endl;
         
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             string otu = ""; 
             in >> otu;
-            string line = m->getline(in); m->gobble(in);
+            string line = util.getline(in); util.gobble(in);
             
-            if (labels.count(m->getSimpleLabel(otu)) != 0) {
+            if (labels.count(util.getSimpleLabel(otu)) != 0) {
 				wroteSomething = true;
 				selectedCount++;
                 
@@ -453,65 +451,42 @@ int GetOtuLabelsCommand::readCorrAxes(){
 int GetOtuLabelsCommand::readShared(){
 	try {
         
-        getShared();
+        SharedRAbundVectors* lookup = getShared();
         
-        if (m->control_pressed) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } return 0; }
+        if (m->getControl_pressed()) { delete lookup; return 0; }
           
         vector<string> newLabels;
         
-        //create new "filtered" lookup
-        vector<SharedRAbundVector*> newLookup;
-        for (int i = 0; i < lookup.size(); i++) {
-            SharedRAbundVector* temp = new SharedRAbundVector();
-			temp->setLabel(lookup[i]->getLabel());
-			temp->setGroup(lookup[i]->getGroup());
-			newLookup.push_back(temp);
-        }
-        
         bool wroteSomething = false;
         int numSelected = 0;
-        for (int i = 0; i < lookup[0]->getNumBins(); i++) {
+        for (int i = 0; i < lookup->getNumBins();) {
             
-            if (m->control_pressed) { for (int j = 0; j < newLookup.size(); j++) { delete newLookup[j]; } for (int j = 0; j < lookup.size(); j++) { delete lookup[j]; } return 0; }
+            if (m->getControl_pressed()) { delete lookup; return 0; }
             
             //is this otu on the list
-            if (labels.count(m->getSimpleLabel(m->currentSharedBinLabels[i])) != 0) {
+            if (labels.count(util.getSimpleLabel(lookup->getOTUNames()[i])) != 0) {
                 numSelected++; wroteSomething = true;
-                newLabels.push_back(m->currentSharedBinLabels[i]);
-                for (int j = 0; j < newLookup.size(); j++) { //add this OTU to the new lookup
-                    newLookup[j]->push_back(lookup[j]->getAbundance(i), lookup[j]->getGroup());
-                }
-            }
+                ++i;
+            }else { lookup->removeOTU(i);  }
         }
-        
+    
         string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(sharedfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(sharedfile);  }
         map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(sharedfile));
-        variables["[extension]"] = m->getExtension(sharedfile);
-        variables["[distance]"] = lookup[0]->getLabel();
-		string outputFileName = getOutputFileName("shared", variables); 
-        ofstream out;
-		m->openOutputFile(outputFileName, out);
-		outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
-        
-		for (int j = 0; j < lookup.size(); j++) { delete lookup[j]; }
-        
-        m->currentSharedBinLabels = newLabels;
-        
-		newLookup[0]->printHeaders(out);
-		
-		for (int i = 0; i < newLookup.size(); i++) {
-			out << newLookup[i]->getLabel() << '\t' << newLookup[i]->getGroup() << '\t';
-			newLookup[i]->print(out);
-		}
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(sharedfile));
+        variables["[extension]"] = util.getExtension(sharedfile);
+        variables["[distance]"] = lookup->getLabel();
+		string outputFileName = getOutputFileName("shared", variables);
+        outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
+        ofstream out; util.openOutputFile(outputFileName, out);
+        lookup->print(out);
 		out.close();
         
-        for (int j = 0; j < newLookup.size(); j++) { delete newLookup[j]; }
+        delete lookup;
         
-        if (wroteSomething == false) { m->mothurOut("Your file does not contain any OTUs from the .accnos file."); m->mothurOutEndLine();  }
+        if (wroteSomething == false) { m->mothurOut("Your file does not contain any OTUs from the .accnos file.\n");  }
 
-		m->mothurOut("Selected " + toString(numSelected) + " OTUs from your shared file."); m->mothurOutEndLine();
+		m->mothurOut("Selected " + toString(numSelected) + " OTUs from your shared file.\n"); 
         
         return 0;
     }
@@ -525,7 +500,7 @@ int GetOtuLabelsCommand::readList(){
 	try {
         getListVector();
         
-        if (m->control_pressed) { delete list; return 0;}
+        if (m->getControl_pressed()) { delete list; return 0;}
         
         ListVector newList;
         newList.setLabel(list->getLabel());
@@ -536,9 +511,9 @@ int GetOtuLabelsCommand::readList(){
         vector<string> newLabels;
         for (int i = 0; i < list->getNumBins(); i++) {
             
-            if (m->control_pressed) { delete list; return 0;}
+            if (m->getControl_pressed()) { delete list; return 0;}
             
-            if (labels.count(m->getSimpleLabel(binLabels[i])) != 0) {
+            if (labels.count(util.getSimpleLabel(binLabels[i])) != 0) {
 				selectedCount++;
                 newList.push_back(list->get(i));
                 newLabels.push_back(binLabels[i]);
@@ -546,21 +521,20 @@ int GetOtuLabelsCommand::readList(){
         }
         
         string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(listfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(listfile);  }
         map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(listfile));
-        variables["[extension]"] = m->getExtension(listfile);
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[extension]"] = util.getExtension(listfile);
         variables["[distance]"] = list->getLabel();
 		string outputFileName = getOutputFileName("list", variables);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
         
 		delete list;
         //print new listvector
         if (newList.getNumBins() != 0) {
             wroteSomething = true;
             newList.setLabels(newLabels);
-            newList.printHeaders(out);
             newList.print(out, false);
         }
 		out.close();
@@ -580,7 +554,7 @@ int GetOtuLabelsCommand::readList(){
 //**********************************************************************************************************************
 int GetOtuLabelsCommand::getListVector(){
 	try {
-		InputData input(listfile, "list");
+		InputData input(listfile, "list", nullVector);
 		list = input.getListVector();
 		string lastLabel = list->getLabel();
 		
@@ -593,7 +567,7 @@ int GetOtuLabelsCommand::getListVector(){
 		
 		//as long as you are not at the end of the file or done wih the lines you want
 		while((list != NULL) && (userLabels.size() != 0)) {
-			if (m->control_pressed) {  return 0;  }
+			if (m->getControl_pressed()) {  return 0;  }
 			
 			if(labels.count(list->getLabel()) == 1){
 				processedLabels.insert(list->getLabel());
@@ -601,7 +575,7 @@ int GetOtuLabelsCommand::getListVector(){
 				break;
 			}
 			
-			if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+			if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 				string saveLabel = list->getLabel();
 				
 				delete list;
@@ -624,23 +598,18 @@ int GetOtuLabelsCommand::getListVector(){
 		}
 		
 		
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
+		if (needToRun )  {
 			delete list; 
 			list = input.getListVector(lastLabel);
 		}	
@@ -653,13 +622,13 @@ int GetOtuLabelsCommand::getListVector(){
 	}
 }
 //**********************************************************************************************************************
-int GetOtuLabelsCommand::getShared(){
+SharedRAbundVectors* GetOtuLabelsCommand::getShared(){
 	try {
-		InputData input(sharedfile, "sharedfile");
-		lookup = input.getSharedRAbundVectors();
-		string lastLabel = lookup[0]->getLabel();
+		InputData input(sharedfile, "sharedfile", nullVector);
+		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+		string lastLabel = lookup->getLabel();
 		
-		if (label == "") { label = lastLabel;  return 0; }
+		if (label == "") { label = lastLabel;  return lookup; }
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		set<string> labels; labels.insert(label);
@@ -667,60 +636,53 @@ int GetOtuLabelsCommand::getShared(){
 		set<string> userLabels = labels;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup[0] != NULL) && (userLabels.size() != 0)) {
-			if (m->control_pressed) {   return 0;  }
+		while((lookup != NULL) && (userLabels.size() != 0)) {
+			if (m->getControl_pressed()) {   delete lookup; return NULL;  }
 			
-			if(labels.count(lookup[0]->getLabel()) == 1){
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+			if(labels.count(lookup->getLabel()) == 1){
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				break;
 			}
 			
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 				
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+                delete lookup;
 				lookup = input.getSharedRAbundVectors(lastLabel);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 				break;
 			}
 			
-			lastLabel = lookup[0]->getLabel();			
+			lastLabel = lookup->getLabel();
 			
 			//get next line to process
 			//prevent memory leak
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+            delete lookup;
 			lookup = input.getSharedRAbundVectors();
 		}
 		
 		
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) {	delete lookup[i];	} } 
+		if (needToRun )  {
+			delete lookup;
 			lookup = input.getSharedRAbundVectors(lastLabel);
 		}	
 		
-		return 0;
+		return lookup;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "GetOtuLabelsCommand", "getShared");	
