@@ -42,7 +42,6 @@ string GetRAbundCommand::getHelpString(){
 		helpString += "Example get.rabund(sorted=F).\n";
 		helpString += "The default value for label is all labels in your inputfile.\n";
 		helpString += "The get.rabund command outputs a .rabund file containing the lines you selected.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. label), '=' and parameters (i.e.yourLabels).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -56,7 +55,7 @@ string GetRAbundCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "rabund")      {   pattern = "[filename],rabund";    }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -108,14 +107,14 @@ GetRAbundCommand::GetRAbundCommand(string option)  {
 			outputTypes["rabund"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -123,7 +122,7 @@ GetRAbundCommand::GetRAbundCommand(string option)  {
 				it = parameters.find("sabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["sabund"] = inputDir + it->second;		}
 				}
@@ -131,7 +130,7 @@ GetRAbundCommand::GetRAbundCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
@@ -139,32 +138,32 @@ GetRAbundCommand::GetRAbundCommand(string option)  {
 			
 			
 			//check for required parameters
-			listfile = validParameter.validFile(parameters, "list", true);
+			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else {  format = "list"; inputfile = listfile; m->setListFile(listfile); }
+			else {  format = "list"; inputfile = listfile; current->setListFile(listfile); }
 			
-			sabundfile = validParameter.validFile(parameters, "sabund", true);
+			sabundfile = validParameter.validFile(parameters, "sabund");
 			if (sabundfile == "not open") { sabundfile = ""; abort = true; }	
 			else if (sabundfile == "not found") { sabundfile = ""; }
-			else {  format = "sabund"; inputfile = sabundfile; m->setSabundFile(sabundfile); }
+			else {  format = "sabund"; inputfile = sabundfile; current->setSabundFile(sabundfile); }
             
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
 			if (countfile == "not open") { countfile = ""; abort = true; }
 			else if (countfile == "not found") { countfile = ""; }
-			else {  m->setCountTableFile(countfile); }
+			else {  current->setCountFile(countfile); }
 			
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
 			string temp;
-			temp = validParameter.validFile(parameters, "sorted", false);			if (temp == "not found") { temp = "T"; }
-			sorted = m->isTrue(temp);
+			temp = validParameter.valid(parameters, "sorted");			if (temp == "not found") { temp = "T"; }
+			sorted = util.isTrue(temp);
 			
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
@@ -172,10 +171,10 @@ GetRAbundCommand::GetRAbundCommand(string option)  {
 				//is there are current file available for any of these?
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
-				listfile = m->getListFile(); 
+				listfile = current->getListFile(); 
 				if (listfile != "") { inputfile = listfile; format = "list"; m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
 				else { 
-					sabundfile = m->getSabundFile(); 
+					sabundfile = current->getSabundFile(); 
 					if (sabundfile != "") { inputfile = sabundfile; format = "sabund"; m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("No valid current files. You must provide a list or sabund file."); m->mothurOutEndLine(); 
@@ -187,7 +186,7 @@ GetRAbundCommand::GetRAbundCommand(string option)  {
 			if ((countfile != "") && (listfile == "")) { m->mothurOut("[ERROR]: You can only use the count file with a list file, aborting.\n"); abort = true; }
             
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(inputfile); 	}			
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputfile); 	}			
 			
 		}
 			
@@ -203,17 +202,17 @@ GetRAbundCommand::GetRAbundCommand(string option)  {
 int GetRAbundCommand::execute(){
 	try {
 	
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputfile));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputfile));
 		filename = getOutputFileName("rabund", variables);
-		m->openOutputFile(filename, out);
+		util.openOutputFile(filename, out);
 		
         if (countfile != "") {
             processList(out);
         }else {
-            InputData input(inputfile, format);
+            InputData input(inputfile, format, nullVector);
             RAbundVector* rabund = input.getRAbundVector();
             string lastLabel = rabund->getLabel();
             
@@ -221,14 +220,14 @@ int GetRAbundCommand::execute(){
             set<string> processedLabels;
             set<string> userLabels = labels;
             
-            if (m->control_pressed) {  outputTypes.clear();  out.close(); m->mothurRemove(filename); delete rabund;  return 0; }
+            if (m->getControl_pressed()) {  outputTypes.clear();  out.close(); util.mothurRemove(filename); delete rabund;  return 0; }
             
             while((rabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
                 
                 if(allLines == 1 || labels.count(rabund->getLabel()) == 1){
 					m->mothurOut(rabund->getLabel()); m->mothurOutEndLine();
 					
-					if (m->control_pressed) {   outputTypes.clear(); out.close(); m->mothurRemove(filename);   delete rabund;  return 0;  }
+					if (m->getControl_pressed()) {   outputTypes.clear(); out.close(); util.mothurRemove(filename);   delete rabund;  return 0;  }
 					
 					if(sorted)	{   rabund->print(out);				}
 					else		{	rabund->nonSortedPrint(out);	}
@@ -237,7 +236,7 @@ int GetRAbundCommand::execute(){
 					userLabels.erase(rabund->getLabel());
                 }
                 
-                if ((m->anyLabelsToProcess(rabund->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+                if ((util.anyLabelsToProcess(rabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 					string saveLabel = rabund->getLabel();
 					
 					delete rabund;
@@ -245,7 +244,7 @@ int GetRAbundCommand::execute(){
 					
 					m->mothurOut(rabund->getLabel()); m->mothurOutEndLine();
 					
-					if (m->control_pressed) {   outputTypes.clear(); out.close(); m->mothurRemove(filename);  delete rabund;  return 0;  }
+					if (m->getControl_pressed()) {   outputTypes.clear(); out.close(); util.mothurRemove(filename);  delete rabund;  return 0;  }
 					
 					if(sorted)	{   rabund->print(out);				}
 					else		{	rabund->nonSortedPrint(out);	}
@@ -277,13 +276,13 @@ int GetRAbundCommand::execute(){
             }
             
             //run last label if you need to
-            if (needToRun == true)  {
+            if (needToRun )  {
                 if (rabund != NULL) {	delete rabund;	}
                 rabund = input.getRAbundVector(lastLabel);
                 
                 m->mothurOut(rabund->getLabel()); m->mothurOutEndLine();
                 
-                if (m->control_pressed) {  outputTypes.clear(); out.close(); m->mothurRemove(filename);   delete rabund;  return 0; }
+                if (m->getControl_pressed()) {  outputTypes.clear(); out.close(); util.mothurRemove(filename);   delete rabund;  return 0; }
                 
                 if(sorted)	{   rabund->print(out);				}
                 else		{	rabund->nonSortedPrint(out);	}
@@ -292,20 +291,19 @@ int GetRAbundCommand::execute(){
             }
 		}
         
-        if (m->control_pressed) {  outputTypes.clear();  out.close(); m->mothurRemove(filename);  return 0; }
+        if (m->getControl_pressed()) {  outputTypes.clear();  out.close(); util.mothurRemove(filename);  return 0; }
         
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
 		m->mothurOut(filename); m->mothurOutEndLine();	outputNames.push_back(filename); outputTypes["rabund"].push_back(filename);
 		m->mothurOutEndLine();
 		
 		out.close(); 
 				
 		//set rabund file as new current rabundfile
-		string current = "";
+		string currentName = "";
 		itTypes = outputTypes.find("rabund");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setRabundFile(current); }
+			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setRabundFile(currentName); }
 		}
 		
 		return 0;		
@@ -322,7 +320,7 @@ int GetRAbundCommand::processList(ofstream& out){
         CountTable ct;
         ct.readTable(countfile, false, false);
         
-        InputData input(inputfile, format);
+        InputData input(inputfile, format, nullVector);
         ListVector* list = input.getListVector();
         string lastLabel = list->getLabel();
         
@@ -330,14 +328,14 @@ int GetRAbundCommand::processList(ofstream& out){
         set<string> processedLabels;
         set<string> userLabels = labels;
         
-        if (m->control_pressed) {  delete list;  return 0; }
+        if (m->getControl_pressed()) {  delete list;  return 0; }
         
         while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
             
             if(allLines == 1 || labels.count(list->getLabel()) == 1){
                 m->mothurOut(list->getLabel()); m->mothurOutEndLine();
                 
-                if (m->control_pressed) {   delete list;  return 0;  }
+                if (m->getControl_pressed()) {   delete list;  return 0;  }
                 
                 RAbundVector* rabund = new RAbundVector();
                 createRabund(ct, list, rabund);
@@ -350,7 +348,7 @@ int GetRAbundCommand::processList(ofstream& out){
                 userLabels.erase(list->getLabel());
             }
             
-            if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+            if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
                 string saveLabel = list->getLabel();
                 
                 delete list;
@@ -358,7 +356,7 @@ int GetRAbundCommand::processList(ofstream& out){
                 
                 m->mothurOut(list->getLabel()); m->mothurOutEndLine();
                 
-                if (m->control_pressed) {    delete list;  return 0;  }
+                if (m->getControl_pressed()) {    delete list;  return 0;  }
                 
                 RAbundVector* rabund = new RAbundVector();
                 createRabund(ct, list, rabund);
@@ -394,13 +392,13 @@ int GetRAbundCommand::processList(ofstream& out){
         }
         
         //run last label if you need to
-        if (needToRun == true)  {
+        if (needToRun )  {
             if (list != NULL) {	delete list;	}
             list = input.getListVector(lastLabel);
             
             m->mothurOut(list->getLabel()); m->mothurOutEndLine();
             
-            if (m->control_pressed) {   delete list;  return 0; }
+            if (m->getControl_pressed()) {   delete list;  return 0; }
             
             RAbundVector* rabund = new RAbundVector();
             createRabund(ct, list, rabund);
@@ -426,10 +424,10 @@ int GetRAbundCommand::createRabund(CountTable& ct, ListVector*& list, RAbundVect
         
         rabund->setLabel(list->getLabel());
         for(int i = 0; i < list->getNumBins(); i++) {
-            if (m->control_pressed) { return 0; }
+            if (m->getControl_pressed()) { return 0; }
             vector<string> binNames;
             string bin = list->get(i);
-            m->splitAtComma(bin, binNames);
+            util.splitAtComma(bin, binNames);
             int total = 0;
             for (int j = 0; j < binNames.size(); j++) {
                 total += ct.getNumSeqs(binNames[j]);
