@@ -40,7 +40,6 @@ string GetSAbundCommand::getHelpString(){
 		helpString += "Example get.sabund().\n";
 		helpString += "The default value for label is all labels in your inputfile.\n";
 		helpString += "The get.sabund command outputs a .sabund file containing the labels you selected.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. label), '=' and parameters (i.e.yourLabel).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -54,7 +53,7 @@ string GetSAbundCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "sabund")      {   pattern = "[filename],sabund";    }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -105,14 +104,14 @@ GetSAbundCommand::GetSAbundCommand(string option)  {
 			outputTypes["sabund"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -120,7 +119,7 @@ GetSAbundCommand::GetSAbundCommand(string option)  {
 				it = parameters.find("rabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["rabund"] = inputDir + it->second;		}
 				}
@@ -128,7 +127,7 @@ GetSAbundCommand::GetSAbundCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
@@ -136,27 +135,27 @@ GetSAbundCommand::GetSAbundCommand(string option)  {
 			
 			
 			//check for required parameters
-			listfile = validParameter.validFile(parameters, "list", true);
+			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else {  format = "list"; inputfile = listfile; m->setListFile(listfile); }
+			else {  format = "list"; inputfile = listfile; current->setListFile(listfile); }
 			
-			rabundfile = validParameter.validFile(parameters, "rabund", true);
+			rabundfile = validParameter.validFile(parameters, "rabund");
 			if (rabundfile == "not open") { rabundfile = ""; abort = true; }	
 			else if (rabundfile == "not found") { rabundfile = ""; }
-			else {  format = "rabund"; inputfile = rabundfile; m->setRabundFile(rabundfile); }
+			else {  format = "rabund"; inputfile = rabundfile; current->setRabundFile(rabundfile); }
 			
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
 			if (countfile == "not open") { countfile = ""; abort = true; }
 			else if (countfile == "not found") { countfile = ""; }
-			else {  m->setCountTableFile(countfile); }
+			else {  current->setCountFile(countfile); }
             
 						//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
@@ -164,10 +163,10 @@ GetSAbundCommand::GetSAbundCommand(string option)  {
 				//is there are current file available for any of these?
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
-				listfile = m->getListFile(); 
+				listfile = current->getListFile(); 
 				if (listfile != "") { inputfile = listfile; format = "list"; m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
 				else { 
-					rabundfile = m->getRabundFile(); 
+					rabundfile = current->getRabundFile(); 
 					if (rabundfile != "") { inputfile = rabundfile; format = "rabund"; m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("No valid current files. You must provide a list or rabund file."); m->mothurOutEndLine(); 
@@ -179,7 +178,7 @@ GetSAbundCommand::GetSAbundCommand(string option)  {
             if ((countfile != "") && (listfile == "")) { m->mothurOut("[ERROR]: You can only use the count file with a list file, aborting.\n"); abort = true; }
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(inputfile); 	}			
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputfile); 	}			
 			
 			
 		}
@@ -195,16 +194,16 @@ GetSAbundCommand::GetSAbundCommand(string option)  {
 int GetSAbundCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputfile));
+		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputfile));
 		filename = getOutputFileName("sabund", variables);
-		m->openOutputFile(filename, out);
+		util.openOutputFile(filename, out);
 		
         if (countfile != "") {
             processList(out);
         }else {
-            InputData input(inputfile, format);
+            InputData input(inputfile, format, nullVector);
             SAbundVector* sabund = input.getSAbundVector();
             string lastLabel = sabund->getLabel();
             
@@ -213,7 +212,7 @@ int GetSAbundCommand::execute(){
             set<string> processedLabels;
             set<string> userLabels = labels;
             
-            if (m->control_pressed) {  outputTypes.clear(); out.close(); m->mothurRemove(filename);  delete sabund;  return 0; }
+            if (m->getControl_pressed()) {  outputTypes.clear(); out.close(); util.mothurRemove(filename);  delete sabund;  return 0; }
             
             
             while((sabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
@@ -223,13 +222,13 @@ int GetSAbundCommand::execute(){
 					
 					sabund->print(out);
 					
-                    if (m->control_pressed) { outputTypes.clear();  out.close(); m->mothurRemove(filename);  delete sabund;   return 0; }
+                    if (m->getControl_pressed()) { outputTypes.clear();  out.close(); util.mothurRemove(filename);  delete sabund;   return 0; }
                     
 					processedLabels.insert(sabund->getLabel());
 					userLabels.erase(sabund->getLabel());
                 }
                 
-                if ((m->anyLabelsToProcess(sabund->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+                if ((util.anyLabelsToProcess(sabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 					string saveLabel = sabund->getLabel();
 					
 					delete sabund;
@@ -238,7 +237,7 @@ int GetSAbundCommand::execute(){
 					m->mothurOut(sabund->getLabel());  m->mothurOutEndLine();
 					sabund->print(out);
 					
-					if (m->control_pressed) {  outputTypes.clear(); out.close(); m->mothurRemove(filename);  delete sabund;   return 0; }
+					if (m->getControl_pressed()) {  outputTypes.clear(); out.close(); util.mothurRemove(filename);  delete sabund;   return 0; }
                     
 					processedLabels.insert(sabund->getLabel());
 					userLabels.erase(sabund->getLabel());
@@ -268,7 +267,7 @@ int GetSAbundCommand::execute(){
             }
             
             //run last label if you need to
-            if (needToRun == true)  {
+            if (needToRun )  {
                 if (sabund != NULL) {	delete sabund;	}
                 sabund = (input.getSAbundVector(lastLabel));
                 
@@ -276,24 +275,23 @@ int GetSAbundCommand::execute(){
                 sabund->print(out);
                 delete sabund;
                 
-                if (m->control_pressed) {  outputTypes.clear(); out.close(); m->mothurRemove(filename); return 0; }
+                if (m->getControl_pressed()) {  outputTypes.clear(); out.close(); util.mothurRemove(filename); return 0; }
                 
             }
 		}
 		out.close();
         
-        if (m->control_pressed) {  outputTypes.clear();  m->mothurRemove(filename);  return 0; }
+        if (m->getControl_pressed()) {  outputTypes.clear();  util.mothurRemove(filename);  return 0; }
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
 		m->mothurOut(filename); m->mothurOutEndLine();	outputNames.push_back(filename); outputTypes["sabund"].push_back(filename);
 		m->mothurOutEndLine();
 		
 		//set sabund file as new current sabundfile
-		string current = "";
+		string currentName = "";
 		itTypes = outputTypes.find("sabund");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSabundFile(current); }
+			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setSabundFile(currentName); }
 		}
 		
 		return 0;		
@@ -310,7 +308,7 @@ int GetSAbundCommand::processList(ofstream& out){
         CountTable ct;
         ct.readTable(countfile, false, false);
         
-        InputData input(inputfile, format);
+        InputData input(inputfile, format, nullVector);
         ListVector* list = input.getListVector();
         string lastLabel = list->getLabel();
         
@@ -318,14 +316,14 @@ int GetSAbundCommand::processList(ofstream& out){
         set<string> processedLabels;
         set<string> userLabels = labels;
         
-        if (m->control_pressed) {  delete list;  return 0; }
+        if (m->getControl_pressed()) {  delete list;  return 0; }
         
         while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
             
             if(allLines == 1 || labels.count(list->getLabel()) == 1){
                 m->mothurOut(list->getLabel()); m->mothurOutEndLine();
                 
-                if (m->control_pressed) {   delete list;  return 0;  }
+                if (m->getControl_pressed()) {   delete list;  return 0;  }
                 
                 RAbundVector* rabund = new RAbundVector();
                 createRabund(ct, list, rabund);
@@ -337,7 +335,7 @@ int GetSAbundCommand::processList(ofstream& out){
                 userLabels.erase(list->getLabel());
             }
             
-            if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+            if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
                 string saveLabel = list->getLabel();
                 
                 delete list;
@@ -345,7 +343,7 @@ int GetSAbundCommand::processList(ofstream& out){
                 
                 m->mothurOut(list->getLabel()); m->mothurOutEndLine();
                 
-                if (m->control_pressed) {    delete list;  return 0;  }
+                if (m->getControl_pressed()) {    delete list;  return 0;  }
                 
                 RAbundVector* rabund = new RAbundVector();
                 createRabund(ct, list, rabund);
@@ -380,13 +378,13 @@ int GetSAbundCommand::processList(ofstream& out){
         }
         
         //run last label if you need to
-        if (needToRun == true)  {
+        if (needToRun )  {
             if (list != NULL) {	delete list;	}
             list = input.getListVector(lastLabel);
             
             m->mothurOut(list->getLabel()); m->mothurOutEndLine();
             
-            if (m->control_pressed) {   delete list;  return 0; }
+            if (m->getControl_pressed()) {   delete list;  return 0; }
             
             RAbundVector* rabund = new RAbundVector();
             createRabund(ct, list, rabund);
@@ -411,10 +409,10 @@ int GetSAbundCommand::createRabund(CountTable& ct, ListVector*& list, RAbundVect
         
         rabund->setLabel(list->getLabel());
         for(int i = 0; i < list->getNumBins(); i++) {
-            if (m->control_pressed) { return 0; }
+            if (m->getControl_pressed()) { return 0; }
             vector<string> binNames;
             string bin = list->get(i);
-            m->splitAtComma(bin, binNames);
+            util.splitAtComma(bin, binNames);
             int total = 0;
             for (int j = 0; j < binNames.size(); j++) {
                 total += ct.getNumSeqs(binNames[j]);
