@@ -65,7 +65,7 @@ string HeatMapSimCommand::getHelpString(){
 		helpString += "Using the command this way, the phylip or column parameter are required, and only one may be used.  If you use a column file the name filename is required. \n";
 		helpString += "The heatmap.sim command should be in the following format: heatmap.sim(phylip=yourDistanceFile).\n";
 		helpString += "Example heatmap.sim(phylip=amazonGroups.dist).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. groups), '=' and parameters (i.e.yourGroups).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -79,7 +79,7 @@ string HeatMapSimCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "svg") {  pattern = "[filename],svg"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -133,14 +133,14 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 			format = "";
 				
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("phylip");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["phylip"] = inputDir + it->second;		}
 				}
@@ -148,7 +148,7 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 				it = parameters.find("column");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["column"] = inputDir + it->second;		}
 				}
@@ -156,7 +156,7 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 				it = parameters.find("name");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["name"] = inputDir + it->second;		}
 				}
@@ -164,7 +164,7 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -172,51 +172,51 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
 			}
 
 			//required parameters
-			phylipfile = validParameter.validFile(parameters, "phylip", true);
+			phylipfile = validParameter.validFile(parameters, "phylip");
 			if (phylipfile == "not open") { abort = true; }
 			else if (phylipfile == "not found") { phylipfile = ""; }	
-			else {  format = "phylip"; 	inputfile = phylipfile; m-> setPhylipFile(phylipfile); if (outputDir == "") { outputDir += m->hasPath(phylipfile); }  }
+			else {  format = "phylip"; 	inputfile = phylipfile; current->setPhylipFile(phylipfile); if (outputDir == "") { outputDir += util.hasPath(phylipfile); }  }
 			
-			columnfile = validParameter.validFile(parameters, "column", true);
+			columnfile = validParameter.validFile(parameters, "column");
 			if (columnfile == "not open") { abort = true; }	
 			else if (columnfile == "not found") { columnfile = ""; }
-			else {  format = "column";	inputfile = columnfile; m->setColumnFile(columnfile); if (outputDir == "") { outputDir += m->hasPath(columnfile); } }
+			else {  format = "column";	inputfile = columnfile; current->setColumnFile(columnfile); if (outputDir == "") { outputDir += util.hasPath(columnfile); } }
 			
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  format = "shared";	inputfile = sharedfile; m->setSharedFile(sharedfile); if (outputDir == "") { outputDir += m->hasPath(sharedfile); } }
+			else {  format = "shared";	inputfile = sharedfile; current->setSharedFile(sharedfile); if (outputDir == "") { outputDir += util.hasPath(sharedfile); } }
 			
-			namefile = validParameter.validFile(parameters, "name", true);
+			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not open") { abort = true; }	
 			else if (namefile == "not found") { namefile = ""; }
-			else { m->setNameFile(namefile); }
+			else { current->setNameFile(namefile); }
 			
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
 			if (countfile == "not open") { abort = true; countfile = ""; }	
 			else if (countfile == "not found") { countfile = ""; }
-			else { m->setCountTableFile(countfile); }
+			else { current->setCountFile(countfile); }
 			
             if ((countfile != "") && (namefile != "")) { m->mothurOut("You must enter ONLY ONE of the following: count or name."); m->mothurOutEndLine(); abort = true; }
 			
 			//error checking on files			
 			if ((sharedfile == "") && ((phylipfile == "") && (columnfile == "")))	{ 
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") { format = "shared"; inputfile = sharedfile; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
 					//is there are current file available for either of these?
 					//give priority to column, then phylip
-					columnfile = m->getColumnFile(); 
+					columnfile = current->getColumnFile(); 
 					if (columnfile != "") {  format = "column"; inputfile = columnfile; m->mothurOut("Using " + columnfile + " as input file for the column parameter."); m->mothurOutEndLine(); }
 					else { 
-						phylipfile = m->getPhylipFile(); 
+						phylipfile = current->getPhylipFile(); 
 						if (phylipfile != "") { format = "phylip";  inputfile = phylipfile; m->mothurOut("Using " + phylipfile + " as input file for the phylip parameter."); m->mothurOutEndLine(); }
 						else { 
 							m->mothurOut("No valid current files. You must provide a shared or phylip or column file."); m->mothurOutEndLine(); 
@@ -229,10 +229,10 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 			
 			if (columnfile != "") {
 				if (namefile == "") { 
-					namefile = m->getNameFile(); 
+					namefile = current->getNameFile(); 
 					if (namefile != "") {  m->mothurOut("Using " + namefile + " as input file for the name parameter."); m->mothurOutEndLine(); }
 					else { 
-                        countfile = m->getCountTableFile(); 
+                        countfile = current->getCountFile(); 
 						if (countfile != "") {  m->mothurOut("Using " + countfile + " as input file for the count parameter."); m->mothurOutEndLine(); }
                         else { 
                             m->mothurOut("You need to provide a name or count file if you are going to use the column format."); m->mothurOutEndLine(); 
@@ -244,46 +244,46 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 			
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(inputfile);		}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputfile);		}
 
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
 							
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 				
-			calc = validParameter.validFile(parameters, "calc", false);			
+			calc = validParameter.valid(parameters, "calc");
 			if (calc == "not found") { calc = "jest-thetayc";  }
 			else { 
 				if (calc == "default")  {  calc = "jest-thetayc";  }
 			}
-			m->splitAtDash(calc, Estimators);
-			if (m->inUsersGroups("citation", Estimators)) { 
+			util.splitAtDash(calc, Estimators);
+			if (util.inUsersGroups("citation", Estimators)) { 
 				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
 				//remove citation from list of calcs
 				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
 			}
 				
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; }
 			else { 
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
 			
-			string temp = validParameter.validFile(parameters, "fontsize", false);				if (temp == "not found") { temp = "24"; }
-			m->mothurConvert(temp, fontsize);
+			string temp = validParameter.valid(parameters, "fontsize");				if (temp == "not found") { temp = "24"; }
+			util.mothurConvert(temp, fontsize);
 			
-			if (abort == false) {
+			if (!abort) {
 				ValidCalculators validCalculator;
 			
 				int i;
 				for (i=0; i<Estimators.size(); i++) {
-					if (validCalculator.isValidCalculator("heat", Estimators[i]) == true) { 
+					if (validCalculator.isValidCalculator("heat", Estimators[i]) ) { 
 						if (Estimators[i] == "jabund") { 	
 							heatCalculators.push_back(new JAbund());
 						}else if (Estimators[i] == "sorabund") { 
@@ -324,7 +324,7 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 int HeatMapSimCommand::execute(){
 	try {
 	
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		heatmap = new HeatMapSim(outputDir, inputfile, fontsize);
 		
@@ -334,12 +334,10 @@ int HeatMapSimCommand::execute(){
 		
 		delete heatmap;
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } outputTypes.clear(); return 0; }
+		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  } outputTypes.clear(); return 0; }
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 	}
@@ -355,94 +353,93 @@ int HeatMapSimCommand::runCommandShared() {
 		//if the users entered no valid calculators don't execute command
 		if (heatCalculators.size() == 0) { m->mothurOut("No valid calculators."); m->mothurOutEndLine(); return 0; }
 		
-		input = new InputData(sharedfile, "sharedfile");
-		lookup = input->getSharedRAbundVectors();
-		string lastLabel = lookup[0]->getLabel();
+		input = new InputData(sharedfile, "sharedfile", Groups);
+		SharedRAbundVectors* lookup = input->getSharedRAbundVectors();
+        Groups = lookup->getNamesGroups();
+		string lastLabel = lookup->getLabel();
 			
-		if (lookup.size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command."); m->mothurOutEndLine(); return 0;}
+		if (lookup->size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command."); m->mothurOutEndLine(); return 0;}
 				
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		set<string> processedLabels;
 		set<string> userLabels = labels;
 		
-		if (m->control_pressed) {  delete input;  for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  m->clearGroups(); return 0; }
+        if (m->getControl_pressed()) {  delete input;  delete lookup;   return 0; }
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) { delete input;  for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } m->clearGroups(); return 0; }
+			if (m->getControl_pressed()) { delete input;  delete lookup;  return 0; }
 
-			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
+			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
 	
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-				vector<string> outfilenames = heatmap->getPic(lookup, heatCalculators);
+				m->mothurOut(lookup->getLabel()+"\n"); 
+                vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+				vector<string> outfilenames = heatmap->getPic(data, heatCalculators, lookup->getNamesGroups());
+                for (int i = 0; i < data.size(); i++) {  delete data[i];  }
 				for(int i = 0; i < outfilenames.size(); i++) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]); }
 					
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 			}
 				
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 			
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+				delete lookup;
 				lookup = input->getSharedRAbundVectors(lastLabel);				
 
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-				vector<string> outfilenames = heatmap->getPic(lookup, heatCalculators);
+				m->mothurOut(lookup->getLabel()+"\n"); 
+                vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+                vector<string> outfilenames = heatmap->getPic(data, heatCalculators, lookup->getNamesGroups());
+                for (int i = 0; i < data.size(); i++) {  delete data[i];  }
 				for(int i = 0; i < outfilenames.size(); i++) { outputNames.push_back(outfilenames[i]); outputTypes["svg"].push_back(outfilenames[i]);  }
 					
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 			}
 				
 			//prevent memory leak
 			 
-			lastLabel = lookup[0]->getLabel();			
+			lastLabel = lookup->getLabel();
 
 			//get next line to process
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			delete lookup;
 			lookup = input->getSharedRAbundVectors();
 
 		}
 		
 			
-		if (m->control_pressed) {  delete input;  m->clearGroups();  return 0; }
+		if (m->getControl_pressed()) {  delete input;    return 0; }
 
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
-		if (m->control_pressed) {  delete input;  m->clearGroups(); return 0; }
+		if (m->getControl_pressed()) {  delete input;   return 0; }
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) { delete lookup[i]; } } 
-			lookup = input->getSharedRAbundVectors(lastLabel);				
-
-			m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-			vector<string> outfilenames = heatmap->getPic(lookup, heatCalculators);
+		if (needToRun )  {
+            delete lookup;
+            lookup = input->getSharedRAbundVectors(lastLabel);
+            
+            m->mothurOut(lookup->getLabel()+"\n"); 
+            vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+            vector<string> outfilenames = heatmap->getPic(data, heatCalculators, lookup->getNamesGroups());
+            for (int i = 0; i < data.size(); i++) {  delete data[i];  }
 			for(int i = 0; i < outfilenames.size(); i++) { outputNames.push_back(outfilenames[i]); outputTypes["svg"].push_back(outfilenames[i]);  }
-			
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			delete lookup;
 		}
 		
-		if (m->control_pressed) {  delete input;  m->clearGroups(); return 0; }
+		if (m->getControl_pressed()) {  delete input;   return 0; }
 			
 		//reset groups parameter
-		m->clearGroups();  
+		  
 			
 		delete input;  
 	
@@ -464,7 +461,7 @@ int HeatMapSimCommand::runCommandDist() {
 		//read distance file and create distance vector and names vector
 		if (format == "phylip") {
 			//read phylip file
-			m->openInputFile(phylipfile, in);
+			util.openInputFile(phylipfile, in);
 			
 			string name;
 			int numSeqs;
@@ -504,15 +501,15 @@ int HeatMapSimCommand::runCommandDist() {
 			}
 			
 			//read rest of matrix
-			if (square == true) { 
+			if (square ) { 
 				for(int i=1;i<numSeqs;i++){
 					in >> name;		
 					names.push_back(name);
 					
-					if (m->control_pressed) { return 0; }
+					if (m->getControl_pressed()) { return 0; }
 					
 					for(int j=0;j<numSeqs;j++) { in >> matrix[i][j];  }
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}else { 
 				double dist;
@@ -520,13 +517,13 @@ int HeatMapSimCommand::runCommandDist() {
 					in >> name;	
 					names.push_back(name);	
 					
-					if (m->control_pressed) { return 0; }
+					if (m->getControl_pressed()) { return 0; }
 					
 					for(int j=0;j<i;j++){
 						in >> dist;
 						matrix[i][j] = dist;  matrix[j][i] = dist;
 					}
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}
 			in.close();
@@ -557,12 +554,12 @@ int HeatMapSimCommand::runCommandDist() {
 			//read column file
 			string first, second;
 			double dist;
-			m->openInputFile(columnfile, in);
+			util.openInputFile(columnfile, in);
 			
 			while (!in.eof()) {
-				in >> first >> second >> dist; m->gobble(in);
+				in >> first >> second >> dist; util.gobble(in);
 				
-				if (m->control_pressed) { return 0; }
+				if (m->getControl_pressed()) { return 0; }
 				
                 if (namefile != "") {
                     map<string, int>::iterator itA = nameMap->find(first);
