@@ -10,7 +10,7 @@
 #include "homovacommand.h"
 #include "groupmap.h"
 #include "readphylipvector.h"
-#include "sharedutilities.h"
+
 #include "designmap.h"
 
 //**********************************************************************************************************************
@@ -46,7 +46,6 @@ string HomovaCommand::getHelpString(){
         helpString += "The sets parameter allows you to specify which of the sets in your designfile you would like to analyze. The set names are separated by dashes. THe default is all sets in the designfile.\n";
 		helpString += "The iters parameter allows you to set number of randomization for the P value.  The default is 1000. \n";
 		helpString += "The homova command should be in the following format: homova(phylip=file.dist, design=file.design).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. iters), '=' and parameters (i.e. 1000).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -60,7 +59,7 @@ string HomovaCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "homova") {  pattern = "[filename],homova"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -111,17 +110,17 @@ HomovaCommand::HomovaCommand(string option) {
 			outputTypes["homova"] = tempOutNames;
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("design");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["design"] = inputDir + it->second;		}
 				}
@@ -129,47 +128,47 @@ HomovaCommand::HomovaCommand(string option) {
 				it = parameters.find("phylip");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["phylip"] = inputDir + it->second;		}
 				}
 			}
 			
-			phylipFileName = validParameter.validFile(parameters, "phylip", true);
+			phylipFileName = validParameter.validFile(parameters, "phylip");
 			if (phylipFileName == "not open") { phylipFileName = ""; abort = true; }
 			else if (phylipFileName == "not found") { 
 				//if there is a current phylip file, use it
-				phylipFileName = m->getPhylipFile(); 
+				phylipFileName = current->getPhylipFile(); 
 				if (phylipFileName != "") { m->mothurOut("Using " + phylipFileName + " as input file for the phylip parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current phylip file and the phylip parameter is required."); m->mothurOutEndLine(); abort = true; }
 				
-			}else { m->setPhylipFile(phylipFileName); }	
+			}else { current->setPhylipFile(phylipFileName); }	
 			
 			//check for required parameters
-			designFileName = validParameter.validFile(parameters, "design", true);
+			designFileName = validParameter.validFile(parameters, "design");
 			if (designFileName == "not open") { abort = true; }
 			else if (designFileName == "not found") {
 				//if there is a current design file, use it
-				designFileName = m->getDesignFile(); 
+				designFileName = current->getDesignFile(); 
 				if (designFileName != "") { m->mothurOut("Using " + designFileName + " as input file for the design parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current design file and the design parameter is required."); m->mothurOutEndLine(); abort = true; }								
-			}else { m->setDesignFile(designFileName); }	
+			}else { current->setDesignFile(designFileName); }	
 			
-			string temp = validParameter.validFile(parameters, "iters", false);
+			string temp = validParameter.valid(parameters, "iters");
 			if (temp == "not found") { temp = "1000"; }
-			m->mothurConvert(temp, iters); 
+			util.mothurConvert(temp, iters); 
 			
-			temp = validParameter.validFile(parameters, "alpha", false);
+			temp = validParameter.valid(parameters, "alpha");
 			if (temp == "not found") { temp = "0.05"; }
-			m->mothurConvert(temp, experimentwiseAlpha); 
+			util.mothurConvert(temp, experimentwiseAlpha); 
             
-            string sets = validParameter.validFile(parameters, "sets", false);			
+            string sets = validParameter.valid(parameters, "sets");			
 			if (sets == "not found") { sets = ""; }
 			else { 
-				m->splitAtDash(sets, Sets);
+				util.splitAtDash(sets, Sets);
 			}
 		}
-		
+		if (outputDir == "") { outputDir = util.hasPath(phylipFileName); }
 	}
 	catch(exception& e) {
 		m->errorOut(e, "HomovaCommand", "HomovaCommand");
@@ -181,31 +180,27 @@ HomovaCommand::HomovaCommand(string option) {
 int HomovaCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		//read design file
-		designMap = new DesignMap(designFileName);
-		
-		if (outputDir == "") { outputDir = m->hasPath(phylipFileName); }
+		DesignMap* designMap = new DesignMap(designFileName);
 		
 		//read in distance matrix and square it
 		ReadPhylipVector readMatrix(phylipFileName);
 		vector<string> sampleNames = readMatrix.read(distanceMatrix);
 		
         if (Sets.size() != 0) { //user selected sets, so we want to remove the samples not in those sets
-            SharedUtil util; 
             vector<string> dGroups = designMap->getCategory();
-            util.setGroups(Sets, dGroups);  
             
             for(int i=0;i<distanceMatrix.size();i++){
                 
-                if (m->control_pressed) { delete designMap; return 0; }
+                if (m->getControl_pressed()) { delete designMap; return 0; }
                 
                 string group = designMap->get(sampleNames[i]);
                 
                 if (group == "not found") {
-                    m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct."); m->mothurOutEndLine(); m->control_pressed = true;
-                }else if (!m->inUsersGroups(group, Sets)){  //not in set we want remove it
+                    m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
+                }else if (!util.inUsersGroups(group, Sets)){  //not in set we want remove it
                     //remove from all other rows
                     for(int j=0;j<distanceMatrix.size();j++){
                         distanceMatrix[j].erase(distanceMatrix[j].begin()+i);
@@ -218,9 +213,7 @@ int HomovaCommand::execute(){
         }
 
 		for(int i=0;i<distanceMatrix.size();i++){
-			for(int j=0;j<i;j++){
-				distanceMatrix[i][j] *= distanceMatrix[i][j];	
-			}
+			for(int j=0;j<i;j++){ distanceMatrix[i][j] *= distanceMatrix[i][j];	 }
 		}
 		
 		//link designMap to rows/columns in distance matrix
@@ -229,19 +222,19 @@ int HomovaCommand::execute(){
 			string group = designMap->get(sampleNames[i]);
 			
 			if (group == "not found") {
-				m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct."); m->mothurOutEndLine(); m->control_pressed = true;
+				m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
 			}else { origGroupSampleMap[group].push_back(i); }
 		}
 		int numGroups = origGroupSampleMap.size();
 		
-		if (m->control_pressed) { delete designMap; return 0; }
+		if (m->getControl_pressed()) { delete designMap; return 0; }
 		
 		//create a new filename
 		ofstream HOMOVAFile;
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(phylipFileName));
+		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipFileName));
 		string HOMOVAFileName = getOutputFileName("homova", variables);				
-		m->openOutputFile(HOMOVAFileName, HOMOVAFile);
+		util.openOutputFile(HOMOVAFileName, HOMOVAFile);
 		outputNames.push_back(HOMOVAFileName); outputTypes["homova"].push_back(HOMOVAFileName);
 		
 		HOMOVAFile << "HOMOVA\tBValue\tP-value\tSSwithin/(Ni-1)_values" << endl;
@@ -268,23 +261,18 @@ int HomovaCommand::execute(){
 				}			
 			}
 			HOMOVAFile << endl;
-			m->mothurOutEndLine();
 			
-			m->mothurOut("Experiment-wise error rate: " + toString(experimentwiseAlpha) + '\n');
+			m->mothurOut("\nExperiment-wise error rate: " + toString(experimentwiseAlpha) + '\n');
 			m->mothurOut("Pair-wise error rate (Bonferroni): " + toString(pairwiseAlpha) + '\n');
 		}
-		else{
-			m->mothurOut("Experiment-wise error rate: " + toString(experimentwiseAlpha) + '\n');
-		}
+		else{ m->mothurOut("Experiment-wise error rate: " + toString(experimentwiseAlpha) + '\n'); }
 		
 		m->mothurOut("If you have borderline P-values, you should try increasing the number of iterations\n");
 		
 		delete designMap;
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 	}
@@ -293,7 +281,6 @@ int HomovaCommand::execute(){
 		exit(1);
 	}
 }
-
 //**********************************************************************************************************************
 
 double HomovaCommand::runHOMOVA(ofstream& HOMOVAFile, map<string, vector<int> > groupSampleMap, double alpha){
@@ -364,14 +351,11 @@ double HomovaCommand::calcSigleSSWithin(vector<int> sampleIndices) {
 			for(int j=0;j<numSamplesInGroup;j++){
 				int col = sampleIndices[j];
 				
-				if(col < row){
-					ssWithin += distanceMatrix[row][col];
-				}
-				
+				if(col < row){ ssWithin += distanceMatrix[row][col]; }
 			}
 		}
 		
-		ssWithin /= numSamplesInGroup;
+		ssWithin /= (double) numSamplesInGroup;
 		return ssWithin;
 	}
 	catch(exception& e) {
@@ -384,20 +368,12 @@ double HomovaCommand::calcSigleSSWithin(vector<int> sampleIndices) {
 
 double HomovaCommand::calcBValue(map<string, vector<int> > groupSampleMap, vector<double>& ssWithinVector) {
 	try {
-
-		map<string, vector<int> >::iterator it;
-		
 		double numGroups = (double)groupSampleMap.size();
 		ssWithinVector.resize(numGroups, 0);
 		
-		double totalNumSamples = 0;
-		double ssWithinFull;
-		double secondTermSum = 0;
-		double inverseOneMinusSum = 0;
-		int index = 0;
+		double totalNumSamples = 0; double ssWithinFull = 0; double secondTermSum = 0; double inverseOneMinusSum = 0; int index = 0;
 		
-		ssWithinVector.resize(numGroups, 0);
-		for(it = groupSampleMap.begin();it!=groupSampleMap.end();it++){
+		for(map<string, vector<int> >::iterator it = groupSampleMap.begin();it!=groupSampleMap.end();it++){
 			int numSamplesInGroup = it->second.size();
 			totalNumSamples += numSamplesInGroup;
 			
@@ -416,14 +392,12 @@ double HomovaCommand::calcBValue(map<string, vector<int> > groupSampleMap, vecto
 		B /= denomintor;
 		
 		return B;
-		
 	}
 	catch(exception& e) {
 		m->errorOut(e, "HomovaCommand", "calcBValue");
 		exit(1);
 	}
 }
-
 //**********************************************************************************************************************
 
 map<string, vector<int> > HomovaCommand::getRandomizedGroups(map<string, vector<int> > origMapping){
@@ -431,18 +405,17 @@ map<string, vector<int> > HomovaCommand::getRandomizedGroups(map<string, vector<
 		vector<int> sampleIndices;
 		vector<int> samplesPerGroup;
 		
-		map<string, vector<int> >::iterator it;
-		for(it=origMapping.begin();it!=origMapping.end();it++){
+		for(map<string, vector<int> >::iterator it=origMapping.begin();it!=origMapping.end();it++){
 			vector<int> indices = it->second;
 			samplesPerGroup.push_back(indices.size());
 			sampleIndices.insert(sampleIndices.end(), indices.begin(), indices.end());
 		}
 		
-		m->mothurRandomShuffle(sampleIndices);
+		util.mothurRandomShuffle(sampleIndices);
 		
 		int index = 0;
 		map<string, vector<int> > randomizedGroups = origMapping;
-		for(it=randomizedGroups.begin();it!=randomizedGroups.end();it++){
+		for(map<string, vector<int> >::iterator it=randomizedGroups.begin();it!=randomizedGroups.end();it++){
 			for(int i=0;i<it->second.size();i++){
 				it->second[i] = sampleIndices[index++];				
 			}
