@@ -57,7 +57,6 @@ string LibShuffCommand::getHelpString(){
 		helpString += "Example libshuff(groups=A-B-C, iters=500, form=discrete, step=0.01, cutOff=2.0).\n";
 		helpString += "The default value for groups is all the groups in your groupfile, iters is 10000, cutoff is 1.0, form is integral and step is 0.01.\n";
 		helpString += "The libshuff command output two files: .coverage and .slsummary their descriptions are in the manual.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. iters), '=' and parameters (i.e.yourIters).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -72,7 +71,7 @@ string LibShuffCommand::getOutputPattern(string type) {
         
         if (type == "coverage") {  pattern = "[filename],libshuff.coverage"; } 
         else if (type == "libshuffsummary") {  pattern = "[filename],libshuff.summary"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -124,14 +123,14 @@ LibShuffCommand::LibShuffCommand(string option)  {
 			outputTypes["coverage"] = tempOutNames;
 			outputTypes["libshuffsummary"] = tempOutNames;
 			
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("phylip");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["phylip"] = inputDir + it->second;		}
 				}
@@ -139,66 +138,66 @@ LibShuffCommand::LibShuffCommand(string option)  {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
 			}
 			
 			//check for required parameters
-			phylipfile = validParameter.validFile(parameters, "phylip", true);
+			phylipfile = validParameter.validFile(parameters, "phylip");
 			if (phylipfile == "not open") { phylipfile = ""; abort = true; }
 			else if (phylipfile == "not found") { 
-				phylipfile = m->getPhylipFile(); 
+				phylipfile = current->getPhylipFile(); 
 				if (phylipfile != "") {  m->mothurOut("Using " + phylipfile + " as input file for the phylip parameter."); m->mothurOutEndLine(); }
 				else { 
 					m->mothurOut("You must provide a phylip file."); m->mothurOutEndLine(); 
 					abort = true;
 				} 
-			}else { m->setPhylipFile(phylipfile); }	
+			}else { current->setPhylipFile(phylipfile); }	
 			
 			//check for required parameters
-			groupfile = validParameter.validFile(parameters, "group", true);
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not open") { groupfile = ""; abort = true; }
 			else if (groupfile == "not found") { 
-				groupfile = m->getGroupFile(); 
+				groupfile = current->getGroupFile(); 
 				if (groupfile != "") {  m->mothurOut("Using " + groupfile + " as input file for the group parameter."); m->mothurOutEndLine(); }
 				else { 
 					m->mothurOut("You must provide a group file."); m->mothurOutEndLine(); 
 					abort = true;
 				} 
-			}else { m->setGroupFile(groupfile); }	
+			}else { current->setGroupFile(groupfile); }	
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
 				outputDir = "";	
-				outputDir += m->hasPath(phylipfile); //if user entered a file with a path then preserve it	
+				outputDir += util.hasPath(phylipfile); //if user entered a file with a path then preserve it	
 			}
 						
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; savegroups = groups; }
 			else { 
 				savegroups = groups;
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
 				
 			string temp;
-			temp = validParameter.validFile(parameters, "iters", false);				if (temp == "not found") { temp = "10000"; }
-			m->mothurConvert(temp, iters); 
+			temp = validParameter.valid(parameters, "iters");				if (temp == "not found") { temp = "10000"; }
+			util.mothurConvert(temp, iters); 
 			
-			temp = validParameter.validFile(parameters, "cutoff", false);				if (temp == "not found") { temp = "1.0"; }
-			m->mothurConvert(temp, cutOff); 
+			temp = validParameter.valid(parameters, "cutoff");				if (temp == "not found") { temp = "1.0"; }
+			util.mothurConvert(temp, cutOff); 
 			
-			temp = validParameter.validFile(parameters, "step", false);				if (temp == "not found") { temp = "0.01"; }
-			m->mothurConvert(temp, step); 
+			temp = validParameter.valid(parameters, "step");				if (temp == "not found") { temp = "0.01"; }
+			util.mothurConvert(temp, step); 
 			
-			temp = validParameter.validFile(parameters, "sim", false);				if (temp == "not found") { temp = "F"; }
-			sim = m->isTrue(temp); 
+			temp = validParameter.valid(parameters, "sim");				if (temp == "not found") { temp = "F"; }
+			sim = util.isTrue(temp); 
 			
-			userform = validParameter.validFile(parameters, "form", false);			if (userform == "not found") { userform = "integral"; }
+			userform = validParameter.valid(parameters, "form");			if (userform == "not found") { userform = "integral"; }
 			
 		}
 		
@@ -213,7 +212,7 @@ LibShuffCommand::LibShuffCommand(string option)  {
 int LibShuffCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		//read files
 		groupMap = new GroupMap(groupfile);
@@ -221,25 +220,25 @@ int LibShuffCommand::execute(){
 		if (error == 1) { delete groupMap; return 0; }
 		
 		ifstream in;
-		m->openInputFile(phylipfile, in);
+		util.openInputFile(phylipfile, in);
 		matrix = new FullMatrix(in, groupMap, sim); //reads the matrix file
 		in.close();
 		
-		if (m->control_pressed) { delete groupMap; delete matrix; return 0; }
+		if (m->getControl_pressed()) { delete groupMap; delete matrix; return 0; }
 		
 		//if files don't match...
 		if (matrix->getNumSeqs() < groupMap->getNumSeqs()) {  
 			m->mothurOut("Your distance file contains " + toString(matrix->getNumSeqs()) + " sequences, and your group file contains " + toString(groupMap->getNumSeqs()) + " sequences.");  m->mothurOutEndLine();				
 			//create new group file
-			if(outputDir == "") { outputDir += m->hasPath(groupfile); }
+			if(outputDir == "") { outputDir += util.hasPath(groupfile); }
 			
-			string newGroupFile = outputDir + m->getRootName(m->getSimpleName(groupfile)) + "editted.groups";
+			string newGroupFile = outputDir + util.getRootName(util.getSimpleName(groupfile)) + "editted.groups";
 			outputNames.push_back(newGroupFile);
 			ofstream outGroups;
-			m->openOutputFile(newGroupFile, outGroups);
+			util.openOutputFile(newGroupFile, outGroups);
 			
 			for (int i = 0; i < matrix->getNumSeqs(); i++) {
-				if (m->control_pressed) { delete groupMap; delete matrix; outGroups.close(); m->mothurRemove(newGroupFile); return 0; }
+				if (m->getControl_pressed()) { delete groupMap; delete matrix; outGroups.close(); util.mothurRemove(newGroupFile); return 0; }
 				
 				Names temp = matrix->getRowInfo(i);
 				outGroups << temp.seqName << '\t' << temp.groupName << endl;
@@ -255,15 +254,15 @@ int LibShuffCommand::execute(){
 			groupMap = new GroupMap(groupfile);
 			groupMap->readMap();
 			
-			if (m->control_pressed) { delete groupMap; delete matrix; m->mothurRemove(newGroupFile); return 0; }
+			if (m->getControl_pressed()) { delete groupMap; delete matrix; util.mothurRemove(newGroupFile); return 0; }
 		}
 		
 			
 		setGroups();								//set the groups to be analyzed and sorts them
 		
-		if (numGroups < 2) { m->mothurOut("[ERROR]: libshuff requires at least 2 groups, you only have " + toString(numGroups) + ", aborting."); m->mothurOutEndLine(); m->control_pressed = true; }
+		if (numGroups < 2) { m->mothurOut("[ERROR]: libshuff requires at least 2 groups, you only have " + toString(numGroups) + ", aborting."); m->mothurOutEndLine(); m->setControl_pressed(true); }
 		
-		if (m->control_pressed) { delete groupMap; delete matrix; return 0; }
+		if (m->getControl_pressed()) { delete groupMap; delete matrix; return 0; }
 		
 		/********************************************************************************************/
 		//this is needed because when we read the matrix we sort it into groups in alphabetical order
@@ -285,35 +284,35 @@ int LibShuffCommand::execute(){
 		savedDXYValues = form->evaluateAll();
 		savedMinValues = form->getSavedMins();
 		
-		if (m->control_pressed) {  delete form; m->clearGroups(); delete matrix; delete groupMap; return 0; }
+		if (m->getControl_pressed()) {  delete form;  delete matrix; delete groupMap; return 0; }
 	
 		pValueCounts.resize(numGroups);
 		for(int i=0;i<numGroups;i++){
 			pValueCounts[i].assign(numGroups, 0);
 		}
 	
-		if (m->control_pressed) {  outputTypes.clear(); delete form; m->clearGroups(); delete matrix; delete groupMap; return 0; }
+		if (m->getControl_pressed()) {  outputTypes.clear(); delete form;  delete matrix; delete groupMap; return 0; }
 				
 		Progress* reading = new Progress();
 		
 		for(int i=0;i<numGroups-1;i++) {
 			for(int j=i+1;j<numGroups;j++) {
 				
-				if (m->control_pressed) {  outputTypes.clear();  delete form; m->clearGroups(); delete matrix; delete groupMap; delete reading; return 0; }
+				if (m->getControl_pressed()) {  outputTypes.clear();  delete form;  delete matrix; delete groupMap; delete reading; return 0; }
 
-				reading->newLine(groupNames[i]+'-'+groupNames[j], iters);
-				int spoti = groupMap->groupIndex[groupNames[i]]; //neccessary in case user selects groups so you know where they are in the matrix
-				int spotj = groupMap->groupIndex[groupNames[j]];
+				reading->newLine(Groups[i]+'-'+Groups[j], iters);
+				int spoti = groupMap->groupIndex[Groups[i]]; //neccessary in case user selects groups so you know where they are in the matrix
+				int spotj = groupMap->groupIndex[Groups[j]];
 	
 				for(int p=0;p<iters;p++) {	
 					
-					if (m->control_pressed) {  outputTypes.clear(); delete form; m->clearGroups(); delete matrix; delete groupMap; delete reading; return 0; }
+					if (m->getControl_pressed()) {  outputTypes.clear(); delete form;  delete matrix; delete groupMap; delete reading; return 0; }
 					
 					form->randomizeGroups(spoti,spotj); 
 					if(form->evaluatePair(spoti,spotj) >= savedDXYValues[spoti][spotj])	{	pValueCounts[i][j]++;	}
 					if(form->evaluatePair(spotj,spoti) >= savedDXYValues[spotj][spoti])	{	pValueCounts[j][i]++;	}
 					
-					if (m->control_pressed) {  outputTypes.clear(); delete form; m->clearGroups(); delete matrix; delete groupMap; delete reading; return 0; }
+					if (m->getControl_pressed()) {  outputTypes.clear(); delete form;  delete matrix; delete groupMap; delete reading; return 0; }
 					
 					reading->update(p);			
 				}
@@ -322,7 +321,7 @@ int LibShuffCommand::execute(){
 			}
 		}
 		
-		if (m->control_pressed) { outputTypes.clear();  delete form; m->clearGroups(); delete matrix; delete groupMap; delete reading; return 0; }
+		if (m->getControl_pressed()) { outputTypes.clear();  delete form;  delete matrix; delete groupMap; delete reading; return 0; }
 	
 		reading->finish();
 		delete reading;
@@ -332,17 +331,15 @@ int LibShuffCommand::execute(){
 		printCoverageFile();
 				
 		//clear out users groups
-		m->clearGroups();
+		
 		delete form;
 		
 		delete matrix; delete groupMap;
 		
-		if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+		if (m->getControl_pressed()) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 	}
@@ -359,9 +356,9 @@ int LibShuffCommand::printCoverageFile() {
 
 		ofstream outCov;
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(phylipfile));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipfile));
 		summaryFile = getOutputFileName("coverage", variables);
-		m->openOutputFile(summaryFile, outCov);
+		util.openOutputFile(summaryFile, outCov);
 		outputNames.push_back(summaryFile); outputTypes["coverage"].push_back(summaryFile);
 		outCov.setf(ios::fixed, ios::floatfield); outCov.setf(ios::showpoint);
 		//cout.setf(ios::fixed, ios::floatfield); cout.setf(ios::showpoint);
@@ -378,12 +375,12 @@ int LibShuffCommand::printCoverageFile() {
 			for(int j=0;j<numGroups;j++){
 				indices[i][j] = index++;
 				
-				int spoti = groupMap->groupIndex[groupNames[i]]; //neccessary in case user selects groups so you know where they are in the matrix
-				int spotj = groupMap->groupIndex[groupNames[j]];
+				int spoti = groupMap->groupIndex[Groups[i]]; //neccessary in case user selects groups so you know where they are in the matrix
+				int spotj = groupMap->groupIndex[Groups[j]];
 				
 				for(int k=0;k<savedMinValues[spoti][spotj].size();k++){
 					
-					if(m->control_pressed)  { outCov.close(); return 0; }
+					if(m->getControl_pressed())  { outCov.close(); return 0; }
 					
 					if(allDistances[savedMinValues[spoti][spotj][k]].size() != 0){
 						allDistances[savedMinValues[spoti][spotj][k]][indices[i][j]]++;
@@ -414,13 +411,13 @@ int LibShuffCommand::printCoverageFile() {
 		
 		outCov << "dist";
 		for (int i = 0; i < numGroups; i++){
-			outCov << '\t' << groupNames[i];
+			outCov << '\t' << Groups[i];
 		}
 		for (int i=0;i<numGroups;i++){
 			for(int j=i+1;j<numGroups;j++){
-				if(m->control_pressed)  { outCov.close(); return 0; }
-				outCov << '\t' << groupNames[i] << '-' << groupNames[j] << '\t';
-				outCov << groupNames[j] << '-' << groupNames[i];
+				if(m->getControl_pressed())  { outCov.close(); return 0; }
+				outCov << '\t' << Groups[i] << '-' << Groups[j] << '\t';
+				outCov << Groups[j] << '-' << Groups[i];
 			}
 		}
 		outCov << endl;
@@ -432,7 +429,7 @@ int LibShuffCommand::printCoverageFile() {
 			}
 			for(int i=0;i<numGroups;i++){
 				for(int j=i+1;j<numGroups;j++){
-					if(m->control_pressed)  { outCov.close(); return 0; }
+					if(m->getControl_pressed())  { outCov.close(); return 0; }
 					
 					outCov << it->second[indices[i][j]]/(float)lastRow[indices[i][j]] << '\t';
 					outCov << it->second[indices[j][i]]/(float)lastRow[indices[j][i]] << '\t';
@@ -457,9 +454,9 @@ int LibShuffCommand::printSummaryFile() {
 
 		ofstream outSum;
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(phylipfile));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipfile));
 		summaryFile = getOutputFileName("libshuffsummary",variables);
-		m->openOutputFile(summaryFile, outSum);
+		util.openOutputFile(summaryFile, outSum);
 		outputNames.push_back(summaryFile); outputTypes["libshuffsummary"].push_back(summaryFile);
 
 		outSum.setf(ios::fixed, ios::floatfield); outSum.setf(ios::showpoint);
@@ -472,30 +469,30 @@ int LibShuffCommand::printSummaryFile() {
 		int precision = (int)log10(iters);
 		for(int i=0;i<numGroups;i++){
 			for(int j=i+1;j<numGroups;j++){
-				if(m->control_pressed)  { outSum.close(); return 0; }
+				if(m->getControl_pressed())  { outSum.close(); return 0; }
 				
-				int spoti = groupMap->groupIndex[groupNames[i]]; //neccessary in case user selects groups so you know where they are in the matrix
-				int spotj = groupMap->groupIndex[groupNames[j]];
+				int spoti = groupMap->groupIndex[Groups[i]]; //neccessary in case user selects groups so you know where they are in the matrix
+				int spotj = groupMap->groupIndex[Groups[j]];
 				
 				if(pValueCounts[i][j]){
-					cout << setw(20) << left << groupNames[i]+'-'+groupNames[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << setprecision(precision) << pValueCounts[i][j]/(float)iters << endl;
-					m->mothurOutJustToLog(groupNames[i]+"-"+groupNames[j] + "\t" + toString(savedDXYValues[spoti][spotj]) + "\t" + toString((pValueCounts[i][j]/(float)iters))); m->mothurOutEndLine();
-					outSum << setw(20) << left << groupNames[i]+'-'+groupNames[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << setprecision(precision) << pValueCounts[i][j]/(float)iters << endl;
+					cout << setw(20) << left << Groups[i]+'-'+Groups[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << setprecision(precision) << pValueCounts[i][j]/(float)iters << endl;
+					m->mothurOutJustToLog(Groups[i]+"-"+Groups[j] + "\t" + toString(savedDXYValues[spoti][spotj]) + "\t" + toString((pValueCounts[i][j]/(float)iters))); m->mothurOutEndLine();
+					outSum << setw(20) << left << Groups[i]+'-'+Groups[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << setprecision(precision) << pValueCounts[i][j]/(float)iters << endl;
 				}
 				else{
-					cout << setw(20) << left << groupNames[i]+'-'+groupNames[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << '<' <<setprecision(precision) << 1/(float)iters << endl;
-					m->mothurOutJustToLog(groupNames[i]+"-"+groupNames[j] + "\t" + toString(savedDXYValues[spoti][spotj]) + "\t" + toString((1/(float)iters))); m->mothurOutEndLine();
-					outSum << setw(20) << left << groupNames[i]+'-'+groupNames[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << '<' <<setprecision(precision) << 1/(float)iters << endl;
+					cout << setw(20) << left << Groups[i]+'-'+Groups[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << '<' <<setprecision(precision) << 1/(float)iters << endl;
+					m->mothurOutJustToLog(Groups[i]+"-"+Groups[j] + "\t" + toString(savedDXYValues[spoti][spotj]) + "\t" + toString((1/(float)iters))); m->mothurOutEndLine();
+					outSum << setw(20) << left << Groups[i]+'-'+Groups[j] << '\t' << setprecision(8) << savedDXYValues[spoti][spotj] << '\t' << '<' <<setprecision(precision) << 1/(float)iters << endl;
 				}
 				if(pValueCounts[j][i]){
-					cout << setw(20) << left << groupNames[j]+'-'+groupNames[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << setprecision (precision) << pValueCounts[j][i]/(float)iters << endl;
-					m->mothurOutJustToLog(groupNames[j]+"-"+groupNames[i] + "\t" + toString(savedDXYValues[spotj][spoti]) + "\t" + toString((pValueCounts[j][i]/(float)iters))); m->mothurOutEndLine();
-					outSum << setw(20) << left << groupNames[j]+'-'+groupNames[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << setprecision (precision) << pValueCounts[j][i]/(float)iters << endl;
+					cout << setw(20) << left << Groups[j]+'-'+Groups[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << setprecision (precision) << pValueCounts[j][i]/(float)iters << endl;
+					m->mothurOutJustToLog(Groups[j]+"-"+Groups[i] + "\t" + toString(savedDXYValues[spotj][spoti]) + "\t" + toString((pValueCounts[j][i]/(float)iters))); m->mothurOutEndLine();
+					outSum << setw(20) << left << Groups[j]+'-'+Groups[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << setprecision (precision) << pValueCounts[j][i]/(float)iters << endl;
 				}
 				else{
-					cout << setw(20) << left << groupNames[j]+'-'+groupNames[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << '<' <<setprecision (precision) << 1/(float)iters << endl;
-					m->mothurOutJustToLog(groupNames[j]+"-"+groupNames[i] + "\t" + toString(savedDXYValues[spotj][spoti]) + "\t" + toString((1/(float)iters))); m->mothurOutEndLine();
-					outSum << setw(20) << left << groupNames[j]+'-'+groupNames[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << '<' <<setprecision (precision) << 1/(float)iters << endl;
+					cout << setw(20) << left << Groups[j]+'-'+Groups[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << '<' <<setprecision (precision) << 1/(float)iters << endl;
+					m->mothurOutJustToLog(Groups[j]+"-"+Groups[i] + "\t" + toString(savedDXYValues[spotj][spoti]) + "\t" + toString((1/(float)iters))); m->mothurOutEndLine();
+					outSum << setw(20) << left << Groups[j]+'-'+Groups[i] << '\t' << setprecision(8) << savedDXYValues[spotj][spoti] << '\t' << '<' <<setprecision (precision) << 1/(float)iters << endl;
 				}
 			}
 		}
@@ -513,13 +510,11 @@ int LibShuffCommand::printSummaryFile() {
 
 void LibShuffCommand::setGroups() {
 	try {
-		vector<string> myGroups = m->getGroups();
+		vector<string> myGroups = Groups;
 		//if the user has not entered specific groups to analyze then do them all
-		if (m->getNumGroups() == 0) {
+		if (Groups.size() == 0) {
 			numGroups = groupMap->getNumGroups();
-			for (int i=0; i < numGroups; i++) { 
-				myGroups.push_back((groupMap->getNamesOfGroups())[i]);
-			}
+			for (int i=0; i < numGroups; i++) {  myGroups.push_back((groupMap->getNamesOfGroups())[i]); }
 		} else {
 			if (savegroups != "all") {
 				//check that groups are valid
@@ -534,31 +529,23 @@ void LibShuffCommand::setGroups() {
 				//if the user only entered invalid groups
 				if ((myGroups.size() == 0) || (myGroups.size() == 1)) { 
 					numGroups = groupMap->getNumGroups();
-					for (int i=0; i < numGroups; i++) { 
-						myGroups.push_back((groupMap->getNamesOfGroups())[i]);
-					}
+					for (int i=0; i < numGroups; i++) {  myGroups.push_back((groupMap->getNamesOfGroups())[i]); }
 					m->mothurOut("When using the groups parameter you must have at least 2 valid groups. I will run the command using all the groups in your groupfile."); m->mothurOutEndLine();
 				} else { numGroups = myGroups.size(); }
 			} else { //users wants all groups
 				numGroups = groupMap->getNumGroups();
 				myGroups.clear();
-				for (int i=0; i < numGroups; i++) { 
-					myGroups.push_back((groupMap->getNamesOfGroups())[i]);
-				}
+				for (int i=0; i < numGroups; i++) {  myGroups.push_back((groupMap->getNamesOfGroups())[i]); }
 			}
 		}
 
 		//sort so labels match
 		sort(myGroups.begin(), myGroups.end());
 		
-		//sort
-		//sort(groupMap->namesOfGroups.begin(), groupMap->namesOfGroups.end());
-		
 		for (int i = 0; i < (groupMap->getNamesOfGroups()).size(); i++) {  groupMap->groupIndex[(groupMap->getNamesOfGroups())[i]] = i;  }
 
-		groupNames = myGroups;
-		m->setGroups(myGroups);
-
+		Groups = myGroups;
+        numGroups = Groups.size();
 	}
 	catch(exception& e) {
 		m->errorOut(e, "LibShuffCommand", "setGroups");
