@@ -54,7 +54,7 @@ string ListOtuLabelsCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "otulabels") {  pattern = "[filename],[distance],otulabels"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -102,7 +102,7 @@ ListOtuLabelsCommand::ListOtuLabelsCommand(string option)  {
 			
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
                 
@@ -112,7 +112,7 @@ ListOtuLabelsCommand::ListOtuLabelsCommand(string option)  {
                 it = parameters.find("relabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["relabund"] = inputDir + it->second;		}
 				}
@@ -120,7 +120,7 @@ ListOtuLabelsCommand::ListOtuLabelsCommand(string option)  {
                 it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -128,7 +128,7 @@ ListOtuLabelsCommand::ListOtuLabelsCommand(string option)  {
                 it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -138,32 +138,32 @@ ListOtuLabelsCommand::ListOtuLabelsCommand(string option)  {
             outputTypes["otulabels"] = tempOutNames; 
             
  			//check for parameters
-            sharedfile = validParameter.validFile(parameters, "shared", true);
+            sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { abort = true; }
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else { inputFileName = sharedfile; format = "sharedfile"; m->setSharedFile(sharedfile); }
+			else { inputFileName = sharedfile; format = "sharedfile"; current->setSharedFile(sharedfile); }
 			
-			relabundfile = validParameter.validFile(parameters, "relabund", true);
+			relabundfile = validParameter.validFile(parameters, "relabund");
 			if (relabundfile == "not open") { abort = true; }
 			else if (relabundfile == "not found") { relabundfile = ""; }
-			else { inputFileName = relabundfile; format = "relabund"; m->setRelAbundFile(relabundfile); }
+			else { inputFileName = relabundfile; format = "relabund"; current->setRelAbundFile(relabundfile); }
             
-            listfile = validParameter.validFile(parameters, "list", true);
+            listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else { inputFileName = listfile; format = "list"; m->setListFile(listfile); }
+			else { inputFileName = listfile; format = "list"; current->setListFile(listfile); }
 
             
             if ((relabundfile == "") && (sharedfile == "") && (listfile== "")) { 
 				//is there are current file available for either of these?
 				//give priority to shared, then relabund
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") {  inputFileName = sharedfile; format="sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
-					relabundfile = m->getRelAbundFile(); 
+					relabundfile = current->getRelAbundFile(); 
 					if (relabundfile != "") {  inputFileName = relabundfile; format="relabund"; m->mothurOut("Using " + relabundfile + " as input file for the relabund parameter."); m->mothurOutEndLine(); }
 					else { 
-                        listfile = m->getListFile();
+                        listfile = current->getListFile();
 						if (listfile != "") {  inputFileName = listfile; format="list"; m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
                         else { 
                             m->mothurOut("No valid current files. You must provide a shared, list or relabund."); m->mothurOutEndLine(); 
@@ -174,19 +174,18 @@ ListOtuLabelsCommand::ListOtuLabelsCommand(string option)  {
 			}
             
             //if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	
-				outputDir = m->hasPath(inputFileName); //if user entered a file with a path then preserve it	
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
+				outputDir = util.hasPath(inputFileName); //if user entered a file with a path then preserve it	
 			}
             
-            string groups = validParameter.validFile(parameters, "groups", false);			
+            string groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; }
-			else { m->splitAtDash(groups, Groups); }
-			m->setGroups(Groups);
+			else { util.splitAtDash(groups, Groups); if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } } }
             
-            string label = validParameter.validFile(parameters, "label", false);			
+            string label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}			
 		}
@@ -202,60 +201,61 @@ ListOtuLabelsCommand::ListOtuLabelsCommand(string option)  {
 int ListOtuLabelsCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
-        InputData input(inputFileName, format);
+        InputData input(inputFileName, format, Groups);
         
         if (format == "relabund") {
-            vector<SharedRAbundFloatVector*> lookup = input.getSharedRAbundFloatVectors();
-            string lastLabel = lookup[0]->getLabel();
+            SharedRAbundFloatVectors* lookup = input.getSharedRAbundFloatVectors();
+            Groups = lookup->getNamesGroups();
+            string lastLabel = lookup->getLabel();
             
             //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
             set<string> processedLabels;
             set<string> userLabels = labels;
             
             //as long as you are not at the end of the file or done wih the lines you want
-            while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+            while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
                 
-                if (m->control_pressed) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); } return 0; }
+                if (m->getControl_pressed()) { delete lookup; for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); } return 0; }
                 
-                if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
+                if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
                     
-                    m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                    m->mothurOut(lookup->getLabel()+"\n"); 
                     
                     createList(lookup);
                     
-                    processedLabels.insert(lookup[0]->getLabel());
-                    userLabels.erase(lookup[0]->getLabel());
+                    processedLabels.insert(lookup->getLabel());
+                    userLabels.erase(lookup->getLabel());
                 }
                 
-                if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-                    string saveLabel = lookup[0]->getLabel();
+                if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+                    string saveLabel = lookup->getLabel();
                     
-                    for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  
+                    delete lookup;
                     lookup = input.getSharedRAbundFloatVectors(lastLabel);
-                    m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                    m->mothurOut(lookup->getLabel()+"\n"); 
                     
                     createList(lookup);
                     
-                    processedLabels.insert(lookup[0]->getLabel());
-                    userLabels.erase(lookup[0]->getLabel());
+                    processedLabels.insert(lookup->getLabel());
+                    userLabels.erase(lookup->getLabel());
                     
                     //restore real lastlabel to save below
-                    lookup[0]->setLabel(saveLabel);
+                    lookup->setLabels(saveLabel);
                 }
                 
-                lastLabel = lookup[0]->getLabel();
+                lastLabel = lookup->getLabel();
                 //prevent memory leak
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }
+                delete lookup;
                 
-                if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+                if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
                 
                 //get next line to process
                 lookup = input.getSharedRAbundFloatVectors();				
             }
             
-            if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+            if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
             
             //output error messages about any remaining user labels
             set<string>::iterator it;
@@ -271,67 +271,68 @@ int ListOtuLabelsCommand::execute(){
             }
             
             //run last label if you need to
-            if (needToRun == true)  {
-                for (int i = 0; i < lookup.size(); i++) { if (lookup[i] != NULL) { delete lookup[i]; } }  
+            if (needToRun )  {
+                delete lookup;
                 lookup = input.getSharedRAbundFloatVectors(lastLabel);
                 
-                m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                m->mothurOut(lookup->getLabel()+"\n"); 
                 
                 createList(lookup);
                 
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+                delete lookup;
             }
         }else if (format == "sharedfile") {
             
-            vector<SharedRAbundVector*> lookup = input.getSharedRAbundVectors();
-            string lastLabel = lookup[0]->getLabel();
+            SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+            Groups = lookup->getNamesGroups();
+            string lastLabel = lookup->getLabel();
             
             //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
             set<string> processedLabels;
             set<string> userLabels = labels;
             
             //as long as you are not at the end of the file or done wih the lines you want
-            while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+            while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
                 
-                if (m->control_pressed) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); } return 0; }
+                if (m->getControl_pressed()) { delete lookup;  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); } return 0; }
                 
-                if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
+                if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
                     
-                    m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                    m->mothurOut(lookup->getLabel()+"\n"); 
                     
                     createList(lookup);
                     
-                    processedLabels.insert(lookup[0]->getLabel());
-                    userLabels.erase(lookup[0]->getLabel());
+                    processedLabels.insert(lookup->getLabel());
+                    userLabels.erase(lookup->getLabel());
                 }
                 
-                if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-                    string saveLabel = lookup[0]->getLabel();
+                if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+                    string saveLabel = lookup->getLabel();
                     
-                    for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  
+                    delete lookup;
                     lookup = input.getSharedRAbundVectors(lastLabel);
-                    m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                    m->mothurOut(lookup->getLabel()+"\n"); 
                     
                     createList(lookup);
                     
-                    processedLabels.insert(lookup[0]->getLabel());
-                    userLabels.erase(lookup[0]->getLabel());
+                    processedLabels.insert(lookup->getLabel());
+                    userLabels.erase(lookup->getLabel());
                     
                     //restore real lastlabel to save below
-                    lookup[0]->setLabel(saveLabel);
+                    lookup->setLabels(saveLabel);
                 }
                 
-                lastLabel = lookup[0]->getLabel();
+                lastLabel = lookup->getLabel();
                 //prevent memory leak
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }
+                delete lookup;
                 
-                if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+                if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
                 
                 //get next line to process
                 lookup = input.getSharedRAbundVectors();				
             }
             
-            if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+            if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
             
             //output error messages about any remaining user labels
             set<string>::iterator it;
@@ -347,15 +348,15 @@ int ListOtuLabelsCommand::execute(){
             }
             
             //run last label if you need to
-            if (needToRun == true)  {
-                for (int i = 0; i < lookup.size(); i++) { if (lookup[i] != NULL) { delete lookup[i]; } }  
+            if (needToRun )  {
+                delete lookup;
                 lookup = input.getSharedRAbundVectors(lastLabel);
                 
-                m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+                m->mothurOut(lookup->getLabel()+"\n"); 
                 
                 createList(lookup);
                 
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
+                delete lookup;
             }
         }else {
             ListVector* list = input.getListVector();
@@ -368,7 +369,7 @@ int ListOtuLabelsCommand::execute(){
             //as long as you are not at the end of the file or done wih the lines you want
             while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
                 
-                if (m->control_pressed) { delete list;  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); } return 0; }
+                if (m->getControl_pressed()) { delete list;  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); } return 0; }
                 
                 if(allLines == 1 || labels.count(list->getLabel()) == 1){			
                     
@@ -380,7 +381,7 @@ int ListOtuLabelsCommand::execute(){
                     userLabels.erase(list->getLabel());
                 }
                 
-                if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+                if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
                     string saveLabel = list->getLabel();
                     
                     delete list; 
@@ -400,13 +401,13 @@ int ListOtuLabelsCommand::execute(){
                 //prevent memory leak
                 delete list; list = NULL;
                 
-                if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+                if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
                 
                 //get next line to process
                 list = input.getListVector();				
             }
             
-            if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+            if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
             
             //output error messages about any remaining user labels
             set<string>::iterator it;
@@ -422,7 +423,7 @@ int ListOtuLabelsCommand::execute(){
             }
             
             //run last label if you need to
-            if (needToRun == true)  {
+            if (needToRun )  {
                 delete list;  
                 list = input.getListVector(lastLabel);
                 
@@ -434,13 +435,11 @@ int ListOtuLabelsCommand::execute(){
             }
         }
         
-        if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]); }  return 0; }
+        if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }  return 0; }
         
         //output files created by command
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
         return 0;
 		
     }
@@ -451,18 +450,19 @@ int ListOtuLabelsCommand::execute(){
 }
 //**********************************************************************************************************************
 
-int ListOtuLabelsCommand::createList(vector<SharedRAbundVector*>& lookup){
+int ListOtuLabelsCommand::createList(SharedRAbundVectors*& lookup){
 	try {
         
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileName));
-        variables["[distance]"] = lookup[0]->getLabel();
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileName));
+        variables["[distance]"] = lookup->getLabel();
         string outputFileName = getOutputFileName("otulabels",variables);
         outputNames.push_back(outputFileName);  outputTypes["otulabels"].push_back(outputFileName);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
         
-        for (int i = 0; i < m->currentSharedBinLabels.size(); i++) {  out << m->currentSharedBinLabels[i] << endl;  }
+        vector<string> currentLabels = lookup->getOTUNames();
+        for (int i = 0; i < currentLabels.size(); i++) {  out << currentLabels[i] << endl;  }
         
         out.close();
         
@@ -476,17 +476,18 @@ int ListOtuLabelsCommand::createList(vector<SharedRAbundVector*>& lookup){
 
 //**********************************************************************************************************************
 
-int ListOtuLabelsCommand::createList(vector<SharedRAbundFloatVector*>& lookup){
+int ListOtuLabelsCommand::createList(SharedRAbundFloatVectors*& lookup){
 	try {
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileName));
-        variables["[distance]"] = lookup[0]->getLabel();
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileName));
+        variables["[distance]"] = lookup->getLabel();
         string outputFileName = getOutputFileName("otulabels",variables);
         outputNames.push_back(outputFileName);  outputTypes["accnos"].push_back(outputFileName);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
         
-        for (int i = 0; i < m->currentSharedBinLabels.size(); i++) {  out << m->currentSharedBinLabels[i] << endl;  }
+        vector<string> currentLabels = lookup->getOTUNames();
+        for (int i = 0; i < currentLabels.size(); i++) {  out << currentLabels[i] << endl;  }
         
         out.close();
         
@@ -501,12 +502,12 @@ int ListOtuLabelsCommand::createList(vector<SharedRAbundFloatVector*>& lookup){
 int ListOtuLabelsCommand::createList(ListVector*& list){
 	try {
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileName));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileName));
         variables["[distance]"] = list->getLabel();
         string outputFileName = getOutputFileName("otulabels",variables);
         outputNames.push_back(outputFileName);  outputTypes["accnos"].push_back(outputFileName);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
         
         vector<string> binLabels = list->getLabels();
         for (int i = 0; i < binLabels.size(); i++) {  out << binLabels[i] << endl;  }
