@@ -59,7 +59,7 @@ string MakeLefseCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "lefse") {  pattern = "[filename],[distance],lefse"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -108,14 +108,14 @@ MakeLefseCommand::MakeLefseCommand(string option)  {
             outputTypes["lefse"] = tempOutNames;
             
 			//if the user changes the input directory command factory will send this info to us in the output parameter
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);
+			string inputDir = validParameter.valid(parameters, "inputdir");
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
                 string path;
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -123,7 +123,7 @@ MakeLefseCommand::MakeLefseCommand(string option)  {
 				it = parameters.find("design");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["design"] = inputDir + it->second;		}
 				}
@@ -131,7 +131,7 @@ MakeLefseCommand::MakeLefseCommand(string option)  {
 				it = parameters.find("constaxonomy");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["constaxonomy"] = inputDir + it->second;		}
 				}
@@ -139,50 +139,47 @@ MakeLefseCommand::MakeLefseCommand(string option)  {
                 it = parameters.find("relabund");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["relabund"] = inputDir + it->second;		}
 				}
             }
                     
 			//check for parameters
-			designfile = validParameter.validFile(parameters, "design", true);
+			designfile = validParameter.validFile(parameters, "design");
 			if (designfile == "not open") { abort = true; }
 			else if (designfile == "not found") { designfile = ""; }
-			else { m->setDesignFile(designfile); }
+			else { current->setDesignFile(designfile); }
             
-            sharedfile = validParameter.validFile(parameters, "shared", true);
+            sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { abort = true; }
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  m->setSharedFile(sharedfile); }
+			else {  current->setSharedFile(sharedfile); }
 			
-			relabundfile = validParameter.validFile(parameters, "relabund", true);
+			relabundfile = validParameter.validFile(parameters, "relabund");
 			if (relabundfile == "not open") { abort = true; }
 			else if (relabundfile == "not found") { relabundfile = ""; }
-			else {  m->setRelAbundFile(relabundfile); }
+			else {  current->setRelAbundFile(relabundfile); }
             
-            constaxonomyfile = validParameter.validFile(parameters, "constaxonomy", true);
+            constaxonomyfile = validParameter.validFile(parameters, "constaxonomy");
 			if (constaxonomyfile == "not open") { constaxonomyfile = ""; abort = true; }
 			else if (constaxonomyfile == "not found") {  constaxonomyfile = "";  }
 			
-			label = validParameter.validFile(parameters, "label", false);
+			label = validParameter.valid(parameters, "label");
 			if (label == "not found") { label = ""; m->mothurOut("You did not provide a label, I will use the first label in your inputfile."); m->mothurOutEndLine(); label=""; }
             
-            string groups = validParameter.validFile(parameters, "groups", false);
+            string groups = validParameter.valid(parameters, "groups");
 			if (groups == "not found") { groups = "";  }
-			else {
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
-			}
+			else { util.splitAtDash(groups, Groups); if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } } }
 
 
             if ((relabundfile == "") && (sharedfile == "")) {
 				//is there are current file available for either of these?
 				//give priority to shared, then relabund
-				sharedfile = m->getSharedFile();
+				sharedfile = current->getSharedFile();
 				if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else {
-					relabundfile = m->getRelAbundFile();
+					relabundfile = current->getRelAbundFile();
 					if (relabundfile != "") {   m->mothurOut("Using " + relabundfile + " as input file for the relabund parameter."); m->mothurOutEndLine(); }
 					else {
 						m->mothurOut("No valid current files. You must provide a shared or relabund."); m->mothurOutEndLine();
@@ -194,10 +191,10 @@ MakeLefseCommand::MakeLefseCommand(string option)  {
 			if ((relabundfile != "") && (sharedfile != "")) { m->mothurOut("[ERROR]: You may not use both a shared and relabund file."); m->mothurOutEndLine(); abort = true;  }
 			
             //if the user changes the output directory command factory will send this info to us in the output parameter
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){
 				outputDir = ""; 			}
             
-            scale = validParameter.validFile(parameters, "scale", false);				if (scale == "not found") { scale = "totalgroup"; }
+            scale = validParameter.valid(parameters, "scale");				if (scale == "not found") { scale = "totalgroup"; }
 			
 			if ((scale != "totalgroup") && (scale != "totalotu") && (scale != "averagegroup") && (scale != "averageotu")) {
 				m->mothurOut(scale + " is not a valid scaling option for the get.relabund command. Choices are totalgroup, totalotu, averagegroup, averageotu."); m->mothurOutEndLine(); abort = true;
@@ -215,30 +212,28 @@ MakeLefseCommand::MakeLefseCommand(string option)  {
 int MakeLefseCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
       
         map<int, consTax2> consTax;
-        if (constaxonomyfile != "") {  m->readConsTax(constaxonomyfile, consTax);  }
+        if (constaxonomyfile != "") {  util.readConsTax(constaxonomyfile, consTax);  }
         
-        if (m->control_pressed) { return 0; }
+        if (m->getControl_pressed()) { return 0; }
         
         if (sharedfile != "") {
             inputFile = sharedfile;
-            vector<SharedRAbundFloatVector*> lookup = getSharedRelabund();
+            SharedRAbundFloatVectors* lookup = getSharedRelabund();
             runRelabund(consTax, lookup);
         }else {
             inputFile = relabundfile;
-            vector<SharedRAbundFloatVector*> lookup = getRelabund();
+            SharedRAbundFloatVectors* lookup = getRelabund();
             runRelabund(consTax, lookup);
         }
         
-        if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+        if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 		
         //output files created by command
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
         return 0;
 		
     }
@@ -248,19 +243,20 @@ int MakeLefseCommand::execute(){
 	}
 }
 //**********************************************************************************************************************
-int MakeLefseCommand::runRelabund(map<int, consTax2>& consTax, vector<SharedRAbundFloatVector*>& lookup){
+int MakeLefseCommand::runRelabund(map<int, consTax2>& consTax, SharedRAbundFloatVectors*& lookup){
 	try {
-        if (outputDir == "") { outputDir = m->hasPath(inputFile); }
+        if (outputDir == "") { outputDir = util.hasPath(inputFile); }
         map<string, string> variables;
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFile));
-        variables["[distance]"] = lookup[0]->getLabel();
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFile));
+        variables["[distance]"] = lookup->getLabel();
 		string outputFile = getOutputFileName("lefse",variables);
 		outputNames.push_back(outputFile); outputTypes["lefse"].push_back(outputFile);
         
         ofstream out;
-        m->openOutputFile(outputFile, out);
+        util.openOutputFile(outputFile, out);
 
         DesignMap* designMap = NULL;
+        vector<string> namesOfGroups = lookup->getNamesGroups();
         if (designfile != "") {
             designMap = new DesignMap(designfile);
             vector<string> categories = designMap->getNamesOfCategories();
@@ -269,46 +265,46 @@ int MakeLefseCommand::runRelabund(map<int, consTax2>& consTax, vector<SharedRAbu
             
             for (int j = 0; j < categories.size(); j++) {
                 out << categories[j];
-                for (int i = 0; i < lookup.size()-1; i++) {
-                    if (m->control_pressed) { out.close(); delete designMap; return 0; }
-                    string value = designMap->get(lookup[i]->getGroup(), categories[j]);
+                for (int i = 0; i < namesOfGroups.size()-1; i++) {
+                    if (m->getControl_pressed()) { out.close(); delete designMap; return 0; }
+                    string value = designMap->get(namesOfGroups[i], categories[j]);
                     if (value == "not found") {
-                        m->mothurOut("[ERROR]: " + lookup[i]->getGroup() + " is not in your design file, please correct.\n"); m->control_pressed = true;
+                        m->mothurOut("[ERROR]: " + namesOfGroups[i] + " is not in your design file, please correct.\n"); m->setControl_pressed(true);
                     }else { out  << '\t' << value; }
                 }
-                string value = designMap->get(lookup[lookup.size()-1]->getGroup(), categories[j]);
+                string value = designMap->get(namesOfGroups[namesOfGroups.size()-1], categories[j]);
                 if (value == "not found") {
-                    m->mothurOut("[ERROR]: " + lookup[lookup.size()-1]->getGroup() + " is not in your design file, please correct.\n"); m->control_pressed = true;
+                    m->mothurOut("[ERROR]: " + namesOfGroups[namesOfGroups.size()-1] + " is not in your design file, please correct.\n"); m->setControl_pressed(true);
                 }else { out << '\t' << value; }
                 out << endl;
             }
         }
         
         out << "group";
-        for (int i = 0; i < lookup.size(); i++) {  out  << '\t' << lookup[i]->getGroup(); }
+        for (int i = 0; i < namesOfGroups.size(); i++) {  out  << '\t' << namesOfGroups[i]; }
         out << endl;
         
-        for (int i = 0; i < lookup[0]->getNumBins(); i++) { //process each otu
-            if (m->control_pressed) { break; }
-            string nameOfOtu = m->currentSharedBinLabels[i];
+        for (int i = 0; i < lookup->getNumBins(); i++) { //process each otu
+            if (m->getControl_pressed()) { break; }
+            string nameOfOtu = lookup->getOTUName(i);
             
             if (constaxonomyfile != "") { //try to find the otuName in consTax to replace with consensus taxonomy
                 int simpleLabel;
-                m->mothurConvert(m->getSimpleLabel(nameOfOtu), simpleLabel);
+                util.mothurConvert(util.getSimpleLabel(nameOfOtu), simpleLabel);
                 map<int, consTax2>::iterator it = consTax.find(simpleLabel);
                 if (it != consTax.end()) {
                     nameOfOtu = it->second.taxonomy;
                     //add sanity check abundances here??
                     string fixedName = "";
                     //remove confidences and change ; to |
-                    m->removeConfidences(nameOfOtu);
+                    util.removeConfidences(nameOfOtu);
                     for (int j = 0; j < nameOfOtu.length(); j++) {
                         if (nameOfOtu[j] == ';') { fixedName += '|'; }
                         else { fixedName += nameOfOtu[j]; }
                     }
-                    nameOfOtu = fixedName + m->currentSharedBinLabels[i] + "|";
+                    nameOfOtu = fixedName + lookup->getOTUName(i) + "|";
                 }else {
-                    m->mothurOut("[ERROR]: can't find " + nameOfOtu + " in constaxonomy file. Do the distances match, did you forget to use the label parameter?\n"); m->control_pressed = true;
+                    m->mothurOut("[ERROR]: can't find " + nameOfOtu + " in constaxonomy file. Do the distances match, did you forget to use the label parameter?\n"); m->setControl_pressed(true);
                 }
                 
             }
@@ -316,7 +312,8 @@ int MakeLefseCommand::runRelabund(map<int, consTax2>& consTax, vector<SharedRAbu
             out << nameOfOtu;
             
             //print out relabunds for each otu
-            for (int j = 0; j < lookup.size(); j++) { out  << '\t' << lookup[j]->getAbundance(i); }
+            vector<float> abunds = lookup->getOTU(i);
+            for (int j = 0; j < abunds.size(); j++) { out  << '\t' << abunds[j]; }
             out << endl;
         }
         out.close();
@@ -329,13 +326,13 @@ int MakeLefseCommand::runRelabund(map<int, consTax2>& consTax, vector<SharedRAbu
 	}
 }
 //**********************************************************************************************************************
-vector<SharedRAbundFloatVector*> MakeLefseCommand::getSharedRelabund(){
+SharedRAbundFloatVectors* MakeLefseCommand::getSharedRelabund(){
 	try {
-		InputData input(sharedfile, "sharedfile");
-		vector<SharedRAbundVector*> templookup = input.getSharedRAbundVectors();
-		string lastLabel = templookup[0]->getLabel();
-        vector<SharedRAbundFloatVector*> lookup;
-		
+		InputData input(sharedfile, "sharedfile", Groups);
+		SharedRAbundVectors* templookup = input.getSharedRAbundVectors();
+        Groups = templookup->getNamesGroups();
+		string lastLabel = templookup->getLabel();
+        
 		if (label == "") { label = lastLabel;  }
 		else {
             //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
@@ -344,39 +341,39 @@ vector<SharedRAbundFloatVector*> MakeLefseCommand::getSharedRelabund(){
             set<string> userLabels = labels;
             
             //as long as you are not at the end of the file or done wih the lines you want
-            while((templookup[0] != NULL) && (userLabels.size() != 0)) {
-                if (m->control_pressed) {  for (int i = 0; i < templookup.size(); i++) {  delete templookup[i];  } return lookup;  }
+            while((templookup != NULL) && (userLabels.size() != 0)) {
+                if (m->getControl_pressed()) {  delete templookup; return NULL;  }
                 
-                if(labels.count(templookup[0]->getLabel()) == 1){
-                    processedLabels.insert(templookup[0]->getLabel());
-                    userLabels.erase(templookup[0]->getLabel());
+                if(labels.count(templookup->getLabel()) == 1){
+                    processedLabels.insert(templookup->getLabel());
+                    userLabels.erase(templookup->getLabel());
                     break;
                 }
                 
-                if ((m->anyLabelsToProcess(templookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-                    string saveLabel = templookup[0]->getLabel();
+                if ((util.anyLabelsToProcess(templookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+                    string saveLabel = templookup->getLabel();
                     
-                    for (int i = 0; i < templookup.size(); i++) {  delete templookup[i];  }
+                    delete templookup;
                     templookup = input.getSharedRAbundVectors(lastLabel);
                     
-                    processedLabels.insert(templookup[0]->getLabel());
-                    userLabels.erase(templookup[0]->getLabel());
+                    processedLabels.insert(templookup->getLabel());
+                    userLabels.erase(templookup->getLabel());
                     
                     //restore real lastlabel to save below
-                    templookup[0]->setLabel(saveLabel);
+                    templookup->setLabels(saveLabel);
                     break;
                 }
                 
-                lastLabel = templookup[0]->getLabel();
+                lastLabel = templookup->getLabel();
                 
                 //get next line to process
                 //prevent memory leak
-                for (int i = 0; i < templookup.size(); i++) {  delete templookup[i];  }
+                delete templookup;
                 templookup = input.getSharedRAbundVectors();
             }
             
             
-            if (m->control_pressed) { for (int i = 0; i < templookup.size(); i++) {  delete templookup[i];  } return lookup;  }
+            if (m->getControl_pressed()) { delete templookup; return NULL;  }
             
             //output error messages about any remaining user labels
             set<string>::iterator it;
@@ -392,51 +389,55 @@ vector<SharedRAbundFloatVector*> MakeLefseCommand::getSharedRelabund(){
             }
             
             //run last label if you need to
-            if (needToRun == true)  {
-                for (int i = 0; i < templookup.size(); i++) {  if (templookup[i] != NULL) {	delete templookup[i];	} }
+            if (needToRun )  {
+                delete templookup;
                 templookup = input.getSharedRAbundVectors(lastLabel);
             }
 		}
         
-        for (int i = 0; i < templookup.size(); i++) {
-            SharedRAbundFloatVector* temp = new SharedRAbundFloatVector();
-            temp->setLabel(templookup[i]->getLabel());
-            temp->setGroup(templookup[i]->getGroup());
-            lookup.push_back(temp);
-        }
+        vector<SharedRAbundVector*> data = templookup->getSharedRAbundVectors();
+        delete templookup;
+        SharedRAbundFloatVectors* lookup = new SharedRAbundFloatVectors();
         
         //convert to relabund
-        for (int i = 0; i < templookup.size(); i++) {
-			for (int j = 0; j < templookup[i]->getNumBins(); j++) {
+        for (int i = 0; i < data.size(); i++) {
+            SharedRAbundFloatVector* rel = new SharedRAbundFloatVector();
+            rel->setGroup(data[i]->getGroup());
+            rel->setLabel(data[i]->getLabel());
+            
+			for (int j = 0; j < data[i]->getNumBins(); j++) {
                 
-				if (m->control_pressed) { for (int k = 0; k < templookup.size(); k++) {  delete templookup[k];  } return lookup; }
+				if (m->getControl_pressed()) { for (int k = 0; k < data.size(); k++) {  delete data[k];  } return lookup; }
                 
-				int abund = templookup[i]->getAbundance(j);
+				int abund = data[i]->get(j);
 				float relabund = 0.0;
 				
 				if (scale == "totalgroup") {
-					relabund = abund / (float) templookup[i]->getNumSeqs();
+					relabund = abund / (float) data[i]->getNumSeqs();
 				}else if (scale == "totalotu") {
 					//calc the total in this otu
 					int totalOtu = 0;
-					for (int l = 0; l < templookup.size(); l++) {  totalOtu += templookup[l]->getAbundance(j); }
+					for (int l = 0; l < data.size(); l++) {  totalOtu += data[l]->get(j); }
 					relabund = abund / (float) totalOtu;
 				}else if (scale == "averagegroup") {
-					relabund = abund / (float) (templookup[i]->getNumSeqs() / (float) templookup[i]->getNumBins());
+					relabund = abund / (float) (data[i]->getNumSeqs() / (float) data[i]->getNumBins());
 				}else if (scale == "averageotu") {
 					//calc the total in this otu
 					int totalOtu = 0;
-					for (int l = 0; l < templookup.size(); l++) {  totalOtu += templookup[l]->getAbundance(j); }
-					float averageOtu = totalOtu / (float) templookup.size();
+					for (int l = 0; l < data.size(); l++) {  totalOtu += data[l]->get(j); }
+					float averageOtu = totalOtu / (float) data.size();
 					
 					relabund = abund / (float) averageOtu;
-				}else{ m->mothurOut(scale + " is not a valid scaling option."); m->mothurOutEndLine(); m->control_pressed = true;  }
+				}else{ m->mothurOut(scale + " is not a valid scaling option."); m->mothurOutEndLine(); m->setControl_pressed(true);  }
 				
-				lookup[i]->push_back(relabund, lookup[i]->getGroup());
+				rel->push_back(relabund);
 			}
+            
+            lookup->push_back(rel);
+            
         }
-
-        for (int k = 0; k < templookup.size(); k++) {  delete templookup[k];  }
+        for (int k = 0; k < data.size(); k++) {  delete data[k];  } data.clear();
+        lookup->eliminateZeroOTUS();
         
 		return lookup;
 	}
@@ -446,11 +447,12 @@ vector<SharedRAbundFloatVector*> MakeLefseCommand::getSharedRelabund(){
 	}
 }
 //**********************************************************************************************************************
-vector<SharedRAbundFloatVector*> MakeLefseCommand::getRelabund(){
+SharedRAbundFloatVectors* MakeLefseCommand::getRelabund(){
 	try {
-		InputData input(relabundfile, "relabund");
-		vector<SharedRAbundFloatVector*> lookupFloat = input.getSharedRAbundFloatVectors();
-		string lastLabel = lookupFloat[0]->getLabel();
+		InputData input(relabundfile, "relabund", Groups);
+		SharedRAbundFloatVectors* lookupFloat = input.getSharedRAbundFloatVectors();
+		string lastLabel = lookupFloat->getLabel();
+        Groups = lookupFloat->getNamesGroups();
 		
 		if (label == "") { label = lastLabel; return lookupFloat; }
 		
@@ -460,40 +462,40 @@ vector<SharedRAbundFloatVector*> MakeLefseCommand::getRelabund(){
 		set<string> userLabels = labels;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookupFloat[0] != NULL) && (userLabels.size() != 0)) {
+		while((lookupFloat != NULL) && (userLabels.size() != 0)) {
 			
-			if (m->control_pressed) {  return lookupFloat;  }
+			if (m->getControl_pressed()) {  return lookupFloat;  }
 			
-			if(labels.count(lookupFloat[0]->getLabel()) == 1){
-				processedLabels.insert(lookupFloat[0]->getLabel());
-				userLabels.erase(lookupFloat[0]->getLabel());
+			if(labels.count(lookupFloat->getLabel()) == 1){
+				processedLabels.insert(lookupFloat->getLabel());
+				userLabels.erase(lookupFloat->getLabel());
 				break;
 			}
 			
-			if ((m->anyLabelsToProcess(lookupFloat[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookupFloat[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookupFloat->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookupFloat->getLabel();
 				
-				for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  }
+                delete lookupFloat;
 				lookupFloat = input.getSharedRAbundFloatVectors(lastLabel);
 				
-				processedLabels.insert(lookupFloat[0]->getLabel());
-				userLabels.erase(lookupFloat[0]->getLabel());
+				processedLabels.insert(lookupFloat->getLabel());
+				userLabels.erase(lookupFloat->getLabel());
 				
 				//restore real lastlabel to save below
-				lookupFloat[0]->setLabel(saveLabel);
+				lookupFloat->setLabels(saveLabel);
 				break;
 			}
 			
-			lastLabel = lookupFloat[0]->getLabel();
+			lastLabel = lookupFloat->getLabel();
 			
 			//get next line to process
 			//prevent memory leak
-			for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  }
+			delete lookupFloat;
 			lookupFloat = input.getSharedRAbundFloatVectors();
 		}
 		
 		
-		if (m->control_pressed) { return lookupFloat;  }
+		if (m->getControl_pressed()) { return lookupFloat;  }
 		
 		//output error messages about any remaining user labels
 		set<string>::iterator it;
@@ -509,8 +511,8 @@ vector<SharedRAbundFloatVector*> MakeLefseCommand::getRelabund(){
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookupFloat.size(); i++) {  if (lookupFloat[i] != NULL) {	delete lookupFloat[i];	} }
+		if (needToRun )  {
+			delete lookupFloat;
 			lookupFloat = input.getSharedRAbundFloatVectors(lastLabel);
 		}
 		
