@@ -42,7 +42,6 @@ string MantelCommand::getHelpString(){
 		helpString += "The iters parameter allows you to set number of randomization for the P value.  The default is 1000. \n";
 		helpString += "The mantel command should be in the following format: mantel(phylip1=veg.dist, phylip2=env.dist).\n";
 		helpString += "The mantel command outputs a .mantel file.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. phylip1), '=' and parameters (i.e. veg.dist).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -56,7 +55,7 @@ string MantelCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "mantel") {  pattern = "[filename],mantel"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -105,14 +104,14 @@ MantelCommand::MantelCommand(string option)  {
 			outputTypes["mantel"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("phylip1");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["phylip1"] = inputDir + it->second;		}
 				}
@@ -120,7 +119,7 @@ MantelCommand::MantelCommand(string option)  {
 				it = parameters.find("phylip2");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["phylip2"] = inputDir + it->second;		}
 				}
@@ -128,20 +127,20 @@ MantelCommand::MantelCommand(string option)  {
 			
 			
 			//check for required parameters
-			phylipfile1 = validParameter.validFile(parameters, "phylip1", true);
+			phylipfile1 = validParameter.validFile(parameters, "phylip1");
 			if (phylipfile1 == "not open") { phylipfile1 = ""; abort = true; }
 			else if (phylipfile1 == "not found") { phylipfile1 = ""; m->mothurOut("phylip1 is a required parameter for the mantel command."); m->mothurOutEndLine(); abort = true;  }	
 			
-			phylipfile2 = validParameter.validFile(parameters, "phylip2", true);
+			phylipfile2 = validParameter.validFile(parameters, "phylip2");
 			if (phylipfile2 == "not open") { phylipfile2 = ""; abort = true; }
 			else if (phylipfile2 == "not found") { phylipfile2 = ""; m->mothurOut("phylip2 is a required parameter for the mantel command."); m->mothurOutEndLine(); abort = true;  }	
 			
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(phylipfile1);	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(phylipfile1);	}
 			
-			method = validParameter.validFile(parameters, "method", false);		if (method == "not found"){	method = "pearson";		}
+			method = validParameter.valid(parameters, "method");		if (method == "not found"){	method = "pearson";		}
 			
-			string temp = validParameter.validFile(parameters, "iters", false);			if (temp == "not found") { temp = "1000"; }
-			m->mothurConvert(temp, iters);
+			string temp = validParameter.valid(parameters, "iters");			if (temp == "not found") { temp = "1000"; }
+			util.mothurConvert(temp, iters);
 			
 			if ((method != "pearson") && (method != "spearman") && (method != "kendall")) { m->mothurOut(method + " is not a valid method. Valid methods are pearson, spearman, and kendall."); m->mothurOutEndLine(); abort = true; }
 		}
@@ -156,7 +155,7 @@ MantelCommand::MantelCommand(string option)  {
 int MantelCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		/***************************************************/
 		//    reading distance files					   //
@@ -167,25 +166,25 @@ int MantelCommand::execute(){
 		vector< vector<double> > matrix1;
 		vector<string> names1 = readMatrix.read(matrix1);
 		
-		if (m->control_pressed) { return 0; }
+		if (m->getControl_pressed()) { return 0; }
 		
 		//read phylip2
 		ReadPhylipVector readMatrix2(phylipfile2);
 		vector< vector<double> > matrix2;
 		vector<string> names2 = readMatrix2.read(matrix2);
 		
-		if (m->control_pressed) { return 0; }
+		if (m->getControl_pressed()) { return 0; }
 		
 		//make sure matrix2 and matrix1 are in the same order
 		if (names1 == names2) { //then everything is in same order and same size
 		}else if (names1.size() != names2.size()) { //wrong size no need to order, abort
 			m->mothurOut("[ERROR]: distance matrices are not the same size, aborting."); m->mothurOutEndLine();
-			m->control_pressed = true;
+			m->setControl_pressed(true);
 		}else { //sizes are the same, but either the names are different or they are in different order
 			m->mothurOut("[WARNING]: Names do not match between distance files. Comparing based on order in files."); m->mothurOutEndLine();
 		}	
 		
-		if (m->control_pressed) { return 0; }
+		if (m->getControl_pressed()) { return 0; }
 		
 		/***************************************************/
 		//    calculating mantel and signifigance		   //
@@ -203,11 +202,11 @@ int MantelCommand::execute(){
 		int count = 0;
 		for (int i = 0; i < iters; i++) {
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			//randomize matrix2
 			vector< vector<double> > matrix2Copy = matrix2;
-			m->mothurRandomShuffle(matrix2Copy);
+			util.mothurRandomShuffle(matrix2Copy);
 		
 			//calc random mantel
 			double randomMantel = 0.0;
@@ -220,15 +219,15 @@ int MantelCommand::execute(){
 		
 		double pValue = count / (float) iters;
 		
-		if (m->control_pressed) { return 0; }
+		if (m->getControl_pressed()) { return 0; }
 		
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(phylipfile1));
+		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipfile1));
 		string outputFile = getOutputFileName("mantel",variables);
 		outputNames.push_back(outputFile); outputTypes["mantel"].push_back(outputFile);
 		ofstream out;
 		
-		m->openOutputFile(outputFile, out);
+		util.openOutputFile(outputFile, out);
 		
 		out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
 		cout.setf(ios::fixed, ios::floatfield); cout.setf(ios::showpoint);
@@ -241,10 +240,8 @@ int MantelCommand::execute(){
 		cout << "\nmantel = " << mantel << "\tpValue = " << pValue << endl;
 		m->mothurOutJustToLog("\nmantel = " + toString(mantel) + "\tpValue = " + toString(pValue) + "\n"); 
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();		
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();		
 		
 		return 0;
 	}
