@@ -47,7 +47,7 @@ string OTUAssociationCommand::getHelpString(){
 		helpString += "The otu.association command should be in the following format: otu.association(shared=yourSharedFile, method=yourMethod).\n";
 		helpString += "Example otu.association(shared=genus.pool.shared, method=kendall).\n";
 		helpString += "The otu.association command outputs a .otu.corr file.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. groups), '=' and parameters (i.e.yourGroups).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -61,7 +61,7 @@ string OTUAssociationCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "otucorr") {  pattern = "[filename],[distance],[tag],otu.corr"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -111,14 +111,14 @@ OTUAssociationCommand::OTUAssociationCommand(string option)  {
 			outputTypes["otucorr"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -126,7 +126,7 @@ OTUAssociationCommand::OTUAssociationCommand(string option)  {
 				it = parameters.find("relabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["relabund"] = inputDir + it->second;		}
 				}
@@ -134,7 +134,7 @@ OTUAssociationCommand::OTUAssociationCommand(string option)  {
                 it = parameters.find("metadata");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["metadata"] = inputDir + it->second;		}
 				}
@@ -142,34 +142,34 @@ OTUAssociationCommand::OTUAssociationCommand(string option)  {
 			
 			
 			//check for required parameters			
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { abort = true; }
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else { inputFileName = sharedfile; m->setSharedFile(sharedfile); }
+			else { inputFileName = sharedfile; current->setSharedFile(sharedfile); }
 			
-			relabundfile = validParameter.validFile(parameters, "relabund", true);
+			relabundfile = validParameter.validFile(parameters, "relabund");
 			if (relabundfile == "not open") { abort = true; }
 			else if (relabundfile == "not found") { relabundfile = ""; }
-			else { inputFileName = relabundfile; m->setRelAbundFile(relabundfile); }
+			else { inputFileName = relabundfile; current->setRelAbundFile(relabundfile); }
 			
-            metadatafile = validParameter.validFile(parameters, "metadata", true);
+            metadatafile = validParameter.valid(parameters, "metadata");
 			if (metadatafile == "not open") { abort = true; metadatafile = ""; }
 			else if (metadatafile == "not found") { metadatafile = ""; }
             
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = "";  pickedGroups = false;  }
 			else { 
 				pickedGroups = true;
-				m->splitAtDash(groups, Groups);	
-			}			
-			m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
+			}
 			
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(inputFileName);	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputFileName);	}
 			
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
@@ -177,10 +177,10 @@ OTUAssociationCommand::OTUAssociationCommand(string option)  {
 				//is there are current file available for any of these?
 				//give priority to shared, then relabund
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") { inputFileName = sharedfile; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
-					relabundfile = m->getRelAbundFile(); 
+					relabundfile = current->getRelAbundFile(); 
 					if (relabundfile != "") { inputFileName = relabundfile;  m->mothurOut("Using " + relabundfile + " as input file for the relabund parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("You must provide either a shared or relabund file."); m->mothurOutEndLine(); abort = true; 
@@ -191,11 +191,11 @@ OTUAssociationCommand::OTUAssociationCommand(string option)  {
 			
 			if ((relabundfile != "") && (sharedfile != "")) { m->mothurOut("You may only use one of the following : shared or relabund file."); m->mothurOutEndLine(); abort = true;  }
 			
-			method = validParameter.validFile(parameters, "method", false);		if (method == "not found"){	method = "pearson";		}
+			method = validParameter.valid(parameters, "method");		if (method == "not found"){	method = "pearson";		}
 			
-            string temp = validParameter.validFile(parameters, "cutoff", false);
+            string temp = validParameter.valid(parameters, "cutoff");
 			if (temp == "not found") { temp = "10"; }
-			m->mothurConvert(temp, cutoff); 
+			util.mothurConvert(temp, cutoff); 
             
 			if ((method != "pearson") && (method != "spearman") && (method != "kendall")) { m->mothurOut(method + " is not a valid method. Valid methods are pearson, spearman, and kendall."); m->mothurOutEndLine(); abort = true; }
 			
@@ -211,7 +211,7 @@ OTUAssociationCommand::OTUAssociationCommand(string option)  {
 int OTUAssociationCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
         if (metadatafile != "") {  readMetadata(); }
 		
@@ -219,12 +219,10 @@ int OTUAssociationCommand::execute(){
 		if (sharedfile != "")			{  processShared();		} 
 		else if (relabundfile != "")	{  processRelabund();	}
 				
-		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+		if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 	}
@@ -236,14 +234,14 @@ int OTUAssociationCommand::execute(){
 //**********************************************************************************************************************
 int OTUAssociationCommand::processShared(){
 	try {
-		InputData* input = new InputData(sharedfile, "sharedfile");
-		vector<SharedRAbundVector*> lookup = input->getSharedRAbundVectors();
-		string lastLabel = lookup[0]->getLabel();
+		InputData* input = new InputData(sharedfile, "sharedfile", Groups);
+		SharedRAbundVectors* lookup = input->getSharedRAbundVectors();
+        Groups = lookup->getNamesGroups();
+		string lastLabel = lookup->getLabel();
         
-        if (metadatafile != "") { 
-            getMetadata();  
+        if (metadatafile != "") {
             bool error = false;
-            if (metadata[0].size() != lookup.size()) { m->mothurOut("[ERROR]: You have selected to use " + toString(metadata[0].size()) + " data rows from the metadata file, but " + toString(lookup.size()) + " from the shared file.\n");  m->control_pressed = true; error=true;}
+            if (metadata[0].size() != lookup->size()) { m->mothurOut("[ERROR]: You have selected to use " + toString(metadata[0].size()) + " data rows from the metadata file, but " + toString(lookup->size()) + " from the shared file.\n");  m->setControl_pressed(true); error=true;}
             if (error) {
                 //maybe add extra info here?? compare groups in each file??
             }
@@ -254,64 +252,57 @@ int OTUAssociationCommand::processShared(){
 		set<string> userLabels = labels;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) {  delete input; return 0;  }
+			if (m->getControl_pressed()) {  delete input; return 0;  }
 			
-			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){	
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				process(lookup);
 			}
 			
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 				
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+				delete lookup;
 				lookup = input->getSharedRAbundVectors(lastLabel);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 				
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				process(lookup);
 			}
 			
-			lastLabel = lookup[0]->getLabel();			
+			lastLabel = lookup->getLabel();
 			
 			//get next line to process
 			//prevent memory leak
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			delete lookup;
 			lookup = input->getSharedRAbundVectors();
 		}
 		
 		
-		if (m->control_pressed) { delete input; return 0;  }
+		if (m->getControl_pressed()) { delete input; return 0;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) {	delete lookup[i];	} } 
+		if (needToRun )  {
+			delete lookup;
 			lookup = input->getSharedRAbundVectors(lastLabel);
 			
-			m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+			m->mothurOut(lookup->getLabel()+"\n"); 
 			process(lookup);
 		}	
 		
@@ -325,17 +316,17 @@ int OTUAssociationCommand::processShared(){
 	}
 }
 //**********************************************************************************************************************
-int OTUAssociationCommand::process(vector<SharedRAbundVector*>& lookup){
+int OTUAssociationCommand::process(SharedRAbundVectors*& lookup){
 	try {
 		map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileName));
-        variables["[distance]"] = lookup[0]->getLabel();
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileName));
+        variables["[distance]"] = lookup->getLabel();
         variables["[tag]"] = method;
 		string outputFileName = getOutputFileName("otucorr",variables);
 		outputNames.push_back(outputFileName); outputTypes["otucorr"].push_back(outputFileName);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
 		
 		//column headings
@@ -343,25 +334,30 @@ int OTUAssociationCommand::process(vector<SharedRAbundVector*>& lookup){
         else { out << "OTUA\tMetadata\t" << method << "Coef\tSignificance\n";  }
 
 		
-		vector< vector<double> > xy; xy.resize(lookup[0]->getNumBins());
-		for (int i = 0; i < lookup[0]->getNumBins(); i++) { for (int j = 0; j < lookup.size(); j++) { xy[i].push_back(lookup[j]->getAbundance(i)); } }
+		vector< vector<double> > xy; xy.resize(lookup->getNumBins());
+        vector<string> sampleNames = lookup->getNamesGroups();
+		for (int i = 0; i < lookup->getNumBins(); i++) {
+            vector<int> abunds = lookup->getOTU(i);
+            for (int j = 0; j < abunds.size(); j++) { xy[i].push_back(abunds[j]); }
+        }
 		
 		LinearAlgebra linear;
+        vector<string> currentLabels = lookup->getOTUNames();
         if (metadatafile == "") {//compare otus
             for (int i = 0; i < xy.size(); i++) {
                 
                 for (int k = 0; k < i; k++) {
                     
-                    if (m->control_pressed) { out.close(); return 0; }
+                    if (m->getControl_pressed()) { out.close(); return 0; }
                     
                     double coef = 0.0;
                     double sig = 0.0;
                     if (method == "spearman")		{   coef = linear.calcSpearman(xy[i], xy[k], sig);	}
                     else if (method == "pearson")	{	coef = linear.calcPearson(xy[i], xy[k], sig);	}
                     else if (method == "kendall")	{	coef = linear.calcKendall(xy[i], xy[k], sig);	}                   
-                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->control_pressed = true; }
+                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->setControl_pressed(true); }
                     
-                    if (sig < cutoff) { out << m->currentSharedBinLabels[i] << '\t' << m->currentSharedBinLabels[k] << '\t' << coef << '\t' << sig << endl; }
+                    if (sig < cutoff) { out << currentLabels[i] << '\t' << currentLabels[k] << '\t' << coef << '\t' << sig << endl; }
                 }
             }
 		}else { //compare otus to metadata
@@ -369,16 +365,16 @@ int OTUAssociationCommand::process(vector<SharedRAbundVector*>& lookup){
                 
                 for (int k = 0; k < metadata.size(); k++) {
                     
-                    if (m->control_pressed) { out.close(); return 0; }
+                    if (m->getControl_pressed()) { out.close(); return 0; }
                     
                     double coef = 0.0;
                     double sig = 0.0;
                     if (method == "spearman")		{   coef = linear.calcSpearman(xy[i], metadata[k], sig);	}
                     else if (method == "pearson")	{	coef = linear.calcPearson(xy[i], metadata[k], sig);	}
                     else if (method == "kendall")	{	coef = linear.calcKendall(xy[i], metadata[k], sig);	}                   
-                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->control_pressed = true; }
+                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->setControl_pressed(true); }
                     
-                    if (sig < cutoff) { out << m->currentSharedBinLabels[i] << '\t' << metadataLabels[k] << '\t' << coef << '\t' << sig << endl; }
+                    if (sig < cutoff) { out << currentLabels[i] << '\t' << metadataLabels[k] << '\t' << coef << '\t' << sig << endl; }
                 }
             }
 
@@ -397,85 +393,77 @@ int OTUAssociationCommand::process(vector<SharedRAbundVector*>& lookup){
 //**********************************************************************************************************************
 int OTUAssociationCommand::processRelabund(){
 	try {
-		InputData* input = new InputData(relabundfile, "relabund");
-		vector<SharedRAbundFloatVector*> lookup = input->getSharedRAbundFloatVectors();
-		string lastLabel = lookup[0]->getLabel();
+		InputData* input = new InputData(relabundfile, "relabund", Groups);
+		SharedRAbundFloatVectors* lookup = input->getSharedRAbundFloatVectors();
+        Groups = lookup->getNamesGroups();
+		string lastLabel = lookup->getLabel();
         
-        if (metadatafile != "") { 
-            getMetadata(); 
+        if (metadatafile != "") {
             bool error = false;
-            if (metadata[0].size() != lookup.size()) { m->mothurOut("[ERROR]: You have selected to use " + toString(metadata[0].size()) + " data rows from the metadata file, but " + toString(lookup.size()) + " from the relabund file.\n");  m->control_pressed = true; error=true;}
+            if (metadata[0].size() != lookup->size()) { m->mothurOut("[ERROR]: You have selected to use " + toString(metadata[0].size()) + " data rows from the metadata file, but " + toString(lookup->size()) + " from the relabund file.\n");  m->setControl_pressed(true); error=true;}
             if (error) {
                 //maybe add extra info here?? compare groups in each file??
             }
         }
-        
-        
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		set<string> processedLabels;
 		set<string> userLabels = labels;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) {  delete input; return 0;  }
+			if (m->getControl_pressed()) {  delete input; return 0;  }
 			
-			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){	
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				process(lookup);
 			}
 			
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 				
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+				delete lookup;
 				lookup = input->getSharedRAbundFloatVectors(lastLabel);
 				
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 				
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(lookup->getLabel()+"\n"); 
 				process(lookup);
 			}
 			
-			lastLabel = lookup[0]->getLabel();			
+			lastLabel = lookup->getLabel();
 			
 			//get next line to process
 			//prevent memory leak
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			delete lookup;
 			lookup = input->getSharedRAbundFloatVectors();
 		}
 		
 		
-		if (m->control_pressed) { delete input; return 0;  }
+		if (m->getControl_pressed()) { delete input; return 0;  }
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) {	delete lookup[i];	} } 
+		if (needToRun )  {
+			delete lookup;
 			lookup = input->getSharedRAbundFloatVectors(lastLabel);
 			
-			m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+			m->mothurOut(lookup->getLabel()+"\n"); 
 			process(lookup);
+            delete lookup;
 		}	
 		
 		delete input;
@@ -488,43 +476,47 @@ int OTUAssociationCommand::processRelabund(){
 	}
 }
 //**********************************************************************************************************************
-int OTUAssociationCommand::process(vector<SharedRAbundFloatVector*>& lookup){
+int OTUAssociationCommand::process(SharedRAbundFloatVectors*& lookup){
 	try {
 		
 		map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(inputFileName));
-        variables["[distance]"] = lookup[0]->getLabel();
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputFileName));
+        variables["[distance]"] = lookup->getLabel();
         variables["[tag]"] = method;
         string outputFileName = getOutputFileName("otucorr",variables);
 		outputNames.push_back(outputFileName); outputTypes["otucorr"].push_back(outputFileName);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
 		
 		//column headings
 		if (metadatafile == "") { out << "OTUA\tOTUB\t" << method << "Coef\tSignificance\n"; }
         else { out << "OTUA\tMetadata\t" << method << "Coef\tSignificance\n";  }
 		
-		vector< vector<double> > xy; xy.resize(lookup[0]->getNumBins());
-		for (int i = 0; i < lookup[0]->getNumBins(); i++) { for (int j = 0; j < lookup.size(); j++) { xy[i].push_back(lookup[j]->getAbundance(i)); } }
+		vector< vector<double> > xy; xy.resize(lookup->getNumBins());
+        vector<string> sampleNames = lookup->getNamesGroups();
+        for (int i = 0; i < lookup->getNumBins(); i++) {
+            for (int j = 0; j < sampleNames.size(); j++) { xy[i].push_back(lookup->get(i, sampleNames[j])); }
+        }
 		
 		LinearAlgebra linear;
+        vector<string> currentLabels = lookup->getOTUNames();
         if (metadatafile == "") {//compare otus
             for (int i = 0; i < xy.size(); i++) {
                 
                 for (int k = 0; k < i; k++) {
                     
-                    if (m->control_pressed) { out.close(); return 0; }
+                    if (m->getControl_pressed()) { out.close(); return 0; }
                     
                     double coef = 0.0;
                     double sig = 0.0;
                     if (method == "spearman")		{   coef = linear.calcSpearman(xy[i], xy[k], sig);	}
                     else if (method == "pearson")	{	coef = linear.calcPearson(xy[i], xy[k], sig);	}
                     else if (method == "kendall")	{	coef = linear.calcKendall(xy[i], xy[k], sig);	}                   
-                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->control_pressed = true; }
+                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->setControl_pressed(true); }
                     
-                    if (sig < cutoff) { out << m->currentSharedBinLabels[i] << '\t' << m->currentSharedBinLabels[k] << '\t' << coef << '\t' << sig << endl; }
+                    if (sig < cutoff) { out << currentLabels[i] << '\t' << currentLabels[k] << '\t' << coef << '\t' << sig << endl; }
                 }
             }
 		}else { //compare otus to metadata
@@ -532,16 +524,16 @@ int OTUAssociationCommand::process(vector<SharedRAbundFloatVector*>& lookup){
                 
                 for (int k = 0; k < metadata.size(); k++) {
                     
-                    if (m->control_pressed) { out.close(); return 0; }
+                    if (m->getControl_pressed()) { out.close(); return 0; }
                     
                     double coef = 0.0;
                     double sig = 0.0;
                     if (method == "spearman")		{   coef = linear.calcSpearman(xy[i], metadata[k], sig);	}
                     else if (method == "pearson")	{	coef = linear.calcPearson(xy[i], metadata[k], sig);	}
                     else if (method == "kendall")	{	coef = linear.calcKendall(xy[i], metadata[k], sig);	}                   
-                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->control_pressed = true; }
+                    else { m->mothurOut("[ERROR]: invalid method, choices are spearman, pearson or kendall."); m->mothurOutEndLine(); m->setControl_pressed(true); }
                     
-                    if (sig < cutoff) { out << m->currentSharedBinLabels[i] << '\t' << metadataLabels[k] << '\t' << coef << '\t' << sig << endl; }
+                    if (sig < cutoff) { out << currentLabels[i] << '\t' << metadataLabels[k] << '\t' << coef << '\t' << sig << endl; }
                 }
             }
             
@@ -561,48 +553,60 @@ int OTUAssociationCommand::process(vector<SharedRAbundFloatVector*>& lookup){
 int OTUAssociationCommand::readMetadata(){
 	try {
 		ifstream in;
-		m->openInputFile(metadatafile, in);
+		util.openInputFile(metadatafile, in);
 		
-		string headerLine = m->getline(in); m->gobble(in);
+		string headerLine = util.getline(in); util.gobble(in);
 		istringstream iss (headerLine,istringstream::in);
 		
 		//read the first label, because it refers to the groups
 		string columnLabel;
-		iss >> columnLabel; m->gobble(iss); 
+		iss >> columnLabel; util.gobble(iss); 
 		
 		//save names of columns you are reading
 		while (!iss.eof()) {
-			iss >> columnLabel; m->gobble(iss);
-            if (m->debug) { m->mothurOut("[DEBUG]: metadata column Label = " + columnLabel + "\n"); }
+			iss >> columnLabel; util.gobble(iss);
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: metadata column Label = " + columnLabel + "\n"); }
 			metadataLabels.push_back(columnLabel);
 		}
+        
 		int count = metadataLabels.size();
+        SharedRAbundFloatVectors* metadataLookup = new SharedRAbundFloatVectors();
+        metadataLookup->setLabels("1");
         
 		//read rest of file
 		while (!in.eof()) {
 			
-			if (m->control_pressed) { in.close(); return 0; }
+			if (m->getControl_pressed()) { in.close(); return 0; }
 			
 			string group = "";
-			in >> group; m->gobble(in);
-            if (m->debug) { m->mothurOut("[DEBUG]: metadata group = " + group + "\n"); }
+			in >> group; util.gobble(in);
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: metadata group = " + group + "\n"); }
             
-			SharedRAbundFloatVector* tempLookup = new SharedRAbundFloatVector();
-			tempLookup->setGroup(group);
-			tempLookup->setLabel("1");
+            SharedRAbundFloatVector* tempLookup = new SharedRAbundFloatVector();
+            tempLookup->setLabel("1");
+            tempLookup->setGroup(group);
 			
 			for (int i = 0; i < count; i++) {
 				float temp = 0.0;
 				in >> temp;
-                if (m->debug) { m->mothurOut("[DEBUG]: metadata value = " + toString(temp) + "\n"); }
-				tempLookup->push_back(temp, group);
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: metadata value = " + toString(temp) + "\n"); }
+				tempLookup->push_back(temp);
 			}
 			
-			metadataLookup.push_back(tempLookup);
+            if (util.inUsersGroups(group, Groups)) {  metadataLookup->push_back(tempLookup);  }
 			
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
+        
+        metadataLookup->setOTUNames(metadataLabels);
+        metadataLookup->eliminateZeroOTUS();
+        
+        metadata.resize(metadataLookup->getNumBins());
+        vector<string> sampleNames = metadataLookup->getNamesGroups();
+        for (int i = 0; i < metadataLookup->getNumBins(); i++) {
+            for (int j = 0; j < sampleNames.size(); j++) { metadata[i].push_back(metadataLookup->get(i, sampleNames[j])); }
+        }
 		
 		return 0;
 	}
@@ -612,69 +616,7 @@ int OTUAssociationCommand::readMetadata(){
 	}
 }
 /*****************************************************************/
-//eliminate groups user did not pick, remove zeroed out otus, fill metadata vector.
-int OTUAssociationCommand::getMetadata(){
-	try {
-        
-		vector<string> mGroups = m->getGroups();
-        
-		bool remove = false;
-		for (int i = 0; i < metadataLookup.size(); i++) {
-			//if this sharedrabund is not from a group the user wants then delete it.
-			if (!(m->inUsersGroups(metadataLookup[i]->getGroup(), mGroups))) { 
-				delete metadataLookup[i]; metadataLookup[i] = NULL;
-				metadataLookup.erase(metadataLookup.begin()+i); 
-				i--; 
-				remove = true;
-			}
-		}
-        
-        vector<SharedRAbundFloatVector*> newLookup;
-		for (int i = 0; i < metadataLookup.size(); i++) {
-			SharedRAbundFloatVector* temp = new SharedRAbundFloatVector();
-			temp->setLabel(metadataLookup[i]->getLabel());
-			temp->setGroup(metadataLookup[i]->getGroup());
-			newLookup.push_back(temp);
-		}
-		
-		//for each bin
-        vector<string> newBinLabels;
-		for (int i = 0; i < metadataLookup[0]->getNumBins(); i++) {
-			if (m->control_pressed) { for (int j = 0; j < newLookup.size(); j++) {  delete newLookup[j];  } return 0; }
-			
-			//look at each sharedRabund and make sure they are not all zero
-			bool allZero = true;
-			for (int j = 0; j < metadataLookup.size(); j++) {
-				if (metadataLookup[j]->getAbundance(i) != 0) { allZero = false;  break;  }
-			}
-			
-			//if they are not all zero add this bin
-			if (!allZero) {
-				for (int j = 0; j < metadataLookup.size(); j++) {
-					newLookup[j]->push_back(metadataLookup[j]->getAbundance(i), metadataLookup[j]->getGroup());
-				}
-                newBinLabels.push_back(metadataLabels[i]);
-			}
-		}
-		
-        metadataLabels = newBinLabels;
-        
-		for (int j = 0; j < metadataLookup.size(); j++) {  delete metadataLookup[j];  } 
-        metadataLookup.clear();
-		
-        metadata.resize(newLookup[0]->getNumBins());
-		for (int i = 0; i < newLookup[0]->getNumBins(); i++) { for (int j = 0; j < newLookup.size(); j++) { metadata[i].push_back(newLookup[j]->getAbundance(i)); } }
-        
-        for (int j = 0; j < newLookup.size(); j++) {  delete newLookup[j];  }
-	        
-        return 0;
-    }
-	catch(exception& e) {
-		m->errorOut(e, "OTUAssociationCommand", "getMetadata");	
-		exit(1);
-	}
-}
-/*****************************************************************/
+
 
 
 
