@@ -40,7 +40,7 @@ string OtuHierarchyCommand::getHelpString(){
 		helpString += "otu.hierarchy(list=yourListFile, label=yourLabels).\n";
 		helpString += "Example otu.hierarchy(list=amazon.fn.list, label=0.01-0.03).\n";
 		helpString += "The otu.hierarchy command outputs a .otu.hierarchy file which is described on the wiki.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. list), '=' and parameters (i.e.yourListFile).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -54,7 +54,7 @@ string OtuHierarchyCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "otuheirarchy") {  pattern = "[filename],[distance1],[tag],[distance2],otu.hierarchy"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -104,46 +104,46 @@ OtuHierarchyCommand::OtuHierarchyCommand(string option) {
 			outputTypes["otuheirarchy"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
 			}
 
-			listFile = validParameter.validFile(parameters, "list", true);
+			listFile = validParameter.validFile(parameters, "list");
 			if (listFile == "not found") { 
-				listFile = m->getListFile(); 
+				listFile = current->getListFile(); 
 				if (listFile != "") {  m->mothurOut("Using " + listFile + " as input file for the list parameter."); m->mothurOutEndLine(); }
 				else { 
 					m->mothurOut("No valid current list file. You must provide a list file."); m->mothurOutEndLine(); 
 					abort = true;
 				}
 			}else if (listFile == "not open") { abort = true; }	
-			else { m->setListFile(listFile); }
+			else { current->setListFile(listFile); }
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
 				outputDir = "";	
-				outputDir += m->hasPath(listFile); //if user entered a file with a path then preserve it	
+				outputDir += util.hasPath(listFile); //if user entered a file with a path then preserve it	
 			}
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { m->mothurOut("label is a required parameter for the otu.hierarchy command."); m->mothurOutEndLine(); abort = true; }
 			else { 
-				m->splitAtDash(label, mylabels);
+				util.splitAtDash(label, mylabels);
 				if (mylabels.size() != 2) { m->mothurOut("You must provide 2 labels."); m->mothurOutEndLine(); abort = true; }
 			}	
 			
-			output = validParameter.validFile(parameters, "output", false);			if (output == "not found") { output = "name"; }
+			output = validParameter.valid(parameters, "output");			if (output == "not found") { output = "name"; }
 			
 			if ((output != "name") && (output != "otulabel")) { m->mothurOut("output options are name and otulabel. I will use name."); m->mothurOutEndLine(); output = "name"; }
 		}
@@ -159,12 +159,12 @@ OtuHierarchyCommand::OtuHierarchyCommand(string option) {
 int OtuHierarchyCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		//get listvectors that correspond to labels requested, (or use smart distancing to get closest listvector)
 		vector< vector<string> > lists = getListVectors();
 		
-		if (m->control_pressed) { outputTypes.clear(); return 0; }
+		if (m->getControl_pressed()) { outputTypes.clear(); return 0; }
 		
 		//determine which is little and which is big, putting little first
 		if (lists.size() == 4) {
@@ -189,29 +189,29 @@ int OtuHierarchyCommand::execute(){
         vector<string> binLabels0 = lists[0];
 		for (int i = 0; i < lists[0].size(); i++) {
 		
-			if (m->control_pressed) {  return 0; }
+			if (m->getControl_pressed()) {  return 0; }
 			string bin = lists[1][i];
-            vector<string> names; m->splitAtComma(bin, names);
+            vector<string> names; util.splitAtComma(bin, names);
 			for (int j = 0; j < names.size(); j++) { littleBins[names[j]] = i; }
         }
 		
 		ofstream out;
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(listFile));
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listFile));
         variables["[distance1]"] = list1Label;
         variables["[tag]"] = "-"; 
         variables["[distance2]"] = list2Label;
 		string outputFileName = getOutputFileName("otuheirarchy",variables);
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		//go through each bin in "big" otu and output the bins in "little" otu which created it
         vector<string> binLabels1 = lists[2];
 		for (int i = 0; i < lists[2].size(); i++) {
 		
-			if (m->control_pressed) { outputTypes.clear(); out.close(); m->mothurRemove(outputFileName); return 0; }
+			if (m->getControl_pressed()) { outputTypes.clear(); out.close(); util.mothurRemove(outputFileName); return 0; }
 			
 			string binnames = lists[3][i];
-            vector<string> names; m->splitAtComma(binnames, names);
+            vector<string> names; util.splitAtComma(binnames, names);
 			
 			//output column 1
 			if (output == "name")	{   out << binnames << '\t';	}
@@ -235,10 +235,9 @@ int OtuHierarchyCommand::execute(){
 		
 		out.close();
 		
-		if (m->control_pressed) { outputTypes.clear(); m->mothurRemove(outputFileName); return 0; }
+		if (m->getControl_pressed()) { outputTypes.clear(); util.mothurRemove(outputFileName); return 0; }
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
 		m->mothurOut(outputFileName); m->mothurOutEndLine();	outputNames.push_back(outputFileName); outputTypes["otuheirarchy"].push_back(outputFileName); 
 		m->mothurOutEndLine();
 		
@@ -261,7 +260,7 @@ vector< vector<string> > OtuHierarchyCommand::getListVectors() { //return value
             string realLabel;
             vector< vector<string> > thisList = getListVector(*it, realLabel);
             
-            if (m->control_pressed) {  return lists; }
+            if (m->getControl_pressed()) {  return lists; }
             
             for (int i = 0; i < thisList.size(); i++) { lists.push_back(thisList[i]); }
             
@@ -281,7 +280,7 @@ vector< vector<string> > OtuHierarchyCommand::getListVector(string label, string
 	try {
         vector< vector<string> > myList;
         
-		InputData input(listFile, "list");
+		InputData input(listFile, "list", nullVector);
 		ListVector* list = input.getListVector();
 		string lastLabel = list->getLabel();
 		
@@ -292,7 +291,7 @@ vector< vector<string> > OtuHierarchyCommand::getListVector(string label, string
 		
 		//as long as you are not at the end of the file or done wih the lines you want
 		while((list != NULL) && (userLabels.size() != 0)) {
-			if (m->control_pressed) {  return myList;  }
+			if (m->getControl_pressed()) {  return myList;  }
 			
 			if(labels.count(list->getLabel()) == 1){
 				processedLabels.insert(list->getLabel());
@@ -300,7 +299,7 @@ vector< vector<string> > OtuHierarchyCommand::getListVector(string label, string
 				break;
 			}
 			
-			if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+			if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 				string saveLabel = list->getLabel();
 				
 				delete list;
@@ -323,7 +322,7 @@ vector< vector<string> > OtuHierarchyCommand::getListVector(string label, string
 		}
 		
 		
-		if (m->control_pressed) {  return myList;  }
+		if (m->getControl_pressed()) {  return myList;  }
 		
 		//output error messages about any remaining user labels
 		set<string>::iterator it;
@@ -339,7 +338,7 @@ vector< vector<string> > OtuHierarchyCommand::getListVector(string label, string
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
+		if (needToRun )  {
 			delete list;
 			list = input.getListVector(lastLabel);
 		}
@@ -348,7 +347,7 @@ vector< vector<string> > OtuHierarchyCommand::getListVector(string label, string
         myList.push_back(list->getLabels());
         vector<string> bins;
         for (int i = 0; i < list->getNumBins(); i++) {
-            if (m->control_pressed) {  return myList;  }
+            if (m->getControl_pressed()) {  return myList;  }
             bins.push_back(list->get(i));
         }
         myList.push_back(bins);
