@@ -46,7 +46,6 @@ string ParsimonyCommand::getHelpString(){
 		helpString += "Example parsimony(random=out, iters=500).\n";
 		helpString += "The default value for random is "" (meaning you want to use the trees in your inputfile, randomtree=out means you just want the random distribution of trees outputted to out.rd_parsimony),\n";
 		helpString += "and iters is 1000.  The parsimony command output two files: .parsimony and .psummary their descriptions are in the manual.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. random), '=' and parameters (i.e.yourOutputFilename).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -61,7 +60,7 @@ string ParsimonyCommand::getOutputPattern(string type) {
         
         if (type == "parsimony") {  pattern = "[filename],parsimony"; } 
         else if (type == "psummary") {  pattern = "[filename],psummary"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -114,14 +113,14 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
 			outputTypes["psummary"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("tree");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["tree"] = inputDir + it->second;		}
 				}
@@ -129,7 +128,7 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -137,7 +136,7 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
 				it = parameters.find("name");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["name"] = inputDir + it->second;		}
 				}
@@ -145,42 +144,42 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
 			}
 			
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
 			
-			randomtree = validParameter.validFile(parameters, "random", false);		if (randomtree == "not found") { randomtree = ""; }
+			randomtree = validParameter.valid(parameters, "random");		if (randomtree == "not found") { randomtree = ""; }
 			
 			//are you trying to use parsimony without reading a tree or saying you want random distribution
 			if (randomtree == "")  {
 				//check for required parameters
-				treefile = validParameter.validFile(parameters, "tree", true);
+				treefile = validParameter.validFile(parameters, "tree");
 				if (treefile == "not open") { treefile = ""; abort = true; }
 				else if (treefile == "not found") { 				//if there is a current design file, use it
-					treefile = m->getTreeFile(); 
+					treefile = current->getTreeFile(); 
 					if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter."); m->mothurOutEndLine(); }
 					else { 	m->mothurOut("You have no current tree file and the tree parameter is required."); m->mothurOutEndLine(); abort = true; }								
-				}else { m->setTreeFile(treefile); }	
+				}else { current->setTreeFile(treefile); }	
 				
 				//check for required parameters
-				groupfile = validParameter.validFile(parameters, "group", true);
+				groupfile = validParameter.validFile(parameters, "group");
 				if (groupfile == "not open") { abort = true; }
 				else if (groupfile == "not found") { groupfile = ""; }
-				else { m->setGroupFile(groupfile); }
+				else { current->setGroupFile(groupfile); }
 				
-				namefile = validParameter.validFile(parameters, "name", true);
+				namefile = validParameter.validFile(parameters, "name");
 				if (namefile == "not open") { namefile = ""; abort = true; }
 				else if (namefile == "not found") { namefile = ""; }
-				else { m->setNameFile(namefile); }
+				else { current->setNameFile(namefile); }
                 
-                countfile = validParameter.validFile(parameters, "count", true);
+                countfile = validParameter.validFile(parameters, "count");
                 if (countfile == "not open") { countfile = ""; abort = true; }
                 else if (countfile == "not found") { countfile = "";  }	
-                else { m->setCountTableFile(countfile); }
+                else { current->setCountFile(countfile); }
                 
                 if ((namefile != "") && (countfile != "")) {
                     m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
@@ -193,28 +192,27 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
 			}
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			string outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";	if (randomtree == "")  { outputDir += m->hasPath(treefile); } }
+			string outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	if (randomtree == "")  { outputDir += util.hasPath(treefile); } }
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			groups = validParameter.validFile(parameters, "groups", false);			
-			if (groups == "not found") { groups = ""; m->clearGroups(); }
+			groups = validParameter.valid(parameters, "groups");			
+			if (groups == "not found") { groups = "";  }
 			else { 
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
 				
-			itersString = validParameter.validFile(parameters, "iters", false);			if (itersString == "not found") { itersString = "1000"; }
-			m->mothurConvert(itersString, iters); 
-			
-			string temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
-			m->setProcessors(temp);
-			m->mothurConvert(temp, processors);
+			itersString = validParameter.valid(parameters, "iters");			if (itersString == "not found") { itersString = "1000"; }
+			util.mothurConvert(itersString, iters); 
 			
+			string temp = validParameter.valid(parameters, "processors");	if (temp == "not found"){	temp = current->getProcessors();	}
+			processors = current->setProcessors(temp);
+						
 			if (countfile=="") {
                 if (namefile == "") {
                     vector<string> files; files.push_back(treefile);
-                    parser.getNameFile(files);
+                    if (!current->getMothurCalling())  {  parser.getNameFile(files);   }
                 } 
             }
 			
@@ -230,14 +228,13 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
 int ParsimonyCommand::execute() {
 	try {
 	
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
-		
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
+        Treenames = util.parseTreeFile(treefile); //extract treenames
 		
 		//randomtree will tell us if user had their own treefile or if they just want the random distribution
 		//user has entered their own tree
-		if (randomtree == "") { 
-			
-			m->setTreeFile(treefile);
+		if (randomtree == "") {
+			current->setTreeFile(treefile);
 			
             TreeReader* reader;
             if (countfile == "") { reader = new TreeReader(treefile, groupfile, namefile); }
@@ -246,49 +243,54 @@ int ParsimonyCommand::execute() {
             ct = T[0]->getCountTable();
             delete reader;
 	
-			if(outputDir == "") { outputDir += m->hasPath(treefile); }
+			if(outputDir == "") { outputDir += util.hasPath(treefile); }
             map<string, string> variables; 
-            variables["[filename]"] = outputDir + m->getSimpleName(treefile) +  ".";
+            variables["[filename]"] = outputDir + util.getSimpleName(treefile) +  ".";
             
 			output = new ColumnFile(getOutputFileName("parsimony",variables), itersString);
 			outputNames.push_back(getOutputFileName("parsimony",variables));
 			outputTypes["parsimony"].push_back(getOutputFileName("parsimony",variables));
 				
 			sumFile = getOutputFileName("psummary",variables);
-			m->openOutputFile(sumFile, outSum);
+			util.openOutputFile(sumFile, outSum);
 			outputNames.push_back(sumFile);
 			outputTypes["psummary"].push_back(sumFile);
 		}else { //user wants random distribution
 			getUserInput();
 				
-			if(outputDir == "") { outputDir += m->hasPath(randomtree); }
-			output = new ColumnFile(outputDir+ m->getSimpleName(randomtree), itersString);
-			outputNames.push_back(outputDir+ m->getSimpleName(randomtree));
-			outputTypes["parsimony"].push_back(outputDir+ m->getSimpleName(randomtree));
+			if(outputDir == "") { outputDir += util.hasPath(randomtree); }
+			output = new ColumnFile(outputDir+ util.getSimpleName(randomtree), itersString);
+			outputNames.push_back(outputDir+ util.getSimpleName(randomtree));
+			outputTypes["parsimony"].push_back(outputDir+ util.getSimpleName(randomtree));
 		}
 			
 		//set users groups to analyze
-		SharedUtil util;
-		vector<string> mGroups = m->getGroups();
 		vector<string> tGroups = ct->getNamesOfGroups();
-		util.setGroups(mGroups, tGroups, allGroups, numGroups, "parsimony");	//sets the groups the user wants to analyze
-		util.getCombos(groupComb, mGroups, numComp);
-		m->setGroups(mGroups);
+        //check that groups are valid
+        for (int i = 0; i < Groups.size(); i++) {
+            if (!util.inUsersGroups(Groups[i], tGroups)) {
+                m->mothurOut(Groups[i] + " is not a valid group, and will be disregarded."); m->mothurOutEndLine();
+                // erase the invalid group from userGroups
+                Groups.erase(Groups.begin()+i);
+                i--;
+            }
+        }
+        if (Groups.size() == 0) { Groups = tGroups;  }
+		util.getCombos(groupComb, Groups, numComp);
 			
 		if (numGroups == 1) { numComp++; groupComb.push_back(allGroups); }
-			
-		Parsimony pars;
+        
+        if (numComp < processors) { m->mothurOut("Reducing processors to " + toString(numComp) + ".\n");  }
+		Parsimony pars(Groups);
 		counter = 0;
 	
-		Progress* reading;
-		reading = new Progress("Comparing to random:", iters);
+		Progress* reading; reading = new Progress("Comparing to random:", iters);
 		
-		if (m->control_pressed) { 
+		if (m->getControl_pressed()) { 
 			delete reading; delete output;
 			delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }
 			if (randomtree == "") {  outSum.close();  }
-			for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear();
-			m->clearGroups();
+			for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } outputTypes.clear();
 			return 0;
 		}
 			
@@ -296,28 +298,21 @@ int ParsimonyCommand::execute() {
 		//get pscore for users tree
 		userData.resize(numComp,0);  //data = AB, AC, BC, ABC.
 		randomData.resize(numComp,0);  //data = AB, AC, BC, ABC.
-		rscoreFreq.resize(numComp);  
-		uscoreFreq.resize(numComp);  
-		rCumul.resize(numComp);  
-		uCumul.resize(numComp);  
-		userTreeScores.resize(numComp);  
-		UScoreSig.resize(numComp); 
+		rscoreFreq.resize(numComp); uscoreFreq.resize(numComp); rCumul.resize(numComp); uCumul.resize(numComp); userTreeScores.resize(numComp); UScoreSig.resize(numComp);
 				
 		if (randomtree == "") {
 			//get pscores for users trees
 			for (int i = 0; i < T.size(); i++) {
 				userData = pars.getValues(T[i], processors, outputDir);  //data = AB, AC, BC, ABC.
 				
-				if (m->control_pressed) { 
+				if (m->getControl_pressed()) { 
 					delete reading; delete output;
 					delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }
 					if (randomtree == "") {  outSum.close();  }
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear();
-					m->clearGroups();
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } outputTypes.clear();
 					return 0;
 				}
 
-
 				//output scores for each combination
 				for(int k = 0; k < numComp; k++) {
 
@@ -335,24 +330,24 @@ int ParsimonyCommand::execute() {
 				}
 			}
 			
+            Utils* stableRandom = new Utils();
 			//get pscores for random trees
 			for (int j = 0; j < iters; j++) {
 								
 				//create new tree with same num nodes and leaves as users
-				randT = new Tree(ct);
+				randT = new Tree(ct, Treenames);
 
 				//create random relationships between nodes
-				randT->assembleRandomTree();
+				randT->assembleRandomTree(stableRandom);
 
 				//get pscore of random tree
 				randomData = pars.getValues(randT, processors, outputDir);
 				
-				if (m->control_pressed) { 
-					delete reading;  delete output; delete randT;
+				if (m->getControl_pressed()) { 
+                    delete reading;  delete output; delete randT; delete stableRandom;
 					if (randomtree == "") {  outSum.close();  }
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear();
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } outputTypes.clear();
 					delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }
-					m->clearGroups();
 					return 0;
 				}
 					
@@ -374,29 +369,29 @@ int ParsimonyCommand::execute() {
 				
 				delete randT;
 			}
-
+            delete stableRandom;
 		}else {
+            Utils* stableRandom = new Utils();
 			//get pscores for random trees
 			for (int j = 0; j < iters; j++) {
 								
 				//create new tree with same num nodes and leaves as users
-				randT = new Tree(ct);
+				randT = new Tree(ct, Treenames);
 				//create random relationships between nodes
 
-				randT->assembleRandomTree();
+				randT->assembleRandomTree(stableRandom);
 				
-				if (m->control_pressed) { 
-					delete reading; delete output; delete randT; delete ct; 
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear(); return 0;
+				if (m->getControl_pressed()) { 
+					delete reading; delete output; delete randT; delete ct;  delete stableRandom;
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } outputTypes.clear(); return 0;
 				}
 
-
 				//get pscore of random tree
 				randomData = pars.getValues(randT, processors, outputDir);
 				
-				if (m->control_pressed) { 
+				if (m->getControl_pressed()) { 
 					delete reading; delete output; delete randT; delete ct; 
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear(); return 0;
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } outputTypes.clear(); return 0;
 				}
 			
 				for(int r = 0; r < numComp; r++) {
@@ -417,6 +412,7 @@ int ParsimonyCommand::execute() {
 				
 				delete randT;
 			}
+            delete stableRandom;
 		}
 
 		for(int a = 0; a < numComp; a++) {
@@ -447,33 +443,28 @@ int ParsimonyCommand::execute() {
 			}
 		}
 		
-		if (m->control_pressed) { 
+		if (m->getControl_pressed()) { 
 				delete reading; delete output;
 				delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }
 				if (randomtree == "") {  outSum.close();  }
-				for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear();
+				for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } outputTypes.clear();
 				return 0;
 		}
 		
 		//finish progress bar
-		reading->finish();
-		delete reading;
+		reading->finish(); delete reading;
 		
 		printParsimonyFile();
 		if (randomtree == "") { printUSummaryFile(); }
 				
         delete output; delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear(); return 0;}
+		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } outputTypes.clear(); return 0;}
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n");
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 
-		
 		return 0;
-		
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ParsimonyCommand", "execute");
@@ -487,11 +478,8 @@ void ParsimonyCommand::printParsimonyFile() {
 		vector<double> data;
 		vector<string> tags;
 		
-		if (randomtree == "") {
-			tags.push_back("Score"); tags.push_back("UserFreq"); tags.push_back("UserCumul"); tags.push_back("RandFreq"); tags.push_back("RandCumul");
-		}else {
-			tags.push_back("Score"); tags.push_back("RandFreq"); tags.push_back("RandCumul");
-		}
+		if (randomtree == "") { tags.push_back("Score"); tags.push_back("UserFreq"); tags.push_back("UserCumul"); tags.push_back("RandFreq"); tags.push_back("RandCumul"); }
+		else { tags.push_back("Score"); tags.push_back("RandFreq"); tags.push_back("RandCumul"); }
 
 		for(int a = 0; a < numComp; a++) {
 			output->initFile(groupComb[a], tags);
@@ -518,16 +506,15 @@ int ParsimonyCommand::printUSummaryFile() {
 	try {
 		//column headers
 		outSum << "Tree#" << '\t' << "Groups" << '\t'  <<  "ParsScore" << '\t' << "ParsSig" <<  endl;
-		m->mothurOut("Tree#\tGroups\tParsScore\tParsSig"); m->mothurOutEndLine();
+		m->mothurOut("Tree#\tGroups\tParsScore\tParsSig\n");
 		
 		//format output
 		outSum.setf(ios::fixed, ios::floatfield); outSum.setf(ios::showpoint);
 		
-		
 		//print each line
 		for (int i = 0; i< T.size(); i++) {
 			for(int a = 0; a < numComp; a++) {
-				if (m->control_pressed) {  outSum.close(); return 0; }
+				if (m->getControl_pressed()) {  outSum.close(); return 0; }
 				if (UScoreSig[a][i] > (1/(float)iters)) {
 					outSum << setprecision(6) << i+1 << '\t' << groupComb[a]  << '\t' << userTreeScores[a][i] << setprecision(itersString.length()) << '\t' << UScoreSig[a][i] << endl;
 					cout << setprecision(6) << i+1 << '\t' << groupComb[a]  << '\t' << userTreeScores[a][i] << setprecision(itersString.length()) << '\t' << UScoreSig[a][i] << endl;
@@ -552,7 +539,6 @@ int ParsimonyCommand::printUSummaryFile() {
 /***********************************************************/
 void ParsimonyCommand::getUserInput() {
 	try {
-	
 		//create treemap
 		ct = new CountTable();
 
@@ -588,8 +574,7 @@ void ParsimonyCommand::getUserInput() {
 		string s;	
 		getline(cin, s);
 		
-		m->Treenames = ct->getNamesOfSeqs(); 
-        m->runParse = false;
+		Treenames = ct->getNamesOfSeqs();
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ParsimonyCommand", "getUserInput");
