@@ -10,7 +10,7 @@
 #include "rarefactsharedcommand.h"
 #include "sharedsobs.h"
 #include "sharednseqs.h"
-#include "sharedutilities.h"
+
 #include "subsample.h"
 
 
@@ -61,7 +61,6 @@ string RareFactSharedCommand::getHelpString(){
 		helpString += validCalculator.printCalc("sharedrarefaction");
 		helpString += "The label parameter is used to analyze specific labels in your input.\n";
 		helpString += "The groups parameter allows you to specify which of the groups in your groupfile you would like analyzed.  You must enter at least 2 valid groups.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. freq), '=' and parameters (i.e.yourFreq).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -76,7 +75,7 @@ string RareFactSharedCommand::getOutputPattern(string type) {
         
         if (type == "sharedrarefaction") {  pattern = "[filename],shared.rarefaction"; }
         else if (type == "sharedr_nseqs") {  pattern = "[filename],shared.r_nseqs"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -130,14 +129,14 @@ RareFactSharedCommand::RareFactSharedCommand(string option)  {
 			outputTypes["sharedr_nseqs"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -145,7 +144,7 @@ RareFactSharedCommand::RareFactSharedCommand(string option)  {
                 it = parameters.find("design");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["design"] = inputDir + it->second;		}
 				}
@@ -153,82 +152,82 @@ RareFactSharedCommand::RareFactSharedCommand(string option)  {
 			}
 			
 			//get shared file
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { 
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}else { m->setSharedFile(sharedfile); }
+			}else { current->setSharedFile(sharedfile); }
             
-            designfile = validParameter.validFile(parameters, "design", true);
+            designfile = validParameter.validFile(parameters, "design");
 			if (designfile == "not open") { abort = true; designfile = ""; }
 			else if (designfile == "not found") {  	designfile = "";	}
-			else { m->setDesignFile(designfile); }
+			else { current->setDesignFile(designfile); }
 			
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(sharedfile);		}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(sharedfile);		}
 			
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
 				
-			calc = validParameter.validFile(parameters, "calc", false);			
+			calc = validParameter.valid(parameters, "calc");			
 			if (calc == "not found") { calc = "sharedobserved";  }
 			else { 
 				 if (calc == "default")  {  calc = "sharedobserved";  }
 			}
-			m->splitAtDash(calc, Estimators);
-			if (m->inUsersGroups("citation", Estimators)) { 
+			util.splitAtDash(calc, Estimators);
+			if (util.inUsersGroups("citation", Estimators)) { 
 				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
 				//remove citation from list of calcs
 				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
 			}
 			
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; }
 			else { 
-				m->splitAtDash(groups, Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
-			m->setGroups(Groups);
             
-            string sets = validParameter.validFile(parameters, "sets", false);			
+            string sets = validParameter.valid(parameters, "sets");			
 			if (sets == "not found") { sets = ""; }
 			else { 
-				m->splitAtDash(sets, Sets);
+				util.splitAtDash(sets, Sets);
+                if (Sets.size() != 0) { if (Sets[0] != "all") { Sets.clear(); } }
 			}
 			
 			string temp;
-			temp = validParameter.validFile(parameters, "freq", false);			if (temp == "not found") { temp = "100"; }
-			m->mothurConvert(temp, freq); 
+			temp = validParameter.valid(parameters, "freq");			if (temp == "not found") { temp = "100"; }
+			util.mothurConvert(temp, freq); 
 			
-			temp = validParameter.validFile(parameters, "iters", false);			if (temp == "not found") { temp = "1000"; }
-			m->mothurConvert(temp, nIters); 
+			temp = validParameter.valid(parameters, "iters");			if (temp == "not found") { temp = "1000"; }
+			util.mothurConvert(temp, nIters); 
 			
-			temp = validParameter.validFile(parameters, "jumble", false);			if (temp == "not found") { temp = "T"; }
-			if (m->isTrue(temp)) { jumble = true; }
+			temp = validParameter.valid(parameters, "jumble");			if (temp == "not found") { temp = "T"; }
+			if (util.isTrue(temp)) { jumble = true; }
 			else { jumble = false; }
-			m->jumble = jumble;
             
-            temp = validParameter.validFile(parameters, "groupmode", false);		if (temp == "not found") { temp = "T"; }
-			groupMode = m->isTrue(temp);
+            temp = validParameter.valid(parameters, "groupmode");		if (temp == "not found") { temp = "T"; }
+			groupMode = util.isTrue(temp);
             
-            temp = validParameter.validFile(parameters, "subsampleiters", false);			if (temp == "not found") { temp = "1000"; }
-			m->mothurConvert(temp, iters); 
+            temp = validParameter.valid(parameters, "subsampleiters");			if (temp == "not found") { temp = "1000"; }
+			util.mothurConvert(temp, iters); 
             
-            temp = validParameter.validFile(parameters, "subsample", false);		if (temp == "not found") { temp = "F"; }
-			if (m->isNumeric1(temp)) { m->mothurConvert(temp, subsampleSize); subsample = true; }
+            temp = validParameter.valid(parameters, "subsample");		if (temp == "not found") { temp = "F"; }
+			if (util.isNumeric1(temp)) { util.mothurConvert(temp, subsampleSize); subsample = true; }
             else {  
-                if (m->isTrue(temp)) { subsample = true; subsampleSize = -1; }  //we will set it to smallest group later 
+                if (util.isTrue(temp)) { subsample = true; subsampleSize = -1; }  //we will set it to smallest group later 
                 else { subsample = false; }
             }
             
@@ -247,7 +246,7 @@ RareFactSharedCommand::RareFactSharedCommand(string option)  {
 int RareFactSharedCommand::execute(){
 	try {
 	
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
         DesignMap designMap;
         if (designfile == "") { //fake out designMap to run with process
@@ -255,24 +254,17 @@ int RareFactSharedCommand::execute(){
         }else {
             designMap.read(designfile);
             
-            //fill Sets - checks for "all" and for any typo groups
-			SharedUtil util;
-			vector<string> nameSets = designMap.getCategory();
-			util.setGroups(Sets, nameSets);
-            
-            for (int i = 0; i < Sets.size(); i++) {
-                process(designMap, Sets[i]);
-            }
+            if (Sets.size() == 0) {  Sets = designMap.getCategory(); }
+        
+            for (int i = 0; i < Sets.size(); i++) { process(designMap, Sets[i]); }
             
             if (groupMode) { outputNames = createGroupFile(outputNames); }
         }
                     
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 
 		return 0;
 	}
@@ -288,59 +280,49 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
         Rarefact* rCurve;
         vector<Display*> rDisplays;
         
-        InputData input(sharedfile, "sharedfile");
-		lookup = input.getSharedRAbundVectors();
-        if (lookup.size() < 2) { 
+        InputData input(sharedfile, "sharedfile", Groups);
+		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+        if (lookup->size() < 2) {
 			m->mothurOut("I cannot run the command without at least 2 valid groups."); 
-            for (int i = 0; i < lookup.size(); i++) { delete lookup[i]; }
+            delete lookup;
             return 0;
         }
         
-        string fileNameRoot = outputDir + m->getRootName(m->getSimpleName(sharedfile));
+        string fileNameRoot = outputDir + util.getRootName(util.getSimpleName(sharedfile));
         
-        vector<string> newGroups = m->getGroups();
+        vector<string> newGroups = lookup->getNamesGroups();
         if (thisSet != "") {  //make groups only filled with groups from this set so that's all inputdata will read
             vector<string> thisSets; thisSets.push_back(thisSet);
             newGroups = designMap.getNamesGroups(thisSets);
             fileNameRoot += thisSet + ".";
         }
         
-        vector<SharedRAbundVector*> subset;
-        if (thisSet == "") {  subset.clear(); subset = lookup;  }
-        else {//fill subset with this sets groups
-            subset.clear();
-            for (int i = 0; i < lookup.size(); i++) {
-                if (m->inUsersGroups(lookup[i]->getGroup(), newGroups)) {
-                    subset.push_back(lookup[i]);
-                }
-            }
-        }
+        SharedRAbundVectors* subset = new SharedRAbundVectors();
+        vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+        if (thisSet != "") {//remove unwanted groups
+            for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
+            subset->eliminateZeroOTUS();
+        }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
+        
 
         /******************************************************/
-        if (subsample) { 
-            if (subsampleSize == -1) { //user has not set size, set size = smallest samples size
-                subsampleSize = subset[0]->getNumSeqs();
-                for (int i = 1; i < subset.size(); i++) {
-                    int thisSize = subset[i]->getNumSeqs();
-                    
-                    if (thisSize < subsampleSize) {	subsampleSize = thisSize;	}
-                }
-            }else {
+        if (subsample) {
+            //user has not set size, set size = smallest samples size
+            if (subsampleSize == -1) { subsampleSize = subset->getNumSeqsSmallestGroup(); }
+            else {
+                vector<string> lookupGroups = subset->getNamesGroups();
                 newGroups.clear();
-                vector<SharedRAbundVector*> temp;
-                for (int i = 0; i < subset.size(); i++) {
-                    if (subset[i]->getNumSeqs() < subsampleSize) { 
-                        m->mothurOut(subset[i]->getGroup() + " contains " + toString(subset[i]->getNumSeqs()) + ". Eliminating."); m->mothurOutEndLine();
-                        delete subset[i];
-                    }else { 
-                        newGroups.push_back(subset[i]->getGroup()); 
-                        temp.push_back(subset[i]);
-                    }
-                } 
-                subset = temp;
+                vector<string> temp;
+                for (int i = 0; i < lookupGroups.size(); i++) {
+                    if (lookup->getNumSeqs(lookupGroups[i]) < subsampleSize) {
+                        m->mothurOut(lookupGroups[i] + " contains " + toString(subset->getNumSeqs(lookupGroups[i])) + ". Eliminating."); m->mothurOutEndLine();
+                        temp.push_back(lookupGroups[i]);
+                    }else { newGroups.push_back(lookupGroups[i]); }
+                }
+                subset->removeGroups(temp);
             }
             
-            if (subset.size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command."); m->mothurOutEndLine(); m->control_pressed = true; return 0; }
+            if (subset->size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command."); m->mothurOutEndLine(); m->setControl_pressed(true); return 0; }
         }
         /******************************************************/
         
@@ -348,7 +330,7 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
         variables["[filename]"] = fileNameRoot;
 		ValidCalculators validCalculator;
 		for (int i=0; i<Estimators.size(); i++) {
-			if (validCalculator.isValidCalculator("sharedrarefaction", Estimators[i]) == true) { 
+			if (validCalculator.isValidCalculator("sharedrarefaction", Estimators[i]) ) { 
 				if (Estimators[i] == "sharedobserved") { 
 					rDisplays.push_back(new RareDisplay(new SharedSobs(), new SharedThreeColumnFile(getOutputFileName("sharedrarefaction",variables), "")));
 					outputNames.push_back(getOutputFileName("sharedrarefaction",variables)); outputTypes["sharedrarefaction"].push_back(getOutputFileName("sharedrarefaction",variables));
@@ -361,141 +343,131 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
 		}
 		
 		//if the users entered no valid calculators don't execute command
-		if (rDisplays.size() == 0) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  return 0; }
+        if (rDisplays.size() == 0) { delete lookup;  delete subset; return 0; }
 		
-		if (m->control_pressed) { 
+		if (m->getControl_pressed()) { 
 			for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
-			for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	}
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
+			delete lookup; delete subset;
 			return 0;
 		}
         
         
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-        string lastLabel = subset[0]->getLabel();
+        string lastLabel = subset->getLabel();
 		set<string> processedLabels;
 		set<string> userLabels = labels;
         
 		//as long as you are not at the end of the file or done wih the lines you want
-		while((subset[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			if (m->control_pressed) { 
+		while((subset != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+			if (m->getControl_pressed()) { 
 				for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
-				for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	}
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+				for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
+                delete lookup; delete subset;
 				return 0;
 			}
 			
-			if(allLines == 1 || labels.count(subset[0]->getLabel()) == 1){
-				m->mothurOut(subset[0]->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
-				rCurve = new Rarefact(subset, rDisplays);
+			if(allLines == 1 || labels.count(subset->getLabel()) == 1){
+				m->mothurOut(subset->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
+                vector<SharedRAbundVector*> rabunds = subset->getSharedRAbundVectors();
+				rCurve = new Rarefact(rabunds, rDisplays, jumble);
 				rCurve->getSharedCurve(freq, nIters);
 				delete rCurve;
+                for (int i = 0; i < rabunds.size(); i++) {	delete rabunds[i]; 	}
                 
                 if (subsample) { subsampleLookup(subset, fileNameRoot);  }
                     
-				processedLabels.insert(subset[0]->getLabel());
-				userLabels.erase(subset[0]->getLabel());
+				processedLabels.insert(subset->getLabel());
+				userLabels.erase(subset->getLabel());
 			}
 			
-			if ((m->anyLabelsToProcess(subset[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-                string saveLabel = subset[0]->getLabel();
+			if ((util.anyLabelsToProcess(subset->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+                string saveLabel = subset->getLabel();
                 
-                for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+                delete subset;
                 lookup = input.getSharedRAbundVectors(lastLabel);
                 
-                if (thisSet == "") {  subset.clear(); subset = lookup;  }
-                else {//fill subset with this sets groups
-                    subset.clear();
-                    for (int i = 0; i < lookup.size(); i++) {
-                        if (m->inUsersGroups(lookup[i]->getGroup(), newGroups)) {
-                            subset.push_back(lookup[i]);
-                        }
-                    }
-                }
-
-                m->mothurOut(subset[0]->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
-                rCurve = new Rarefact(subset, rDisplays);
+                subset = new SharedRAbundVectors();
+                vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+                if (thisSet != "") {//remove unwanted groups
+                    for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
+                    subset->eliminateZeroOTUS();
+                }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
+                
+                m->mothurOut(subset->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
+                vector<SharedRAbundVector*> rabunds = subset->getSharedRAbundVectors();
+                rCurve = new Rarefact(rabunds, rDisplays, jumble);
                 rCurve->getSharedCurve(freq, nIters);
                 delete rCurve;
+                for (int i = 0; i < rabunds.size(); i++) {	delete rabunds[i]; 	}
                 
                 if (subsample) { subsampleLookup(subset, fileNameRoot);  }
                 
-                processedLabels.insert(subset[0]->getLabel());
-                userLabels.erase(subset[0]->getLabel());
+                processedLabels.insert(subset->getLabel());
+                userLabels.erase(subset->getLabel());
                 
                 //restore real lastlabel to save below
-                subset[0]->setLabel(saveLabel);
+                subset->setLabels(saveLabel);
 			}
             
 			
-			lastLabel = subset[0]->getLabel();
+			lastLabel = subset->getLabel();
 			
 			//get next line to process
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+            delete lookup; delete subset;
 			lookup = input.getSharedRAbundVectors();
             
-            if (lookup[0] != NULL) {
-                if (thisSet == "") {  subset.clear(); subset = lookup;  }
-                else {//fill subset with this sets groups
-                    subset.clear();
-                    for (int i = 0; i < lookup.size(); i++) {
-                        if (m->inUsersGroups(lookup[i]->getGroup(), newGroups)) {
-                            subset.push_back(lookup[i]);
-                        }
-                    }
-                }
-            }else {  subset.clear(); subset.push_back(NULL); }
+            if (lookup != NULL) {
+                if (thisSet != "") {//remove unwanted groups
+                    for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
+                    subset->eliminateZeroOTUS();
+                }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
+            }else {  subset = NULL; }
 
 		}
 		
-		if (m->control_pressed) { 
+		if (m->getControl_pressed()) { 
 			for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
-			for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	}
+			for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
 			return 0;
 		}
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
-		if (m->control_pressed) { 
+		if (m->getControl_pressed()) { 
 			for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
-			for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	}
+			for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
 			return 0;
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) {	delete lookup[i]; }  } 
-			lookup = input.getSharedRAbundVectors(lastLabel);
+		if (needToRun )  {
+            delete lookup; delete subset;
+            lookup = input.getSharedRAbundVectors();
             
-            if (thisSet == "") {  subset.clear(); subset = lookup;  }
-            else {//fill subset with this sets groups
-                subset.clear();
-                for (int i = 0; i < lookup.size(); i++) {
-                    if (m->inUsersGroups(lookup[i]->getGroup(), newGroups)) {
-                        subset.push_back(lookup[i]);
-                    }
-                }
-            }
+            if (lookup != NULL) {
+                if (thisSet != "") {//remove unwanted groups
+                    for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
+                    subset->eliminateZeroOTUS();
+                }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
+            }else {  subset = NULL; }
             
-			m->mothurOut(subset[0]->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
-			rCurve = new Rarefact(subset, rDisplays);
+			m->mothurOut(subset->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
+            vector<SharedRAbundVector*> rabunds = subset->getSharedRAbundVectors();
+			rCurve = new Rarefact(rabunds, rDisplays, jumble);
 			rCurve->getSharedCurve(freq, nIters);
 			delete rCurve;
+            for (int i = 0; i < rabunds.size(); i++) {	delete rabunds[i]; 	}
             
             if (subsample) { subsampleLookup(subset, fileNameRoot);  }
                 
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			delete lookup; delete subset;
 		}
 		
 		for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}	
@@ -509,36 +481,15 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
 	}
 }
 //**********************************************************************************************************************
-int RareFactSharedCommand::subsampleLookup(vector<SharedRAbundVector*>& thisLookup, string fileNameRoot) {
+int RareFactSharedCommand::subsampleLookup(SharedRAbundVectors*& thisLookup, string fileNameRoot) {
 	try {
         
         map<string, vector<string> > filenames;
+        SubSample sample;
         for (int thisIter = 0; thisIter < iters; thisIter++) {
             
-            vector<SharedRAbundVector*> thisItersLookup = thisLookup;
-            
-             //we want the summary results for the whole dataset, then the subsampling
-            SubSample sample;
-            vector<string> tempLabels; //dont need since we arent printing the sampled sharedRabunds
-                
-            //make copy of lookup so we don't get access violations
-            vector<SharedRAbundVector*> newLookup;
-            for (int k = 0; k < thisItersLookup.size(); k++) {
-                SharedRAbundVector* temp = new SharedRAbundVector();
-                temp->setLabel(thisItersLookup[k]->getLabel());
-                temp->setGroup(thisItersLookup[k]->getGroup());
-                newLookup.push_back(temp);
-            }
-                
-            //for each bin
-            for (int k = 0; k < thisItersLookup[0]->getNumBins(); k++) {
-                if (m->control_pressed) { for (int j = 0; j < newLookup.size(); j++) {  delete newLookup[j];  } return 0; }
-                for (int j = 0; j < thisItersLookup.size(); j++) { newLookup[j]->push_back(thisItersLookup[j]->getAbundance(k), thisItersLookup[j]->getGroup()); }
-                }
-                
-            tempLabels = sample.getSample(newLookup, subsampleSize);
-            thisItersLookup = newLookup;
-            
+            SharedRAbundVectors* thisItersLookup = new SharedRAbundVectors(*thisLookup);
+            sample.getSample(thisItersLookup, subsampleSize);
             
             Rarefact* rCurve;
             vector<Display*> rDisplays;
@@ -550,7 +501,7 @@ int RareFactSharedCommand::subsampleLookup(vector<SharedRAbundVector*>& thisLook
             
             ValidCalculators validCalculator;
             for (int i=0; i<Estimators.size(); i++) {
-                if (validCalculator.isValidCalculator("sharedrarefaction", Estimators[i]) == true) { 
+                if (validCalculator.isValidCalculator("sharedrarefaction", Estimators[i]) ) { 
                     if (Estimators[i] == "sharedobserved") { 
                         rDisplays.push_back(new RareDisplay(new SharedSobs(), new SharedThreeColumnFile(getOutputFileName("sharedrarefaction",variables), "")));
                         filenames["sharedrarefaction"].push_back(getOutputFileName("sharedrarefaction",variables));
@@ -561,14 +512,15 @@ int RareFactSharedCommand::subsampleLookup(vector<SharedRAbundVector*>& thisLook
                 }
             }
             
-            rCurve = new Rarefact(thisItersLookup, rDisplays);
+            vector<SharedRAbundVector*> rabunds = thisItersLookup->getSharedRAbundVectors();
+            rCurve = new Rarefact(rabunds, rDisplays, jumble);
 			rCurve->getSharedCurve(freq, nIters);
 			delete rCurve;
+            for (int i = 0; i < rabunds.size(); i++) {	delete rabunds[i]; 	}
             
             //clean up memory
-            for (int i = 0; i < thisItersLookup.size(); i++) { delete thisItersLookup[i]; }
-            thisItersLookup.clear();
             for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
+            delete thisItersLookup;
         }
         
         //create std and ave outputs
@@ -578,32 +530,32 @@ int RareFactSharedCommand::subsampleLookup(vector<SharedRAbundVector*>& thisLook
             vector<string> columnHeaders;
             for (int i = 0; i < thisTypesFiles.size(); i++) {
                 ifstream in;
-                m->openInputFile(thisTypesFiles[i], in);
+                util.openInputFile(thisTypesFiles[i], in);
                 
-                string headers = m->getline(in); m->gobble(in);
-                columnHeaders = m->splitWhiteSpace(headers);
+                string headers = util.getline(in); util.gobble(in);
+                columnHeaders = util.splitWhiteSpace(headers);
                 int numCols = columnHeaders.size();
                 
                 vector<vector<double> > thisFilesLines;
                 while (!in.eof()) {
-                    if (m->control_pressed) { break; }
+                    if (m->getControl_pressed()) { break; }
                     vector<double> data; data.resize(numCols, 0);
                     //read numSampled line
-                    for (int j = 0; j < numCols; j++) { in >> data[j]; m->gobble(in); }
+                    for (int j = 0; j < numCols; j++) { in >> data[j]; util.gobble(in); }
                     thisFilesLines.push_back(data);
                 }
                 in.close();
                 results.push_back(thisFilesLines);
-                m->mothurRemove(thisTypesFiles[i]);
+                util.mothurRemove(thisTypesFiles[i]);
             }
             
-            if (!m->control_pressed) {
+            if (!m->getControl_pressed()) {
                 //process results
-                map<string, string> variables; variables["[filename]"] = fileNameRoot + "ave-std." + thisLookup[0]->getLabel() + ".";
+                map<string, string> variables; variables["[filename]"] = fileNameRoot + "ave-std." + thisLookup->getLabel() + ".";
 
                 string outputFile = getOutputFileName(it->first,variables);
                 ofstream out;
-                m->openOutputFile(outputFile, out);
+                util.openOutputFile(outputFile, out);
                 outputNames.push_back(outputFile); outputTypes[it->first].push_back(outputFile);
                 
                 out << columnHeaders[0] << '\t' << "method";
@@ -677,18 +629,18 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
         vector<string> groupNames;
 		for (int i = 0; i < outputNames.size(); i++) {
             
-			string extension = m->getExtension(outputNames[i]);
-            string combineFileName = outputDir + m->getRootName(m->getSimpleName(sharedfile)) + "groups" + extension;
-			m->mothurRemove(combineFileName); //remove old file
+			string extension = util.getExtension(outputNames[i]);
+            string combineFileName = outputDir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + extension;
+			util.mothurRemove(combineFileName); //remove old file
             
 			ifstream in;
-			m->openInputFile(outputNames[i], in);
+			util.openInputFile(outputNames[i], in);
 			
-			string labels = m->getline(in);
+			string labels = util.getline(in);
             
 			istringstream iss (labels,istringstream::in);
             string newLabel = ""; vector<string> theseLabels;
-            while(!iss.eof()) {  iss >> newLabel; m->gobble(iss); theseLabels.push_back(newLabel); }
+            while(!iss.eof()) {  iss >> newLabel; util.gobble(iss); theseLabels.push_back(newLabel); }
             vector< vector<string> > allLabels;
             vector<string> thisSet; thisSet.push_back(theseLabels[0]); allLabels.push_back(thisSet); thisSet.clear(); //makes "numSampled" its own grouping
             for (int j = 1; j < theseLabels.size()-1; j++) {
@@ -713,7 +665,7 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
                 temp[outputNames[i]] = file2Group[i];
                 typesFiles[extension] = temp;
             }
-            if (!(m->inUsersGroups(file2Group[i], groupNames))) {  groupNames.push_back(file2Group[i]); }
+            if (!(util.inUsersGroups(file2Group[i], groupNames))) {  groupNames.push_back(file2Group[i]); }
 		}
 		
 		//for each type create a combo file
@@ -721,8 +673,8 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
 		for (map<string, map<string, string> >::iterator it = typesFiles.begin(); it != typesFiles.end(); it++) {
 			
 			ofstream out;
-			string combineFileName = outputDir + m->getRootName(m->getSimpleName(sharedfile)) + "groups" + it->first;
-			m->openOutputFileAppend(combineFileName, out);
+			string combineFileName = outputDir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + it->first;
+			util.openOutputFileAppend(combineFileName, out);
 			newFileNames.push_back(combineFileName);
 			map<string, string> thisTypesFiles = it->second; //it->second maps filename to group
             set<int> numSampledSet;
@@ -736,15 +688,15 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
                 string group = itFileNameGroup->second;
                 
 				ifstream temp;
-				m->openInputFile(thisfilename, temp);
+				util.openInputFile(thisfilename, temp);
 				
 				//read through first line - labels
-				m->getline(temp);	m->gobble(temp);
+				util.getline(temp);	util.gobble(temp);
 				
 				map<int, vector< vector<string> > > thisFilesLines;
 				while (!temp.eof()){
                     int numSampled = 0;
-                    temp >> numSampled; m->gobble(temp);
+                    temp >> numSampled; util.gobble(temp);
                     
                     vector< vector<string> > theseReads;
                     vector<string> thisSet; thisSet.push_back(toString(numSampled)); theseReads.push_back(thisSet); thisSet.clear();
@@ -752,13 +704,13 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
                         vector<string> reads;
                         string next = "";
                         for (int l = 0; l < fileLabels[combineFileName][k].size(); l++) { //output modified labels
-                            temp >> next; m->gobble(temp);
+                            temp >> next; util.gobble(temp);
                             reads.push_back(next);
                         }
                         theseReads.push_back(reads);
                     }
                     thisFilesLines[numSampled] = theseReads;
-                    m->gobble(temp);
+                    util.gobble(temp);
                     
                     numSampledSet.insert(numSampled);
 				}
@@ -769,7 +721,7 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
 				if (maxLines < thisFilesLines.size()) { maxLines = thisFilesLines.size(); }
 				
 				temp.close();
-				m->mothurRemove(thisfilename);
+				util.mothurRemove(thisfilename);
 			}
 			
             //output new labels line
@@ -788,7 +740,7 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
 				
                 out << (*itNumSampled);
                 
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
                 for (int k = 1; k < fileLabels[combineFileName].size(); k++) { //each chunk
 				    //grab data for each group
