@@ -10,7 +10,7 @@
 #include "removerarecommand.h"
 #include "sequence.hpp"
 #include "groupmap.h"
-#include "sharedutilities.h"
+
 #include "inputdata.h"
 
 //**********************************************************************************************************************
@@ -52,7 +52,6 @@ string RemoveRareCommand::getHelpString(){
 		helpString += "The nseqs parameter allows you to set the cutoff for an otu to be deemed rare. It is required.\n";
 		helpString += "The remove.rare command should be in the following format: remove.rare(shared=yourSharedFile, nseqs=yourRareCutoff).\n";
 		helpString += "Example remove.rare(shared=amazon.fn.shared, nseqs=2).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. shared), '=' and parameters (i.e.yourSharedFile).\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -71,7 +70,7 @@ string RemoveRareCommand::getOutputPattern(string type) {
         else if (type == "count")       {   pattern = "[filename],pick,[extension]";    }
         else if (type == "list")        {   pattern = "[filename],[tag],pick,[extension]";    }
         else if (type == "shared")      {   pattern = "[filename],[tag],pick,[extension]";    }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -132,17 +131,17 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
             outputTypes["count"] = tempOutNames;
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";		}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -150,7 +149,7 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -158,7 +157,7 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 				it = parameters.find("sabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["sabund"] = inputDir + it->second;		}
 				}
@@ -166,7 +165,7 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 				it = parameters.find("rabund");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["rabund"] = inputDir + it->second;		}
 				}
@@ -174,7 +173,7 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -182,7 +181,7 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
@@ -190,35 +189,35 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 			
 			
 			//check for file parameters
-			listfile = validParameter.validFile(parameters, "list", true);
+			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { abort = true; }
 			else if (listfile == "not found") {  listfile = "";  }
-			else { m->setListFile(listfile); }
+			else { current->setListFile(listfile); }
 			
-			sabundfile = validParameter.validFile(parameters, "sabund", true);
+			sabundfile = validParameter.validFile(parameters, "sabund");
 			if (sabundfile == "not open") { abort = true; }
 			else if (sabundfile == "not found") {  sabundfile = "";  }	
-			else { m->setSabundFile(sabundfile); }
+			else { current->setSabundFile(sabundfile); }
 			
-			rabundfile = validParameter.validFile(parameters, "rabund", true);
+			rabundfile = validParameter.validFile(parameters, "rabund");
 			if (rabundfile == "not open") { abort = true; }
 			else if (rabundfile == "not found") {  rabundfile = "";  }				
-			else { m->setRabundFile(rabundfile); }
+			else { current->setRabundFile(rabundfile); }
 			
-			groupfile = validParameter.validFile(parameters, "group", true);
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not open") { groupfile = ""; abort = true; }
 			else if (groupfile == "not found") {  groupfile = "";  }	
-			else { m->setGroupFile(groupfile); }
+			else { current->setGroupFile(groupfile); }
 			
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = "";  abort = true; }
 			else if (sharedfile == "not found") {  sharedfile = "";  }
-			else { m->setSharedFile(sharedfile); }
+			else { current->setSharedFile(sharedfile); }
             
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
 			if (countfile == "not open") { countfile = ""; abort = true; }
 			else if (countfile == "not found") { countfile = "";  }	
-			else { m->setCountTableFile(countfile); }
+			else { current->setCountFile(countfile); }
             			
             if ((groupfile != "") && (countfile != "")) {
                 m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
@@ -228,16 +227,16 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 				//is there are current file available for any of these?
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
-					listfile = m->getListFile(); 
+					listfile = current->getListFile(); 
 					if (listfile != "") {  m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
 					else { 
-						rabundfile = m->getRabundFile(); 
+						rabundfile = current->getRabundFile(); 
 						if (rabundfile != "") {  m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter."); m->mothurOutEndLine(); }
 						else { 
-							sabundfile = m->getSabundFile(); 
+							sabundfile = current->getSabundFile(); 
 							if (sabundfile != "") {  m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter."); m->mothurOutEndLine(); }
 							else { 
 								m->mothurOut("No valid current files. You must provide a list, sabund, rabund or shared file."); m->mothurOutEndLine(); 
@@ -248,23 +247,24 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 				}
 			} 
 			
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = "all"; }
-			m->splitAtDash(groups, Groups);
+			util.splitAtDash(groups, Groups);
+            if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
-			string temp = validParameter.validFile(parameters, "nseqs", false);	 
+			string temp = validParameter.valid(parameters, "nseqs");
 			if (temp == "not found") { m->mothurOut("nseqs is a required parameter."); m->mothurOutEndLine(); abort = true; }
-			else { m->mothurConvert(temp, nseqs); }
+			else { util.mothurConvert(temp, nseqs); }
 			
-			temp = validParameter.validFile(parameters, "bygroup", false);	 if (temp == "not found") { temp = "f"; }
-			byGroup = m->isTrue(temp);
+			temp = validParameter.valid(parameters, "bygroup");	 if (temp == "not found") { temp = "f"; }
+			byGroup = util.isTrue(temp);
 			
 			if (byGroup && (sharedfile == "")) { m->mothurOut("The byGroup parameter is only valid with a shared file."); m->mothurOutEndLine(); }
 			
@@ -282,9 +282,9 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 int RemoveRareCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-		if (m->control_pressed) { return 0; }
+		if (m->getControl_pressed()) { return 0; }
 		
 		//read through the correct file and output lines you want to keep
 		if (sabundfile != "")		{		processSabund();	}
@@ -292,7 +292,7 @@ int RemoveRareCommand::execute(){
 		if (listfile != "")			{		processList();		}
 		if (sharedfile != "")		{		processShared();	}
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 			
 		if (outputNames.size() != 0) {
 			m->mothurOutEndLine();
@@ -301,35 +301,35 @@ int RemoveRareCommand::execute(){
 			m->mothurOutEndLine();
 			
 			//set rabund file as new current rabundfile
-			string current = "";
+			string currentName = "";
 			itTypes = outputTypes.find("rabund");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setRabundFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setRabundFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("sabund");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSabundFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setSabundFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("group");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setGroupFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setGroupFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("list");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setListFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setListFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("shared");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSharedFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setSharedFile(currentName); }
 			}
             
             itTypes = outputTypes.find("count");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setCountTableFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setCountFile(currentName); }
 			}
 		}
 		
@@ -352,7 +352,7 @@ int RemoveRareCommand::processList(){
 		else if (labels.size() > 1) { m->mothurOut("For the listfile you must select one label, using " + (*labels.begin()) + "."); m->mothurOutEndLine(); thisLabel = *labels.begin(); }
 		else { thisLabel = *labels.begin(); }
 		
-		InputData input(listfile, "list");
+		InputData input(listfile, "list", nullVector);
 		ListVector* list = input.getListVector();
 		
 		//get first one or the one we want
@@ -368,7 +368,7 @@ int RemoveRareCommand::processList(){
 					break;
 				}
 				
-				if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+				if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 					processedLabels.insert(list->getLabel());
 					userLabels.erase(list->getLabel());
 					delete list;
@@ -386,21 +386,21 @@ int RemoveRareCommand::processList(){
 		}
         
         string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(listfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(listfile);  }
         map<string, string> variables;
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(listfile));
-        variables["[extension]"] = m->getExtension(listfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[extension]"] = util.getExtension(listfile);
         variables["[tag]"] = list->getLabel();
 		string outputFileName = getOutputFileName("list", variables);
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(groupfile));
-        variables["[extension]"] = m->getExtension(groupfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(groupfile));
+        variables["[extension]"] = util.getExtension(groupfile);
 		string outputGroupFileName = getOutputFileName("group", variables);
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(countfile));
-        variables["[extension]"] = m->getExtension(countfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(countfile));
+        variables["[extension]"] = util.getExtension(countfile);
         string outputCountFileName = getOutputFileName("count", variables);
         
 		ofstream out, outGroup;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		bool wroteSomething = false;
 
@@ -410,17 +410,13 @@ int RemoveRareCommand::processList(){
         CountTable ct;
 		if (groupfile != "") { 
 			groupMap = new GroupMap(groupfile); groupMap->readMap(); 
-			SharedUtil util;
-			vector<string> namesGroups = groupMap->getNamesOfGroups();
-			util.setGroups(Groups, namesGroups);
-			m->openOutputFile(outputGroupFileName, outGroup);
+            if (Groups.size() == 0) { Groups = groupMap->getNamesOfGroups(); }
+			util.openOutputFile(outputGroupFileName, outGroup);
 		}else if (countfile != "") {
             ct.readTable(countfile, true, false);
             if (ct.hasGroupInfo()) {
                 vector<string> namesGroups = ct.getNamesOfGroups();
-                SharedUtil util;
-                util.setGroups(Groups, namesGroups);
-            }
+                if (Groups.size() == 0) { Groups = ct.getNamesOfGroups(); }            }
         }
 		
 		
@@ -435,13 +431,13 @@ int RemoveRareCommand::processList(){
 			
 			//for each bin
 			for (int i = 0; i < list->getNumBins(); i++) {
-				if (m->control_pressed) {  if (groupfile != "") { delete groupMap; outGroup.close(); m->mothurRemove(outputGroupFileName); } out.close();  m->mothurRemove(outputFileName);  return 0; }
+				if (m->getControl_pressed()) {  if (groupfile != "") { delete groupMap; outGroup.close(); util.mothurRemove(outputGroupFileName); } out.close();  util.mothurRemove(outputFileName);  return 0; }
 				
 				//parse out names that are in accnos file
 				string binnames = list->get(i);
 				vector<string> names;
 				string saveBinNames = binnames;
-				m->splitAtComma(binnames, names);
+				util.splitAtComma(binnames, names);
                 int binsize = names.size();
 				
 				vector<string> newGroupFile;
@@ -451,7 +447,7 @@ int RemoveRareCommand::processList(){
 					for(int k = 0; k < names.size(); k++) {
 						string group = groupMap->getGroup(names[k]);
 						
-						if (m->inUsersGroups(group, Groups)) {
+						if (util.inUsersGroups(group, Groups)) {
 							newGroupFile.push_back(names[k] + "\t" + group); 
 								
 							newNames.push_back(names[k]);	
@@ -469,7 +465,7 @@ int RemoveRareCommand::processList(){
                             
                             int thisSeqsCount = 0;
                             for (int n = 0; n < thisSeqsGroups.size(); n++) {
-                                if (m->inUsersGroups(thisSeqsGroups[n], Groups)) {
+                                if (util.inUsersGroups(thisSeqsGroups[n], Groups)) {
                                     thisSeqsCount += ct.getGroupCount(names[k], thisSeqsGroups[n]);
                                 }
                             }
@@ -497,7 +493,6 @@ int RemoveRareCommand::processList(){
 			if (newList.getNumBins() != 0) {
 				wroteSomething = true;
 				newList.setLabels(newLabels);
-                newList.printHeaders(out);
                 newList.print(out, false);
 			}
 		}	
@@ -508,7 +503,7 @@ int RemoveRareCommand::processList(){
             if (ct.hasGroupInfo()) {
                 vector<string> allGroups = ct.getNamesOfGroups();
                 for (int i = 0; i < allGroups.size(); i++) {
-                    if (!m->inUsersGroups(allGroups[i], Groups)) { ct.removeGroup(allGroups[i]); }
+                    if (!util.inUsersGroups(allGroups[i], Groups)) { ct.removeGroup(allGroups[i]); }
                 }
 
             }
@@ -530,18 +525,18 @@ int RemoveRareCommand::processList(){
 int RemoveRareCommand::processSabund(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(sabundfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(sabundfile);  }
         map<string, string> variables; 
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(sabundfile));
-        variables["[extension]"] = m->getExtension(sabundfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(sabundfile));
+        variables["[extension]"] = util.getExtension(sabundfile);
 		string outputFileName = getOutputFileName("sabund", variables);
 		outputTypes["sabund"].push_back(outputFileName); outputNames.push_back(outputFileName);
 
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-		InputData input(sabundfile, "sabund");
+		InputData input(sabundfile, "sabund", nullVector);
 		SAbundVector* sabund = input.getSAbundVector();
 		string lastLabel = sabund->getLabel();
 		set<string> processedLabels;
@@ -549,7 +544,7 @@ int RemoveRareCommand::processSabund(){
 		
 		while((sabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) { delete sabund; out.close(); return 0; }
+			if (m->getControl_pressed()) { delete sabund; out.close(); return 0; }
 			
 			if(allLines == 1 || labels.count(sabund->getLabel()) == 1){			
 				
@@ -564,7 +559,7 @@ int RemoveRareCommand::processSabund(){
 				if (sabund->getNumBins() > 0) { sabund->print(out); }
 			}
 			
-			if ((m->anyLabelsToProcess(sabund->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+			if ((util.anyLabelsToProcess(sabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 				string saveLabel = sabund->getLabel();
 				
 				delete sabund;
@@ -590,23 +585,18 @@ int RemoveRareCommand::processSabund(){
 			sabund = input.getSAbundVector();
 		}
 		
-		if (m->control_pressed) {  out.close(); return 0; }	
+		if (m->getControl_pressed()) {  out.close(); return 0; }	
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
+		if (needToRun )  {
 			if (sabund != NULL) {	delete sabund;	}
 			sabund = input.getSAbundVector(lastLabel);
 			
@@ -632,18 +622,18 @@ int RemoveRareCommand::processSabund(){
 int RemoveRareCommand::processRabund(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(rabundfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(rabundfile);  }
         map<string, string> variables; 
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(rabundfile));
-        variables["[extension]"] = m->getExtension(rabundfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(rabundfile));
+        variables["[extension]"] = util.getExtension(rabundfile);
 		string outputFileName = getOutputFileName("rabund", variables);
 		outputTypes["rabund"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-		InputData input(rabundfile, "rabund");
+		InputData input(rabundfile, "rabund", nullVector);
 		RAbundVector* rabund = input.getRAbundVector();
 		string lastLabel = rabund->getLabel();
 		set<string> processedLabels;
@@ -651,7 +641,7 @@ int RemoveRareCommand::processRabund(){
 		
 		while((rabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) { delete rabund; out.close(); return 0; }
+			if (m->getControl_pressed()) { delete rabund; out.close(); return 0; }
 			
 			if(allLines == 1 || labels.count(rabund->getLabel()) == 1){			
 				
@@ -668,7 +658,7 @@ int RemoveRareCommand::processRabund(){
 				if (newRabund.getNumBins() > 0) { newRabund.print(out); }
 			}
 			
-			if ((m->anyLabelsToProcess(rabund->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+			if ((util.anyLabelsToProcess(rabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 				string saveLabel = rabund->getLabel();
 				
 				delete rabund;
@@ -696,23 +686,18 @@ int RemoveRareCommand::processRabund(){
 			rabund = input.getRAbundVector();
 		}
 		
-		if (m->control_pressed) {  out.close(); return 0; }	
+		if (m->getControl_pressed()) {  out.close(); return 0; }	
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
+		if (needToRun )  {
 			if (rabund != NULL) {	delete rabund;	}
 			rabund = input.getRAbundVector(lastLabel);
 			
@@ -739,74 +724,65 @@ int RemoveRareCommand::processRabund(){
 //**********************************************************************************************************************
 int RemoveRareCommand::processShared(){
 	try {
-		m->setGroups(Groups);
-		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-		InputData input(sharedfile, "sharedfile");
-		vector<SharedRAbundVector*> lookup = input.getSharedRAbundVectors();
-		string lastLabel = lookup[0]->getLabel();
+		InputData input(sharedfile, "sharedfile", Groups);
+		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+		string lastLabel = lookup->getLabel();
 		set<string> processedLabels;
 		set<string> userLabels = labels;
 		
-		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) { for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }   return 0; }
+            if (m->getControl_pressed()) { delete lookup; return 0; }
 			
-			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
+			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
 				
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				m->mothurOut(lookup->getLabel()+"\n"); 
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				processLookup(lookup);
 			}
 			
-			if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup[0]->getLabel();
+			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+				string saveLabel = lookup->getLabel();
 				
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+				delete lookup;
 				lookup = input.getSharedRAbundVectors(lastLabel);
 				
-				m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-				processedLabels.insert(lookup[0]->getLabel());
-				userLabels.erase(lookup[0]->getLabel());
+				m->mothurOut(lookup->getLabel()+"\n"); 
+				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
 				processLookup(lookup);			
 				
 				//restore real lastlabel to save below
-				lookup[0]->setLabel(saveLabel);
+				lookup->setLabels(saveLabel);
 			}		
 			
-			lastLabel = lookup[0]->getLabel();			
+			lastLabel = lookup->getLabel();
 			
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			delete lookup;
 			lookup = input.getSharedRAbundVectors();
 		}
 		
-		if (m->control_pressed) {  return 0; }	
+		if (m->getControl_pressed()) {  return 0; }	
 		
 		//output error messages about any remaining user labels
-		set<string>::iterator it;
 		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
+		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
 			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
+            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
+			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
 		}
 		
 		//run last label if you need to
-		if (needToRun == true)  {
-			for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) {	delete lookup[i];	}  }
+		if (needToRun )  {
+			delete lookup;
 			lookup = input.getSharedRAbundVectors(lastLabel);
 			
-			m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
+			m->mothurOut(lookup->getLabel()+"\n"); 
 			processLookup(lookup);	
 			
-			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+			delete lookup;
 		}
 		
 		return 0;
@@ -817,68 +793,69 @@ int RemoveRareCommand::processShared(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveRareCommand::processLookup(vector<SharedRAbundVector*>& lookup){
+int RemoveRareCommand::processLookup(SharedRAbundVectors*& lookup){
 	try {
 		
         string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(sharedfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(sharedfile);  }
         map<string, string> variables;
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(sharedfile));
-        variables["[extension]"] = m->getExtension(sharedfile);
-        variables["[tag]"] = lookup[0]->getLabel();
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(sharedfile));
+        variables["[extension]"] = util.getExtension(sharedfile);
+        variables["[tag]"] = lookup->getLabel();
 		string outputFileName = getOutputFileName("shared", variables);
 		outputTypes["shared"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
         
-		vector<SharedRAbundVector> newRabunds;  newRabunds.resize(lookup.size());
+		vector<SharedRAbundVector> newRabunds;  newRabunds.resize(lookup->size());
         vector<string> headers;
-		for (int i = 0; i < lookup.size(); i++) {  
-			newRabunds[i].setGroup(lookup[i]->getGroup());
-			newRabunds[i].setLabel(lookup[i]->getLabel());
+        vector<string> namesOfGroups = lookup->getNamesGroups();
+		for (int i = 0; i < namesOfGroups.size(); i++) {
+			newRabunds[i].setGroup(namesOfGroups[i]);
+			newRabunds[i].setLabel(lookup->getLabel());
 		}
 		
+        vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+        vector<string> currentLabels = lookup->getOTUNames();
 		if (byGroup) {
 			
 			//for each otu
-			for (int i = 0; i < lookup[0]->getNumBins(); i++) {
+			for (int i = 0; i < lookup->getNumBins(); i++) {
 				bool allZero = true;
 				
-				if (m->control_pressed) { out.close(); return 0; }
+				if (m->getControl_pressed()) { out.close(); return 0; }
 				
 				//for each group
-				for (int j = 0; j < lookup.size(); j++) {
+                vector<int> abunds = lookup->getOTU(i);
+				for (int j = 0; j < abunds.size(); j++) {
 					
 					//are you rare?
-					if (lookup[j]->getAbundance(i) > nseqs) {
-						newRabunds[j].push_back(lookup[j]->getAbundance(i), newRabunds[j].getGroup());
-						allZero = false;
-					}else {
-						newRabunds[j].push_back(0, newRabunds[j].getGroup());
-					}
+                    if (abunds[j] > nseqs) { allZero = false; }
+                    else { abunds[j] = 0; }
 				}
 				
 				//eliminates zero otus
-				if (allZero) { for (int j = 0; j < newRabunds.size(); j++) {  newRabunds[j].pop_back(); } }
-                else { headers.push_back(m->currentSharedBinLabels[i]); }
+				if (allZero) { }
+                else {
+                    for (int j = 0; j < abunds.size(); j++) {  newRabunds[j].push_back(abunds[j]); }
+                    headers.push_back(currentLabels[i]);
+                }
 			}
 		}else {
 			//for each otu
-			for (int i = 0; i < lookup[0]->getNumBins(); i++) {
+			for (int i = 0; i < lookup->getNumBins(); i++) {
 				
-				if (m->control_pressed) { out.close(); return 0; }
+				if (m->getControl_pressed()) { out.close(); return 0; }
 				
-				int totalAbund = 0;
-				//get total otu abundance
-				for (int j = 0; j < lookup.size(); j++) {
-					newRabunds[j].push_back(lookup[j]->getAbundance(i), newRabunds[j].getGroup());
-					totalAbund += lookup[j]->getAbundance(i);
-				}
+                int totalAbund = lookup->getOTUTotal(i);
 				
 				//eliminates otus below rare cutoff
-				if (totalAbund <= nseqs) { for (int j = 0; j < newRabunds.size(); j++) {  newRabunds[j].pop_back(); } }
-                else { headers.push_back(m->currentSharedBinLabels[i]); }
+				if (totalAbund <= nseqs) {  } //ignore
+                else {
+                    headers.push_back(currentLabels[i]);
+                    for (int j = 0; j < data.size(); j++) { newRabunds[j].push_back(data[j]->get(i)); }
+                }
 			}
 		}
 		
@@ -887,10 +864,7 @@ int RemoveRareCommand::processLookup(vector<SharedRAbundVector*>& lookup){
             out << "label\tGroup\tnumOtus";
             for (int j = 0; j < headers.size(); j++) { out << '\t' << headers[j]; }
             out << endl;
-			for (int j = 0; j < newRabunds.size(); j++) { 
-				out << newRabunds[j].getLabel() << '\t' << newRabunds[j].getGroup() << '\t';
-				newRabunds[j].print(out); 
-			}
+			for (int j = 0; j < newRabunds.size(); j++) { newRabunds[j].print(out);  }
 		}
 		
         out.close();
