@@ -12,6 +12,7 @@
 #include "listvector.hpp"
 #include "counttable.h"
 #include "fastqread.h"
+#include "inputdata.h"
 
 //**********************************************************************************************************************
 vector<string> RemoveSeqsCommand::setParameters(){	
@@ -52,7 +53,7 @@ string RemoveSeqsCommand::getHelpString(){
 		helpString += "The dups parameter allows you to remove the entire line from a name file if you remove any name from the line. default=true. \n";
 		helpString += "The remove.seqs command should be in the following format: remove.seqs(accnos=yourAccnos, fasta=yourFasta).\n";
 		helpString += "Example remove.seqs(accnos=amazon.accnos, fasta=amazon.fasta).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. fasta), '=' and parameters (i.e.yourFasta).\n";
+		;
 		return helpString;
 	}
 	catch(exception& e) {
@@ -74,7 +75,7 @@ string RemoveSeqsCommand::getOutputPattern(string type) {
         else if (type == "list")        {   pattern = "[filename],[distance],pick,[extension]";    }
         else if (type == "qfile")       {   pattern = "[filename],pick,[extension]";    }
         else if (type == "alignreport")      {   pattern = "[filename],pick.align.report";    }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -140,17 +141,17 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
             outputTypes["count"] = tempOutNames;
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";		}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("alignreport");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["alignreport"] = inputDir + it->second;		}
 				}
@@ -158,7 +159,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 				it = parameters.find("fasta");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
 				}
@@ -166,7 +167,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 				it = parameters.find("accnos");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["accnos"] = inputDir + it->second;		}
 				}
@@ -174,7 +175,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
@@ -182,7 +183,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 				it = parameters.find("name");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["name"] = inputDir + it->second;		}
 				}
@@ -190,7 +191,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -198,7 +199,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 				it = parameters.find("taxonomy");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
 				}
@@ -206,7 +207,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 				it = parameters.find("qfile");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["qfile"] = inputDir + it->second;		}
 				}
@@ -214,7 +215,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
@@ -222,7 +223,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
                 it = parameters.find("fastq");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["fastq"] = inputDir + it->second;		}
 				}
@@ -230,67 +231,67 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 
 			
 			//check for required parameters
-			accnosfile = validParameter.validFile(parameters, "accnos", true);
+			accnosfile = validParameter.validFile(parameters, "accnos");
 			if (accnosfile == "not open") { abort = true; }
 			else if (accnosfile == "not found") {  
-				accnosfile = m->getAccnosFile(); 
+				accnosfile = current->getAccnosFile();
 				if (accnosfile != "") {  m->mothurOut("Using " + accnosfile + " as input file for the accnos parameter."); m->mothurOutEndLine(); }
 				else { 
 					m->mothurOut("You have no valid accnos file and accnos is required."); m->mothurOutEndLine(); 
 					abort = true;
 				}  
-			}else { m->setAccnosFile(accnosfile); }	
+			}else { current->setAccnosFile(accnosfile); }	
 			
-			fastafile = validParameter.validFile(parameters, "fasta", true);
+			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not open") { fastafile = ""; abort = true; }
 			else if (fastafile == "not found") {  fastafile = "";  }	
-			else { m->setFastaFile(fastafile); }
+			else { current->setFastaFile(fastafile); }
 								   
-			namefile = validParameter.validFile(parameters, "name", true);
+			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not open") { namefile = ""; abort = true; }
 			else if (namefile == "not found") {  namefile = "";  }	
-			else { m->setNameFile(namefile); } 
+			else { current->setNameFile(namefile); } 
 								   
-			groupfile = validParameter.validFile(parameters, "group", true);
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not open") { abort = true; }
 			else if (groupfile == "not found") {  groupfile = "";  }
-			else { m->setGroupFile(groupfile); }
+			else { current->setGroupFile(groupfile); }
 			
-			alignfile = validParameter.validFile(parameters, "alignreport", true);
+			alignfile = validParameter.validFile(parameters, "alignreport");
 			if (alignfile == "not open") { abort = true; }
 			else if (alignfile == "not found") {  alignfile = "";  }
 			
-			listfile = validParameter.validFile(parameters, "list", true);
+			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { abort = true; }
 			else if (listfile == "not found") {  listfile = "";  }
-			else { m->setListFile(listfile); }
+			else { current->setListFile(listfile); }
 			
-			taxfile = validParameter.validFile(parameters, "taxonomy", true);
+			taxfile = validParameter.validFile(parameters, "taxonomy");
 			if (taxfile == "not open") { abort = true; }
 			else if (taxfile == "not found") {  taxfile = "";  }
-			else { m->setTaxonomyFile(taxfile); }
+			else { current->setTaxonomyFile(taxfile); }
 			
-			qualfile = validParameter.validFile(parameters, "qfile", true);
+			qualfile = validParameter.validFile(parameters, "qfile");
 			if (qualfile == "not open") { abort = true; }
 			else if (qualfile == "not found") {  qualfile = "";  }			
-			else { m->setQualFile(qualfile); }
+			else { current->setQualFile(qualfile); }
             
-            fastqfile = validParameter.validFile(parameters, "fastq", true);
+            fastqfile = validParameter.validFile(parameters, "fastq");
 			if (fastqfile == "not open") { abort = true; }
 			else if (fastqfile == "not found") {  fastqfile = "";  }
 			
 			string usedDups = "true";
-			string temp = validParameter.validFile(parameters, "dups", false);	
+			string temp = validParameter.valid(parameters, "dups");
 			if (temp == "not found") { 
 				if (namefile != "") {  temp = "true";					}
 				else				{  temp = "false"; usedDups = "";	}
 			}
-			dups = m->isTrue(temp);
+			dups = util.isTrue(temp);
             
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
             if (countfile == "not open") { countfile = ""; abort = true; }
             else if (countfile == "not found") { countfile = "";  }	
-            else { m->setCountTableFile(countfile); }
+            else { current->setCountFile(countfile); }
             
             if ((namefile != "") && (countfile != "")) {
                 m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
@@ -305,11 +306,11 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
             if (countfile == "") {
                 if ((fastafile != "") && (namefile == "")) {
                     vector<string> files; files.push_back(fastafile);
-                    parser.getNameFile(files);
+                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
                 }
             }
             
-            format = validParameter.validFile(parameters, "format", false);		if (format == "not found"){	format = "illumina1.8+";	}
+            format = validParameter.valid(parameters, "format");		if (format == "not found"){	format = "illumina1.8+";	}
             
             if ((format != "sanger") && (format != "illumina") && (format != "illumina1.8+") && (format != "solexa"))  {
                 m->mothurOut(format + " is not a valid format. Your format choices are sanger, solexa, illumina1.8+ and illumina, aborting." ); m->mothurOutEndLine();
@@ -328,12 +329,12 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 int RemoveSeqsCommand::execute(){
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		//get names you want to keep
-		names = m->readAccnos(accnosfile);
+		names = util.readAccnos(accnosfile);
 		
-		if (m->control_pressed) { return 0; }
+		if (m->getControl_pressed()) { return 0; }
         
         if (countfile != "") {
             if ((fastafile != "") || (listfile != "") || (taxfile != "")) { 
@@ -352,7 +353,7 @@ int RemoveSeqsCommand::execute(){
 		if (qualfile != "")			{		readQual();		}
         if (countfile != "")		{		readCount();		}
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 	
 		if (outputNames.size() != 0) {
 			m->mothurOutEndLine();
@@ -361,40 +362,40 @@ int RemoveSeqsCommand::execute(){
 			m->mothurOutEndLine();
 			
 			//set fasta file as new current fastafile
-			string current = "";
+			string currentName = "";
 			itTypes = outputTypes.find("fasta");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setFastaFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setFastaFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("name");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setNameFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setNameFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("group");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setGroupFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setGroupFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("list");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setListFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setListFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("taxonomy");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setTaxonomyFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setTaxonomyFile(currentName); }
 			}
 			
 			itTypes = outputTypes.find("qfile");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setQualFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setQualFile(currentName); }
 			}	
             
             itTypes = outputTypes.find("count");
 			if (itTypes != outputTypes.end()) {
-				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setCountTableFile(current); }
+				if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setCountFile(currentName); }
 			}
 		}
 		
@@ -411,17 +412,17 @@ int RemoveSeqsCommand::execute(){
 int RemoveSeqsCommand::readFasta(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(fastafile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(fastafile);  }
 		map<string, string> variables; 
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(fastafile));
-        variables["[extension]"] = m->getExtension(fastafile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(fastafile));
+        variables["[extension]"] = util.getExtension(fastafile);
 		string outputFileName = getOutputFileName("fasta", variables);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		ifstream in;
-		m->openInputFile(fastafile, in);
+		util.openInputFile(fastafile, in);
 		string name;
 		
 		bool wroteSomething = false;
@@ -429,7 +430,7 @@ int RemoveSeqsCommand::readFasta(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
 			
 			Sequence currSeq(in);
             
@@ -453,7 +454,7 @@ int RemoveSeqsCommand::readFasta(){
                     }
 				}else {  removedCount++;  }
 			}
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();	
 		out.close();
@@ -478,25 +479,25 @@ int RemoveSeqsCommand::readFastq(){
 		int removedCount = 0;
         
 		ifstream in;
-		m->openInputFile(fastqfile, in);
+		util.openInputFile(fastqfile, in);
 		
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(fastqfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(fastqfile);  }
 		map<string, string> variables;
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(fastqfile));
-        variables["[extension]"] = m->getExtension(fastqfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(fastqfile));
+        variables["[extension]"] = util.getExtension(fastqfile);
 		string outputFileName = getOutputFileName("fastq", variables);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
         
 		set<string> uniqueNames;
 		while(!in.eof()){
 			
-			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName); return 0; }
+			if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove(outputFileName); return 0; }
 			
             //read sequence name
             bool ignore;
-            FastqRead fread(in, ignore, format); m->gobble(in);
+            FastqRead fread(in, ignore, format); util.gobble(in);
             
             if (!ignore) {
                 string name = fread.getName();
@@ -513,7 +514,7 @@ int RemoveSeqsCommand::readFastq(){
                 }else { removedCount++; }
             }
             
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
 		out.close();
@@ -537,17 +538,17 @@ int RemoveSeqsCommand::readFastq(){
 int RemoveSeqsCommand::readQual(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(qualfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(qualfile);  }
 		map<string, string> variables; 
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(qualfile));
-        variables["[extension]"] = m->getExtension(qualfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(qualfile));
+        variables["[extension]"] = util.getExtension(qualfile);
 		string outputFileName = getOutputFileName("qfile", variables);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		
 		ifstream in;
-		m->openInputFile(qualfile, in);
+		util.openInputFile(qualfile, in);
 		string name;
 		
 		bool wroteSomething = false;
@@ -568,7 +569,7 @@ int RemoveSeqsCommand::readQual(){
 					if (c == 10 || c == 13 || c == -1){	break;	}
 					else { name += c; }	
 				} 
-				m->gobble(in);
+				util.gobble(in);
 			}
 			
 			while(in){
@@ -577,7 +578,7 @@ int RemoveSeqsCommand::readQual(){
 				else{ scores += letter; }
 			}
 			
-			m->gobble(in);
+			util.gobble(in);
 			
             if (!dups) {//adjust name if needed
                 map<string, string>::iterator it = uniqueMap.find(saveName);
@@ -595,7 +596,7 @@ int RemoveSeqsCommand::readQual(){
                 }
 			}else {  removedCount++;  }
 			
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
 		out.close();
@@ -619,35 +620,35 @@ int RemoveSeqsCommand::readCount(){
 	try {
         
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(countfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(countfile);  }
 		map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(countfile));
-        variables["[extension]"] = m->getExtension(countfile);
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(countfile));
+        variables["[extension]"] = util.getExtension(countfile);
 		string outputFileName = getOutputFileName("count", variables);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 		
 		ifstream in;
-		m->openInputFile(countfile, in);
+		util.openInputFile(countfile, in);
 		
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
-        string headers = m->getline(in); m->gobble(in);
+        string headers = util.getline(in); util.gobble(in);
         out << headers << endl;
-        string test = headers; vector<string> pieces = m->splitWhiteSpace(test);
+        string test = headers; vector<string> pieces = util.splitWhiteSpace(test);
         
         string name, rest; int thisTotal; rest = "";
         set<string> uniqueNames;
         while (!in.eof()) {
             
-            if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+            if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
             
-            in >> name; m->gobble(in); 
-            in >> thisTotal; m->gobble(in);
-            if (pieces.size() > 2) {  rest = m->getline(in); m->gobble(in);  }
-            if (m->debug) { m->mothurOut("[DEBUG]: " + name + '\t' + rest + "\n"); }
+            in >> name; util.gobble(in); 
+            in >> thisTotal; util.gobble(in);
+            if (pieces.size() > 2) {  rest = util.getline(in); util.gobble(in);  }
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: " + name + '\t' + rest + "\n"); }
             
             if (names.count(name) == 0) {
                 if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
@@ -686,50 +687,45 @@ int RemoveSeqsCommand::readCount(){
 int RemoveSeqsCommand::readList(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(listfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(listfile);  }
 		map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(listfile));
-        variables["[extension]"] = m->getExtension(listfile);
-				
-		ifstream in;
-		m->openInputFile(listfile, in);
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[extension]"] = util.getExtension(listfile);
+        InputData input(listfile, "list", nullVector);
+        ListVector* list = input.getListVector();
 		
 		bool wroteSomething = false;
 		int removedCount = 0;
-		
         
-		while(!in.eof()){
+		while(list != NULL) {
 			
 			removedCount = 0;
             set<string> uniqueNames;
 			
-			//read in list vector
-			ListVector list(in);
-			
-			//make a new list vector
+            //make a new list vector
 			ListVector newList;
-			newList.setLabel(list.getLabel());
+			newList.setLabel(list->getLabel());
             
-			variables["[distance]"] = list.getLabel();
+			variables["[distance]"] = list->getLabel();
             string outputFileName = getOutputFileName("list", variables);
 			
 			ofstream out;
-			m->openOutputFile(outputFileName, out);
+			util.openOutputFile(outputFileName, out);
 			outputTypes["list"].push_back(outputFileName);  outputNames.push_back(outputFileName);
             
-            vector<string> binLabels = list.getLabels();
+            vector<string> binLabels = list->getLabels();
             vector<string> newBinLabels;
             
-            if (m->control_pressed) { in.close(); out.close();  return 0; }
+            if (m->getControl_pressed()) { out.close();  return 0; }
 
 			//for each bin
-			for (int i = 0; i < list.getNumBins(); i++) {
-				if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+			for (int i = 0; i < list->getNumBins(); i++) {
+				if (m->getControl_pressed()) {  out.close();  util.mothurRemove(outputFileName);  return 0; }
 			
 				//parse out names that are in accnos file
-				string bin = list.get(i);
+				string bin = list->get(i);
                 vector<string> bnames;
-                m->splitAtComma(bin, bnames);
+                util.splitAtComma(bin, bnames);
 				
 				string newNames = "";
                 for (int j = 0; j < bnames.size(); j++) {
@@ -758,15 +754,15 @@ int RemoveSeqsCommand::readList(){
 			if (newList.getNumBins() != 0) {
 				wroteSomething = true;
 				newList.setLabels(newBinLabels);
-                newList.printHeaders(out);
 				newList.print(out, false);
 
 			}
-			
-			m->gobble(in);
+
             out.close();
+            
+            delete list;
+            list = input.getListVector();
 		}
-		in.close();	
 		
 		
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
@@ -785,16 +781,16 @@ int RemoveSeqsCommand::readList(){
 int RemoveSeqsCommand::readName(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(namefile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(namefile);  }
 		map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(namefile));
-        variables["[extension]"] = m->getExtension(namefile);
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(namefile));
+        variables["[extension]"] = util.getExtension(namefile);
 		string outputFileName = getOutputFileName("name", variables);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 
 		ifstream in;
-		m->openInputFile(namefile, in);
+		util.openInputFile(namefile, in);
 		string name, firstCol, secondCol;
 		
 		bool wroteSomething = false;
@@ -802,13 +798,13 @@ int RemoveSeqsCommand::readName(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
 			
-			in >> firstCol;		m->gobble(in);		
+			in >> firstCol;		util.gobble(in);		
 			in >> secondCol;			
 			
 			vector<string> parsedNames;
-			m->splitAtComma(secondCol, parsedNames);
+			util.splitAtComma(secondCol, parsedNames);
 			
             vector<string> validSecond;  validSecond.clear(); vector<string> parsedNames2;
             bool parsedError = false;
@@ -863,7 +859,7 @@ int RemoveSeqsCommand::readName(){
                     }
                 }
 			}
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
 		out.close();
@@ -885,16 +881,16 @@ int RemoveSeqsCommand::readName(){
 int RemoveSeqsCommand::readGroup(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(groupfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(groupfile);  }
 		map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(groupfile));
-        variables["[extension]"] = m->getExtension(groupfile);
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(groupfile));
+        variables["[extension]"] = util.getExtension(groupfile);
 		string outputFileName = getOutputFileName("group", variables);	
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 
 		ifstream in;
-		m->openInputFile(groupfile, in);
+		util.openInputFile(groupfile, in);
 		string name, group;
 		
 		bool wroteSomething = false;
@@ -902,9 +898,9 @@ int RemoveSeqsCommand::readGroup(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
 			
-			in >> name;			m->gobble(in);		//read from first column
+			in >> name;			util.gobble(in);		//read from first column
 			in >> group;			//read from second column
 			
 			//if this name is in the accnos file
@@ -918,7 +914,7 @@ int RemoveSeqsCommand::readGroup(){
                 }
 			}else {  removedCount++;  }
 					
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
 		out.close();
@@ -940,16 +936,16 @@ int RemoveSeqsCommand::readGroup(){
 int RemoveSeqsCommand::readTax(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(taxfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(taxfile);  }
 		map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(taxfile));
-        variables["[extension]"] = m->getExtension(taxfile);
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(taxfile));
+        variables["[extension]"] = util.getExtension(taxfile);
 		string outputFileName = getOutputFileName("taxonomy", variables);
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 
 		ifstream in;
-		m->openInputFile(taxfile, in);
+		util.openInputFile(taxfile, in);
 		string name, tax;
 		
 		bool wroteSomething = false;
@@ -957,10 +953,10 @@ int RemoveSeqsCommand::readTax(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
 			
-            in >> name; m->gobble(in);
-            tax = m->getline(in); m->gobble(in);
+            in >> name; util.gobble(in);
+            tax = util.getline(in); util.gobble(in);
             
             if (!dups) {//adjust name if needed
                 map<string, string>::iterator it = uniqueMap.find(name);
@@ -999,16 +995,16 @@ int RemoveSeqsCommand::readTax(){
 int RemoveSeqsCommand::readAlign(){
 	try {
 		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += m->hasPath(alignfile);  }
+		if (outputDir == "") {  thisOutputDir += util.hasPath(alignfile);  }
 		map<string, string> variables; 
-		variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(alignfile));
+		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(alignfile));
 		string outputFileName = getOutputFileName("alignreport", variables);
 		
 		ofstream out;
-		m->openOutputFile(outputFileName, out);
+		util.openOutputFile(outputFileName, out);
 
 		ifstream in;
-		m->openInputFile(alignfile, in);
+		util.openInputFile(alignfile, in);
 		string name, junk;
 		
 		bool wroteSomething = false;
@@ -1023,7 +1019,7 @@ int RemoveSeqsCommand::readAlign(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
 			
 			in >> name;				//read from first column
             
@@ -1059,7 +1055,7 @@ int RemoveSeqsCommand::readAlign(){
 				}
 			}
 			
-			m->gobble(in);
+			util.gobble(in);
 		}
 		in.close();
 		out.close();
