@@ -53,7 +53,7 @@ string RenameSeqsCommand::getHelpString(){
         helpString += "The rename.seqs command should be in the following format: \n";
 		helpString += "rename.seqs(fasta=yourFastaFile, group=yourGroupFile) \n";
 		helpString += "Example rename.seqs(fasta=abrecovery.unique.fasta, group=abrecovery.group).\n";
-		helpString += "Note: No spaces between parameter labels (i.e. fasta), '=' and parameters (i.e.yourFasta).\n";
+		;
 		return helpString;
 	}
 	catch(exception& e) {
@@ -73,7 +73,7 @@ string RenameSeqsCommand::getOutputPattern(string type) {
         else if (type == "qfile")               {  pattern = "[filename],renamed,[extension]"; }
         else if (type == "contigsreport")       {  pattern = "[filename],renamed,[extension]"; }
         else if (type == "map")                 {  pattern = "[filename],renamed_map"; }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -134,14 +134,14 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
             outputTypes["contigsreport"] = tempOutNames;
             
 			//if the user changes the input directory command factory will send this info to us in the output parameter
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);
+			string inputDir = validParameter.valid(parameters, "inputdir");
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("fasta");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
 				}
@@ -149,7 +149,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
 				it = parameters.find("name");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["name"] = inputDir + it->second;		}
 				}
@@ -157,7 +157,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
                 it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -165,7 +165,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
                 it = parameters.find("count");
                 //user has given a template file
                 if(it != parameters.end()){
-                    path = m->hasPath(it->second);
+                    path = util.hasPath(it->second);
                     //if the user has not given a path then, add inputdir. else leave path alone.
                     if (path == "") {	parameters["count"] = inputDir + it->second;		}
                 }
@@ -173,7 +173,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
                 it = parameters.find("qfile");
                 //user has given a template file
                 if(it != parameters.end()){
-                    path = m->hasPath(it->second);
+                    path = util.hasPath(it->second);
                     //if the user has not given a path then, add inputdir. else leave path alone.
                     if (path == "") {	parameters["qfile"] = inputDir + it->second;		}
                 }
@@ -181,7 +181,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
                 it = parameters.find("contigsreport");
                 //user has given a template file
                 if(it != parameters.end()){
-                    path = m->hasPath(it->second);
+                    path = util.hasPath(it->second);
                     //if the user has not given a path then, add inputdir. else leave path alone.
                     if (path == "") {	parameters["contigsreport"] = inputDir + it->second;		}
                 }
@@ -189,7 +189,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
                 it = parameters.find("map");
                 //user has given a template file
                 if(it != parameters.end()){
-                    path = m->hasPath(it->second);
+                    path = util.hasPath(it->second);
                     //if the user has not given a path then, add inputdir. else leave path alone.
                     if (path == "") {	parameters["map"] = inputDir + it->second;		}
                 }
@@ -197,61 +197,61 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
                 it = parameters.find("file");
                 //user has given a template file
                 if(it != parameters.end()){
-                    path = m->hasPath(it->second);
+                    path = util.hasPath(it->second);
                     //if the user has not given a path then, add inputdir. else leave path alone.
                     if (path == "") {	parameters["file"] = inputDir + it->second;		}
                 }
 			}
             
             //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){ outputDir = ""; }
+            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){ outputDir = ""; }
 			
 			//check for required parameters
-			fastaFile = validParameter.validFile(parameters, "fasta", true);
+			fastaFile = validParameter.validFile(parameters, "fasta");
 			if (fastaFile == "not open") { abort = true; }
 			else if (fastaFile == "not found") { fastaFile = ""; }
-			else { m->setFastaFile(fastaFile); }
+			else { current->setFastaFile(fastaFile); }
             
-            fileFile = validParameter.validFile(parameters, "file", true);
+            fileFile = validParameter.validFile(parameters, "file");
             if (fileFile == "not open") { abort = true; }
             else if (fileFile == "not found") { fileFile = ""; }
-            else { m->setFileFile(fileFile); }
+            else { current->setFileFile(fileFile); }
             
             if ((fastaFile == "") && (fileFile == "")) {
-                fastaFile = m->getFastaFile();
+                fastaFile = current->getFastaFile();
                 if (fastaFile != "") { m->mothurOut("Using " + fastaFile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
                 else {
-                    fileFile = m->getFileFile();
+                    fileFile = current->getFileFile();
                     if (fileFile != "") { m->mothurOut("Using " + fileFile + " as input file for the file parameter."); m->mothurOutEndLine(); }
                     else {  m->mothurOut("You have no current fastafile or file file and the fasta or file parameter is required."); m->mothurOutEndLine(); abort = true; }
                 }
             }
 			
-            groupfile = validParameter.validFile(parameters, "group", true);
+            groupfile = validParameter.validFile(parameters, "group");
             if (groupfile == "not open") { abort = true; }
             else if (groupfile == "not found") {  groupfile = ""; }
-			else { m->setGroupFile(groupfile); }
+			else { current->setGroupFile(groupfile); }
 
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
             if (countfile == "not open") { countfile = ""; abort = true; }
             else if (countfile == "not found") { countfile = ""; }
-            else {  m->setCountTableFile(countfile);  }
+            else {  current->setCountFile(countfile);  }
             
-            nameFile = validParameter.validFile(parameters, "name", true);
+            nameFile = validParameter.validFile(parameters, "name");
             if (nameFile == "not open") { abort = true; }
             else if (nameFile == "not found"){ nameFile =""; }
-            else { m->setNameFile(nameFile); }
+            else { current->setNameFile(nameFile); }
             
-            qualfile = validParameter.validFile(parameters, "qfile", true);
+            qualfile = validParameter.validFile(parameters, "qfile");
             if (qualfile == "not open") { abort = true; }
             else if (qualfile == "not found"){ qualfile =""; }
-            else { m->setQualFile(qualfile); }
+            else { current->setQualFile(qualfile); }
             
-            mapFile = validParameter.validFile(parameters, "map", true);
+            mapFile = validParameter.validFile(parameters, "map");
             if (mapFile == "not open") { abort = true; }
             else if (mapFile == "not found"){ mapFile = ""; }
             
-            contigsfile = validParameter.validFile(parameters, "contigsreport", true);
+            contigsfile = validParameter.validFile(parameters, "contigsreport");
             if (contigsfile == "not open") { abort = true; }
             else if (contigsfile == "not found"){ contigsfile = ""; }
             
@@ -265,16 +265,16 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
                 m->mothurOut("[ERROR]: The file option cannot be used with any other files except the map file."); m->mothurOutEndLine(); abort = true;
             }
 
-            placement = validParameter.validFile(parameters, "placement", false);		if (placement == "not found") { placement = "back"; }
+            placement = validParameter.valid(parameters, "placement");		if (placement == "not found") { placement = "back"; }
             if ((placement == "front") || (placement == "back")) { }
             else { m->mothurOut("[ERROR]: " + placement + " is not a valid placement option.  Valid placement options are front or back.\n"); abort = true; }
             
-            delim = validParameter.validFile(parameters, "delim", false);			if (delim == "not found") { delim = "_"; }
+            delim = validParameter.valid(parameters, "delim");			if (delim == "not found") { delim = "_"; }
             
             if (countfile == "") {
                 if (nameFile == "")  {
                     vector<string> files; files.push_back(fastaFile);
-                    parser.getNameFile(files);
+                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
                 }
             }
 		}
@@ -289,7 +289,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
 int RenameSeqsCommand::execute() {
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
         map<string, string> renameMap;
         if (mapFile != "") { readMapFile(renameMap);  }
@@ -299,90 +299,87 @@ int RenameSeqsCommand::execute() {
             
             //prepare filenames and open files
             string thisOutputDir = outputDir;
-            if (outputDir == "") {  thisOutputDir += m->hasPath(fastaFile);  }
-            string outFastaFile = thisOutputDir + m->getRootName(m->getSimpleName(fastaFile));
+            if (outputDir == "") {  thisOutputDir += util.hasPath(fastaFile);  }
+            string outFastaFile = thisOutputDir + util.getRootName(util.getSimpleName(fastaFile));
             map<string, string> variables;
             variables["[filename]"] = outFastaFile;
-            variables["[extension]"] = m->getExtension(fastaFile);
+            variables["[extension]"] = util.getExtension(fastaFile);
             outFastaFile = getOutputFileName("fasta", variables);
             outputNames.push_back(outFastaFile); outputTypes["fasta"].push_back(outFastaFile);
             
-            string outMapFile = thisOutputDir + m->getRootName(m->getSimpleName(fastaFile));
+            string outMapFile = thisOutputDir + util.getRootName(util.getSimpleName(fastaFile));
             variables["[filename]"] = outMapFile;
             outMapFile = getOutputFileName("map", variables);
             outputNames.push_back(outMapFile); outputTypes["map"].push_back(outMapFile);
-            ofstream outMap; m->openOutputFile(outMapFile, outMap);
+            ofstream outMap; util.openOutputFile(outMapFile, outMap);
             
             ofstream outName;
             map<string, vector<string> > nameMap;
             if (nameFile != "") {
                 thisOutputDir = outputDir;
-                if (outputDir == "") {  thisOutputDir += m->hasPath(nameFile);  }
-                string outNameFile = thisOutputDir + m->getRootName(m->getSimpleName(nameFile));
+                if (outputDir == "") {  thisOutputDir += util.hasPath(nameFile);  }
+                string outNameFile = thisOutputDir + util.getRootName(util.getSimpleName(nameFile));
                 variables["[filename]"] = outNameFile;
-                variables["[extension]"] = m->getExtension(nameFile);
+                variables["[extension]"] = util.getExtension(nameFile);
                 outNameFile = getOutputFileName("name", variables);
                 outputNames.push_back(outNameFile); outputTypes["name"].push_back(outNameFile);
                 
-                m->openOutputFile(outNameFile, outName);
-                m->readNames(nameFile, nameMap);
+                util.openOutputFile(outNameFile, outName);
+                util.readNames(nameFile, nameMap);
             }
             
             ofstream outGroup;
             if (groupfile != "") {
                 thisOutputDir = outputDir;
-                if (outputDir == "") {  thisOutputDir += m->hasPath(groupfile);  }
-                string outGroupFile = thisOutputDir + m->getRootName(m->getSimpleName(groupfile));
+                if (outputDir == "") {  thisOutputDir += util.hasPath(groupfile);  }
+                string outGroupFile = thisOutputDir + util.getRootName(util.getSimpleName(groupfile));
                 variables["[filename]"] = outGroupFile;
-                variables["[extension]"] = m->getExtension(groupfile);
+                variables["[extension]"] = util.getExtension(groupfile);
                 outGroupFile = getOutputFileName("group", variables);
                 outputNames.push_back(outGroupFile); outputTypes["group"].push_back(outGroupFile);
                 
-                m->openOutputFile(outGroupFile, outGroup);
+                util.openOutputFile(outGroupFile, outGroup);
             }
             
             ofstream outFasta;
-            m->openOutputFile(outFastaFile, outFasta);
+            util.openOutputFile(outFastaFile, outFasta);
             
             ifstream in;
-            m->openInputFile(fastaFile, in);
+            util.openInputFile(fastaFile, in);
             
             GroupMap* groupMap = NULL;
             CountTable* countTable = NULL;
             
             bool hasGroups = false;
-            vector<string> allGroups; allGroups.push_back("");
-            m->setAllGroups(allGroups);
+            vector<string> Groups;
             if (groupfile != "") {
                 groupMap = new GroupMap(groupfile);
-                
                 int groupError = groupMap->readMap();
                 if (groupError == 1) { delete groupMap; return 0; }
-                allGroups = groupMap->getNamesOfGroups();
-                m->setAllGroups(allGroups);
+                Groups = groupMap->getNamesOfGroups();
                 hasGroups = true;
             }else if (countfile != "") {
                 countTable = new CountTable();
                 countTable->readTable(countfile, true, false);
                 hasGroups = countTable->hasGroupInfo();
-                if (hasGroups) {     allGroups = countTable->getNamesOfGroups(); allGroups.push_back("Multi"); m->setAllGroups(allGroups); }
+                if (hasGroups) {     Groups = countTable->getNamesOfGroups(); Groups.push_back("Multi"); }
             }
             
             //set up for reads
-            map<string, int> counts; for (int i = 0; i < allGroups.size(); i++) {  counts[allGroups[i]] = 1; }
+            map<string, int> counts; for (int i = 0; i < Groups.size(); i++) {  counts[Groups[i]] = 1; }
             map<string, string> old2NewNameMap;
             bool fillOld2NewNameMap = false;
             if ((qualfile != "") || (contigsfile != "")) { fillOld2NewNameMap = true; }
             
             while (!in.eof()) {
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
-                Sequence seq(in); m->gobble(in);
+                Sequence seq(in); util.gobble(in);
                 
                 vector<string> dups;
                 if (nameFile != "") {
                     map<string, vector<string> >::iterator it = nameMap.find(seq.getName());
-                    if (it == nameMap.end()) {  m->mothurOut("[ERROR]: " + seq.getName() + " is not in your name file, please correct.\n"); m->control_pressed = true;  }
+                    if (it == nameMap.end()) {  m->mothurOut("[ERROR]: " + seq.getName() + " is not in your name file, please correct.\n"); m->setControl_pressed(true);  }
                     else { dups = it->second; }
                 }else { dups.push_back(seq.getName()); }
                 
@@ -400,13 +397,13 @@ int RenameSeqsCommand::execute() {
                         }
                     }
                     
-                    if (group == "not found") {  m->mothurOut("[ERROR]: " + seq.getName() + " is not in your file, please correct.\n"); m->control_pressed = true; }
+                    if (group == "not found") {  m->mothurOut("[ERROR]: " + seq.getName() + " is not in your file, please correct.\n"); m->setControl_pressed(true); }
                     else {
                         //get new name
                         string newName = "";
                         if (mapFile != "") {
                             map<string, string>::iterator itMap = renameMap.find(dups[i]);
-                            if (itMap == renameMap.end()) { m->mothurOut("[ERROR]: " + dups[i] + " is not in your map file, please correct.\n"); m->control_pressed = true;}
+                            if (itMap == renameMap.end()) { m->mothurOut("[ERROR]: " + dups[i] + " is not in your map file, please correct.\n"); m->setControl_pressed(true);}
                             else { newName = itMap->second; }
                         }else {
                             newName = toString(counts[group]); counts[group]++;
@@ -437,16 +434,16 @@ int RenameSeqsCommand::execute() {
             if (nameFile != "") { outName.close(); }
             renameMap.clear();
             
-            if (m->control_pressed) {  if (groupMap != NULL) { delete groupMap; } if (countTable != NULL) { delete countTable; } for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]);  } return 0; }
+            if (m->getControl_pressed()) {  if (groupMap != NULL) { delete groupMap; } if (countTable != NULL) { delete countTable; } for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]);  } return 0; }
             
             
             if (groupfile != "") {   outGroup.close(); }
             else if (countfile != "") {
                 thisOutputDir = outputDir;
-                if (outputDir == "") {  thisOutputDir += m->hasPath(countfile);  }
-                string outCountFile = thisOutputDir + m->getRootName(m->getSimpleName(countfile));
+                if (outputDir == "") {  thisOutputDir += util.hasPath(countfile);  }
+                string outCountFile = thisOutputDir + util.getRootName(util.getSimpleName(countfile));
                 variables["[filename]"] = outCountFile;
-                variables["[extension]"] = m->getExtension(countfile);
+                variables["[extension]"] = util.getExtension(countfile);
                 outCountFile = getOutputFileName("count", variables);
                 outputNames.push_back(outCountFile); outputTypes["count"].push_back(outCountFile);
                 countTable->printTable(outCountFile);
@@ -459,7 +456,7 @@ int RenameSeqsCommand::execute() {
             if (contigsfile != "")      { readContigs(old2NewNameMap);  }
         }
         
-        if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) { m->mothurRemove(outputNames[i]);  } return 0; }
+        if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]);  } return 0; }
 
         m->mothurOutEndLine();
         m->mothurOut("Output File Names: "); m->mothurOutEndLine();
@@ -467,30 +464,30 @@ int RenameSeqsCommand::execute() {
         m->mothurOutEndLine();
         
         //set fasta file as new current fastafile
-        string current = "";
+        string currentName = "";
         itTypes = outputTypes.find("fasta");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setFastaFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setFastaFile(currentName); }
         }
         
         itTypes = outputTypes.find("name");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setNameFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setNameFile(currentName); }
         }
         
         itTypes = outputTypes.find("group");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setGroupFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setGroupFile(currentName); }
         }
         
         itTypes = outputTypes.find("count");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setCountTableFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setCountFile(currentName); }
         }
         
         itTypes = outputTypes.find("qfile");
         if (itTypes != outputTypes.end()) {
-            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setQualFile(current); }
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setQualFile(currentName); }
         }
 				
 		return 0;
@@ -504,28 +501,28 @@ int RenameSeqsCommand::execute() {
 int RenameSeqsCommand::readQual(map<string, string>& oldMap){
     try {
         string thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += m->hasPath(qualfile);  }
+        if (outputDir == "") {  thisOutputDir += util.hasPath(qualfile);  }
         map<string, string> variables;
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(qualfile));
-        variables["[extension]"] = m->getExtension(qualfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(qualfile));
+        variables["[extension]"] = util.getExtension(qualfile);
         string outputFileName = getOutputFileName("qfile", variables);
         ofstream out;
-        m->openOutputFile(outputFileName, out);
+        util.openOutputFile(outputFileName, out);
         outputNames.push_back(outputFileName); outputTypes["qfile"].push_back(outputFileName);
 
         ifstream in;
-        m->openInputFile(qualfile, in);
+        util.openInputFile(qualfile, in);
         
         map<string, string>::iterator it;
         
         while(!in.eof()){
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            QualityScores qual(in); m->gobble(in);
+            QualityScores qual(in); util.gobble(in);
             
             it = oldMap.find(qual.getName());
             if (it == oldMap.end()) {
-                m->mothurOut("[ERROR]: " + qual.getName() + " is not in your quality file, please correct.\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: " + qual.getName() + " is not in your quality file, please correct.\n"); m->setControl_pressed(true);
             }else {
                 qual.setName(it->second);
             }
@@ -547,32 +544,32 @@ int RenameSeqsCommand::readQual(map<string, string>& oldMap){
 int RenameSeqsCommand::readContigs(map<string, string>& oldMap){
     try {
         string thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += m->hasPath(contigsfile);  }
+        if (outputDir == "") {  thisOutputDir += util.hasPath(contigsfile);  }
         map<string, string> variables;
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(contigsfile));
-        variables["[extension]"] = m->getExtension(contigsfile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(contigsfile));
+        variables["[extension]"] = util.getExtension(contigsfile);
         string outputFileName = getOutputFileName("contigsreport", variables);
         ofstream out;
-        m->openOutputFile(outputFileName, out);
+        util.openOutputFile(outputFileName, out);
         outputNames.push_back(outputFileName); outputTypes["contigsreport"].push_back(outputFileName);
 
         ifstream in;
-        m->openInputFile(contigsfile, in);
-        out << (m->getline(in)) << endl;   //skip headers
+        util.openInputFile(contigsfile, in);
+        out << (util.getline(in)) << endl;   //skip headers
         
         map<string, string>::iterator it;
         int length, OLength, thisOStart, thisOEnd, numMisMatches, numNs;
         string name;
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             //seqname	start	end	nbases	ambigs	polymer	numSeqs
-            in >> name >> length >> OLength >> thisOStart >> thisOEnd >> numMisMatches >> numNs; m->gobble(in);
+            in >> name >> length >> OLength >> thisOStart >> thisOEnd >> numMisMatches >> numNs; util.gobble(in);
             
             it = oldMap.find(name);
             if (it == oldMap.end()) {
-                m->mothurOut("[ERROR]: " + name + " is not in your contigs report file, please correct.\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: " + name + " is not in your contigs report file, please correct.\n"); m->setControl_pressed(true);
             }else {
                 name = it->second;
             }
@@ -594,28 +591,28 @@ int RenameSeqsCommand::readContigs(map<string, string>& oldMap){
 int RenameSeqsCommand::readFasta(string thisFastaFile, map<string, string>& oldMap){
     try {
         string thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += m->hasPath(thisFastaFile);  }
+        if (outputDir == "") {  thisOutputDir += util.hasPath(thisFastaFile);  }
         map<string, string> variables;
-        variables["[filename]"] = thisOutputDir + m->getRootName(m->getSimpleName(thisFastaFile));
-        variables["[extension]"] = m->getExtension(thisFastaFile);
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(thisFastaFile));
+        variables["[extension]"] = util.getExtension(thisFastaFile);
         string outputFileName = getOutputFileName("fasta", variables);
         ofstream out;
-        m->openOutputFile(outputFileName, out);
+        util.openOutputFile(outputFileName, out);
         outputNames.push_back(outputFileName); outputTypes["fasta"].push_back(outputFileName);
         
         ifstream in;
-        m->openInputFile(thisFastaFile, in);
+        util.openInputFile(thisFastaFile, in);
         
         map<string, string>::iterator it;
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            Sequence seq(in); m->gobble(in);
+            Sequence seq(in); util.gobble(in);
             
             it = oldMap.find(seq.getName());
             if (it == oldMap.end()) {
-                m->mothurOut("[ERROR]: " + seq.getName() + " is not in your fasta file, please correct.\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: " + seq.getName() + " is not in your fasta file, please correct.\n"); m->setControl_pressed(true);
             }else {
                 seq.setName(it->second);
             }
@@ -635,20 +632,20 @@ int RenameSeqsCommand::readFasta(string thisFastaFile, map<string, string>& oldM
 int RenameSeqsCommand::readMapFile(map<string, string>& readMap){
     try {
         ifstream in;
-        m->openInputFile(mapFile, in);
+        util.openInputFile(mapFile, in);
         
         map<string, string>::iterator it;
         string oldname, newname;
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            in >> oldname; m->gobble(in);
-            in >> newname; m->gobble(in);
+            in >> oldname; util.gobble(in);
+            in >> newname; util.gobble(in);
             
             it = readMap.find(oldname);
             if (it != readMap.end()) {
-                m->mothurOut("[ERROR]: " + oldname + " is already in your map file. Sequence names must be unique, quitting.\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: " + oldname + " is already in your map file. Sequence names must be unique, quitting.\n"); m->setControl_pressed(true);
             }else {
                 readMap[oldname] = newname;
             }
@@ -670,7 +667,7 @@ int RenameSeqsCommand::processFile(map<string, string>& readMap){
         vector<map<string, string> > files = readFiles();
         
         for (int i = 0; i < files.size(); i++) {
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             string thisFile = "";
             string thisFileType = "";
@@ -685,43 +682,43 @@ int RenameSeqsCommand::processFile(map<string, string>& readMap){
             }
             
             string thisOutputDir = outputDir;
-            if (outputDir == "") {  thisOutputDir += m->hasPath(thisFile);  }
-            string outMapFile = thisOutputDir + m->getSimpleName(thisFile);
+            if (outputDir == "") {  thisOutputDir += util.hasPath(thisFile);  }
+            string outMapFile = thisOutputDir + util.getSimpleName(thisFile);
             map<string, string> variables;
             variables["[filename]"] = outMapFile + ".";
             outMapFile = getOutputFileName("map", variables);
             outputNames.push_back(outMapFile); outputTypes["map"].push_back(outMapFile);
-            ofstream outMap; m->openOutputFile(outMapFile, outMap);
+            ofstream outMap; util.openOutputFile(outMapFile, outMap);
             
             //prepare filenames and open files
-            string outFile = thisOutputDir + m->getRootName(m->getSimpleName(thisFile));
+            string outFile = thisOutputDir + util.getRootName(util.getSimpleName(thisFile));
             variables["[filename]"] = outFile;
-            variables["[extension]"] = m->getExtension(thisFile);
+            variables["[extension]"] = util.getExtension(thisFile);
             outFile = getOutputFileName(thisFileType, variables);
             outputNames.push_back(outFile); outputTypes[thisFileType].push_back(outFile);
             
             ofstream out;
-            m->openOutputFile(outFile, out);
+            util.openOutputFile(outFile, out);
             
             ifstream in;
-            m->openInputFile(thisFile, in);
+            util.openInputFile(thisFile, in);
             
             int count = 1;
             while (!in.eof()) {
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
                 Sequence* seq;  QualityScores* qual;
                 string name = "";
                 if (thisFileType == "fasta")        {  seq = new Sequence(in);   name = seq->getName();        }
                 else if (thisFileType == "qfile")   {  qual = new QualityScores(in);  name = qual->getName();  }
-                else if (thisFileType == "group")   {  in >> name; m->gobble(in); in >> group;                 }
-                m->gobble(in);
+                else if (thisFileType == "group")   {  in >> name; util.gobble(in); in >> group;               }
+                util.gobble(in);
  
                 //get new name
                 string newName = "";
                 if (mapFile != "") {
                     map<string, string>::iterator itMap = readMap.find(name);
-                    if (itMap == readMap.end()) { m->mothurOut("[ERROR]: " + name + " is not in your map file, please correct.\n"); m->control_pressed = true;}
+                    if (itMap == readMap.end()) { m->mothurOut("[ERROR]: " + name + " is not in your map file, please correct.\n"); m->setControl_pressed(true);}
                     else { newName = itMap->second; }
                 }else {
                     newName = toString(count); count++;
@@ -756,13 +753,13 @@ vector<map<string, string> > RenameSeqsCommand::readFiles(){
         vector<map<string, string> > files;
         
         ifstream in;
-        m->openInputFile(fileFile, in);
+        util.openInputFile(fileFile, in);
         
         while (!in.eof()) {
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            string line = m->getline(in);  m->gobble(in);
-            vector<string> pieces = m->splitWhiteSpace(line);
+            string line = util.getline(in);  util.gobble(in);
+            vector<string> pieces = util.splitWhiteSpace(line);
             
             string group = "";
             string thisFileName; thisFileName = "";
@@ -771,9 +768,9 @@ vector<map<string, string> > RenameSeqsCommand::readFiles(){
             }else if (pieces.size() == 3) {
                 thisFileName = pieces[0]+"-"+pieces[1];
                 group = pieces[2];
-                m->checkGroupName(group);
+                util.checkGroupName(group);
             }else {
-                m->mothurOut("[ERROR]: Your file contains " + toString(pieces.size()) + " columns. TThe file option allows you to provide a 2 or 3 column file. The first column contains the file type: fasta or qfile. The second column is the filename, and the optional third column can be a group name. If there is a third column, all sequences in the file will be assigned to that group.  This can be helpful when renaming data separated into samples.\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: Your file contains " + toString(pieces.size()) + " columns. TThe file option allows you to provide a 2 or 3 column file. The first column contains the file type: fasta or qfile. The second column is the filename, and the optional third column can be a group name. If there is a third column, all sequences in the file will be assigned to that group.  This can be helpful when renaming data separated into samples.\n"); m->setControl_pressed(true);
             }
             
             map<string, string> temp; temp[thisFileName] = group;
