@@ -57,7 +57,7 @@ string UnifracUnweightedCommand::getHelpString(){
 		helpString += "Example unifrac.unweighted(groups=A-B-C, iters=500).\n";
 		helpString += "The default value for groups is all the groups in your groupfile, and iters is 1000.\n";
 		helpString += "The unifrac.unweighted command output two files: .unweighted and .uwsummary their descriptions are in the manual.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. groups), '=' and parameters (i.e.yourGroups).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -74,7 +74,7 @@ string UnifracUnweightedCommand::getOutputPattern(string type) {
         else if (type == "phylip")           {  pattern = "[filename],[tag],[tag2],dist";   }
         else if (type == "column")           {  pattern = "[filename],[tag],[tag2],dist";   }
         else if (type == "tree")             {  pattern = "[filename],[tag],[tag2],tre";   }
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -133,14 +133,14 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
             outputTypes["tree"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("tree");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["tree"] = inputDir + it->second;		}
 				}
@@ -148,7 +148,7 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["group"] = inputDir + it->second;		}
 				}
@@ -156,7 +156,7 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 				it = parameters.find("name");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["name"] = inputDir + it->second;		}
 				}
@@ -164,36 +164,36 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
                 it = parameters.find("count");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["count"] = inputDir + it->second;		}
 				}
 			}
 			
             //check for required parameters
-			treefile = validParameter.validFile(parameters, "tree", true);
+			treefile = validParameter.validFile(parameters, "tree");
 			if (treefile == "not open") { abort = true; }
 			else if (treefile == "not found") { 				//if there is a current design file, use it
-				treefile = m->getTreeFile(); 
-				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current tree file and the tree parameter is required."); m->mothurOutEndLine(); abort = true; }								
-			}else { m->setTreeFile(treefile); }	
+				treefile = current->getTreeFile();
+				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter.\n");  }
+				else { 	m->mothurOut("You have no current tree file and the tree parameter is required.\n");  abort = true; }
+			}else { current->setTreeFile(treefile); }
 			
 			//check for required parameters
-			groupfile = validParameter.validFile(parameters, "group", true);
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not open") { abort = true; }
 			else if (groupfile == "not found") { groupfile = ""; }
-			else { m->setGroupFile(groupfile); }
+			else { current->setGroupFile(groupfile); }
 			
-			namefile = validParameter.validFile(parameters, "name", true);
+			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not open") { namefile = ""; abort = true; }
 			else if (namefile == "not found") { namefile = ""; }
-			else { m->setNameFile(namefile); }
+			else { current->setNameFile(namefile); }
             
-            countfile = validParameter.validFile(parameters, "count", true);
+            countfile = validParameter.validFile(parameters, "count");
 			if (countfile == "not open") { countfile = ""; abort = true; }
 			else if (countfile == "not found") { countfile = "";  }	
-			else { m->setCountTableFile(countfile); }
+			else { current->setCountFile(countfile); }
             
             if ((namefile != "") && (countfile != "")) {
                 m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
@@ -203,21 +203,21 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
                 m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
             }
 			
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(treefile);	}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(treefile);	}
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; }
 			else { 
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
 				
-			itersString = validParameter.validFile(parameters, "iters", false);				if (itersString == "not found") { itersString = "1000"; }
-			m->mothurConvert(itersString, iters); 
+			itersString = validParameter.valid(parameters, "iters");				if (itersString == "not found") { itersString = "1000"; }
+			util.mothurConvert(itersString, iters); 
 			
-			string temp = validParameter.validFile(parameters, "distance", false);			
+			string temp = validParameter.valid(parameters, "distance");
 			if (temp == "not found") { phylip = false; outputForm = ""; }
 			else{
                 if (temp=="phylip") { temp = "lt"; }
@@ -225,28 +225,28 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 				else { m->mothurOut("Options for distance are: lt, square, or column. Using lt."); m->mothurOutEndLine(); phylip = true; outputForm = "lt"; }
 			}
 			
-			temp = validParameter.validFile(parameters, "random", false);					if (temp == "not found") { temp = "f"; }
-			random = m->isTrue(temp);
+			temp = validParameter.valid(parameters, "random");					if (temp == "not found") { temp = "f"; }
+			random = util.isTrue(temp);
 			
-			temp = validParameter.validFile(parameters, "root", false);					if (temp == "not found") { temp = "F"; }
-			includeRoot = m->isTrue(temp);
+			temp = validParameter.valid(parameters, "root");					if (temp == "not found") { temp = "F"; }
+			includeRoot = util.isTrue(temp);
 			
-			temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
-			m->setProcessors(temp);
-			m->mothurConvert(temp, processors); 
+			temp = validParameter.valid(parameters, "processors");	if (temp == "not found"){	temp = current->getProcessors();	}
+			current->setProcessors(temp);
+			util.mothurConvert(temp, processors); 
 			
-            temp = validParameter.validFile(parameters, "subsample", false);		if (temp == "not found") { temp = "F"; }
-			if (m->isNumeric1(temp)) { m->mothurConvert(temp, subsampleSize); subsample = true; }
+            temp = validParameter.valid(parameters, "subsample");		if (temp == "not found") { temp = "F"; }
+			if (util.isNumeric1(temp)) { util.mothurConvert(temp, subsampleSize); subsample = true; }
             else {  
-                if (m->isTrue(temp)) { subsample = true; subsampleSize = -1; }  //we will set it to smallest group later 
+                if (util.isTrue(temp)) { subsample = true; subsampleSize = -1; }  //we will set it to smallest group later 
                 else { subsample = false; }
             }
 			
             if (!subsample) { subsampleIters = 0;   }
             else { subsampleIters = iters;          }
             
-            temp = validParameter.validFile(parameters, "consensus", false);					if (temp == "not found") { temp = "F"; }
-			consensus = m->isTrue(temp);
+            temp = validParameter.valid(parameters, "consensus");					if (temp == "not found") { temp = "F"; }
+			consensus = util.isTrue(temp);
             
 			if (subsample && random) {  m->mothurOut("[ERROR]: random must be false, if subsample=t.\n"); abort=true;  } 
             if (countfile == "") { if (subsample && (groupfile == "")) {  m->mothurOut("[ERROR]: if subsample=t, a group file must be provided.\n"); abort=true;  } }
@@ -261,17 +261,10 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 
 			if (!random) {  iters = 0;  } //turn off random calcs
 			
-			//if user selects distance = true and no groups it won't calc the pairwise
-			if ((phylip) && (Groups.size() == 0)) {
-				groups = "all";
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
-			}
-			
 			if (countfile=="") {
                 if (namefile == "") {
                     vector<string> files; files.push_back(treefile);
-                    parser.getNameFile(files);
+                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
                 } 
             }
 		}
@@ -287,37 +280,29 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 int UnifracUnweightedCommand::execute() {
 	try {
 		
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
-		
-		m->setTreeFile(treefile);
-		
-		TreeReader* reader;
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
+
+        TreeReader* reader = NULL;
         if (countfile == "") { reader = new TreeReader(treefile, groupfile, namefile); }
         else { reader = new TreeReader(treefile, countfile); }
-        T = reader->getTrees();
-        ct = T[0]->getCountTable();
+        
+        vector<Tree*> T; T = reader->getTrees();   //user trees
+        CountTable* ct; ct = T[0]->getCountTable();
+        if ((Groups.size() == 0) || (Groups.size() < 2)) {  Groups = ct->getNamesOfGroups();  } //must have at least 2 groups to compare
         delete reader;
         
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(treefile));
+		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(treefile));
 		sumFile = getOutputFileName("uwsummary",variables);
 		outputNames.push_back(sumFile); outputTypes["uwsummary"].push_back(sumFile);
-		m->openOutputFile(sumFile, outSum);
-		
-		SharedUtil util;
-		Groups = m->getGroups();
-		vector<string> namesGroups = ct->getNamesOfGroups();
-		util.setGroups(Groups, namesGroups, allGroups, numGroups, "unweighted");	//sets the groups the user wants to analyze
-		
-		Unweighted unweighted(includeRoot);
-		
-		int start = time(NULL);
+		util.openOutputFile(sumFile, outSum);
+
+		long start = time(NULL);
         
         //set or check size
         if (subsample) {
             //user has not set size, set size = smallest samples size
-            if (subsampleSize == -1) { 
-                vector<string> temp; temp.push_back(Groups[0]);
+            if (subsampleSize == -1) {
                 subsampleSize = ct->getGroupCount(Groups[0]); //num in first group
                 for (int i = 1; i < Groups.size(); i++) {
                     int thisSize = ct->getGroupCount(Groups[i]);
@@ -332,17 +317,16 @@ int UnifracUnweightedCommand::execute() {
                     
                     if (thisSize >= subsampleSize) {    Groups.push_back(newGroups[i]);	}
                     else {   m->mothurOut("You have selected a size that is larger than "+newGroups[i]+" number of sequences, removing "+newGroups[i]+".\n"); }
-                } 
-                m->setGroups(Groups);
+                }
             }
         }
-		
+        if ((Groups.size() == 0) || (Groups.size() < 2)) {  Groups = ct->getNamesOfGroups();  } //must have at least 2 groups to compare
+		Unweighted unweighted(includeRoot, Groups);
         util.getCombos(groupComb, Groups, numComp);
-		m->setGroups(Groups);
         
 		if (numGroups == 1) { numComp++; groupComb.push_back(allGroups); }
         
-		if (numComp < processors) { processors = numComp;  }
+		if (numComp < processors) { processors = numComp;  m->mothurOut("Reducing processors to " + toString(numComp) + ".\n"); }
         
         if (consensus && (numComp < 2)) { m->mothurOut("consensus can only be used with numComparisions greater than 1, setting consensus=f.\n"); consensus=false; }
 		
@@ -353,30 +337,15 @@ int UnifracUnweightedCommand::execute() {
 	 
 		//get pscores for users trees
 		for (int i = 0; i < T.size(); i++) {
-			if (m->control_pressed) { delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }outSum.close(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } return 0; }
+			if (m->getControl_pressed()) { break; }
 			
-            counter = 0;
-			
-			if (random)  {  
-                variables["[filename]"] = outputDir + m->getSimpleName(treefile);
-                variables["[tag]"] = toString(i+1);
-                string unFileName = getOutputFileName("unweighted", variables);
-				output = new ColumnFile(unFileName, itersString);
-				outputNames.push_back(unFileName); outputTypes["unweighted"].push_back(unFileName);
-			}
-			
-			
-			//get unweighted for users tree
-			rscoreFreq.resize(numComp);  
-			rCumul.resize(numComp);  
-			utreeScores.resize(numComp);  
-			UWScoreSig.resize(numComp); 
+            counter = 0; rscoreFreq.resize(numComp);   rCumul.resize(numComp);   utreeScores.resize(numComp);   UWScoreSig.resize(numComp);
             
             vector<double> userData; userData.resize(numComp,0);  //weighted score info for user tree. data[0] = weightedscore AB, data[1] = weightedscore AC...
 
 			userData = unweighted.getValues(T[i], processors, outputDir);  //userData[0] = unweightedscore
 		
-			if (m->control_pressed) { delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close();  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }return 0; }
+			if (m->getControl_pressed()) { break; }
 			
 			//output scores for each combination
 			for(int k = 0; k < numComp; k++) {
@@ -391,29 +360,30 @@ int UnifracUnweightedCommand::execute() {
             
             if (random) {  runRandomCalcs(T[i], userData);  }
 			
-			if (m->control_pressed) { delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } return 0;  }
+			if (m->getControl_pressed()) { break; }
             
             int startSubsample = time(NULL);
             
             //subsample loop
+            SubSample sample;
             vector< vector<double> > calcDistsTotals;  //each iter, each groupCombos dists. this will be used to make .dist files
             for (int thisIter = 0; thisIter < subsampleIters; thisIter++) { //subsampleIters=0, if subsample=f.
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 
                 //copy to preserve old one - would do this in subsample but memory cleanup becomes messy.
                 CountTable* newCt = new CountTable();
                  
                 //uses method of setting groups to doNotIncludeMe
                 int sampleTime = 0;
-                if (m->debug) { sampleTime = time(NULL); }
-                SubSample sample;
-                Tree* subSampleTree = sample.getSample(T[i], ct, newCt, subsampleSize);
+                if (m->getDebug()) { sampleTime = time(NULL); }
                 
-                if (m->debug) { m->mothurOut("[DEBUG]: iter " + toString(thisIter) + " took " + toString(time(NULL) - sampleTime) + " seconds to sample tree.\n"); }
+                Tree* subSampleTree = sample.getSample(T[i], ct, newCt, subsampleSize, Groups);
+                
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: iter " + toString(thisIter) + " took " + toString(time(NULL) - sampleTime) + " seconds to sample tree.\n"); }
                 
                 //call new weighted function
                 vector<double> iterData; iterData.resize(numComp,0);
-                Unweighted thisUnweighted(includeRoot);
+                Unweighted thisUnweighted(includeRoot, Groups);
                 iterData = thisUnweighted.getValues(subSampleTree, processors, outputDir); //userData[0] = weightedscore
         
                 //save data to make ave dist, std dist
@@ -426,49 +396,42 @@ int UnifracUnweightedCommand::execute() {
             }
             if (subsample) { m->mothurOut("It took " + toString(time(NULL) - startSubsample) + " secs to run the subsampling."); m->mothurOutEndLine(); }
             
-            if (m->control_pressed) { delete ct; for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } return 0;  }
+            if (m->getControl_pressed()) { break; }
 
             if (subsample) {  getAverageSTDMatrices(calcDistsTotals, i); }
             if (consensus) {  getConsensusTrees(calcDistsTotals, i);  }
             
             //print output files
 			printUWSummaryFile(i);
-			if (random)  {	printUnweightedFile();	delete output;	}
+			if (random)  {	printUnweightedFile(i+1);	}
 			if (phylip) {	createPhylipFile(i);		}
 			
-			rscoreFreq.clear(); 
-			rCumul.clear();  
-			validScores.clear(); 
-			utreeScores.clear();  
-			UWScoreSig.clear(); 
+			rscoreFreq.clear();  rCumul.clear();  validScores.clear();  utreeScores.clear();  UWScoreSig.clear();
 		}
 		
-
 		outSum.close();
 		delete ct; 
 		for (int i = 0; i < T.size(); i++) { delete T[i]; }
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }	return 0; }
+		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  }	return 0; }
 		
 		m->mothurOut("It took " + toString(time(NULL) - start) + " secs to run unifrac.unweighted."); m->mothurOutEndLine();
 		
 		//set phylip file as new current phylipfile
-		string current = "";
+		string currentName = "";
 		itTypes = outputTypes.find("phylip");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setPhylipFile(current); }
+			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setPhylipFile(currentName); }
 		}
 		
 		//set column file as new current columnfile
 		itTypes = outputTypes.find("column");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setColumnFile(current); }
+			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setColumnFile(currentName); }
 		}
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 		
 		return 0;
 		
@@ -483,33 +446,33 @@ int UnifracUnweightedCommand::getAverageSTDMatrices(vector< vector<double> >& di
 	try {
         //we need to find the average distance and standard deviation for each groups distance
         //finds sum
-        vector<double> averages = m->getAverages(dists);
+        vector<double> averages = util.getAverages(dists);
         
         //find standard deviation
-        vector<double> stdDev = m->getStandardDeviation(dists, averages);
+        vector<double> stdDev = util.getStandardDeviation(dists, averages);
         
         //make matrix with scores in it
         vector< vector<double> > avedists;	//avedists.resize(m->getNumGroups());
-        for (int i = 0; i < m->getNumGroups(); i++) {
+        for (int i = 0; i < numGroups; i++) {
             vector<double> temp;
-            for (int j = 0; j < m->getNumGroups(); j++) { temp.push_back(0.0); }
+            for (int j = 0; j < numGroups; j++) { temp.push_back(0.0); }
             avedists.push_back(temp);
         }
         
         //make matrix with scores in it
         vector< vector<double> > stddists;	//stddists.resize(m->getNumGroups());
-        for (int i = 0; i < m->getNumGroups(); i++) {
+        for (int i = 0; i < numGroups; i++) {
             vector<double> temp;
-            for (int j = 0; j < m->getNumGroups(); j++) { temp.push_back(0.0); }
+            for (int j = 0; j < numGroups; j++) { temp.push_back(0.0); }
             //stddists[i].resize(m->getNumGroups(), 0.0);
             stddists.push_back(temp);
         }
         
-        if (m->debug) { m->mothurOut("[DEBUG]: about to fill matrix.\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: about to fill matrix.\n"); }
         
         //flip it so you can print it
         int count = 0;
-        for (int r=0; r<m->getNumGroups(); r++) { 
+        for (int r=0; r<numGroups; r++) {
             for (int l = 0; l < r; l++) {
                 avedists[r][l] = averages[count];
                 avedists[l][r] = averages[count];
@@ -519,35 +482,35 @@ int UnifracUnweightedCommand::getAverageSTDMatrices(vector< vector<double> >& di
             }
         }
         
-        if (m->debug) { m->mothurOut("[DEBUG]: done filling matrix.\n"); }
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: done filling matrix.\n"); }
         
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(treefile));
+		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(treefile));
         variables["[tag]"] = toString(treeNum+1);
         variables["[tag2]"] = "unweighted.ave";
         string aveFileName = getOutputFileName("phylip",variables);
         if (outputForm != "column") { outputNames.push_back(aveFileName); outputTypes["phylip"].push_back(aveFileName);  }
         else { outputNames.push_back(aveFileName); outputTypes["column"].push_back(aveFileName);  }
         ofstream out;
-        m->openOutputFile(aveFileName, out);
+        util.openOutputFile(aveFileName, out);
         
         variables["[tag2]"] = "unweighted.std";
         string stdFileName = getOutputFileName("phylip",variables);
         if (outputForm != "column") { outputNames.push_back(stdFileName); outputTypes["phylip"].push_back(stdFileName); }
         else { outputNames.push_back(stdFileName); outputTypes["column"].push_back(stdFileName); }
         ofstream outStd;
-        m->openOutputFile(stdFileName, outStd);
+        util.openOutputFile(stdFileName, outStd);
         
         if ((outputForm == "lt") || (outputForm == "square")) {
             //output numSeqs
-            out << m->getNumGroups() << endl;
-            outStd << m->getNumGroups() << endl;
+            out << numGroups << endl;
+            outStd << numGroups << endl;
         }
         
         //output to file
-        for (int r=0; r<m->getNumGroups(); r++) { 
+        for (int r=0; r<numGroups; r++) {
             //output name
-            string name = (m->getGroups())[r];
+            string name = Groups[r];
             if (name.length() < 10) { //pad with spaces to make compatible
                 while (name.length() < 10) {  name += " ";  }
             }
@@ -564,12 +527,12 @@ int UnifracUnweightedCommand::getAverageSTDMatrices(vector< vector<double> >& di
                 outStd << name;
                 
                 //output distances
-                for (int l = 0; l < m->getNumGroups(); l++) {	out  << '\t' << avedists[r][l]; outStd   << '\t' << stddists[r][l]; }
+                for (int l = 0; l < numGroups; l++) {	out  << '\t' << avedists[r][l]; outStd   << '\t' << stddists[r][l]; }
                 out << endl; outStd << endl;
             }else{
                 //output distances
                 for (int l = 0; l < r; l++) {	
-                    string otherName = (m->getGroups())[l];
+                    string otherName = Groups[l];
                     if (otherName.length() < 10) { //pad with spaces to make compatible
                         while (otherName.length() < 10) {  otherName += " ";  }
                     }
@@ -593,50 +556,39 @@ int UnifracUnweightedCommand::getAverageSTDMatrices(vector< vector<double> >& di
 /**************************************************************************************************/
 int UnifracUnweightedCommand::getConsensusTrees(vector< vector<double> >& dists, int treeNum) {
 	try {
-        
-        //used in tree constructor 
-        m->runParse = false;
-        
         //create treemap class from groupmap for tree class to use
         CountTable newCt;
         set<string> nameMap;
         map<string, string> groupMap;
         set<string> gps;
-        for (int i = 0; i < m->getGroups().size(); i++) { 
-            nameMap.insert(m->getGroups()[i]); 
-            gps.insert(m->getGroups()[i]); 
-            groupMap[m->getGroups()[i]] = m->getGroups()[i];
+        for (int i = 0; i < Groups.size(); i++) {
+            nameMap.insert(Groups[i]);
+            gps.insert(Groups[i]);
+            groupMap[Groups[i]] = Groups[i];
         }
         newCt.createTable(nameMap, groupMap, gps);
         
-        //clear  old tree names if any
-        m->Treenames.clear();
-        
-        //fills globaldatas tree names
-        m->Treenames = m->getGroups();
-        
         vector<Tree*> newTrees = buildTrees(dists, treeNum, newCt); //also creates .all.tre file containing the trees created
         
-        if (m->control_pressed) { return 0; }
+        if (m->getControl_pressed()) { return 0; }
         
         Consensus con;
         Tree* conTree = con.getTree(newTrees);
         
         //create a new filename
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(treefile));
+		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(treefile));
         variables["[tag]"] = toString(treeNum+1);
         variables["[tag2]"] = "unweighted.cons";
         string conFile = getOutputFileName("tree",variables);				
         outputNames.push_back(conFile); outputTypes["tree"].push_back(conFile); 
         ofstream outTree;
-        m->openOutputFile(conFile, outTree);
+        util.openOutputFile(conFile, outTree);
         
         if (conTree != NULL) { conTree->print(outTree, "boot"); delete conTree; }
         outTree.close();
         
         return 0;
-        
     }
 	catch(exception& e) {
 		m->errorOut(e, "UnifracUnweightedCommand", "getConsensusTrees");
@@ -652,28 +604,28 @@ vector<Tree*> UnifracUnweightedCommand::buildTrees(vector< vector<double> >& dis
         
         //create a new filename
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getRootName(m->getSimpleName(treefile));
+		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(treefile));
         variables["[tag]"] = toString(treeNum+1);
         variables["[tag2]"] = "unweighted.all";
         string outputFile = getOutputFileName("tree",variables);				
         outputNames.push_back(outputFile); outputTypes["tree"].push_back(outputFile); 
         
         ofstream outAll;
-        m->openOutputFile(outputFile, outAll);
+        util.openOutputFile(outputFile, outAll);
         
         
         for (int i = 0; i < dists.size(); i++) { //dists[0] are the dists for the first subsampled tree.
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
             //make matrix with scores in it
-            vector< vector<double> > sims;	sims.resize(m->getNumGroups());
-            for (int j = 0; j < m->getNumGroups(); j++) {
-                sims[j].resize(m->getNumGroups(), 0.0);
+            vector< vector<double> > sims;	sims.resize(Groups.size());
+            for (int j = 0; j < Groups.size(); j++) {
+                sims[j].resize(Groups.size(), 0.0);
             }
             
             int count = 0;
-			for (int r=0; r<m->getNumGroups(); r++) { 
+			for (int r=0; r<Groups.size(); r++) {
 				for (int l = 0; l < r; l++) {
                     double sim = -(dists[i][count]-1.0);
 					sims[r][l] = sim;
@@ -683,7 +635,7 @@ vector<Tree*> UnifracUnweightedCommand::buildTrees(vector< vector<double> >& dis
 			}
             
             //create tree
-            Tree* tempTree = new Tree(&myct, sims);
+            Tree* tempTree = new Tree(&myct, sims, Groups);
             tempTree->assembleTree();
             
             trees.push_back(tempTree);
@@ -694,7 +646,7 @@ vector<Tree*> UnifracUnweightedCommand::buildTrees(vector< vector<double> >& dis
         
         outAll.close();
         
-        if (m->control_pressed) {  for (int i = 0; i < trees.size(); i++) {  delete trees[i]; trees[i] = NULL; } m->mothurRemove(outputFile); }
+        if (m->getControl_pressed()) {  for (int i = 0; i < trees.size(); i++) {  delete trees[i]; trees[i] = NULL; } util.mothurRemove(outputFile); }
         
         return trees;
     }
@@ -709,15 +661,34 @@ int UnifracUnweightedCommand::runRandomCalcs(Tree* thisTree, vector<double> user
 	try {
         vector<double> randomData; randomData.resize(numComp,0); //weighted score info for random trees. data[0] = weightedscore AB, data[1] = weightedscore AC...
         
-        Unweighted unweighted(includeRoot);
+        Unweighted unweighted(includeRoot, Groups);
+        
+        vector< vector<string> > namesOfGroupCombos;
+        int numGroups = Groups.size();
+        for (int a=0; a<numGroups; a++) {
+            for (int l = 0; l < a; l++) {
+                vector<string> groups; groups.push_back(Groups[a]); groups.push_back(Groups[l]);
+                namesOfGroupCombos.push_back(groups);
+            }
+        }
+        vector<vector<int> > randomTreeNodes;
+        for (int f = 0; f < numComp; f++) {
+            vector<int> randomNodesForThisCombo = thisTree->getNodes(namesOfGroupCombos[f]);
+            randomTreeNodes.push_back(randomNodesForThisCombo);
+        }
+        vector<vector<int> > savedRandomTreeNodes = randomTreeNodes;
         
         //get unweighted scores for random trees - if random is false iters = 0
         for (int j = 0; j < iters; j++) {
             
-            //we need a different getValues because when we swap the labels we only want to swap those in each pairwise comparison
-            randomData = unweighted.getValues(thisTree, "", "", processors, outputDir);
+            randomTreeNodes = savedRandomTreeNodes;
             
-            if (m->control_pressed) { return 0; }
+            for (int f = 0; f < numComp; f++) { util.mothurRandomShuffle(randomTreeNodes[f]);  } //randomize labels
+            
+            //we need a different getValues because when we swap the labels we only want to swap those in each pairwise comparison
+            randomData = unweighted.getValues(thisTree, randomTreeNodes, processors, outputDir);
+            
+            if (m->getControl_pressed()) { return 0; }
 			
             for(int k = 0; k < numComp; k++) {	
                 //add trees unweighted score to map of scores
@@ -756,13 +727,20 @@ int UnifracUnweightedCommand::runRandomCalcs(Tree* thisTree, vector<double> user
 	}
 }
 /***********************************************************/
-void UnifracUnweightedCommand::printUnweightedFile() {
+void UnifracUnweightedCommand::printUnweightedFile(int treeNum) {
 	try {
 		vector<double> data;
 		vector<string> tags;
 		
 		tags.push_back("Score");
 		tags.push_back("RandFreq"); tags.push_back("RandCumul");
+        
+        map<string, string> variables;
+        variables["[filename]"] = outputDir + util.getSimpleName(treefile);
+        variables["[tag]"] = toString(treeNum);
+        string unFileName = getOutputFileName("unweighted", variables);
+        FileOutput* output = new ColumnFile(unFileName, itersString);
+        outputNames.push_back(unFileName); outputTypes["unweighted"].push_back(unFileName);
 			
 		for(int a = 0; a < numComp; a++) {
 			output->initFile(groupComb[a], tags);
@@ -774,6 +752,7 @@ void UnifracUnweightedCommand::printUnweightedFile() {
 			} 
 			output->resetFile();
 		}
+        delete output;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "UnifracUnweightedCommand", "printUnweightedFile");
@@ -822,7 +801,7 @@ void UnifracUnweightedCommand::createPhylipFile(int i) {
 	try {
 		string phylipFileName;
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + m->getSimpleName(treefile);
+		variables["[filename]"] = outputDir + util.getSimpleName(treefile);
         variables["[tag]"] = toString(i+1);
 		if ((outputForm == "lt") || (outputForm == "square")) {
             variables["[tag2]"] = "unweighted.phylip";
@@ -835,22 +814,23 @@ void UnifracUnweightedCommand::createPhylipFile(int i) {
 		}
 		
 		ofstream out;
-		m->openOutputFile(phylipFileName, out);
+		util.openOutputFile(phylipFileName, out);
 		
+        int numGroups = Groups.size();
 		if ((outputForm == "lt") || (outputForm == "square")) {
 			//output numSeqs
-			out << m->getNumGroups() << endl;
+			out << numGroups << endl;
 		}
 		
 		//make matrix with scores in it
-		vector< vector<float> > dists;	dists.resize(m->getNumGroups());
-		for (int i = 0; i < m->getNumGroups(); i++) {
-			dists[i].resize(m->getNumGroups(), 0.0);
+		vector< vector<float> > dists;	dists.resize(numGroups);
+		for (int i = 0; i < numGroups; i++) {
+			dists[i].resize(numGroups, 0.0);
 		}
 		
 		//flip it so you can print it
 		int count = 0;
-		for (int r=0; r<m->getNumGroups(); r++) { 
+		for (int r=0; r<numGroups; r++) {
 			for (int l = 0; l < r; l++) {
 				dists[r][l] = utreeScores[count][0];
 				dists[l][r] = utreeScores[count][0];
@@ -859,9 +839,9 @@ void UnifracUnweightedCommand::createPhylipFile(int i) {
 		}
 		
 		//output to file
-		for (int r=0; r<m->getNumGroups(); r++) { 
+		for (int r=0; r<numGroups; r++) {
 			//output name
-			string name = (m->getGroups())[r];
+			string name = Groups[r];
 			if (name.length() < 10) { //pad with spaces to make compatible
 				while (name.length() < 10) {  name += " ";  }
 			}
@@ -876,12 +856,12 @@ void UnifracUnweightedCommand::createPhylipFile(int i) {
 				out << name;
 				
 				//output distances
-				for (int l = 0; l < m->getNumGroups(); l++) {	out  << '\t' << dists[r][l];  }
+				for (int l = 0; l < numGroups; l++) {	out  << '\t' << dists[r][l];  }
 				out << endl;
 			}else{
 				//output distances
 				for (int l = 0; l < r; l++) {	
-					string otherName = (m->getGroups())[l];
+					string otherName = Groups[l];
 					if (otherName.length() < 10) { //pad with spaces to make compatible
 						while (otherName.length() < 10) {  otherName += " ";  }
 					}
