@@ -60,7 +60,7 @@ string VennCommand::getHelpString(){
 		helpString += "The only estimators available four 4 groups are sharedsobs and sharedchao.\n";
         helpString += "The sharedotus parameter can be used with the sharedsobs calculator to get the names of the OTUs in each section of the venn diagram. Default=t.\n";
 		helpString += "The venn command outputs a .svg file for each calculator you specify at each distance you choose.\n";
-		helpString += "Note: No spaces between parameter labels (i.e. groups), '=' and parameters (i.e.yourGroups).\n";
+		
 		return helpString;
 	}
 	catch(exception& e) {
@@ -74,7 +74,7 @@ string VennCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "svg") {  pattern = "[filename],svg"; } 
-        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->control_pressed = true;  }
+        else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
     }
@@ -123,14 +123,14 @@ VennCommand::VennCommand(string option)  {
 			}
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
+			string inputDir = validParameter.valid(parameters, "inputdir");		
 			if (inputDir == "not found"){	inputDir = "";		}
 			else {
 				string path;
 				it = parameters.find("shared");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
@@ -138,31 +138,31 @@ VennCommand::VennCommand(string option)  {
 				it = parameters.find("list");
 				//user has given a template file
 				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
+					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["list"] = inputDir + it->second;		}
 				}
 			}
 			
 			//check for required parameters
-			listfile = validParameter.validFile(parameters, "list", true);
+			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else {  format = "list"; inputfile = listfile; m->setListFile(listfile); }
+			else {  format = "list"; inputfile = listfile; current->setListFile(listfile); }
 			
-			sharedfile = validParameter.validFile(parameters, "shared", true);
+			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  format = "sharedfile"; inputfile = sharedfile; m->setSharedFile(sharedfile); }
+			else {  format = "sharedfile"; inputfile = sharedfile; current->setSharedFile(sharedfile); }
 			
 			if ((sharedfile == "") && (listfile == "")) { 
 				//is there are current file available for any of these?
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
-				sharedfile = m->getSharedFile(); 
+				sharedfile = current->getSharedFile(); 
 				if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 
-					listfile = m->getListFile(); 
+					listfile = current->getListFile(); 
 					if (listfile != "") { inputfile = listfile; format = "list"; m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
 					else { 
 						m->mothurOut("No valid current files. You must provide a list or shared file."); m->mothurOutEndLine(); 
@@ -172,25 +172,25 @@ VennCommand::VennCommand(string option)  {
 			}
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(inputfile);		}
+			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputfile);		}
 
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			label = validParameter.validFile(parameters, "label", false);			
+			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  m->splitAtDash(label, labels);  allLines = 0;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
 				else { allLines = 1;  }
 			}
 			
-			groups = validParameter.validFile(parameters, "groups", false);			
+			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; }
 			else { 
-				m->splitAtDash(groups, Groups);
-				m->setGroups(Groups);
+				util.splitAtDash(groups, Groups);
+                if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
 			
-			calc = validParameter.validFile(parameters, "calc", false);			
+			calc = validParameter.valid(parameters, "calc");			
 			if (calc == "not found") { 
 				if(format == "list") { calc = "sobs"; }
 				else { calc = "sharedsobs"; }
@@ -201,39 +201,39 @@ VennCommand::VennCommand(string option)  {
 					else { calc = "sharedsobs"; }
 				}
 			}
-			m->splitAtDash(calc, Estimators);
-			if (m->inUsersGroups("citation", Estimators)) { 
+			util.splitAtDash(calc, Estimators);
+			if (util.inUsersGroups("citation", Estimators)) { 
 				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
 				//remove citation from list of calcs
 				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
 			}
 			
 			string temp;
-			temp = validParameter.validFile(parameters, "abund", false);		if (temp == "not found") { temp = "10"; }
-			m->mothurConvert(temp, abund); 
+			temp = validParameter.valid(parameters, "abund");		if (temp == "not found") { temp = "10"; }
+			util.mothurConvert(temp, abund); 
 			
-			temp = validParameter.validFile(parameters, "nseqs", false);		if (temp == "not found"){	temp = "f";				}
-			nseqs = m->isTrue(temp); 
+			temp = validParameter.valid(parameters, "nseqs");		if (temp == "not found"){	temp = "f";				}
+			nseqs = util.isTrue(temp); 
 
-			temp = validParameter.validFile(parameters, "permute", false);
+			temp = validParameter.valid(parameters, "permute");
             if (temp == "not found"){	temp = "4";				}
             else {
                 if ((temp == "1") || (temp == "2") || (temp == "3") || (temp == "4")) {}
                 else {
-                    bool permTrue = m->isTrue(temp);
+                    bool permTrue = util.isTrue(temp);
                     if (permTrue) { temp = "4"; }
                     else { }
                 }
             }
-			m->mothurConvert(temp, perm);
+			util.mothurConvert(temp, perm);
             if ((perm == 1) || (perm == 2) || (perm == 3) || (perm == 4)) { }
             else { m->mothurOut("[ERROR]: Not a valid permute value.  Valid values are 1, 2, 3, 4 and true."); m->mothurOutEndLine(); abort = true;  }
             
-            temp = validParameter.validFile(parameters, "sharedotus", false);		if (temp == "not found"){	temp = "t";				}
-			sharedOtus = m->isTrue(temp); 
+            temp = validParameter.valid(parameters, "sharedotus");		if (temp == "not found"){	temp = "t";				}
+			sharedOtus = util.isTrue(temp); 
 			
-			temp = validParameter.validFile(parameters, "fontsize", false);		if (temp == "not found") { temp = "24"; }
-			m->mothurConvert(temp, fontsize);
+			temp = validParameter.valid(parameters, "fontsize");		if (temp == "not found") { temp = "24"; }
+			util.mothurConvert(temp, fontsize);
 
 		}
 				
@@ -248,13 +248,13 @@ VennCommand::VennCommand(string option)  {
 int VennCommand::execute(){
 	try {
 	
-		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
+		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 	
 		ValidCalculators validCalculator;
 					
 		if (format == "list") {
 			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("vennsingle", Estimators[i]) == true) { 
+				if (validCalculator.isValidCalculator("vennsingle", Estimators[i]) ) { 
 					if (Estimators[i] == "sobs") { 
 						vennCalculators.push_back(new Sobs());
 					}else if (Estimators[i] == "chao") { 
@@ -267,7 +267,7 @@ int VennCommand::execute(){
 			}
 		}else {
 			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("vennshared", Estimators[i]) == true) { 
+				if (validCalculator.isValidCalculator("vennshared", Estimators[i]) ) { 
 					if (Estimators[i] == "sharedsobs") { 
 						vennCalculators.push_back(new SharedSobsCS());
 					}else if (Estimators[i] == "sharedchao") { 
@@ -283,17 +283,19 @@ int VennCommand::execute(){
 		if (vennCalculators.size() == 0) { m->mothurOut("No valid calculators given, please correct."); m->mothurOutEndLine(); return 0;  }
 		
 		venn = new Venn(outputDir, nseqs, inputfile, fontsize, sharedOtus); 
-		input = new InputData(inputfile, format);
+		InputData input(inputfile, format, Groups);
 		
 		string lastLabel;
 		
+        SharedRAbundVectors* lookup = NULL;
 		if (format == "sharedfile") {
-			lookup = input->getSharedRAbundVectors();
-			lastLabel = lookup[0]->getLabel();
+			lookup = input.getSharedRAbundVectors();
+			lastLabel = lookup->getLabel();
+            Groups = lookup->getNamesGroups();
 			
-			if ((lookup.size() > 4)) { combos = findCombinations(lookup.size()); }
+			if ((lookup->size() > 4)) { combos = findCombinations(lookup->size()); }
 		}else if (format == "list") {
-			sabund = input->getSAbundVector();
+			sabund = input.getSAbundVector();
 			lastLabel = sabund->getLabel();
 		}
 		
@@ -304,84 +306,82 @@ int VennCommand::execute(){
 		if (format != "list") {	
 			
 			//as long as you are not at the end of the file or done wih the lines you want
-			while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+			while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-				if (m->control_pressed) {
+				if (m->getControl_pressed()) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
-					m->clearGroups(); delete venn; delete input;
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
+                    delete lookup;  delete venn;
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  }
 					return 0;
 				}
 
-				if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
-					m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-					processedLabels.insert(lookup[0]->getLabel());
-					userLabels.erase(lookup[0]->getLabel());
-					
-					
-
-					if (lookup.size() > 4) {
+				if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
+					m->mothurOut(lookup->getLabel()+"\n"); 
+					processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
+                    
+                    vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+					if (lookup->size() > 4) {
 						set< set<int> >::iterator it3;
 						set<int>::iterator it2;
 						for (it3 = combos.begin(); it3 != combos.end(); it3++) {  
 			
 							set<int> poss = *it3;
 							vector<SharedRAbundVector*> subset;
-							for (it2 = poss.begin(); it2 != poss.end(); it2++) {   subset.push_back(lookup[*it2]);   }
+							for (it2 = poss.begin(); it2 != poss.end(); it2++) {   subset.push_back(data[*it2]);   }
 							
 							vector<string> outfilenames = venn->getPic(subset, vennCalculators);
 							for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]); }  }
 						}		
 					}else {
-						vector<string> outfilenames = venn->getPic(lookup, vennCalculators);
-						for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]);  }  }
-					}					
-				}
-				
-				if ((m->anyLabelsToProcess(lookup[0]->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
-					string saveLabel = lookup[0]->getLabel();
-					
-					for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
-					lookup = input->getSharedRAbundVectors(lastLabel);
-
-					m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-					processedLabels.insert(lookup[0]->getLabel());
-					userLabels.erase(lookup[0]->getLabel());
-
-					if (lookup.size() > 4) {
-						set< set<int> >::iterator it3;
-						set<int>::iterator it2;
-						for (it3 = combos.begin(); it3 != combos.end(); it3++) {  
-			
-							set<int> poss = *it3;
-							vector<SharedRAbundVector*> subset;
-							for (it2 = poss.begin(); it2 != poss.end(); it2++) {   subset.push_back(lookup[*it2]);   }
-							
-							vector<string> outfilenames = venn->getPic(subset, vennCalculators);
-							for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]);  }  }
-						}		
-					}else {
-						vector<string> outfilenames = venn->getPic(lookup, vennCalculators);
+						vector<string> outfilenames = venn->getPic(data, vennCalculators);
 						for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]);  }  }
 					}
-										
-					//restore real lastlabel to save below
-					lookup[0]->setLabel(saveLabel);
+                    for (int i = 0; i < data.size(); i++) {	delete data[i];  } data.clear();
+				}
+				
+				if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
+					string saveLabel = lookup->getLabel();
+					
+                    delete lookup;
+					lookup = input.getSharedRAbundVectors(lastLabel);
+
+					m->mothurOut(lookup->getLabel()+"\n"); 
+					processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
+
+                    vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+                    if (lookup->size() > 4) {
+                        set< set<int> >::iterator it3;
+                        set<int>::iterator it2;
+                        for (it3 = combos.begin(); it3 != combos.end(); it3++) {
+                            
+                            set<int> poss = *it3;
+                            vector<SharedRAbundVector*> subset;
+                            for (it2 = poss.begin(); it2 != poss.end(); it2++) {   subset.push_back(data[*it2]);   }
+                            
+                            vector<string> outfilenames = venn->getPic(subset, vennCalculators);
+                            for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]); }  }
+                        }
+                    }else {
+                        vector<string> outfilenames = venn->getPic(data, vennCalculators);
+                        for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]);  }  }
+                    }
+                    for (int i = 0; i < data.size(); i++) {	delete data[i];  } data.clear();
+					
+					lookup->setLabels(saveLabel); //restore real lastlabel to save below
 				}
 				
 				
-				lastLabel = lookup[0]->getLabel();	
+				lastLabel = lookup->getLabel();
 						
 				//get next line to process
-				for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
-				lookup = input->getSharedRAbundVectors();
+				delete lookup;
+				lookup = input.getSharedRAbundVectors();
 			}
 			
-			if (m->control_pressed) {
+			if (m->getControl_pressed()) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					m->clearGroups(); delete venn; delete input; 
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
+					 delete venn;
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  }
 					return 0;
 			}
 
@@ -400,42 +400,42 @@ int VennCommand::execute(){
 			}
 		
 			//run last label if you need to
-			if (needToRun == true)  {
-					for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) {	delete lookup[i]; }  } 
-					lookup = input->getSharedRAbundVectors(lastLabel);
+			if (needToRun )  {
+					delete lookup;
+					lookup = input.getSharedRAbundVectors(lastLabel);
 
-					m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
-					processedLabels.insert(lookup[0]->getLabel());
-					userLabels.erase(lookup[0]->getLabel());
+					m->mothurOut(lookup->getLabel()+"\n"); 
+					processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 
-					if (lookup.size() > 4) {
-						set< set<int> >::iterator it3;
-						set<int>::iterator it2;
-						for (it3 = combos.begin(); it3 != combos.end(); it3++) {  
-			
-							set<int> poss = *it3;
-							vector<SharedRAbundVector*> subset;
-							for (it2 = poss.begin(); it2 != poss.end(); it2++) {   subset.push_back(lookup[*it2]);   }
-							
-							vector<string> outfilenames = venn->getPic(subset, vennCalculators);
-							for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]); }  }
-						}		
-					}else {
-						vector<string> outfilenames = venn->getPic(lookup, vennCalculators);
-						for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]);  }  }
-					}
-					
-					for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
+                vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
+                if (lookup->size() > 4) {
+                    set< set<int> >::iterator it3;
+                    set<int>::iterator it2;
+                    for (it3 = combos.begin(); it3 != combos.end(); it3++) {
+                        
+                        set<int> poss = *it3;
+                        vector<SharedRAbundVector*> subset;
+                        for (it2 = poss.begin(); it2 != poss.end(); it2++) {   subset.push_back(data[*it2]);   }
+                        
+                        vector<string> outfilenames = venn->getPic(subset, vennCalculators);
+                        for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]); }  }
+                    }
+                }else {
+                    vector<string> outfilenames = venn->getPic(data, vennCalculators);
+                    for(int i = 0; i < outfilenames.size(); i++) { if (outfilenames[i] != "control" ) { outputNames.push_back(outfilenames[i]);  outputTypes["svg"].push_back(outfilenames[i]);  }  }
+                }
+                for (int i = 0; i < data.size(); i++) {	delete data[i];  } data.clear();
+                delete lookup;
 			}
 		
 
 			//reset groups parameter
-			m->clearGroups();  
+			  
 			
-			if (m->control_pressed) {
-					m->clearGroups(); delete venn; delete input;
+			if (m->getControl_pressed()) {
+					 delete venn;
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  }
 					return 0;
 			}
 
@@ -444,10 +444,10 @@ int VennCommand::execute(){
 		
 			while((sabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-				if (m->control_pressed) {
+				if (m->getControl_pressed()) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					delete sabund; delete venn; delete input;
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
+					delete sabund; delete venn;
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  }
 					return 0;
 				}
 		
@@ -462,11 +462,11 @@ int VennCommand::execute(){
 					userLabels.erase(sabund->getLabel());
 				}
 				
-				if ((m->anyLabelsToProcess(sabund->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
+				if ((util.anyLabelsToProcess(sabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
 					string saveLabel = sabund->getLabel();
 				
 					delete sabund;
-					sabund = input->getSAbundVector(lastLabel);
+					sabund = input.getSAbundVector(lastLabel);
 					
 					m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
 					vector<string> outfilenames = venn->getPic(sabund, vennCalculators);
@@ -483,14 +483,13 @@ int VennCommand::execute(){
 				lastLabel = sabund->getLabel();		
 				
 				delete sabund;
-				sabund = input->getSAbundVector();
+				sabund = input.getSAbundVector();
 			}
 			
-			if (m->control_pressed) {
+			if (m->getControl_pressed()) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
-					delete venn; delete input;
-					return 0;
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  }
+					delete venn;  return 0;
 			}
 			
 			//output error messages about any remaining user labels
@@ -507,9 +506,9 @@ int VennCommand::execute(){
 			}
 		
 			//run last label if you need to
-			if (needToRun == true)  {
+			if (needToRun )  {
 				if (sabund != NULL) {	delete sabund;	}
-				sabund = input->getSAbundVector(lastLabel);
+				sabund = input.getSAbundVector(lastLabel);
 					
 				m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
 				vector<string> outfilenames = venn->getPic(sabund, vennCalculators);
@@ -519,21 +518,19 @@ int VennCommand::execute(){
 					
 			}
 			
-			if (m->control_pressed) {
-					delete venn; delete input;
+			if (m->getControl_pressed()) {
+					delete venn;
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
+					for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  }
 					return 0;
 			}
 		}
 		
 		for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-		delete venn; delete input;
+		delete venn; 
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
-		m->mothurOutEndLine();
+		m->mothurOut("\nOutput File Names: \n"); 
+		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 
 		
 		return 0;
