@@ -16,25 +16,25 @@
 AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gapOpen, float gapExtend, float match, float misMatch, int tid, bool writeShortcut){		//	This assumes that the template database is in fasta format, may
 	try {											//	need to alter this in the future?
 		m = MothurOut::getInstance();
+        current = CurrentFile::getInstance();
 		longest = 0;
 		method = s;
 		bool needToGenerate = true;
-		bool silent = false;
 		threadID = tid;
-		
-        int start = time(NULL);
-        m->mothurOutEndLine();
-        m->mothurOut("Reading in the " + fastaFileName + " template sequences...\t");	cout.flush();
+		Utils util;
+        
+        long start = time(NULL);
+        m->mothurOut("\nReading in the " + fastaFileName + " template sequences...\t");	cout.flush();
         //bool aligned = false;
         int tempLength = 0;
         
         ifstream fastaFile;
-        m->openInputFile(fastaFileName, fastaFile);
+        util.openInputFile(fastaFileName, fastaFile);
         
         while (!fastaFile.eof()) {
-            Sequence temp(fastaFile);  m->gobble(fastaFile);
+            Sequence temp(fastaFile);  util.gobble(fastaFile);
             
-            if (m->control_pressed) {  templateSequences.clear(); break;  }
+            if (m->getControl_pressed()) {  templateSequences.clear(); break;  }
             
             if (temp.getName() != "") {
                 templateSequences.push_back(temp);
@@ -43,7 +43,7 @@ AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gap
                 if (temp.getUnaligned().length() >= longest)  { longest = (temp.getUnaligned().length()+1); }
                 
                 if (tempLength != 0) {
-                    if (tempLength != temp.getAligned().length()) { m->mothurOut("[ERROR]: template is not aligned, aborting.\n"); m->control_pressed=true; }
+                    if (tempLength != temp.getAligned().length()) { m->mothurOut("[ERROR]: template is not aligned, aborting.\n"); m->setControl_pressed(true); }
                 }else { tempLength = temp.getAligned().length(); }
             }
         }
@@ -52,9 +52,9 @@ AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gap
         numSeqs = templateSequences.size();
         //all of this is elsewhere already!
         
-        m->mothurOut("DONE.");
-        m->mothurOutEndLine();	cout.flush();
-        m->mothurOut("It took " + toString(time(NULL) - start) + " to read  " + toString(templateSequences.size()) + " sequences."); m->mothurOutEndLine();  
+        m->mothurOut("DONE.\n");
+        cout.flush();
+        m->mothurOut("It took " + toString(time(NULL) - start) + " to read  " + toString(templateSequences.size()) + " sequences.\n");   
 
 		
 		//in case you delete the seqs and then ask for them
@@ -73,9 +73,10 @@ AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gap
             ifstream kmerFileTest(kmerDBName.c_str());
 				
             if(kmerFileTest){
-                bool GoodFile = m->checkReleaseVersion(kmerFileTest, m->getVersion());
-                int shortcutTimeStamp = m->getTimeStamp(kmerDBName);
-                int referenceTimeStamp = m->getTimeStamp(fastaFileName);
+                string line = util.getline(kmerFileTest);
+                bool GoodFile = util.checkReleaseVersion(line, current->getVersion());  kmerFileTest.close();
+                int shortcutTimeStamp = util.getTimeStamp(kmerDBName);
+                int referenceTimeStamp = util.getTimeStamp(fastaFileName);
                 
                 //if the shortcut file is older then the reference file, remake shortcut file
                 if (shortcutTimeStamp < referenceTimeStamp) {  GoodFile = false;  }
@@ -88,21 +89,20 @@ AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gap
 		else if(method == "blast")		{	search = new BlastDB(fastaFileName.substr(0,fastaFileName.find_last_of(".")+1), gapOpen, gapExtend, match, misMatch, "", threadID);	}
 		else {
 			method = "kmer";
-			m->mothurOut(method + " is not a valid search option. I will run the command using kmer, ksize=8.");
-			m->mothurOutEndLine();
+			m->mothurOut(method + " is not a valid search option. I will run the command using kmer, ksize=8.\n");
 			search = new KmerDB(fastaFileName, 8);
 		}
 		
-		if (!(m->control_pressed)) {
+		if (!m->getControl_pressed()) {
 			if (needToGenerate) {
 				//add sequences to search 
 				for (int i = 0; i < templateSequences.size(); i++) {
 					search->addSequence(templateSequences[i]);
 					
-					if (m->control_pressed) {  templateSequences.clear(); break;  }
+					if (m->getControl_pressed()) {  templateSequences.clear(); break;  }
 				}
 				
-				if (m->control_pressed) {  templateSequences.clear();  }
+				if (m->getControl_pressed()) {  templateSequences.clear();  }
 				
                 if ((method != "kmer") || ((method == "kmer") && (writeShortcut))) { search->generateDB(); }
                 
@@ -146,13 +146,14 @@ AlignmentDB::AlignmentDB(string s){
 /**************************************************************************************************/
 AlignmentDB::~AlignmentDB() {  delete search;	}
 /**************************************************************************************************/
-Sequence AlignmentDB::findClosestSequence(Sequence* seq) {
+Sequence AlignmentDB::findClosestSequence(Sequence* seq, float& searchScore) {
 	try{
+        lock_guard<std::mutex> guard(mutex);
+        vector<float> scores;
+		vector<int> spot = search->findClosestSequences(seq, 1, scores);
 	
-		vector<int> spot = search->findClosestSequences(seq, 1);
-	
-		if (spot.size() != 0)	{		return templateSequences[spot[0]];	}
-		else					{		return emptySequence;				}
+        if (spot.size() != 0)	{	searchScore = scores[0]; return templateSequences[spot[0]];	}
+        else					{ 	searchScore = 0; return emptySequence;                      }
 		
 	}
 	catch(exception& e) {
