@@ -39,6 +39,7 @@
 #include "mothurout.h"
 #include "listvector.hpp"
 #include "groupmap.h"
+#include "sequence.hpp"
 
 class CountTable {
     
@@ -51,9 +52,11 @@ class CountTable {
         int createTable(set<string>&, map<string, string>&, set<string>&); //seqNames, seqName->group, groupNames 
         int createTable(string, string, bool); //namefile, groupfile, createGroup
         int readTable(string, bool, bool); //filename, readGroups, mothurRunning
+        int readTable(string, string); //filename, format - if format=fasta, read fasta file and create unique table
     
         int printTable(string);
         int printHeaders(ofstream&);
+        vector<string> getHardCodedHeaders(); //Representative_Sequence, total
         int printSeq(ofstream&, string);
         bool testGroups(string file); //used to check if file has group data without reading it
         bool testGroups(string file, vector<string>&); //used to check if file has group data without reading it, return groups if found.
@@ -94,6 +97,7 @@ class CountTable {
     private:
         string filename;
         MothurOut* m;
+        Utils util;
         bool hasGroups;
         int total, uniques;
         vector<string> groups;
