@@ -24,20 +24,20 @@ DesignMap::DesignMap(string file) {
 int DesignMap::read(string file) {
     try {
         ifstream in;
-        m->openInputFile(file, in);
+        util.openInputFile(file, in);
         
         string temp = "";
-        in >> temp; m->gobble(in);
+        in >> temp; util.gobble(in);
         
         vector<string> columnHeaders;
         vector<string> tempColumnHeaders;
         if (temp == "group") {
-            string headers = m->getline(in); m->gobble(in);
-            columnHeaders = m->splitWhiteSpace(headers);
+            string headers = util.getline(in); util.gobble(in);
+            columnHeaders = util.splitWhiteSpace(headers);
             columnHeaders.insert(columnHeaders.begin(), "group");
         }else {
-            string headers = m->getline(in); m->gobble(in);
-            tempColumnHeaders = m->splitWhiteSpace(headers);
+            string headers = util.getline(in); util.gobble(in);
+            tempColumnHeaders = util.splitWhiteSpace(headers);
             int num = tempColumnHeaders.size();
             columnHeaders.push_back("group");
             for (int i = 0; i < num; i++) { columnHeaders.push_back("value" + toString(i)); }
@@ -51,7 +51,7 @@ int DesignMap::read(string file) {
         for (int i = 1; i < columnHeaders.size(); i++) {  namesOfCategories.push_back(columnHeaders[i]);  originalGroupIndexes[i-1] = columnHeaders[i]; }
         if (columnHeaders.size() > 1) { defaultClass = columnHeaders[1]; }
         else {
-            m->mothurOut("[ERROR]: Your design file contains only one column. Please correct."); m->mothurOutEndLine(); m->control_pressed = true;
+            m->mothurOut("[ERROR]: Your design file contains only one column. Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
         }
         
         //sort groups to keep consistent with how we store the groups in groupmap
@@ -67,18 +67,18 @@ int DesignMap::read(string file) {
         //file without headers, fix it
         if (temp != "group") {
             group = temp;
-            m->checkGroupName(group);
-            if (m->debug) { m->mothurOut("[DEBUG]: group = " + group + "\n"); }
+            util.checkGroupName(group);
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: group = " + group + "\n"); }
             
             //if group info, then read it
             vector<string> categoryValues; categoryValues.resize(numCategories, "not found");
             for (int i = 0; i < numCategories; i++) {
                 int thisIndex = indexCategoryMap[originalGroupIndexes[i]]; //find index of this category because we sort the values.
                 string temp = tempColumnHeaders[i];
-                m->checkGroupName(temp);
+                util.checkGroupName(temp);
                 categoryValues[thisIndex] = temp;
             
-                if (m->debug) { m->mothurOut("[DEBUG]: value = " + temp + "\n"); }
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: value = " + temp + "\n"); }
                 
                 //do we have this value for this category already
                 map<string, int>::iterator it = totalCategories[thisIndex].find(temp);
@@ -101,21 +101,21 @@ int DesignMap::read(string file) {
         
         while (!in.eof()) {
             
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            in >> group; m->gobble(in);
-            m->checkGroupName(group);
-            if (m->debug) { m->mothurOut("[DEBUG]: group = " + group + "\n"); }
+            in >> group; util.gobble(in);
+            util.checkGroupName(group);
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: group = " + group + "\n"); }
             
             //if group info, then read it
             vector<string> categoryValues; categoryValues.resize(numCategories, "not found");
             for (int i = 0; i < numCategories; i++) {
                 int thisIndex = indexCategoryMap[originalGroupIndexes[i]]; //find index of this category because we sort the values.
                 string temp = "not found";
-                in >> temp; categoryValues[thisIndex] = temp; m->gobble(in);
-                m->checkGroupName(temp);
+                in >> temp; categoryValues[thisIndex] = temp; util.gobble(in);
+                util.checkGroupName(temp);
                 
-                if (m->debug) { m->mothurOut("[DEBUG]: value = " + temp + "\n"); }
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: value = " + temp + "\n"); }
                 
                 //do we have this value for this category already
                 map<string, int>::iterator it = totalCategories[thisIndex].find(temp);
@@ -137,7 +137,7 @@ int DesignMap::read(string file) {
         }
         in.close();
         
-        if (error) { m->control_pressed = true; }
+        if (error) { m->setControl_pressed(true); }
         
         return 0;
     }
@@ -154,7 +154,7 @@ string DesignMap::get(string groupName) {
         
         map<string, int>::iterator it2 = indexGroupNameMap.find(groupName);
         if (it2 == indexGroupNameMap.end()) {
-            m->mothurOut("[ERROR]: group " + groupName + " is not in your design file. Please correct.\n"); m->control_pressed = true;
+            m->mothurOut("[ERROR]: group " + groupName + " is not in your design file. Please correct.\n"); m->setControl_pressed(true);
         }else {
             return designMap[it2->second][indexCategoryMap[defaultClass]];
         }
@@ -193,7 +193,7 @@ vector<string> DesignMap::getCategory(string catName) {
         
         map<string, int>::iterator it2 = indexCategoryMap.find(catName);
         if (it2 == indexCategoryMap.end()) {
-            m->mothurOut("[ERROR]: category " + catName + " is not in your design file. Please correct.\n"); m->control_pressed = true;
+            m->mothurOut("[ERROR]: category " + catName + " is not in your design file. Please correct.\n"); m->setControl_pressed(true);
         }else {
             for (map<string, int>::iterator it = totalCategories[it2->second].begin(); it != totalCategories[it2->second].end(); it++) {
                 values.push_back(it->first);
@@ -215,11 +215,11 @@ string DesignMap::get(string groupName, string categoryName) {
         string value = "not found";
         map<string, int>::iterator it = indexCategoryMap.find(categoryName);
         if (it == indexCategoryMap.end()) {
-            m->mothurOut("[ERROR]: category " + categoryName + " is not in your design file. Please correct.\n"); m->control_pressed = true;
+            m->mothurOut("[ERROR]: category " + categoryName + " is not in your design file. Please correct.\n"); m->setControl_pressed(true);
         }else {
             map<string, int>::iterator it2 = indexGroupNameMap.find(groupName);
             if (it2 == indexGroupNameMap.end()) {
-                m->mothurOut("[ERROR]: group " + groupName + " is not in your design file. Please correct.\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: group " + groupName + " is not in your design file. Please correct.\n"); m->setControl_pressed(true);
             }else {
                 return designMap[it2->second][it->second];
             }
@@ -235,10 +235,10 @@ string DesignMap::get(string groupName, string categoryName) {
 //add group, assumes order is correct
 int DesignMap::push_back(string group, vector<string> values) {
     try {
-        m->checkGroupName(group);
+        util.checkGroupName(group);
         map<string, int>::iterator it = indexGroupNameMap.find(group);
         if (it == indexGroupNameMap.end()) {
-            if (values.size() != getNumCategories()) {  m->mothurOut("[ERROR]: Your design file has a " + toString(getNumCategories()) + " categories and " + group + " has " + toString(values.size()) + ", please correct."); m->mothurOutEndLine(); m->control_pressed = true;  return 0; }
+            if (values.size() != getNumCategories()) {  m->mothurOut("[ERROR]: Your design file has a " + toString(getNumCategories()) + " categories and " + group + " has " + toString(values.size()) + ", please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);  return 0; }
             
             for (int i = 0; i < values.size(); i++) {
                 //do we have this value for this category already
@@ -250,7 +250,7 @@ int DesignMap::push_back(string group, vector<string> values) {
             indexGroupNameMap[group] = count;
             designMap.push_back(values);
         }else {
-            m->mothurOut("[ERROR]: Your design file contains more than 1 group named " + group + ", group names must be unique. Please correct."); m->mothurOutEndLine(); m->control_pressed = true;
+            m->mothurOut("[ERROR]: Your design file contains more than 1 group named " + group + ", group names must be unique. Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
         }
         
         return 0;
@@ -270,7 +270,7 @@ int DesignMap::setValues(string group, map<string, string> values) {
                 
                 map<string, int>::iterator it3 = indexCategoryMap.find(it2->first); //do we have this category
                 if (it3 == indexCategoryMap.end()) {
-                     m->mothurOut("[ERROR]: Your design file does not contain a category called " + it2->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true;
+                     m->mothurOut("[ERROR]: Your design file does not contain a category called " + it2->first + ". Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
                 }else {
                     string oldCategory = designMap[it->second][it3->second];
                     //adjust totals for old category
@@ -287,7 +287,7 @@ int DesignMap::setValues(string group, map<string, string> values) {
                 }
             }
         }else {
-            m->mothurOut("[ERROR]: Your design file does not contain a group named " + group + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true;
+            m->mothurOut("[ERROR]: Your design file does not contain a group named " + group + ". Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
         }
         
         return 0;
@@ -301,7 +301,7 @@ int DesignMap::setValues(string group, map<string, string> values) {
 //set defaultclass
 void DesignMap::setDefaultClass(string dClass) {
     try {
-        if (m->inUsersGroups(dClass, namesOfCategories)) {
+        if (util.inUsersGroups(dClass, namesOfCategories)) {
             defaultClass = dClass;
         }else{
             m->mothurOut("[WARNING]: Your design file does not contain a category named " + dClass + ". Using default class " + defaultClass + " .\n\n");
@@ -323,7 +323,7 @@ int DesignMap::getNumUnique(map<string, vector<string> > selected) {
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
-                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return 0;
+                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return 0;
             }else {
                 indexes[it2->second] = it->second;
             }
@@ -333,7 +333,7 @@ int DesignMap::getNumUnique(map<string, vector<string> > selected) {
             bool hasAll = true; //innocent til proven guilty
             for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
                //column number is it->first
-                if (!m->inUsersGroups(designMap[j][it->first], it->second)) { hasAll = false;  }
+                if (!util.inUsersGroups(designMap[j][it->first], it->second)) { hasAll = false;  }
             }
             if (hasAll) { num++; }
         }
@@ -356,7 +356,7 @@ int DesignMap::getNumShared(map<string, vector<string> > selected) {
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
-                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return 0;
+                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return 0;
             }else {
                 indexes[it2->second] = it->second;
             }
@@ -366,7 +366,7 @@ int DesignMap::getNumShared(map<string, vector<string> > selected) {
             bool hasAny = false; //innocent til proven guilty
             for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
                 //column number is it->first
-                if (m->inUsersGroups(designMap[j][it->first], it->second)) { hasAny = true;  }
+                if (util.inUsersGroups(designMap[j][it->first], it->second)) { hasAny = true;  }
             }
             if (hasAny) { num++; }
         }
@@ -390,7 +390,7 @@ vector<string> DesignMap::getNamesUnique(map<string, vector<string> > selected)
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
-                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
+                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return names;
             }else {
                 indexes[it2->second] = it->second;
             }
@@ -406,12 +406,12 @@ vector<string> DesignMap::getNamesUnique(map<string, vector<string> > selected)
             bool hasAll = true; //innocent til proven guilty
             for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
                 //column number is it->first
-                if (!m->inUsersGroups(designMap[j][it->first], it->second)) { hasAll = false;  }
+                if (!util.inUsersGroups(designMap[j][it->first], it->second)) { hasAll = false;  }
             }
             if (hasAll) {
                 map<int, string>::iterator it = reverse.find(j);
                 if (it == reverse.end()) {
-                    m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
+                    m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return names;
                 }else { names.push_back(it->second); }
             }
         }
@@ -434,7 +434,7 @@ vector<string> DesignMap::getNamesShared(map<string, vector<string> > selected)
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
-                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
+                m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return names;
             }else {
                 indexes[it2->second] = it->second;
             }
@@ -450,13 +450,13 @@ vector<string> DesignMap::getNamesShared(map<string, vector<string> > selected)
             bool hasAny = false; //innocent til proven guilty
             for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
                 //column number is it->first
-                if (m->inUsersGroups(designMap[j][it->first], it->second)) { hasAny = true;  }
+                if (util.inUsersGroups(designMap[j][it->first], it->second)) { hasAny = true;  }
             }
 
             if (hasAny) {
                 map<int, string>::iterator it = reverse.find(j);
                 if (it == reverse.end()) {
-                    m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
+                    m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return names;
                 }else { names.push_back(it->second); }
             }
         }
@@ -479,7 +479,7 @@ vector<string> DesignMap::getNamesGroups(string category, string value) {
         
         map<string, int>::iterator it = indexCategoryMap.find(category);
         if (it == indexCategoryMap.end()) {
-            m->mothurOut("[ERROR]: category " + category + " is not in your design file. Please correct.\n"); m->control_pressed = true;
+            m->mothurOut("[ERROR]: category " + category + " is not in your design file. Please correct.\n"); m->setControl_pressed(true);
         }else {
             int column = it->second;
             
@@ -493,7 +493,7 @@ vector<string> DesignMap::getNamesGroups(string category, string value) {
                 if (designMap[i][column] == value) {
                     map<int, string>::iterator it2 = reverse.find(i);
                     if (it2 == reverse.end()) {
-                        m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
+                        m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); return names;
                     }else { names.push_back(it2->second); }
                 }
             }
@@ -568,7 +568,7 @@ int DesignMap::printCategories(ofstream& out, vector<string> cats) {
     try {
         
 		out << "group";
-        for (int i = 0; i < namesOfCategories.size(); i++) { if (m->inUsersGroups(namesOfCategories[i], cats)) { out  << '\t' << namesOfCategories[i]; } }
+        for (int i = 0; i < namesOfCategories.size(); i++) { if (util.inUsersGroups(namesOfCategories[i], cats)) { out  << '\t' << namesOfCategories[i]; } }
         out << endl;
         
         map<int, string> reverse; //use this to preserve order
@@ -581,7 +581,7 @@ int DesignMap::printCategories(ofstream& out, vector<string> cats) {
                 out << itR->second;
                 
                 for (int j = 0; j < namesOfCategories.size(); j++) {
-                    if (m->inUsersGroups(namesOfCategories[i], cats)) {
+                    if (util.inUsersGroups(namesOfCategories[i], cats)) {
                         out  << '\t' << designMap[i][j];
                     }
                 }
@@ -615,7 +615,7 @@ int DesignMap::printGroups(ofstream& out, vector<string> groups) {
             
             if (itR != reverse.end()) { //will equal end if groups were removed because remove just removes from indexNameMap
                 
-                if (m->inUsersGroups(itR->second, groups)) {
+                if (util.inUsersGroups(itR->second, groups)) {
                     out << itR->second;
                 
                     for (int j = 0; j < namesOfCategories.size(); j++) {
