@@ -14,7 +14,7 @@
  GroupMap::GroupMap(string filename) {
 	m = MothurOut::getInstance();
 	groupFileName = filename;
-	m->openInputFile(filename, fileHandle);
+	util.openInputFile(filename, fileHandle);
 	index = 0;
 }
 
@@ -25,11 +25,11 @@ int GroupMap::addSeq(string name, string group) {
     try {
         int error = 0;
         
-        m->checkGroupName(group);
+        util.checkGroupName(group);
         setNamesOfGroups(group);
         
-        if (m->debug) { m->mothurOut("[DEBUG]: name = '" + name + "', group = '" + group + "'\n"); }
-        m->checkName(name);
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + name + "', group = '" + group + "'\n"); }
+        util.checkName(name);
         it = groupmap.find(name);
         
         if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + name + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -57,21 +57,21 @@ int GroupMap::readMap() {
         bool columnOne = true;
     
         while (!fileHandle.eof()) {
-            if (m->control_pressed) { fileHandle.close();  return 1; }
+            if (m->getControl_pressed()) { fileHandle.close();  return 1; }
         
             fileHandle.read(buffer, 4096);
-            vector<string> pieces = m->splitWhiteSpace(rest, buffer, fileHandle.gcount());
+            vector<string> pieces = util.splitWhiteSpace(rest, buffer, fileHandle.gcount());
         
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
             
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -86,18 +86,18 @@ int GroupMap::readMap() {
 		fileHandle.close();
         
         if (rest != "") {
-            vector<string> pieces = m->splitWhiteSpace(rest);
+            vector<string> pieces = util.splitWhiteSpace(rest);
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -110,7 +110,6 @@ int GroupMap::readMap() {
             }
         }
         
-		m->setAllGroups(namesOfGroups);
 		return error;
     }
 	catch(exception& e) {
@@ -129,21 +128,21 @@ int GroupMap::readDesignMap() {
         bool columnOne = true;
         
         while (!fileHandle.eof()) {
-            if (m->control_pressed) { fileHandle.close();  return 1; }
+            if (m->getControl_pressed()) { fileHandle.close();  return 1; }
             
             fileHandle.read(buffer, 4096);
-            vector<string> pieces = m->splitWhiteSpace(rest, buffer, fileHandle.gcount());
+            vector<string> pieces = util.splitWhiteSpace(rest, buffer, fileHandle.gcount());
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -158,18 +157,18 @@ int GroupMap::readDesignMap() {
 		fileHandle.close();
         
         if (rest != "") {
-            vector<string> pieces = m->splitWhiteSpace(rest);
+            vector<string> pieces = util.splitWhiteSpace(rest);
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -183,7 +182,6 @@ int GroupMap::readDesignMap() {
 
         }
         
-		m->setAllGroups(namesOfGroups);
 		return error;
     }
 	catch(exception& e) {
@@ -195,7 +193,7 @@ int GroupMap::readDesignMap() {
 int GroupMap::readMap(string filename) {
     try {
         groupFileName = filename;
-        m->openInputFile(filename, fileHandle);
+        util.openInputFile(filename, fileHandle);
         index = 0;
         string seqName, seqGroup;
 		int error = 0;
@@ -205,21 +203,21 @@ int GroupMap::readMap(string filename) {
         bool columnOne = true;
         
         while (!fileHandle.eof()) {
-            if (m->control_pressed) { fileHandle.close();  return 1; }
+            if (m->getControl_pressed()) { fileHandle.close();  return 1; }
             
             fileHandle.read(buffer, 4096);
-            vector<string> pieces = m->splitWhiteSpace(rest, buffer, fileHandle.gcount());
+            vector<string> pieces = util.splitWhiteSpace(rest, buffer, fileHandle.gcount());
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your group file contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -234,18 +232,18 @@ int GroupMap::readMap(string filename) {
 		fileHandle.close();
         
         if (rest != "") {
-            vector<string> pieces = m->splitWhiteSpace(rest);
+            vector<string> pieces = util.splitWhiteSpace(rest);
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your group file contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -258,7 +256,6 @@ int GroupMap::readMap(string filename) {
             }
         }
         
-		m->setAllGroups(namesOfGroups);
 		return error;
     }
 	catch(exception& e) {
@@ -270,7 +267,7 @@ int GroupMap::readMap(string filename) {
 int GroupMap::readDesignMap(string filename) {
     try {
         groupFileName = filename;
-        m->openInputFile(filename, fileHandle);
+        util.openInputFile(filename, fileHandle);
         index = 0;
         string seqName, seqGroup;
 		int error = 0;
@@ -280,21 +277,21 @@ int GroupMap::readDesignMap(string filename) {
         bool columnOne = true;
         
         while (!fileHandle.eof()) {
-            if (m->control_pressed) { fileHandle.close();  return 1; }
+            if (m->getControl_pressed()) { fileHandle.close();  return 1; }
             
             fileHandle.read(buffer, 4096);
-            vector<string> pieces = m->splitWhiteSpace(rest, buffer, fileHandle.gcount());
+            vector<string> pieces = util.splitWhiteSpace(rest, buffer, fileHandle.gcount());
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -309,18 +306,18 @@ int GroupMap::readDesignMap(string filename) {
 		fileHandle.close();
         
         if (rest != "") {
-            vector<string> pieces = m->splitWhiteSpace(rest);
+            vector<string> pieces = util.splitWhiteSpace(rest);
             
             for (int i = 0; i < pieces.size(); i++) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
                 if (pairDone) {
-                    m->checkGroupName(seqGroup);
+                    util.checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
-                    if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
-                    m->checkName(seqName);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
                     if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -333,7 +330,6 @@ int GroupMap::readDesignMap(string filename) {
             }
         }
         
-		m->setAllGroups(namesOfGroups);
 		return error;
     }
 	catch(exception& e) {
@@ -352,7 +348,7 @@ string GroupMap::getGroup(string sequenceName) {
 		return it->second;	
 	}else {
         //look for it in names of groups to see if the user accidently used the wrong file
-        if (m->inUsersGroups(sequenceName, namesOfGroups)) {
+        if (util.inUsersGroups(sequenceName, namesOfGroups)) {
             m->mothurOut("[WARNING]: Your group or design file contains a group named " + sequenceName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine(); 
         }
 		return "not found";
@@ -362,9 +358,9 @@ string GroupMap::getGroup(string sequenceName) {
 /************************************************************/
 
 void GroupMap::setGroup(string sequenceName, string groupN) {
-    m->checkGroupName(groupN);
+    util.checkGroupName(groupN);
 	setNamesOfGroups(groupN);
-	m->checkName(sequenceName);
+	util.checkName(sequenceName);
 	it = groupmap.find(sequenceName);
 	
 	if (it != groupmap.end()) {  m->mothurOut("Your groupfile contains more than 1 sequence named " + sequenceName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
@@ -411,7 +407,7 @@ int GroupMap::getCopy(GroupMap* g) {
 	try {
         vector<string> names = g->getNamesSeqs();
         for (int i = 0; i < names.size(); i++) {
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             string group = g->getGroup(names[i]);
             setGroup(names[i], group);
         }
@@ -450,7 +446,7 @@ int GroupMap::renameSeq(string oldName, string newName) {
 		
 		if (itName == groupmap.end()) {
             m->mothurOut("[ERROR]: cannot find " + toString(oldName) + " in group file");
-            m->control_pressed = true;
+            m->setControl_pressed(true);
             return 0;
         }else {
             string group = itName->second;
@@ -487,7 +483,7 @@ int GroupMap::print(ofstream& out, vector<string> userGroups) {
 	try {
 		
 		for (map<string, string>::iterator itName = groupmap.begin(); itName != groupmap.end(); itName++) {
-            if (m->inUsersGroups(itName->second, userGroups)) {
+            if (util.inUsersGroups(itName->second, userGroups)) {
                 out << itName->first << '\t' << itName->second << endl;
             }
         }
@@ -525,7 +521,7 @@ vector<string> GroupMap::getNamesSeqs(vector<string> picked){
 		
 		for (it = groupmap.begin(); it != groupmap.end(); it++) {
 			//if you are belong to one the the groups in the picked vector add you
-			if (m->inUsersGroups(it->second, picked)) {
+			if (util.inUsersGroups(it->second, picked)) {
 				names.push_back(it->first);
 			}
 		}
