@@ -48,19 +48,22 @@ inline bool abundNamesSort2(listCt left, listCt right){
 
 /***********************************************************************/
 
-ListVector::ListVector() : DataVector(), maxRank(0), numBins(0), numSeqs(0){}
+ListVector::ListVector() : DataVector(), maxRank(0), numBins(0), numSeqs(0), otuTag("Otu"), printListHeaders(true) {}
 
 /***********************************************************************/
 
-ListVector::ListVector(int n):	DataVector(), data(n, "") , maxRank(0), numBins(0), numSeqs(0){}
+ListVector::ListVector(int n):	DataVector(), data(n, "") , maxRank(0), numBins(0), numSeqs(0), otuTag("Otu"), printListHeaders(true){}
 
 /***********************************************************************/
 
-ListVector::ListVector(string id, vector<string> lv) : DataVector(id), data(lv){
+ListVector::ListVector(string id, vector<string> lv, string& tag) : DataVector(id), data(lv){
 	try {
+        printListHeaders = true;
+        otuTag = tag;
+        Utils util;
 		for(int i=0;i<data.size();i++){
 			if(data[i] != ""){
-				int binSize = m->getNumNames(data[i]);
+				int binSize = util.getNumNames(data[i]);
 				numBins = i+1;
 				if(binSize > maxRank)	{	maxRank = binSize;	}
 				numSeqs += binSize;
@@ -75,34 +78,38 @@ ListVector::ListVector(string id, vector<string> lv) : DataVector(id), data(lv){
 
 /**********************************************************************/
 
-ListVector::ListVector(ifstream& f) : DataVector(), maxRank(0), numBins(0), numSeqs(0) {
+ListVector::ListVector(ifstream& f, string& readHeaders, string& labelTag) : DataVector(), maxRank(0), numBins(0), numSeqs(0) {
 	try {
+        printListHeaders = true;
 		int hold;
+        Utils util;
         
         //are we at the beginning of the file??
-		if (m->saveNextLabel == "") {
+		if (readHeaders == "") {
 			f >> label;
             
 			//is this a shared file that has headers
 			if (label == "label") {
 				
 				//gets "numOtus"
-				f >> label; m->gobble(f);
+				f >> label; util.gobble(f);
 				
 				//eat rest of line
-				label = m->getline(f); m->gobble(f);
+				label = util.getline(f); util.gobble(f);
 				
 				//parse labels to save
 				istringstream iStringStream(label);
-				m->listBinLabelsInFile.clear();
 				while(!iStringStream.eof()){
-					if (m->control_pressed) { break; }
+					if (m->getControl_pressed()) { break; }
 					string temp;
-					iStringStream >> temp;  m->gobble(iStringStream);
-                    
-					m->listBinLabelsInFile.push_back(temp);
+					iStringStream >> temp;  util.gobble(iStringStream);
+					binLabels.push_back(temp);
 				}
-				
+                if (binLabels.size() != 0) {
+                    string binLabelTag = binLabels[0];
+                    labelTag = "";
+                    for (int i = 0; i < binLabelTag.length(); i++) { if (isalpha(binLabelTag[i])){ labelTag += binLabelTag[i]; } }
+                }
 				f >> label >> hold;
 			}else {
                 //read in first row
@@ -110,37 +117,30 @@ ListVector::ListVector(ifstream& f) : DataVector(), maxRank(0), numBins(0), numS
                 
                 //make binlabels because we don't have any
                 string snumBins = toString(hold);
-                m->listBinLabelsInFile.clear();
+                if (labelTag == "") { labelTag = "Otu"; }
                 for (int i = 0; i < hold; i++) {
                     //if there is a bin label use it otherwise make one
-                    string binLabel = "Otu";
+                    string binLabel = labelTag;
                     string sbinNumber = toString(i+1);
                     if (sbinNumber.length() < snumBins.length()) {
                         int diff = snumBins.length() - sbinNumber.length();
                         for (int h = 0; h < diff; h++) { binLabel += "0"; }
                     }
                     binLabel += sbinNumber;
-                    m->listBinLabelsInFile.push_back(binLabel);
+                    binLabels.push_back(binLabel);
                 }
             }
-            m->saveNextLabel = label;
-		}else {
-            f >> label >> hold;
-            m->saveNextLabel = label;
-        }
-	
-        binLabels.assign(m->listBinLabelsInFile.begin(), m->listBinLabelsInFile.begin()+hold);
+		}else { f >> label >> hold; }
 		
 		data.assign(hold, "");
 		string inputData = "";
+        otuTag = labelTag;
 	
 		for(int i=0;i<hold;i++){
 			f >> inputData;
 			set(i, inputData);
 		}
-		m->gobble(f);
-        
-        if (f.eof()) { m->saveNextLabel = ""; }
+		util.gobble(f);
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ListVector", "ListVector");
@@ -152,9 +152,10 @@ ListVector::ListVector(ifstream& f) : DataVector(), maxRank(0), numBins(0), numS
 
 void ListVector::set(int binNumber, string seqNames){
 	try {
-		int nNames_old = m->getNumNames(data[binNumber]);
+        Utils util;
+		int nNames_old = util.getNumNames(data[binNumber]);
 		data[binNumber] = seqNames;
-		int nNames_new = m->getNumNames(seqNames);
+		int nNames_new = util.getNumNames(seqNames);
 	
 		if(nNames_old == 0)			{	numBins++;				}
 		if(nNames_new == 0)			{	numBins--;				}
@@ -178,6 +179,7 @@ string ListVector::get(int index){
 void ListVector::setLabels(vector<string> labels){
 	try {
 		binLabels = labels;
+        getLabels();
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ListVector", "setLabels");
@@ -191,35 +193,8 @@ void ListVector::setLabels(vector<string> labels){
 //if you had a listfile that had been subsampled and then added to it, dup names would be possible.
 vector<string> ListVector::getLabels(){
     try {
-        
-        string tagHeader = "Otu";
-        if (m->sharedHeaderMode == "tax") { tagHeader = "PhyloType"; }
-        
-        if (binLabels.size() < data.size()) {
-            string snumBins = toString(numBins);
-            
-            for (int i = 0; i < numBins; i++) {
-                string binLabel = tagHeader;
-                
-                if (i < binLabels.size()) { //label exists, check leading zeros length
-                    string sbinNumber = m->getSimpleLabel(binLabels[i]);
-                    if (sbinNumber.length() < snumBins.length()) {
-                        int diff = snumBins.length() - sbinNumber.length();
-                        for (int h = 0; h < diff; h++) { binLabel += "0"; }
-                    }
-                    binLabel += sbinNumber;
-                    binLabels[i] = binLabel;
-                }else{
-                    string sbinNumber = toString(i+1);
-                    if (sbinNumber.length() < snumBins.length()) {
-                        int diff = snumBins.length() - sbinNumber.length();
-                        for (int h = 0; h < diff; h++) { binLabel += "0"; }
-                    }
-                    binLabel += sbinNumber;
-                    binLabels.push_back(binLabel);
-                }
-            }
-        }
+        Utils util;
+        util.getOTUNames(binLabels, numBins, otuTag);
         return binLabels;
     }
 	catch(exception& e) {
@@ -232,8 +207,9 @@ vector<string> ListVector::getLabels(){
 
 void ListVector::push_back(string seqNames){
 	try {
+        Utils util;
 		data.push_back(seqNames);
-		int nNames = m->getNumNames(seqNames);
+		int nNames = util.getNumNames(seqNames);
 	
 		numBins++;
 	
@@ -269,22 +245,46 @@ void ListVector::clear(){
 }
 
 /***********************************************************************/
-void ListVector::printHeaders(ostream& output){
+void ListVector::printHeaders(ostream& output, map<string, int>& ct, bool sortPlease){
 	try {
-		string snumBins = toString(numBins);
-        string tagHeader = "Otu";
-        if (m->sharedHeaderMode == "tax") { tagHeader = "PhyloType"; }
-		output << "label\tnum" + tagHeader + "s";
-        
-        vector<string> theseLabels = getLabels();
-        
-        for(int i = 0; i < theseLabels.size(); i++) { //print original label for sorted by abundance otu
-            output  << '\t' << theseLabels[i];
+        if (printListHeaders) {
+            if (binLabels.size() == 0) { sortPlease = false; } //we are creating arbitary otuNames
+            
+            vector<string> theseLabels = getLabels();
+            
+            output << "label\tnum" + otuTag + "s";
+            
+            if (sortPlease) {
+                Utils util;
+                vector<listCt> hold;
+                for (int i = 0; i < data.size(); i++) {
+                    if (data[i] != "") {
+                        vector<string> binNames;
+                        string bin = data[i];
+                        util.splitAtComma(bin, binNames);
+                        int total = 0;
+                        for (int j = 0; j < binNames.size(); j++) {
+                            map<string, int>::iterator it = ct.find(binNames[j]);
+                            if (it == ct.end()) {
+                                m->mothurOut("[ERROR]: " + binNames[j] + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
+                            }else { total += ct[binNames[j]]; }
+                        }
+                        listCt temp(data[i], total, theseLabels[i]);
+                        hold.push_back(temp);
+                    }
+                }
+                sort(hold.begin(), hold.end(), abundNamesSort2);
+
+                //print original label for sorted by abundance otu
+                for (int i = 0; i < hold.size(); i++) { output  << '\t' << hold[i].label; }
+            }else {
+                for (int i = 0; i < theseLabels.size(); i++) { output  << '\t' << theseLabels[i]; }
+            }
+            
+            output << endl;
+            
+            printListHeaders = false;
         }
-					
-        output << endl;
-		
-		m->printedListHeaders = true;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ListVector", "printHeaders");
@@ -296,23 +296,24 @@ void ListVector::printHeaders(ostream& output){
 
 void ListVector::print(ostream& output, map<string, int>& ct){
 	try {
+        printHeaders(output, ct, true);
 		output << label << '\t' << numBins;
-	
         
+        Utils util;
         vector<listCt> hold;
         for (int i = 0; i < data.size(); i++) {
             if (data[i] != "") {
                 vector<string> binNames;
                 string bin = data[i];
-                m->splitAtComma(bin, binNames);
+                util.splitAtComma(bin, binNames);
                 int total = 0;
                 for (int j = 0; j < binNames.size(); j++) {
                     map<string, int>::iterator it = ct.find(binNames[j]);
                     if (it == ct.end()) {
-                        m->mothurOut("[ERROR]: " + binNames[j] + " is not in your count table. Please correct.\n"); m->control_pressed = true;
+                        m->mothurOut("[ERROR]: " + binNames[j] + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
                     }else { total += ct[binNames[j]]; }
                 }
-                listCt temp(data[i], total);
+                listCt temp(data[i], total, "");
                 hold.push_back(temp);
             }
         }
@@ -336,21 +337,16 @@ void ListVector::print(ostream& output, map<string, int>& ct){
 
 void ListVector::print(ostream& output){
     try {
-        output << label << '\t' << numBins;
-        
-        vector<string> hold = data;
-        sort(hold.begin(), hold.end(), abundNamesSort);
-        
-        //find first non blank otu
-        int start = 0;
-        for(int i=0;i<hold.size();i++){  if(hold[i] != ""){  start = i; break; } }
-        
-        for(int i=start;i<hold.size();i++){
-            if(hold[i] != ""){
-                output << '\t' << hold[i];
+        map<string, int> ct;
+        for (int i = 0; i < data.size(); i++) {
+            if (data[i] != "") {
+                string bin = data[i];
+                vector<string> binNames; util.splitAtComma(bin, binNames);
+                for (int j = 0; j < binNames.size(); j++) { ct[binNames[j]] = 1; }
             }
         }
-        output << endl;
+        
+        print(output, ct);
     }
     catch(exception& e) {
         m->errorOut(e, "ListVector", "print");
@@ -361,6 +357,16 @@ void ListVector::print(ostream& output){
 //no sort for subsampling and get.otus and remove.otus
 void ListVector::print(ostream& output, bool sortOtus){
     try {
+        map<string, int> ct;
+        for (int i = 0; i < data.size(); i++) {
+            if (data[i] != "") {
+                string bin = data[i];
+                vector<string> binNames; util.splitAtComma(bin, binNames);
+                for (int j = 0; j < binNames.size(); j++) { ct[binNames[j]] = 1; }
+            }
+        }
+        
+        printHeaders(output, ct, sortOtus);
         output << label << '\t' << numBins;
         
         vector<string> hold = data;
@@ -388,21 +394,11 @@ void ListVector::print(ostream& output, bool sortOtus){
 RAbundVector ListVector::getRAbundVector(){
 	try {
 		RAbundVector rav;
-	
+        Utils util;
 		for(int i=0;i<data.size();i++){
-			int binSize = m->getNumNames(data[i]);
+			int binSize = util.getNumNames(data[i]);
 			rav.push_back(binSize);
 		}
-	
-	//  This was here before to output data in a nice format, but it screws up the name mapping steps
-	//	sort(rav.rbegin(), rav.rend());
-	//	
-	//	for(int i=data.size()-1;i>=0;i--){
-	//		if(rav.get(i) == 0){	rav.pop_back();	}
-	//		else{
-	//			break;
-	//		}
-	//	}
 		rav.setLabel(label);
 	
 		return rav;
@@ -418,9 +414,9 @@ RAbundVector ListVector::getRAbundVector(){
 SAbundVector ListVector::getSAbundVector(){
 	try {
 		SAbundVector sav(maxRank+1);
-	
+        Utils util;
 		for(int i=0;i<data.size();i++){
-			int binSize = m->getNumNames(data[i]);	
+			int binSize = util.getNumNames(data[i]);	
 			sav.set(binSize, sav.get(binSize) + 1);	
 		}
 		sav.set(0, 0);
@@ -437,18 +433,18 @@ SAbundVector ListVector::getSAbundVector(){
 /***********************************************************************/
 
 OrderVector ListVector::getOrderVector(map<string,int>* orderMap = NULL){
-	
 	try {
+        Utils util;
 		if(orderMap == NULL){
 			OrderVector ov;
 		
 			for(int i=0;i<data.size();i++){
-				int binSize = m->getNumNames(data[i]);		
+				int binSize = util.getNumNames(data[i]);		
 				for(int j=0;j<binSize;j++){
 					ov.push_back(i);
 				}
 			}
-			m->mothurRandomShuffle(ov);
+			util.mothurRandomShuffle(ov);
 			ov.setLabel(label);
 			ov.getNumBins();
 		
