@@ -16,12 +16,12 @@ QualityScores::QualityScores(){
 		m = MothurOut::getInstance();
 		seqName = "";
 		seqLength = -1;
-		
+
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "QualityScores");
 		exit(1);
-	}							
+	}
 }
 /**************************************************************************************************/
 
@@ -40,107 +40,107 @@ QualityScores::QualityScores(string n, vector<int> s){
 
 QualityScores::QualityScores(ifstream& qFile){
 	try {
-		
+
 		m = MothurOut::getInstance();
 
 		int score;
-		seqName = getSequenceName(qFile); m->gobble(qFile);
-		
-        if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "'\n.");  }
-        
-		if (!m->control_pressed) {
-            string qScoreString = m->getline(qFile); m->gobble(qFile);
-            
-            if (m->debug) { m->mothurOut("[DEBUG]: scores = '" + qScoreString + "'\n.");  }
-            
+        seqName = getSequenceName(qFile); util.gobble(qFile); getCommentString(qFile);
+
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "'\n.");  }
+
+		if (!m->getControl_pressed()) {
+            string qScoreString = util.getline(qFile); util.gobble(qFile);
+
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: scores = '" + qScoreString + "'\n.");  }
+
             while(qFile.peek() != '>' && qFile.peek() != EOF){
-                if (m->control_pressed) { break; }
-                string temp = m->getline(qFile); m->gobble(qFile);
-                //if (m->debug) { m->mothurOut("[DEBUG]: scores = '" + temp + "'\n.");  }
+                if (m->getControl_pressed()) { break; }
+                string temp = util.getline(qFile); util.gobble(qFile);
+                //if (m->getDebug()) { m->mothurOut("[DEBUG]: scores = '" + temp + "'\n.");  }
                 qScoreString +=  ' ' + temp;
             }
             //cout << "done reading " << endl;
             istringstream qScoreStringStream(qScoreString);
             int count = 0;
             while(!qScoreStringStream.eof()){
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 string temp;
-                qScoreStringStream >> temp;  m->gobble(qScoreStringStream);
-                
-                //if (m->debug) { m->mothurOut("[DEBUG]: score " + toString(qScores.size()) + " = '" + temp + "'\n.");  }
-                
+                qScoreStringStream >> temp;  util.gobble(qScoreStringStream);
+
+                //if (m->getDebug()) { m->mothurOut("[DEBUG]: score " + toString(qScores.size()) + " = '" + temp + "'\n.");  }
+
                 //check temp to make sure its a number
-                if (!m->isContainingOnlyDigits(temp)) { m->mothurOut("[ERROR]: In sequence " + seqName + "'s quality scores, expected a number and got " + temp + ", setting score to 0."); m->mothurOutEndLine(); temp = "0"; }
+                if (!util.isContainingOnlyDigits(temp)) { m->mothurOut("[ERROR]: In sequence " + seqName + "'s quality scores, expected a number and got " + temp + ", setting score to 0."); m->mothurOutEndLine(); temp = "0"; }
                 convert(temp, score);
-                
+
                 //cout << count << '\t' << score << endl;
                 qScores.push_back(score);
                 count++;
             }
         }
-		
+
 		seqLength = qScores.size();
 		//cout << "seqlength = " << seqLength  << endl;
-		
+
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "QualityScores");
 		exit(1);
-	}							
-	
+	}
+
 }
 /**************************************************************************************************/
 #ifdef USE_BOOST
 QualityScores::QualityScores(boost::iostreams::filtering_istream& qFile){
     try {
-        
+
         m = MothurOut::getInstance();
-        
+
         int score;
-        seqName = getSequenceName(qFile); m->gobble(qFile);
-        
-        if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "'\n.");  }
-        
-        if (!m->control_pressed) {
-            string qScoreString = ""; std::getline(qFile, qScoreString); m->gobble(qFile);
-            
-            if (m->debug) { m->mothurOut("[DEBUG]: scores = '" + qScoreString + "'\n.");  }
-            
+        seqName = getSequenceName(qFile); util.gobble(qFile); getCommentString(qFile);
+
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "'\n.");  }
+
+        if (!m->getControl_pressed()) {
+            string qScoreString = ""; std::getline(qFile, qScoreString); util.gobble(qFile);
+
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: scores = '" + qScoreString + "'\n.");  }
+
             while(qFile.peek() != '>' && qFile.peek() != EOF){
-                if (m->control_pressed) { break; }
-                string temp = ""; std::getline(qFile, temp); m->gobble(qFile);
-                //if (m->debug) { m->mothurOut("[DEBUG]: scores = '" + temp + "'\n.");  }
+                if (m->getControl_pressed()) { break; }
+                string temp = ""; std::getline(qFile, temp); util.gobble(qFile);
+                //if (m->getDebug()) { m->mothurOut("[DEBUG]: scores = '" + temp + "'\n.");  }
                 qScoreString +=  ' ' + temp;
             }
             //cout << "done reading " << endl;
             istringstream qScoreStringStream(qScoreString);
             int count = 0;
             while(!qScoreStringStream.eof()){
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 string temp;
-                qScoreStringStream >> temp;  m->gobble(qScoreStringStream);
-                
-                //if (m->debug) { m->mothurOut("[DEBUG]: score " + toString(qScores.size()) + " = '" + temp + "'\n.");  }
-                
+                qScoreStringStream >> temp;  util.gobble(qScoreStringStream);
+
+                //if (m->getDebug()) { m->mothurOut("[DEBUG]: score " + toString(qScores.size()) + " = '" + temp + "'\n.");  }
+
                 //check temp to make sure its a number
-                if (!m->isContainingOnlyDigits(temp)) { m->mothurOut("[ERROR]: In sequence " + seqName + "'s quality scores, expected a number and got " + temp + ", setting score to 0."); m->mothurOutEndLine(); temp = "0"; }
+                if (!util.isContainingOnlyDigits(temp)) { m->mothurOut("[ERROR]: In sequence " + seqName + "'s quality scores, expected a number and got " + temp + ", setting score to 0."); m->mothurOutEndLine(); temp = "0"; }
                 convert(temp, score);
-                
+
                 //cout << count << '\t' << score << endl;
                 qScores.push_back(score);
                 count++;
             }
         }
-        
+
         seqLength = qScores.size();
         //cout << "seqlength = " << seqLength  << endl;
-        
+
     }
     catch(exception& e) {
         m->errorOut(e, "QualityScores", "QualityScores");
         exit(1);
-    }							
-    
+    }
+
 }
 #endif
 /**************************************************************************************************/
@@ -148,70 +148,70 @@ QualityScores::QualityScores(boost::iostreams::filtering_istream& qFile){
 int QualityScores::read(ifstream& qFile){
     try {
         int score;
-        seqName = getSequenceName(qFile); m->gobble(qFile);
-        
-        if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "'\n.");  }
-        
-        if (!m->control_pressed) {
-            string qScoreString = m->getline(qFile); m->gobble(qFile);
-            
-            if (m->debug) { m->mothurOut("[DEBUG]: scores = '" + qScoreString + "'\n.");  }
-            
+        seqName = getSequenceName(qFile); util.gobble(qFile); getCommentString(qFile);
+
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "'\n.");  }
+
+        if (!m->getControl_pressed()) {
+            string qScoreString = util.getline(qFile); util.gobble(qFile);
+
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: scores = '" + qScoreString + "'\n.");  }
+
             while(qFile.peek() != '>' && qFile.peek() != EOF){
-                if (m->control_pressed) { break; }
-                string temp = m->getline(qFile); m->gobble(qFile);
-                //if (m->debug) { m->mothurOut("[DEBUG]: scores = '" + temp + "'\n.");  }
+                if (m->getControl_pressed()) { break; }
+                string temp = util.getline(qFile); util.gobble(qFile);
+                //if (m->getDebug()) { m->mothurOut("[DEBUG]: scores = '" + temp + "'\n.");  }
                 qScoreString +=  ' ' + temp;
             }
             //cout << "done reading " << endl;
             istringstream qScoreStringStream(qScoreString);
             int count = 0;
             while(!qScoreStringStream.eof()){
-                if (m->control_pressed) { break; }
+                if (m->getControl_pressed()) { break; }
                 string temp;
-                qScoreStringStream >> temp;  m->gobble(qScoreStringStream);
-                
-                //if (m->debug) { m->mothurOut("[DEBUG]: score " + toString(qScores.size()) + " = '" + temp + "'\n.");  }
-                
+                qScoreStringStream >> temp;  util.gobble(qScoreStringStream);
+
+                //if (m->getDebug()) { m->mothurOut("[DEBUG]: score " + toString(qScores.size()) + " = '" + temp + "'\n.");  }
+
                 //check temp to make sure its a number
-                if (!m->isContainingOnlyDigits(temp)) { m->mothurOut("[ERROR]: In sequence " + seqName + "'s quality scores, expected a number and got " + temp + ", setting score to 0."); m->mothurOutEndLine(); temp = "0"; }
+                if (!util.isContainingOnlyDigits(temp)) { m->mothurOut("[ERROR]: In sequence " + seqName + "'s quality scores, expected a number and got " + temp + ", setting score to 0."); m->mothurOutEndLine(); temp = "0"; }
                 convert(temp, score);
-                
+
                 //cout << count << '\t' << score << endl;
                 qScores.push_back(score);
                 count++;
             }
         }
-        
+
         seqLength = qScores.size();
         //cout << "seqlength = " << seqLength  << endl;
-        
+
         return seqLength;
-        
+
     }
     catch(exception& e) {
         m->errorOut(e, "QualityScores", "read");
         exit(1);
-    }							
-    
+    }
+
 }
 
 //********************************************************************************************************************
 string QualityScores::getSequenceName(ifstream& qFile) {
 	try {
 		string name = "";
-		
+
         qFile >> name;
-        m->getline(qFile);
-		
-		if (name.length() != 0) { 
-            
-			name = name.substr(1); 
-            
-            m->checkName(name);
-            
-        }else{ m->mothurOut("Error in reading your qfile, at position " + toString(qFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->control_pressed = true;  }
-        
+        //string rest = util.getline(qFile);
+
+		if (name.length() != 0) {
+
+			name = name.substr(1);
+
+            util.checkName(name);
+
+        }else{ m->mothurOut("Error in reading your qfile, at position " + toString(qFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->setControl_pressed(true);  }
+
 		return name;
 	}
 	catch(exception& e) {
@@ -224,18 +224,18 @@ string QualityScores::getSequenceName(ifstream& qFile) {
 string QualityScores::getSequenceName(boost::iostreams::filtering_istream& qFile) {
     try {
         string name = "";
-        
+
         qFile >> name; string temp;
-        std::getline(qFile, temp);
-        
+        //std::getline(qFile, temp);
+
         if (name.length() != 0) {
-            
+
             name = name.substr(1);
-            
-            m->checkName(name);
-            
-        }else{ m->mothurOut("Error in reading your qfile, at position " + toString(qFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->control_pressed = true;  }
-        
+
+            util.checkName(name);
+
+        }else{ m->mothurOut("Error in reading your qfile, at position " + toString(qFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->setControl_pressed(true);  }
+
         return name;
     }
     catch(exception& e) {
@@ -245,10 +245,60 @@ string QualityScores::getSequenceName(boost::iostreams::filtering_istream& qFile
 }
 #endif
 //********************************************************************************************************************
+//comment can contain '>' so we need to account for that
+string QualityScores::getCommentString(ifstream& fastaFile) {
+    try {
+        char letter;
+        string temp = "";
+
+        while(fastaFile){
+            letter=fastaFile.get();
+            if((letter == '\r') || (letter == '\n') || letter == -1){
+                util.gobble(fastaFile);  //in case its a \r\n situation
+                break;
+            }else {
+                temp += letter;
+            }
+        }
+
+        return temp;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "QualityScores", "getCommentString");
+        exit(1);
+    }
+}
+//********************************************************************************************************************
+#ifdef USE_BOOST
+//comment can contain '>' so we need to account for that
+string QualityScores::getCommentString(boost::iostreams::filtering_istream& fastaFile) {
+    try {
+        char letter;
+        string temp = "";
+
+        while(fastaFile){
+            letter=fastaFile.get();
+            if((letter == '\r') || (letter == '\n') || letter == -1){
+                util.gobble(fastaFile);  //in case its a \r\n situation
+                break;
+            }else {
+                temp += letter;
+            }
+        }
+
+        return temp;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "QualityScores", "getCommentString");
+        exit(1);
+    }
+}
+#endif
+//********************************************************************************************************************
 void QualityScores::setName(string name) {
 	try {
-      
-        m->checkName(name);   
+
+        util.checkName(name);
         seqName = name;
 	}
 	catch(exception& e) {
@@ -259,55 +309,66 @@ void QualityScores::setName(string name) {
 /**************************************************************************************************/
 
 string QualityScores::getName(){
-	
+
 	try {
 		return seqName;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "getName");
 		exit(1);
-	}							
+	}
 }
+/**************************************************************************************************/
+void QualityScores::printQScores(OutputWriter* qFile){
+    try {
+        double expected_errors = calculateExpectedErrors();
 
+        string outputQualString = ">";  outputQualString += seqName + '\t' + toString(expected_errors) + '\n';
+
+        for(int i=0;i<seqLength;i++){ outputQualString += qScores[i] + ' '; } outputQualString += '\n';
+
+        qFile->write(outputQualString);
+    }
+    catch(exception& e) {
+        m->errorOut(e, "QualityScores", "printQScores");
+        exit(1);
+    }
+}
 /**************************************************************************************************/
 
 void QualityScores::printQScores(ofstream& qFile){
 	try {
-		
-		double aveQScore = calculateAverage(false);
-		
-		qFile << '>' << seqName << '\t' << aveQScore << endl;
-		
-		for(int i=0;i<seqLength;i++){
-			qFile << qScores[i] << ' ';
-		}
-		qFile << endl;
-				
+
+	    double expected_errors = calculateExpectedErrors();
+
+			qFile << '>' << seqName << '\t' << expected_errors << endl;
+
+			for(int i=0;i<seqLength;i++){ qFile << qScores[i] << ' '; } qFile << endl;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "printQScores");
 		exit(1);
-	}							
+	}
 }
 /**************************************************************************************************/
 
 void QualityScores::printQScores(ostream& qFile){
     try {
-        
-        double aveQScore = calculateAverage(false);
-        
-        qFile << '>' << seqName << '\t' << aveQScore << endl;
-        
+
+        double expected_errors = calculateExpectedErrors();
+
+        qFile << '>' << seqName << '\t' << expected_errors << endl;
+
         for(int i=0;i<seqLength;i++){
             qFile << qScores[i] << ' ';
         }
         qFile << endl;
-        
+
     }
     catch(exception& e) {
         m->errorOut(e, "QualityScores", "printQScores");
         exit(1);
-    }							
+    }
 }
 
 
@@ -316,18 +377,18 @@ void QualityScores::printQScores(ostream& qFile){
 void QualityScores::trimQScores(int start, int end){
 	try {
 		vector<int> hold;
-		
+
 
 		//cout << seqName << '\t' << start << '\t' << end << '\t' << qScores.size() << endl;
 		//for (int i = 0; i < qScores.size(); i++) { cout << qScores[i] << end; }
-		if(end == -1){		
+		if(end == -1){
 			hold = vector<int>(qScores.begin()+start, qScores.end());
-			qScores = hold;		
+			qScores = hold;
 		}
 		if(start == -1){
 			if(qScores.size() > end){
 				hold = vector<int>(qScores.begin(), qScores.begin()+end);
-				qScores = hold;		
+				qScores = hold;
 			}
 		}
 
@@ -336,24 +397,24 @@ void QualityScores::trimQScores(int start, int end){
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "trimQScores");
 		exit(1);
-	}							
+	}
 }
 
 /**************************************************************************************************/
 
 void QualityScores::flipQScores(){
 	try {
-		
+
 		vector<int> temp = qScores;
 		for(int i=0;i<seqLength;i++){
 			qScores[seqLength - i - 1] = temp[i];
 		}
-		
+
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "flipQScores");
 		exit(1);
-	}							
+	}
 }
 
 /**************************************************************************************************/
@@ -362,12 +423,12 @@ bool QualityScores::stripQualThreshold(Sequence& sequence, double qThreshold){
 	try {
 		string rawSequence = sequence.getUnaligned();
 		int seqLength = sequence.getNumBases();
-		
+
 		if(seqName != sequence.getName()){
 			m->mothurOut("sequence name mismatch btwn fasta: " + sequence.getName() + " and qual file: " + seqName);
-			m->mothurOutEndLine();	m->control_pressed = true;
+			m->mothurOutEndLine();	m->setControl_pressed(true);
 		}
-		
+
 		int end;
 		for(int i=0;i<seqLength;i++){
 			end = i;
@@ -375,20 +436,20 @@ bool QualityScores::stripQualThreshold(Sequence& sequence, double qThreshold){
 				break;
 			}
 		}
-		
+
 		//every score passed
 		if (end == (seqLength-1)) { end = seqLength; }
-		
+
 		sequence.setUnaligned(rawSequence.substr(0,end));
 		trimQScores(-1, end);
-		
+
 		return 1;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "flipQScores");
 		exit(1);
-	}							
-	
+	}
+
 }
 
 /**************************************************************************************************/
@@ -397,49 +458,49 @@ bool QualityScores::stripQualRollingAverage(Sequence& sequence, double qThreshol
 	try {
 		string rawSequence = sequence.getUnaligned();
 		int seqLength = sequence.getNumBases();
-		
+
 		if(seqName != sequence.getName()){
 			m->mothurOut("sequence name mismatch btwn fasta: " + sequence.getName() + " and qual file: " + seqName);
-			m->mothurOutEndLine();	
+			m->mothurOutEndLine();
 		}
-		
+
 		int end = -1;
 		double rollingSum = 0.0000;
         double value = 0.0;
-		
+
 		for(int i=0;i<seqLength;i++){
-            
+
             if (logTransform)   {
                 rollingSum += (double)pow(10.0, qScores[i]);
                 value = log10(rollingSum / (double)(i+1));
-                
+
             } //Sum 10^Q
             else                {
                 rollingSum += (double)qScores[i];
                 value = rollingSum / (double)(i+1);
             }
-			
-			
+
+
 			if(value < qThreshold){
 				end = i;
 				break;
 			}
 		}
-		
+
 		if(end == -1){	end = seqLength;	}
-		
-		
+
+
 		sequence.setUnaligned(rawSequence.substr(0,end));
 		trimQScores(-1, end);
-		
-		
+
+
 		return 1;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "flipQScores");
 		exit(1);
-	}							
-	
+	}
+
 }
 
 /**************************************************************************************************/
@@ -448,17 +509,17 @@ bool QualityScores::stripQualWindowAverage(Sequence& sequence, int stepSize, int
 	try {
 		string rawSequence = sequence.getUnaligned();
 		int seqLength = sequence.getNumBases();
-		
+
 		if(seqName != sequence.getName()){
 			m->mothurOut("sequence name mismatch between fasta: " + sequence.getName() + " and qual file: " + seqName);
 			m->mothurOutEndLine();
 		}
-		
+
 		int end = windowSize;
 		int start = 0;
 
 		if(seqLength < windowSize) {	return 0;	}
-			
+
 		while((start+windowSize) < seqLength){
 			double windowSum = 0.0000;
 
@@ -469,50 +530,63 @@ bool QualityScores::stripQualWindowAverage(Sequence& sequence, int stepSize, int
 			double windowAverage = 0.0;
             if (logTransform)   { windowAverage = log10(windowSum / (double)(end-start)); }
             else                { windowAverage = windowSum / (double)(end-start);      }
-				
+
 			if(windowAverage < qThreshold){
 				end = end - stepSize;
 				break;
 			}
-			
+
 			start += stepSize;
 			end = start + windowSize;
-				
+
 			if(end >= seqLength){	end = seqLength;	}
-				
+
 		}
-	
+
 		if(end == -1){	end = seqLength;	}
-		
+
 		//failed first window
 		if (end < windowSize) { return 0; }
-			
+
 		sequence.setUnaligned(rawSequence.substr(0,end));
 		trimQScores(-1, end);
-		
+
 		return 1;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "stripQualWindowAverage");
 		exit(1);
-	}							
-	
+	}
+
+}
+
+/**************************************************************************************************/
+
+double QualityScores::calculateExpectedErrors(void){
+
+	double expected_errors = 0.0000;
+
+	for(int i=0;i<seqLength;i++){
+        expected_errors += pow(10.0, -qScores[i]/10.0);
+	}
+
+	return expected_errors;
 }
 
 /**************************************************************************************************/
 
 double QualityScores::calculateAverage(bool logTransform){
-	
+
 	double aveQScore = 0.0000;
-	
+
 	for(int i=0;i<seqLength;i++){
         if (logTransform)   {  aveQScore += pow(10.0, qScores[i]);  }
         else                {  aveQScore += qScores[i];             }
 	}
-    
+
     if (logTransform)   {  aveQScore = log10(aveQScore /(double) seqLength);    }
     else                {  aveQScore /= (double) seqLength;                     }
-	
+
 	return aveQScore;
 }
 
@@ -522,19 +596,19 @@ bool QualityScores::cullQualAverage(Sequence& sequence, double qAverage, bool lo
 	try {
 		string rawSequence = sequence.getUnaligned();
 		bool success = 0;	//guilty until proven innocent
-		
+
 		if(seqName != sequence.getName())	{
 			m->mothurOut("sequence name mismatch btwn fasta: " + sequence.getName() + " and qual file: " + seqName);
-			m->mothurOutEndLine();	
-		} 
-			
+			m->mothurOutEndLine();
+		}
+
 		double aveQScore = calculateAverage(logTransform);
-		
-        if (m->debug) { m->mothurOut("[DEBUG]: " + sequence.getName() + " average = " + toString(aveQScore) + "\n"); }
-        
+
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: " + sequence.getName() + " average = " + toString(aveQScore) + "\n"); }
+
 		if(aveQScore >= qAverage)	{	success = 1;	}
 		else						{	success = 0;	}
-		
+
 		return success;
 	}
 	catch(exception& e) {
@@ -549,11 +623,11 @@ void QualityScores::updateQScoreErrorMap(map<char, vector<int> >& qualErrorMap,
 	try {
 
 		int seqLength = errorSeq.size();
-		
+
 		int qIndex = start - 1;
 
 		for(int i=0;i<seqLength;i++){
-			
+
 			if(errorSeq[i] == 'm')		{	qualErrorMap['m'][qScores[qIndex]] += weight;	}
 			else if(errorSeq[i] == 's')	{	qualErrorMap['s'][qScores[qIndex]] += weight;	}
 			else if(errorSeq[i] == 'i')	{	qualErrorMap['i'][qScores[qIndex]] += weight;	}
@@ -561,9 +635,9 @@ void QualityScores::updateQScoreErrorMap(map<char, vector<int> >& qualErrorMap,
 			else if(errorSeq[i] == 'd')	{	/*	there are no qScores for deletions	*/		}
 
 			if(errorSeq[i] != 'd')		{	qIndex++;	}
-						
+
 			if(qIndex > stop){	break;	}
-		}	
+		}
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "updateQScoreErrorMap");
@@ -575,12 +649,12 @@ void QualityScores::updateQScoreErrorMap(map<char, vector<int> >& qualErrorMap,
 
 void QualityScores::updateForwardMap(vector<vector<int> >& forwardMap, int start, int stop, int weight){
 	try {
-		
+
 		int index = 0;
 		for(int i=start-1;i<stop;i++){
 			forwardMap[index++][qScores[i]] += weight;
 		}
-		
+
 	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "updateForwardMap");
@@ -592,13 +666,13 @@ void QualityScores::updateForwardMap(vector<vector<int> >& forwardMap, int start
 
 void QualityScores::updateReverseMap(vector<vector<int> >& reverseMap, int start, int stop, int weight){
 	try {
-		
+
 		int index = 0;
 		for(int i=stop-1;i>=start-1;i--){
 			reverseMap[index++][qScores[i]] += weight;
 		}
-		
-	}	
+
+	}
 	catch(exception& e) {
 		m->errorOut(e, "QualityScores", "updateReverseMap");
 		exit(1);
