@@ -8,7 +8,6 @@
  */
 
 #include "sabundvector.hpp"
-#include "calculator.h"
 
 /***********************************************************************/
 
@@ -126,8 +125,7 @@ void SAbundVector::quicksort(){
 /***********************************************************************/
 
 int SAbundVector::sum(){
-	VecCalc vecCalc;
-	return vecCalc.sumElements(data);
+	return util.sum(data);
 }
 
 /***********************************************************************/
@@ -238,7 +236,7 @@ OrderVector SAbundVector::getOrderVector(map<string,int>* hold){
 			}
 		}
 	
-		m->mothurRandomShuffle(ov);
+		util.mothurRandomShuffle(ov);
 
 		ov.setLabel(label);
 		ov.getNumBins();
