@@ -21,7 +21,7 @@ Sequence::Sequence(string newName, string sequence) {
 		initialize();	
 		name = newName;
         
-        m->checkName(name);
+        util.checkName(name);
 		
 		//setUnaligned removes any gap characters for us
 		setUnaligned(sequence);
@@ -39,7 +39,7 @@ Sequence::Sequence(string newName, string sequence, string justUnAligned) {
 		initialize();	
 		name = newName;
         
-        m->checkName(name);
+        util.checkName(name);
 		
 		//setUnaligned removes any gap characters for us
 		setUnaligned(sequence);
@@ -59,7 +59,7 @@ Sequence::Sequence(istringstream& fastaString){
 		initialize();
         name = getSequenceName(fastaString);
 		
-		if (!m->control_pressed) { 
+		if (!m->getControl_pressed()) { 
 			string sequence;
 		
 			//read comments
@@ -104,7 +104,7 @@ Sequence::Sequence(istringstream& fastaString, string JustUnaligned){
 		initialize();
 		name = getSequenceName(fastaString);
 		
-		if (!m->control_pressed) { 
+		if (!m->getControl_pressed()) { 
 			string sequence;
 		
 			//read comments
@@ -150,7 +150,7 @@ Sequence::Sequence(ifstream& fastaFile){
 		initialize();
 		name = getSequenceName(fastaFile);
 		
-		if (!m->control_pressed) { 
+		if (!m->getControl_pressed()) { 
 			
 			string sequence;
 		
@@ -197,7 +197,7 @@ Sequence::Sequence(boost::iostreams::filtering_istream& fastaFile){
         initialize();
         name = getSequenceName(fastaFile);
         
-        if (!m->control_pressed) {
+        if (!m->getControl_pressed()) {
             
             string sequence;
             
@@ -246,7 +246,7 @@ Sequence::Sequence(ifstream& fastaFile, string& extraInfo, bool getInfo){
 		
 		name = getSequenceName(fastaFile);
 		
-		if (!m->control_pressed) { 			
+		if (!m->getControl_pressed()) { 			
 			string sequence;
             
 			//read comments
@@ -296,7 +296,7 @@ Sequence::Sequence(ifstream& fastaFile, string JustUnaligned){
 		initialize();
 		name = getSequenceName(fastaFile);
 		
-		if (!m->control_pressed) { 
+		if (!m->getControl_pressed()) { 
 			string sequence;
 			
 			//read comments
@@ -343,9 +343,9 @@ string Sequence::getSequenceName(ifstream& fastaFile) {
             
 			name = name.substr(1); 
             
-            m->checkName(name);
+            util.checkName(name);
             
-        }else{ m->mothurOut("Error in reading your fastafile, at position " + toString(fastaFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->control_pressed = true;  }
+        }else{ if (!fastaFile.eof()) { m->mothurOut("Error in reading your fastafile, at position " + toString(fastaFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->setControl_pressed(true);  } }
         
 		return name;
 	}
@@ -366,9 +366,9 @@ string Sequence::getSequenceName(boost::iostreams::filtering_istream& fastaFile)
             
             name = name.substr(1);
             
-            m->checkName(name);
+            util.checkName(name);
             
-        }else{ m->mothurOut("Error in reading your fastafile, at position " + toString(fastaFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->control_pressed = true;  }
+        }else{ if (!fastaFile.eof()) { m->mothurOut("Error in reading your fastafile, at position " + toString(fastaFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->setControl_pressed(true);  }  }
         
         return name;
     }
@@ -389,9 +389,9 @@ string Sequence::getSequenceName(istringstream& fastaFile) {
             
 			name = name.substr(1); 
             
-            m->checkName(name);
+            util.checkName(name);
             
-        }else{ m->mothurOut("Error in reading your fastafile, at position " + toString(fastaFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->control_pressed = true;  }
+        }else{ if (!fastaFile.eof()) { m->mothurOut("Error in reading your fastafile, at position " + toString(fastaFile.tellg()) + ". Blank name."); m->mothurOutEndLine(); m->setControl_pressed(true);  }  }
         
 		return name;
 	}
@@ -474,7 +474,7 @@ string Sequence::getCommentString(ifstream& fastaFile) {
 		while(fastaFile){
 			letter=fastaFile.get();
 			if((letter == '\r') || (letter == '\n') || letter == -1){
-				m->gobble(fastaFile);  //in case its a \r\n situation
+				util.gobble(fastaFile);  //in case its a \r\n situation
 				break;
 			}else {
                 temp += letter;
@@ -499,7 +499,7 @@ string Sequence::getCommentString(boost::iostreams::filtering_istream& fastaFile
         while(fastaFile){
             letter=fastaFile.get();
             if((letter == '\r') || (letter == '\n') || letter == -1){
-                m->gobble(fastaFile);  //in case its a \r\n situation
+                util.gobble(fastaFile);  //in case its a \r\n situation
                 break;
             }else {
                 temp += letter;
@@ -556,7 +556,7 @@ string Sequence::getCommentString(istringstream& fastaFile) {
 		while(fastaFile){
 			letter=fastaFile.get();
 			if((letter == '\r') || (letter == '\n') || letter == -1){  
-				m->gobble(fastaFile);  //in case its a \r\n situation
+				util.gobble(fastaFile);  //in case its a \r\n situation
 				break;
 			}else {
                 temp += letter;
@@ -612,6 +612,10 @@ void Sequence::setUnaligned(string sequence){
 		unaligned = sequence;
 	}
 	numBases = unaligned.length();
+    startPos = -1;
+    endPos = -1;
+    longHomoPolymer = -1;
+    ambigBases = -1;
 	
 }
 
@@ -642,7 +646,7 @@ void Sequence::setAligned(string sequence){
 			}
 		}
 	}
-	isAligned = 1;	
+	isAligned = 1;
 }
 
 //********************************************************************************************************************
@@ -720,7 +724,15 @@ int Sequence::getNumNs(){
     }
     return numNs;
 }
-
+//********************************************************************************************************************
+void Sequence::printSequence(OutputWriter* out){
+    string seqOutput = ">";
+    seqOutput += name + '\t' + comment + '\n';
+    if(isAligned){ seqOutput += aligned + '\n'; }
+    else{ seqOutput += unaligned + '\n'; }
+    
+    out->write(seqOutput);
+}
 //********************************************************************************************************************
 
 void Sequence::printSequence(ostream& out){
@@ -907,8 +919,8 @@ void Sequence::reverseComplement(){
 		else if(unaligned[i] == 'C'){	temp += 'G';	}
 		else						{	temp += 'N';	}
 	}
-	unaligned = temp;
-	aligned = temp;
+	
+	setAligned(temp);
 	
 }
 
