@@ -19,7 +19,8 @@
 
 #include "mothur.h"
 #include "mothurout.h"
-
+#include "utils.hpp"
+#include "writer.h"
 
 /**************************************************************************************************/
 
@@ -74,6 +75,7 @@ public:
 	int getLongHomoPolymer();
 	bool getIsAligned();
 	void printSequence(ostream&);
+    void printSequence(OutputWriter*);
     void printUnAlignedSequence(ostream&);
 	
 private:
@@ -101,6 +103,7 @@ private:
 	int longHomoPolymer;
 	int ambigBases;
 	int startPos, endPos;
+    Utils util;
 };
 
 /**************************************************************************************************/
