@@ -12,55 +12,68 @@
 #include "ordervector.hpp"
 #include "sharedlistvector.h"
 #include "sharedordervector.h"
-#include "sharedutilities.h"
+
 
 /***********************************************************************/
 
-SharedListVector::SharedListVector() : DataVector(), maxRank(0), numBins(0), numSeqs(0){ groupmap = NULL; countTable = NULL; }
+//SharedListVector::SharedListVector() : DataVector(), maxRank(0), numBins(0), numSeqs(0){ groupmap = NULL; countTable = NULL; fillGroups = true; }
 
 /***********************************************************************/
 
-SharedListVector::SharedListVector(int n):	DataVector(), data(n, "") , maxRank(0), numBins(0), numSeqs(0){ groupmap = NULL; countTable = NULL; }
+//SharedListVector::SharedListVector(int n):	DataVector(), data(n, "") , maxRank(0), numBins(0), numSeqs(0){ groupmap = NULL; countTable = NULL; fillGroups = true;  }
 
 /***********************************************************************/
-SharedListVector::SharedListVector(ifstream& f) : DataVector(), maxRank(0), numBins(0), numSeqs(0) {
+SharedListVector::SharedListVector(ifstream& f, vector<string>& userGroups, string& previousLabel, string& labelTag) : DataVector(), maxRank(0), numBins(0), numSeqs(0) {
 	try {
+        Utils util;
+        groups = userGroups; fillGroups = true;
+        if (groups.size() > 0) { fillGroups = false; }
+        
+        CurrentFile* current = CurrentFile::getInstance();
+        groupMode = current->getGroupMode();
         groupmap = NULL; countTable = NULL;
 		//set up groupmap for later.
-        if (m->groupMode == "group") {
-            groupmap = new GroupMap(m->getGroupFile());
-            groupmap->readMap(); 
+        if (groupMode == "group") {
+            groupmap = new GroupMap(current->getGroupFile());
+            groupmap->readMap();
+            if (fillGroups) { groups = groupmap->getNamesOfGroups(); m->mothurOut("[ERROR]: requesting groups not present in files, aborting.\n"); fillGroups = false; }
+            else { if (!util.isSubset(groupmap->getNamesOfGroups(), groups)) { m->mothurOut("[ERROR]: requesting groups not present in files, aborting.\n"); m->setControl_pressed(true); } }
         }else {
             countTable = new CountTable();
-            countTable->readTable(m->getCountTableFile(), true, false);
+            countTable->readTable(current->getCountFile(), true, false);
+            if (fillGroups) { groups = countTable->getNamesOfGroups(); fillGroups = false; }
+            else { if (!util.isSubset(countTable->getNamesOfGroups(), groups)) { m->mothurOut("[ERROR]: requesting groups not present in files, aborting.\n"); m->setControl_pressed(true); } }
         }
 
         int hold;
         
-		//are we at the beginning of the file??
-		if (m->saveNextLabel == "") {
+		//are we at the beginning of the file?? If yes, read or create headers
+		if (previousLabel == "") {
 			f >> label;
             
 			//is this a shared file that has headers
 			if (label == "label") {
 				
 				//gets "numOtus"
-				f >> label; m->gobble(f);
+				f >> label; util.gobble(f);
 				
 				//eat rest of line
-				label = m->getline(f); m->gobble(f);
+				label = util.getline(f); util.gobble(f);
 				
 				//parse labels to save
 				istringstream iStringStream(label);
-				m->listBinLabelsInFile.clear();
 				while(!iStringStream.eof()){
-					if (m->control_pressed) { break; }
+					if (m->getControl_pressed()) { break; }
 					string temp;
-					iStringStream >> temp;  m->gobble(iStringStream);
+					iStringStream >> temp;  util.gobble(iStringStream);
                     
-					m->listBinLabelsInFile.push_back(temp);
+					binLabels.push_back(temp);
 				}
-				
+                if (binLabels.size() != 0) {
+                    string binLabelTag = binLabels[0];
+                    labelTag = "";
+                    for (int i = 0; i < binLabelTag.length(); i++) { if (isalpha(binLabelTag[i])){ labelTag += binLabelTag[i]; } }
+                }
 				f >> label >> hold;
 			}else {
                 //read in first row
@@ -68,38 +81,32 @@ SharedListVector::SharedListVector(ifstream& f) : DataVector(), maxRank(0), numB
                 
                 //make binlabels because we don't have any
                 string snumBins = toString(hold);
-                m->listBinLabelsInFile.clear();
+                if (labelTag == "") { labelTag = "Otu"; }
                 for (int i = 0; i < hold; i++) {
                     //if there is a bin label use it otherwise make one
-                    string binLabel = "Otu";
+                    string binLabel = labelTag;
                     string sbinNumber = toString(i+1);
                     if (sbinNumber.length() < snumBins.length()) {
                         int diff = snumBins.length() - sbinNumber.length();
                         for (int h = 0; h < diff; h++) { binLabel += "0"; }
                     }
                     binLabel += sbinNumber;
-                    m->listBinLabelsInFile.push_back(binLabel);
+                    binLabels.push_back(binLabel);
                 }
             }
-            m->saveNextLabel = label;
-		}else {
-            f >> label >> hold;
-            m->saveNextLabel = label;
-        }
+            
+		}else {  f >> label >> hold; }
         
-        binLabels.assign(m->listBinLabelsInFile.begin(), m->listBinLabelsInFile.begin()+hold);
-		
 		data.assign(hold, "");
 		string inputData = "";
+        otuTag = labelTag;
+        previousLabel = label;
         
 		for(int i=0;i<hold;i++){
 			f >> inputData;
 			set(i, inputData);
 		}
-		m->gobble(f);
-        
-        if (f.eof()) { m->saveNextLabel = ""; }
-		
+		util.gobble(f);
 	}
 	catch(exception& e) {
 		m->errorOut(e, "SharedListVector", "SharedListVector");
@@ -110,9 +117,10 @@ SharedListVector::SharedListVector(ifstream& f) : DataVector(), maxRank(0), numB
 /***********************************************************************/
 void SharedListVector::set(int binNumber, string seqNames){
 	try {
-		int nNames_old = m->getNumNames(data[binNumber]);
+        Utils util;
+		int nNames_old = util.getNumNames(data[binNumber]);
 		data[binNumber] = seqNames;
-		int nNames_new = m->getNumNames(seqNames);
+		int nNames_new = util.getNumNames(seqNames);
 	
 		if(nNames_old == 0)			{	numBins++;				}
 		if(nNames_new == 0)			{	numBins--;				}
@@ -138,6 +146,7 @@ string SharedListVector::get(int index){
 void SharedListVector::setLabels(vector<string> labels){
 	try {
 		binLabels = labels;
+        getLabels();
 	}
 	catch(exception& e) {
 		m->errorOut(e, "SharedListVector", "setLabels");
@@ -151,34 +160,7 @@ void SharedListVector::setLabels(vector<string> labels){
 //if you had a listfile that had been subsampled and then added to it, dup names would be possible.
 vector<string> SharedListVector::getLabels(){
     try {
-        string tagHeader = "Otu";
-        if (m->sharedHeaderMode == "tax") { tagHeader = "PhyloType"; }
-        
-        if (binLabels.size() < data.size()) {
-            string snumBins = toString(numBins);
-            
-            for (int i = 0; i < numBins; i++) {
-                string binLabel = tagHeader;
-                
-                if (i < binLabels.size()) { //label exists, check leading zeros length
-                    string sbinNumber = m->getSimpleLabel(binLabels[i]);
-                    if (sbinNumber.length() < snumBins.length()) {
-                        int diff = snumBins.length() - sbinNumber.length();
-                        for (int h = 0; h < diff; h++) { binLabel += "0"; }
-                    }
-                    binLabel += sbinNumber;
-                    binLabels[i] = binLabel;
-                }else{
-                    string sbinNumber = toString(i+1);
-                    if (sbinNumber.length() < snumBins.length()) {
-                        int diff = snumBins.length() - sbinNumber.length();
-                        for (int h = 0; h < diff; h++) { binLabel += "0"; }
-                    }
-                    binLabel += sbinNumber;
-                    binLabels.push_back(binLabel);
-                }
-            }
-        }
+        Utils util; util.getOTUNames(binLabels, numBins, otuTag);
         return binLabels;
     }
 	catch(exception& e) {
@@ -190,14 +172,45 @@ vector<string> SharedListVector::getLabels(){
 
 void SharedListVector::push_back(string seqNames){
 	try {
+        Utils util;
 		data.push_back(seqNames);
-		int nNames = m->getNumNames(seqNames);
+		int nNames = util.getNumNames(seqNames);
 	
 		numBins++;
 	
 		if(nNames > maxRank)	{	maxRank = nNames;	}
 	
 		numSeqs += nNames;
+    
+        int otuNum = numBins; bool notDone = true;
+        
+        //find label prefix
+        string prefix = "Otu";
+        if (binLabels[binLabels.size()-1][0] == 'P') { prefix = "PhyloType"; }
+        
+        string tempLabel = binLabels[binLabels.size()-1];
+        string simpleLastLabel = util.getSimpleLabel(tempLabel);
+        util.mothurConvert(simpleLastLabel, otuNum); otuNum++;
+        string potentialLabel = toString(otuNum);
+        
+        while (notDone) {
+            if (m->getControl_pressed()) { notDone = false; break; }
+            
+            potentialLabel = toString(otuNum);
+            vector<string>::iterator it = find(binLabels.begin(), binLabels.end(), potentialLabel);
+            if (it == binLabels.end()) {
+                potentialLabel = prefix + toString(otuNum);
+                it = find(binLabels.begin(), binLabels.end(), potentialLabel);
+                if (it == binLabels.end()) {
+                    notDone = false; break;
+                }
+            }
+            otuNum++;
+        }
+        
+       
+        binLabels.push_back(potentialLabel);
+
 	}
 	catch(exception& e) {
 		m->errorOut(e, "SharedListVector", "push_back");
@@ -222,6 +235,7 @@ void SharedListVector::clear(){
 	numBins = 0;
 	maxRank = 0;
 	numSeqs = 0;
+    binLabels.clear();
 	return data.clear();
 	
 }
@@ -251,9 +265,9 @@ void SharedListVector::print(ostream& output){
 RAbundVector SharedListVector::getRAbundVector(){
 	try {
 		RAbundVector rav;
-	
+        Utils util;
 		for(int i=0;i<data.size();i++){
-			int binSize = m->getNumNames(data[i]);
+			int binSize = util.getNumNames(data[i]);
 			rav.push_back(binSize);
 		}
 	
@@ -281,9 +295,9 @@ RAbundVector SharedListVector::getRAbundVector(){
 SAbundVector SharedListVector::getSAbundVector(){
 	try {
 		SAbundVector sav(maxRank+1);
-	
+        Utils util;
 		for(int i=0;i<data.size();i++){
-			int binSize = m->getNumNames(data[i]);	
+			int binSize = util.getNumNames(data[i]);	
 			sav.set(binSize, sav.get(binSize) + 1);	
 		}
 		sav.set(0, 0);
@@ -302,35 +316,34 @@ SharedOrderVector* SharedListVector::getSharedOrderVector(){
 	try {
 		SharedOrderVector* order = new SharedOrderVector();
 		order->setLabel(label);
-	
+        Utils util;
 		for(int i=0;i<numBins;i++){
-			int binSize = m->getNumNames(get(i));	//find number of individual in given bin	
+			int binSize = util.getNumNames(get(i));	//find number of individual in given bin	
 			string names = get(i);
             vector<string> binNames;
-            m->splitAtComma(names, binNames);
-            if (m->groupMode != "group") {
+            util.splitAtComma(names, binNames);
+            if (groupMode != "group") {
                 binSize = 0;
                 for (int j = 0; j < binNames.size(); j++) {  binSize += countTable->getNumSeqs(binNames[i]);  }
             }
 			for (int j = 0; j < binNames.size(); j++) { 
-                if (m->control_pressed) { return order; }
-                if (m->groupMode == "group") {
+                if (m->getControl_pressed()) { return order; }
+                if (groupMode == "group") {
                     string groupName = groupmap->getGroup(binNames[i]);
                     if(groupName == "not found") {	m->mothurOut("Error: Sequence '" + binNames[i] + "' was not found in the group file, please correct."); m->mothurOutEndLine();  exit(1); }
-				
-                    order->push_back(i, binSize, groupName);  //i represents what bin you are in
+                    if (util.inUsersGroups(groupName, groups)) { order->push_back(i, binSize, groupName);  }//i represents what bin you are in
                 }else {
                     vector<int> groupAbundances = countTable->getGroupCounts(binNames[i]);
                     vector<string> groupNames = countTable->getNamesOfGroups();
                     for (int k = 0; k < groupAbundances.size(); k++) { //groupAbundances.size() == 0 if there is a file mismatch and m->control_pressed is true.
-                        if (m->control_pressed) { return order; }
-                        for (int l = 0; l < groupAbundances[k]; l++) {  order->push_back(i, binSize, groupNames[k]);  }
+                        if (m->getControl_pressed()) { return order; }
+                        for (int l = 0; l < groupAbundances[k]; l++) {  if (util.inUsersGroups(groupNames[k], groups)) { order->push_back(i, binSize, groupNames[k]); } }
                     }
                 }
 			}
 		}
 
-		m->mothurRandomShuffle(*order);
+		util.mothurRandomShuffle(*order);
 		order->updateStats();
 		
 		return order;
@@ -341,132 +354,85 @@ SharedOrderVector* SharedListVector::getSharedOrderVector(){
 	}
 }
 /***********************************************************************/
-SharedRAbundVector SharedListVector::getSharedRAbundVector(string groupName) {
+SharedRAbundVectors* SharedListVector::getSharedRAbundVector() {
 	try {
-        m->currentSharedBinLabels = binLabels;
+        vector<SharedRAbundVector*> lookup;  //contains just the groups the user selected
+        //vector<string> groups;
+        map<string, SharedRAbundVector*> finder;  //contains all groups in groupmap
+        map<string, SharedRAbundVector*>::iterator it;
         
-		SharedRAbundVector rav(data.size());
-		
-		for(int i=0;i<numBins;i++){
-			string names = get(i);
-            vector<string> binNames;
-            m->splitAtComma(names, binNames);
-            for (int j = 0; j < binNames.size(); j++) { 
-				if (m->control_pressed) { return rav; }
-                if (m->groupMode == "group") {
-                    string group = groupmap->getGroup(binNames[j]);
-                    if(group == "not found") {	m->mothurOut("Error: Sequence '" + binNames[j] + "' was not found in the group file, please correct."); m->mothurOutEndLine();  exit(1); }
-                    if (group == groupName) { //this name is in the group you want the vector for.
-                        rav.set(i, rav.getAbundance(i) + 1, group);  //i represents what bin you are in
-                    }
-                }else {
-                    int count = countTable->getGroupCount(binNames[j], groupName);
-                    rav.set(i, rav.getAbundance(i) + count, groupName);
-                }
-			}
-		}
-		
-		rav.setLabel(label);
-		rav.setGroup(groupName);
-
-		return rav;
-		
-	}
-	catch(exception& e) {
-		m->errorOut(e, "SharedListVector", "getSharedRAbundVector");
-		exit(1);
-	}
-}
-/***********************************************************************/
-vector<SharedRAbundVector*> SharedListVector::getSharedRAbundVector() {
-	try {
-        m->currentSharedBinLabels = binLabels;
-        
-		SharedUtil* util;
-		util = new SharedUtil();
-		vector<SharedRAbundVector*> lookup;  //contains just the groups the user selected
-        vector<SharedRAbundVector*> lookupDelete;
-		map<string, SharedRAbundVector*> finder;  //contains all groups in groupmap
-		
-		vector<string> Groups = m->getGroups();
-        vector<string> allGroups;
-		if (m->groupMode == "group") {  allGroups = groupmap->getNamesOfGroups();  }
-        else {  allGroups = countTable->getNamesOfGroups();  }
-		util->setGroups(Groups, allGroups);
-		m->setGroups(Groups);
-		delete util;
-
-		for (int i = 0; i < allGroups.size(); i++) {
-			SharedRAbundVector* temp = new SharedRAbundVector(data.size());
-			finder[allGroups[i]] = temp;
-			finder[allGroups[i]]->setLabel(label);
-			finder[allGroups[i]]->setGroup(allGroups[i]);
-			if (m->inUsersGroups(allGroups[i], m->getGroups())) {  //if this group is in user groups
-				lookup.push_back(finder[allGroups[i]]);
-			}else {
-                lookupDelete.push_back(finder[allGroups[i]]);
-            }
-		}
-	
+		for (int i = 0; i < groups.size(); i++) {
+            SharedRAbundVector* temp = new SharedRAbundVector(numBins);
+            finder[groups[i]] = temp;
+            finder[groups[i]]->setLabel(label);
+            finder[groups[i]]->setGroup(groups[i]);
+            lookup.push_back(finder[groups[i]]);
+        }
+        Utils util;
 		//fill vectors
 		for(int i=0;i<numBins;i++){
 			string names = get(i);  
 			vector<string> binNames;
-            m->splitAtComma(names, binNames);
+            util.splitAtComma(names, binNames);
             for (int j = 0; j < binNames.size(); j++) { 
-                if (m->groupMode == "group") {
+                if (groupMode == "group") {
                     string group = groupmap->getGroup(binNames[j]);
                     if(group == "not found") {	m->mothurOut("Error: Sequence '" + binNames[j] + "' was not found in the group file, please correct."); m->mothurOutEndLine();  exit(1); }
-                    finder[group]->set(i, finder[group]->getAbundance(i) + 1, group);  //i represents what bin you are in	
+                    it = finder.find(group);
+                    if (it != finder.end()) { it->second->set(i, it->second->get(i) + 1); } //i represents what bin you are in
                 }else{
                     vector<int> counts = countTable->getGroupCounts(binNames[j]);
+                    vector<string> allGroups = countTable->getNamesOfGroups();
                     for (int k = 0; k < allGroups.size(); k++) {
-                        finder[allGroups[k]]->set(i, finder[allGroups[k]]->getAbundance(i) + counts[k], allGroups[k]);
+                        it = finder.find(allGroups[k]);
+                        if (it != finder.end()) { it->second->set(i, it->second->get(i) + counts[k]); } //i represents what bin you are in
                     }
                 }
 			}
 		}
         
-        for (int j = 0; j < lookupDelete.size(); j++) {  delete lookupDelete[j];  }
+        SharedRAbundVectors* shared = new SharedRAbundVectors();
+        for (int j = 0; j < lookup.size(); j++) {  shared->push_back(lookup[j]);  }
+        shared->setOTUNames(binLabels);
+        shared->eliminateZeroOTUS();
 
-		return lookup;
+		return shared;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "SharedListVector", "getSharedRAbundVector");
 		exit(1);
 	}
 }
-
 /***********************************************************************/
-SharedSAbundVector SharedListVector::getSharedSAbundVector(string groupName) {
-	try { 
-		SharedSAbundVector sav;
-		SharedRAbundVector rav;
-		
-		rav = this->getSharedRAbundVector(groupName);
-		sav = rav.getSharedSAbundVector();
-		
-		return sav;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "SharedListVector", "getSharedSAbundVector");
-		exit(1);
-	}
+SharedRAbundFloatVectors* SharedListVector::getSharedRAbundFloatVector() {
+    try {
+        SharedRAbundVectors* shared = getSharedRAbundVector();
+        vector<SharedRAbundFloatVector*> thisLookup = shared->getSharedRAbundFloatVectors();
+        SharedRAbundFloatVectors* sharedFloat = new SharedRAbundFloatVectors();
+        for (int j = 0; j < thisLookup.size(); j++) {  sharedFloat->push_back(thisLookup[j]);  }
+        return sharedFloat;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "SharedListVector", "getSharedRAbundVector");
+        exit(1);
+    }
 }
+
 /***********************************************************************/
 
 OrderVector SharedListVector::getOrderVector(map<string,int>* orderMap = NULL){
 	
 	try {
+        Utils util;
 		if(orderMap == NULL){
 			OrderVector ov;
 		
 			for(int i=0;i<data.size();i++){
                 string names = data[i];
                 vector<string> binNames;
-                m->splitAtComma(names, binNames);
+                util.splitAtComma(names, binNames);
 				int binSize = binNames.size();	
-                if (m->groupMode != "group") {
+                if (groupMode != "group") {
                     binSize = 0;
                     for (int j = 0; j < binNames.size(); j++) {  binSize += countTable->getNumSeqs(binNames[i]);  }
                 }
@@ -474,7 +440,7 @@ OrderVector SharedListVector::getOrderVector(map<string,int>* orderMap = NULL){
 					ov.push_back(i);
 				}
 			}
-			m->mothurRandomShuffle(ov);
+			util.mothurRandomShuffle(ov);
 			ov.setLabel(label);
 			ov.getNumBins();
 		
@@ -487,7 +453,7 @@ OrderVector SharedListVector::getOrderVector(map<string,int>* orderMap = NULL){
 			for(int i=0;i<data.size();i++){
 				string listOTU = data[i];
 				vector<string> binNames;
-                m->splitAtComma(listOTU, binNames);
+                util.splitAtComma(listOTU, binNames);
                 for (int j = 0; j < binNames.size(); j++) { 
                     if(orderMap->count(binNames[j]) == 0){
                         m->mothurOut(binNames[j] + " not found, check *.names file\n");
