@@ -8,7 +8,7 @@
  */
 
 #include "sharedordervector.h"
-#include "sharedutilities.h"
+
 
 /***********************************************************************/
 
@@ -26,11 +26,13 @@ SharedOrderVector::SharedOrderVector(string id, vector<individual>  ov) :
 //This function is used to read a .shared file for the collect.shared, rarefaction.shared and summary.shared commands
 //if you don't use a list and groupfile.  
 
-SharedOrderVector::SharedOrderVector(ifstream& f) : DataVector() {  //reads in a shared file
+SharedOrderVector::SharedOrderVector(ifstream& f, vector<string>& userGroups, string& previousLabel) : DataVector() {  //reads in a shared file
 	try {
 		maxRank = 0; numBins = 0; numSeqs = 0;
+        int numUserGroups = userGroups.size();
 				
-		groupmap = new GroupMap(); 
+		groupmap = new GroupMap();
+        if (!util.isSubset(groupmap->getNamesOfGroups(), userGroups)) { m->mothurOut("[ERROR]: requesting groups not present in files, aborting.\n"); m->setControl_pressed(true); }
 		
 		int num, inputData, count;
 		count = 0;  numSeqs = 0;
@@ -39,93 +41,110 @@ SharedOrderVector::SharedOrderVector(ifstream& f) : DataVector() {  //reads in a
 		
 		//read in first row since you know there is at least 1 group.
 		//are we at the beginning of the file??
-		if (m->saveNextLabel == "") {  
+		if (previousLabel == "") {
 			f >> label; 
 			
 			//is this a shared file that has headers
 			if (label == "label") { 
 				//gets "group"
-				f >> label; m->gobble(f);
+				f >> label; util.gobble(f);
 				
 				//gets "numOtus"
-				f >> label; m->gobble(f);
+				f >> label; util.gobble(f);
 				
 				//eat rest of line
-				label = m->getline(f); m->gobble(f);
+				label = util.getline(f); util.gobble(f);
 				
 				//parse labels to save
 				istringstream iStringStream(label);
-				m->sharedBinLabelsInFile.clear();
 				while(!iStringStream.eof()){
-					if (m->control_pressed) { break; }
+					if (m->getControl_pressed()) { break; }
 					string temp;
-					iStringStream >> temp;  m->gobble(iStringStream);
+					iStringStream >> temp;  util.gobble(iStringStream);
 					
-					m->sharedBinLabelsInFile.push_back(temp);
+					currentLabels.push_back(temp);
 				}
 				
 				f >> label;
 			}
-		}else { label = m->saveNextLabel; }
-		
-		//reset labels, currentLabels may have gotten changed as otus were eliminated because of group choices or sampling
-		m->currentSharedBinLabels = m->sharedBinLabelsInFile;
+		}else { label = previousLabel; }
 		
 		//read in first row since you know there is at least 1 group.
 		f >> groupN >> num;
+        bool readData = false;
+        if (numUserGroups == 0) { //user has not specified groups, so we will use all of them
+            userGroups.push_back(groupN);
+            readData = true;
+        }else{
+            if (util.inUsersGroups(groupN, userGroups)) { readData = true; }
+            //else - skipline because you are a group we dont care about
+        }
 		
 		holdLabel = label;
+        
+        if (readData) {
+            //save group in groupmap
+            setNamesOfGroups(groupN);
+            groupmap->groupIndex[groupN] = 0;
+            
+            
+            for(int i=0;i<num;i++){
+                f >> inputData;
+                
+                for (int j = 0; j < inputData; j++) {
+                    push_back(i, i, groupN);
+                    numSeqs++;
+                }
+            }
+        } else { util.getline(f); }
 		
-		
-		vector<string> allGroups;
-		//save group in groupmap
-		allGroups.push_back(groupN);
-		groupmap->groupIndex[groupN] = 0;
-		
-		
-		for(int i=0;i<num;i++){
-			f >> inputData;
-			
-			for (int j = 0; j < inputData; j++) {
-				push_back(i, i, groupN);
-				numSeqs++;
-			}
-		}
-		
-		m->gobble(f); 
+		util.gobble(f);
 		
 		if (!(f.eof())) { f >> nextLabel; }
 		
 		//read the rest of the groups info in
 		while ((nextLabel == holdLabel) && (f.eof() != true)) {
 			f >> groupN >> num;
-			count++;
+            
+            bool readData = false;
+            if (numUserGroups == 0) { //user has not specified groups, so we will use all of them
+                userGroups.push_back(groupN);
+                readData = true;
+            }else{
+                if (util.inUsersGroups(groupN, userGroups)) { readData = true; }
+                //else - skipline because you are a group we dont care about
+            }
+
+            if (readData) {
+                count++;
+                
+                //save group in groupmap
+                setNamesOfGroups(groupN);
+                groupmap->groupIndex[groupN] = count;
+                
+                
+                for(int i=0;i<num;i++){
+                    f >> inputData;
+                    
+                    for (int j = 0; j < inputData; j++) {
+                        push_back(i, i, groupN);
+                        numSeqs++;
+                    }
+                }
+            }else { util.getline(f); }
 			
-			
-			//save group in groupmap
-			allGroups.push_back(groupN);
-			groupmap->groupIndex[groupN] = count;
-			
-			
-			for(int i=0;i<num;i++){
-				f >> inputData;
-				
-				for (int j = 0; j < inputData; j++) {
-					push_back(i, i, groupN);
-					numSeqs++;
-				}
-			}
-			
-			m->gobble(f);
+			util.gobble(f);
 				
 			if (f.eof() != true) { f >> nextLabel; }
 
 		}
 		
-		m->saveNextLabel = nextLabel;
+		previousLabel = nextLabel;
+        
+        sort(userGroups.begin(), userGroups.end());
+        for (int i = 0; i < userGroups.size(); i++) { setNamesOfGroups(userGroups[i]); }
 			
 		groupmap->setNamesOfGroups(allGroups);
-		m->setAllGroups(allGroups);
 		
 		updateStats();
 		
@@ -155,11 +174,8 @@ int SharedOrderVector::getMaxRank(){
 
 
 /***********************************************************************/
-
-
-
 void SharedOrderVector::set(int index, int binNumber, int abund, string groupName){
-	
+    setNamesOfGroups(groupName);
 	data[index].group = groupName;
 	data[index].bin = binNumber;
 	data[index].abundance = abund;
@@ -173,11 +189,26 @@ individual SharedOrderVector::get(int index){
 	return data[index];			
 }
 
-
+/************************************************************/
+void SharedOrderVector::setNamesOfGroups(string seqGroup) {
+    int i, count;
+    count = 0;
+    for (i=0; i<allGroups.size(); i++) {
+        if (allGroups[i] != seqGroup) {
+            count++; //you have not found this group
+        }else {
+            break; //you already have it
+        }
+    }
+    if (count == allGroups.size()) {
+        allGroups.push_back(seqGroup); //new group
+    }
+}
 /***********************************************************************/
 //commented updateStats out to improve speed, but whoever calls this must remember to update when they are done with all the pushbacks they are doing 
 void SharedOrderVector::push_back(int binNumber, int abund, string groupName){
-	individual newGuy;
+	setNamesOfGroups(groupName);
+    individual newGuy;
 	newGuy.group = groupName;
 	newGuy.abundance = abund;
 	newGuy.bin = binNumber;
@@ -274,7 +305,7 @@ OrderVector SharedOrderVector::getOrderVector(map<string,int>* nameMap = NULL) {
 			ov.push_back(data[i].bin);
 		}
 		
-		m->mothurRandomShuffle(ov);
+		util.mothurRandomShuffle(ov);
 
 		ov.setLabel(label);	
 		return ov;
@@ -295,19 +326,23 @@ SAbundVector SharedOrderVector::getSAbundVector(){
 
 }
 /***********************************************************************/
-SharedRAbundVector SharedOrderVector::getSharedRAbundVector(string group) {
+SharedRAbundVectors* SharedOrderVector::getSharedRAbundVector(string group) {
 	try {
-		SharedRAbundVector sharedRav(data.size());
+		SharedRAbundVector* sharedRav = new SharedRAbundVector(data.size());
 		
-		sharedRav.setLabel(label);
-		sharedRav.setGroup(group);
+		sharedRav->setLabel(label);
+		sharedRav->setGroup(group);
 		
 		for (int i = 0; i < data.size(); i++) {
 			if (data[i].group == group) {
-				sharedRav.set(data[i].abundance, sharedRav.getAbundance(data[i].abundance) + 1, data[i].group);
+				sharedRav->set(data[i].abundance, sharedRav->get(data[i].abundance) + 1);
 			}
 		}
-		return sharedRav;
+        
+        SharedRAbundVectors* lookup = new SharedRAbundVectors();
+        lookup->setOTUNames(currentLabels);
+        lookup->push_back(sharedRav);
+		return lookup;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "SharedOrderVector", "getSharedRAbundVector");
@@ -315,18 +350,29 @@ SharedRAbundVector SharedOrderVector::getSharedRAbundVector(string group) {
 	}
 }
 /***********************************************************************/
-vector<SharedRAbundVector*> SharedOrderVector::getSharedRAbundVector() {
+SharedRAbundVectors* SharedOrderVector::getSharedRAbundVector() {
 	try {
-		SharedUtil* util;
-		util = new SharedUtil();
-		vector<SharedRAbundVector*> lookup;
-		
-		vector<string> Groups = m->getGroups();
-		vector<string> allGroups = m->getAllGroups();
-		util->setGroups(Groups, allGroups);
-		util->getSharedVectors(Groups, lookup, this);
-		m->setGroups(Groups);
-		m->setAllGroups(allGroups);
+        SharedRAbundVectors* lookup = new SharedRAbundVectors();
+        sort(allGroups.begin(), allGroups.end());
+        
+        //create and initialize vector of sharedvectors, one for each group
+        for (int i = 0; i < allGroups.size(); i++) {
+            SharedRAbundVector* temp = new SharedRAbundVector(numBins);
+            temp->setLabel(getLabel());
+            temp->setGroup(allGroups[i]);
+            lookup->push_back(temp);
+        }
+        
+        int numSeqs = size();
+        //sample all the members
+        for(int i=0;i<numSeqs;i++){
+            //get first sample
+            individual chosen = get(i);
+            int abundance = lookup->get(chosen.bin, chosen.group);
+            lookup->set(chosen.bin, (abundance + 1), chosen.group);
+        }
+        
+        lookup->setOTUNames(currentLabels);
 		
 		return lookup;
 	}
@@ -335,24 +381,10 @@ vector<SharedRAbundVector*> SharedOrderVector::getSharedRAbundVector() {
 		exit(1);
 	}
 }
-/***********************************************************************/
-SharedSAbundVector SharedOrderVector::getSharedSAbundVector(string group) {
-	try {
-		
-		SharedRAbundVector sharedRav(this->getSharedRAbundVector(group));
-		return sharedRav.getSharedSAbundVector();
-				
-	}
-	catch(exception& e) {
-		m->errorOut(e, "SharedOrderVector", "getSharedSAbundVector");
-		exit(1);
-	}
-}
-
 /***********************************************************************/
 
 SharedOrderVector SharedOrderVector::getSharedOrderVector(){
-	m->mothurRandomShuffle(*this);
+	util.mothurRandomShuffle(*this);
 	return *this;			
 }
 
