@@ -13,12 +13,14 @@
 
 
 #include "engine.hpp"
+#include "mothur.h"
 
 /***********************************************************************/
 Engine::Engine(){
 	try {
 		cFactory = CommandFactory::getInstance();
 		mout = MothurOut::getInstance();
+        current = CurrentFile::getInstance();
 	}
 	catch(exception& e) {
 		mout->errorOut(e, "Engine", "Engine");
@@ -35,18 +37,28 @@ InteractEngine::InteractEngine(string path){
 	string temppath = path.substr(0, (path.find_last_of("othur")-5));
 	
 	//this will happen if you set the path variable to contain mothur's exe location
-	if (temppath == "") { path = mout->findProgramPath("mothur"); }
+    Utils util;
+	if (temppath == "") { path = util.findProgramPath("mothur"); }
     else { path = temppath; }
 	
-	mout->mothurProgramPath = mout->getFullPathName(path);
-    mout->setBlastPath(mout->mothurProgramPath);
+	current->setProgramPath(util.getFullPathName(path));
+    current->setBlastPath(current->getProgramPath());
 
     //if you haven't set your own location
     #ifdef MOTHUR_FILES
     #else
         //set default location to search for files to mothur's executable location.  This will resolve issue of double-clicking on the executable which opens mothur and sets pwd to your home directory instead of the mothur directory and leads to "unable to find file" errors.
-        if (mout->mothurProgramPath != "") { mout->setDefaultPath(mout->mothurProgramPath); }
+        if (current->getProgramPath() != "") { current->setDefaultPath(current->getProgramPath()); }
     #endif
+    
+    if (mout->getLogFileName() == "") {
+        time_t ltime = time(NULL); /* calendar time */
+        string outputPath = current->getOutputDir();
+        //if (outputPath == "") { outputPath = current->getDefaultPath();  }
+        string logFileName = outputPath + "mothur." + toString(ltime) + ".logfile";
+        mout->setLogFileName(logFileName, false);
+        mout->mothurOut("\n");
+    }
 }
 
 /***********************************************************************/
@@ -63,54 +75,38 @@ bool InteractEngine::getInput(){
 		string options = "";
 		int quitCommandCalled = 0;
 		
-		while(quitCommandCalled != 1){
-
-                    
-			if (mout->changedSeqNames) { mout->mothurOut("[WARNING]: your sequence names contained ':'.  I changed them to '_' to avoid problems in your downstream analysis.\n"); }
-                    
-			input = getCommand();	
-			
-			if (mout->control_pressed) { input = "quit()"; }
-			
-			//allow user to omit the () on the quit command
-			if (input == "quit") { input = "quit()"; }
-
-			CommandOptionParser parser(input);
-			commandName = parser.getCommandString();
-	
-			options = parser.getOptionString();
-			
-			if (commandName != "") {
-					mout->executing = true;
-
-					//executes valid command
-                    mout->changedSeqNames = false;
-					mout->runParse = true;
-					mout->clearGroups();
-					mout->clearAllGroups();
-					mout->Treenames.clear();
-					mout->saveNextLabel = "";
-                    mout->commandInputsConvertError = false;
-					mout->printedSharedHeaders = false;
-					mout->currentSharedBinLabels.clear();
-					mout->sharedBinLabelsInFile.clear();
-                    mout->printedListHeaders = false;
-                    mout->listBinLabelsInFile.clear();
-							
-					Command* command = cFactory->getCommand(commandName, options);
-					if (mout->commandInputsConvertError) { quitCommandCalled = 2; }
-					else { quitCommandCalled = command->execute(); }
-							
-					//if we aborted command
-					if (quitCommandCalled == 2) {  mout->mothurOut("[ERROR]: did not complete " + commandName + ".\n");  }
-
-					mout->control_pressed = 0;
-					mout->executing = false;
-										
-				}else {		
-					mout->mothurOut("Invalid.\n");
-				}
-		}	
+        while(quitCommandCalled != 1){
+            
+            input = getCommand();
+            
+            if (mout->getControl_pressed()) { input = "quit()"; }
+            
+            //allow user to omit the () on the quit command
+            if (input == "quit") { input = "quit()"; }
+            if (input == "help") { input = "help()"; }
+            
+            CommandOptionParser parser(input);
+            commandName = parser.getCommandString();
+            
+            options = parser.getOptionString();
+            
+            if (commandName != "") {
+                mout->setExecuting(true);
+                
+                //executes valid command
+                mout->setChangedSeqNames(true);
+                
+                Command* command = cFactory->getCommand(commandName, options);
+                quitCommandCalled = command->execute();
+                
+                //if we aborted command
+                if (quitCommandCalled == 2) {  mout->mothurOut("[ERROR]: did not complete " + commandName + ".\n");  }
+                
+                mout->setControl_pressed(false);
+                mout->setExecuting(false);
+                
+            }else { mout->mothurOut("[ERROR]: Invalid.\n"); }
+        }
 		return 1;
 	}
 	catch(exception& e) {
@@ -119,10 +115,10 @@ bool InteractEngine::getInput(){
 	}
 }
 /***********************************************************************/
-string Engine::getCommand()  {
+string InteractEngine::getCommand()  {
 	try {
 	
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
+		#if defined NON_WINDOWS
 			#ifdef USE_READLINE
 				char* nextCommand = NULL;
 				nextCommand = readline("\nmothur > ");
@@ -130,8 +126,6 @@ string Engine::getCommand()  {
 				if(nextCommand != NULL) {  add_history(nextCommand);  }	
 				else{ //^D causes null string and we want it to quit mothur
 					nextCommand = strdup("quit");
-					mout->mothurOut(nextCommand);
-                    mout->mothurOut("\n");
 				}	
 				
 				mout->mothurOutJustToLog("\nmothur > " + toString(nextCommand) + "\n");
@@ -159,7 +153,7 @@ string Engine::getCommand()  {
 						
 	}
 	catch(exception& e) {
-		mout->errorOut(e, "Engine", "getCommand");
+		mout->errorOut(e, "InteractEngine", "getCommand");
 		exit(1);
 	}
 }
@@ -167,23 +161,26 @@ string Engine::getCommand()  {
 //This function opens the batchfile to be used by BatchEngine::getInput.
 BatchEngine::BatchEngine(string path, string batchFileName){
 	try {
-	
-		openedBatch = mout->openInputFile(batchFileName, inputBatchFile);
-		
 		string temppath = path.substr(0, (path.find_last_of("othur")-5));
 	
 		//this will happen if you set the path variable to contain mothur's exe location
-		if (temppath == "") { path = mout->findProgramPath("mothur"); }
+		if (temppath == "") { path = util.findProgramPath("mothur"); }
         else { path = temppath; }
 		
-		mout->mothurProgramPath = mout->getFullPathName(path);
-        mout->setBlastPath(mout->mothurProgramPath);
+        current->setProgramPath(util.getFullPathName(path));
+        current->setBlastPath(current->getProgramPath());
+        
+        openedBatch = util.openInputFile(batchFileName, inputBatchFile, "no error");
+        if (!openedBatch) {
+            if (util.checkLocations(batchFileName, current->getLocations())) { openedBatch = util.openInputFile(batchFileName, inputBatchFile); }
+            else {  mout->mothurOut("[ERROR]: unable to open batch file, please correct.\n");  }
+        }
         
         //if you haven't set your own location
 #ifdef MOTHUR_FILES
 #else
         //set default location to search for files to mothur's executable location.  This will resolve issue of double-clicking on the executable which opens mothur and sets pwd to your home directory instead of the mothur directory and leads to "unable to find file" errors.
-        if (mout->mothurProgramPath != "") { mout->setDefaultPath(mout->mothurProgramPath); }
+        if (current->getProgramPath() != "") { current->setDefaultPath(current->getProgramPath()); }
 #endif
 
 				
@@ -203,10 +200,7 @@ BatchEngine::~BatchEngine(){	}
 bool BatchEngine::getInput(){
 	try {
 		//check if this is a valid batchfile
-		if (openedBatch == 1) {  
-			mout->mothurOut("unable to open batchfile\n");
-			return 1; 
-		}
+		if (!openedBatch) { return 1;  }
 	
 		string input = "";
 		string commandName = "";
@@ -221,55 +215,38 @@ bool BatchEngine::getInput(){
 			count++;
 			
             if (input[0] != '#') {
-				if (mout->changedSeqNames) { mout->mothurOut("[WARNING]: your sequence names contained ':'.  I changed them to '_' to avoid problems in your downstream analysis.\n"); }
+				mout->appendLogBuffer("\nmothur > " + input + "\n");
 				
-				mout->mothurOut("\nmothur > " + input + "\n");
-				
-							
-				if (mout->control_pressed) { input = "quit()"; }
+				if (mout->getControl_pressed()) { input = "quit()"; }
 				
 				//allow user to omit the () on the quit command
 				if (input == "quit") { input = "quit()"; }
+                if (input == "help") { input = "help()"; }
 
 				CommandOptionParser parser(input);
 				commandName = parser.getCommandString();
 				options = parser.getOptionString();
 										
 				if (commandName != "") {
-					mout->executing = true;
+					mout->setExecuting(true);
 					
 					//executes valid command
-                    mout->changedSeqNames = false;
-					mout->runParse = true;
-					mout->clearGroups();
-					mout->clearAllGroups();
-					mout->Treenames.clear();
-					mout->saveNextLabel = "";
-					mout->commandInputsConvertError = false;
-                    mout->printedSharedHeaders = false;
-                    mout->currentSharedBinLabels.clear();
-                    mout->sharedBinLabelsInFile.clear();
-                    mout->printedListHeaders = false;
-                    mout->listBinLabelsInFile.clear();
-
+                    mout->setChangedSeqNames(true);
 							
 					Command* command = cFactory->getCommand(commandName, options);
-					if (mout->commandInputsConvertError) { quitCommandCalled = 2; }
-					else { quitCommandCalled = command->execute(); }
+					quitCommandCalled = command->execute();
 							
 					//if we aborted command
 					if (quitCommandCalled == 2) {  mout->mothurOut("[ERROR]: did not complete " + commandName + ".\n");  }
                     
-                    if (mout->control_pressed) { break;  }
-					mout->control_pressed = 0;
-					mout->executing = false;
+                    if (mout->getControl_pressed()) { break;  }
+                    mout->setControl_pressed(false);
+                    mout->setExecuting(false);
 										
-				}else {		
-					mout->mothurOut("Invalid.\n");
-				}
+				}else {	 mout->mothurOut("[ERROR]: Invalid.\n"); }
 				
 			}
-			mout->gobble(inputBatchFile);
+			util.gobble(inputBatchFile);
 		}
 		
 		inputBatchFile.close();
@@ -287,7 +264,7 @@ string BatchEngine::getNextCommand(ifstream& inputBatchFile) {
 		string nextcommand = "";
 		
 		if (inputBatchFile.eof()) { nextcommand = "quit()"; }
-		else { nextcommand = mout->getline(inputBatchFile); }
+		else { nextcommand = util.getline(inputBatchFile); }
 		
 		return nextcommand;
 	}
@@ -299,7 +276,6 @@ string BatchEngine::getNextCommand(ifstream& inputBatchFile) {
 
 /***********************************************************************/
 /***********************************************************************/
-//This function opens the batchfile to be used by BatchEngine::getInput.
 ScriptEngine::ScriptEngine(string path, string commandString){
 	try {
 		
@@ -309,18 +285,18 @@ ScriptEngine::ScriptEngine(string path, string commandString){
 		string temppath = path.substr(0, (path.find_last_of("othur")-5));
 
 		//this will happen if you set the path variable to contain mothur's exe location
-		if (temppath == "") { path = mout->findProgramPath("mothur"); }
+		if (temppath == "") { path = util.findProgramPath("mothur"); }
         else { path = temppath; }
 		
-		mout->mothurProgramPath = mout->getFullPathName(path);
-        mout->setBlastPath(mout->mothurProgramPath);
+        current->setProgramPath(util.getFullPathName(path));
+        current->setBlastPath(current->getProgramPath());
     
         //if you haven't set your own location
 #ifdef MOTHUR_FILES
 #else
         //set default location to search for files to mothur's executable location.  This will resolve issue of double-clicking on the executable which opens mothur and sets pwd to your home directory instead of the mothur directory and leads to "unable to find file" errors.
         //string tempDefault = path.substr(0, (path.find_last_of('m')));
-        if (path != "") { mout->setDefaultPath(path); }
+        if (path != "") { current->setDefaultPath(path); }
 #endif
 
 				
@@ -353,59 +329,36 @@ bool ScriptEngine::getInput(){
 			input = getNextCommand(listOfCommands);	
 			
 			if (input == "") { input = "quit()"; }
-                    
-            if (mout->changedSeqNames) { mout->mothurOut("[WARNING]: your sequence names contained ':'.  I changed them to '_' to avoid problems in your downstream analysis.\n"); }
 			
-			if (mout->gui) {
-				if ((input.find("quit") != string::npos) || (input.find("set.logfile") != string::npos)) {}
-				else if ((input.find("get.current") != string::npos) && (!mout->hasCurrentFiles())) {}
-				else {  mout->mothurOut("\nmothur > " + input + "\n");  }
-			}else{
-				mout->mothurOut("\nmothur > " + input + "\n");
-			}
-			
-            if (mout->control_pressed) { input = "quit()"; }
+            mout->appendLogBuffer("\nmothur > " + input + "\n");
+        
+            if (mout->getControl_pressed()) { input = "quit()"; }
 				
 			//allow user to omit the () on the quit command
 			if (input == "quit") { input = "quit()"; }
+            if (input == "help") { input = "help()"; }
 
 			CommandOptionParser parser(input);
 			commandName = parser.getCommandString();
 			options = parser.getOptionString();
 										
 			if (commandName != "") {
-					mout->executing = true;
-					
-					//executes valid command
-                    mout->changedSeqNames = false;
-					mout->runParse = true;
-					mout->clearGroups();
-					mout->clearAllGroups();
-					mout->Treenames.clear();
-					mout->saveNextLabel = "";
-                    mout->commandInputsConvertError = false;
-                    mout->printedSharedHeaders = false;
-                    mout->currentSharedBinLabels.clear();
-                    mout->sharedBinLabelsInFile.clear();
-                    mout->printedListHeaders = false;
-                    mout->listBinLabelsInFile.clear();
-
-					Command* command = cFactory->getCommand(commandName, options);
-					if (mout->commandInputsConvertError) { quitCommandCalled = 2; }
-					else { quitCommandCalled = command->execute(); }
-					
-					//if we aborted command
-					if (quitCommandCalled == 2) {  mout->mothurOut("[ERROR]: did not complete " + commandName + ".\n");  }
-					
-                    if (mout->control_pressed) { break;  }
-					mout->control_pressed = 0;
-					mout->executing = false;
-									
-				}else {		
-					mout->mothurOut("Invalid.\n");
-				}
-
-			
+                mout->setExecuting(true);
+                
+                //executes valid command
+                mout->setChangedSeqNames(true);
+               
+                Command* command = cFactory->getCommand(commandName, options);
+                quitCommandCalled = command->execute();
+                
+                //if we aborted command
+                if (quitCommandCalled == 2) {  mout->mothurOut("[ERROR]: did not complete " + commandName + ".\n");  }
+                
+                if (mout->getControl_pressed()) { break;  }
+                mout->setControl_pressed(false);
+                mout->setExecuting(false);
+                                
+            }else {	mout->mothurOut("[ERROR]: Invalid.\n"); }
 		}
 		
 		return 1;
