@@ -10,16 +10,16 @@
 #include "heatmap.h"
 
 //**********************************************************************************************************************
-HeatMap::HeatMap(string sort, string scale, int num, int fsize, string dir, string i){
+HeatMap::HeatMap(string sort, string scale, int num, int fsize, string dir, string i, vector<string> cl){
 	try {
 		m = MothurOut::getInstance();
-//		format = globaldata->getFormat();
 		sorted = sort;
 		scaler = scale;
 		outputDir = dir;
 		numOTU = num;
 		fontSize = fsize;
 		inputfile = i;
+        currentLabels = cl;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "HeatMap", "HeatMap");
@@ -53,7 +53,7 @@ string HeatMap::getPic(RAbundVector* rabund) {
 		for(int i=0;i<numBinsToDisplay;i++){
 			float relAbund = rabund->get(i) / (float)rabund->getNumSeqs();
 			
-			if (m->control_pressed) { return "control"; }
+			if (m->getControl_pressed()) { return "control"; }
 			
 			if (rabund->get(i) != 0) { //don't want log value of 0.
 				if (scaler == "log10") {
@@ -70,8 +70,8 @@ string HeatMap::getPic(RAbundVector* rabund) {
 		}
 		
 		
-		string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + rabund->getLabel() + ".heatmap.bin.svg";
-		m->openOutputFile(filenamesvg, outsvg);
+		string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + rabund->getLabel() + ".heatmap.bin.svg";
+		util.openOutputFile(filenamesvg, outsvg);
 		
 		//svg image
 		outsvg << "<svg xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns=\"http://www.w3.org/2000/svg\" width=\"100%\" height=\"100%\" viewBox=\"0 0 " + toString(300) + " " + toString((numBinsToDisplay*5 + 120))  + "\">\n";
@@ -90,7 +90,7 @@ string HeatMap::getPic(RAbundVector* rabund) {
 		y = 70;
 
 		for (int i = 0; i < scaleRelAbund.size(); i++) {
-			if (m->control_pressed) { outsvg.close(); return "control"; }
+			if (m->getControl_pressed()) { outsvg.close(); return "control"; }
 			
 			outsvg << "<rect fill=\"#" + scaleRelAbund[i] + "\" stroke=\"#" + scaleRelAbund[i] + "\" x=\"" + toString(x) + "\" y=\"" + toString(y) + "\" width=\"300\" height=\"5\"/>\n";
 			y += 5;
@@ -109,27 +109,27 @@ string HeatMap::getPic(RAbundVector* rabund) {
 
 //**********************************************************************************************************************
 
-string HeatMap::getPic(vector<SharedRAbundVector*> lookup) {
+string HeatMap::getPic(vector<SharedRAbundVector*> lookup, vector<string> groups) {
 	try {
 	
-		int numBinsToDisplay = lookup[0]->size();
+		int numBinsToDisplay = lookup[0]->getNumBins();
 		
 		if (numOTU != 0) { //user want to display a portion of the otus
 			if (numOTU < numBinsToDisplay) {  numBinsToDisplay = numOTU; }
 		}
 		
 		//sort lookup so shared bins are on top
-        vector<string> sortedLabels = m->currentSharedBinLabels;
+        vector<string> sortedLabels = currentLabels;
 		if (sorted != "none") {  sortedLabels = sortSharedVectors(lookup);  }
 		
 		vector<vector<string> > scaleRelAbund;
-		vector<float> maxRelAbund(lookup[0]->size(), 0.0);		
+		vector<float> maxRelAbund(lookup.size(), 0.0);
 		float superMaxRelAbund = 0;
 		
 		for(int i = 0; i < lookup.size(); i++){
 			for(int j=0; j<lookup[i]->size(); j++){
 				
-				float relAbund = lookup[i]->getAbundance(j) / (float)lookup[i]->getNumSeqs();
+				float relAbund = lookup[i]->get(j) / (float)lookup[i]->getNumSeqs();
 				if(relAbund > maxRelAbund[i]){	maxRelAbund[i] = relAbund;	}
 			}
 			if(maxRelAbund[i] > superMaxRelAbund){	superMaxRelAbund = maxRelAbund[i];	}
@@ -139,10 +139,10 @@ string HeatMap::getPic(vector<SharedRAbundVector*> lookup) {
 		for(int i=0;i<lookup.size();i++){
 			scaleRelAbund[i].assign(numBinsToDisplay, "");
 			for(int j=0;j<numBinsToDisplay;j++){
-				if (m->control_pressed) {  return "control"; }
-				float relAbund = lookup[i]->getAbundance(j) / (float)lookup[i]->getNumSeqs();
+				if (m->getControl_pressed()) {  return "control"; }
+				float relAbund = lookup[i]->get(j) / (float)lookup[i]->getNumSeqs();
 				
-				if (lookup[i]->getAbundance(j) != 0) { //don't want log value of 0.
+				if (lookup[i]->get(j) != 0) { //don't want log value of 0.
 					if (scaler == "log10") {
                         if (maxRelAbund[i] == 1) { maxRelAbund[i] -= 0.001; }
                         if (relAbund == 1) { relAbund -= 0.001; }
@@ -162,8 +162,8 @@ string HeatMap::getPic(vector<SharedRAbundVector*> lookup) {
 			}
 		}
 
-		string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + ".heatmap.bin.svg";
-		m->openOutputFile(filenamesvg, outsvg);
+		string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + ".heatmap.bin.svg";
+		util.openOutputFile(filenamesvg, outsvg);
         int binHeight = 20;
         int labelBump = 100;
         int binWidth = 300;
@@ -182,7 +182,7 @@ string HeatMap::getPic(vector<SharedRAbundVector*> lookup) {
                 string tempLabel = "OTU";
                 outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(labelBump-labelBump/2+1) + "\" y=\"50\">" + tempLabel + "</text>\n";
             }else {
-                outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(((binWidth * h) - 150) - ((int)lookup[h-1]->getGroup().length() / 2)+labelBump/2) + "\" y=\"50\">" + lookup[h-1]->getGroup() + "</text>\n";
+                outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(((binWidth * h) - 150) - ((int)groups[h-1].length() / 2)+labelBump/2) + "\" y=\"50\">" + groups[h-1] + "</text>\n";
             }
 		}
 
@@ -197,7 +197,7 @@ string HeatMap::getPic(vector<SharedRAbundVector*> lookup) {
             outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(x) + "\" y=\"" + toString(y) + "\">" + sortedLabels[i] + "</text>\n";
             x += labelBump;
 			for (int j = 0; j < scaleRelAbund.size(); j++) {
-				if (m->control_pressed) { outsvg.close(); return "control"; }
+				if (m->getControl_pressed()) { outsvg.close(); return "control"; }
 				
 				outsvg << "<rect fill=\"#" + scaleRelAbund[j][i] + "\" stroke=\"#" + scaleRelAbund[j][i] + "\" x=\"" + toString(x) + "\" y=\"" + toString(y) + "\" width=\"" + toString(binWidth) +  "\" height=\"" + toString(binHeight) +  "\"/>\n";
 				x += binWidth;
@@ -219,15 +219,13 @@ string HeatMap::getPic(vector<SharedRAbundVector*> lookup) {
 }
 
 //**********************************************************************************************************************
-vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundVector*>& lookup){
+vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundVector*> lookup){
 	try {
-				
+        vector<string> sortedLabels; sortedLabels.resize(currentLabels.size(), "");
 		vector<SharedRAbundVector*> looktemp;
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
 		map<int, int>::iterator it;
         
-        vector<string> sortedLabels = m->currentSharedBinLabels;
-		
 		/****************** find order of otus **********************/
 		if (sorted == "shared") {
 			place = orderShared(lookup);	
@@ -235,40 +233,29 @@ vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundVector*>& lookup){
 			place = orderTopOtu(lookup);	
 		}else if (sorted == "topgroup") {
 			place = orderTopGroup(lookup);	
-		}else { m->mothurOut("Error: invalid sort option."); m->mothurOutEndLine();  return sortedLabels; }
+		}else { m->mothurOut("Error: invalid sort option."); m->mothurOutEndLine();   }
 				
 		
 		/******************* create copy of lookup *********************/
 		//create and initialize looktemp as a copy of lookup
 		for (int i = 0; i < lookup.size(); i++) { 
-			SharedRAbundVector* temp = new SharedRAbundVector(lookup[i]->getNumBins());
+			SharedRAbundVector* temp = new SharedRAbundVector(*lookup[i]);
 			temp->setLabel(lookup[i]->getLabel());
-			temp->setGroup(lookup[i]->getGroup());
-			//copy lookup i's info
-			for (int j = 0; j < lookup[i]->size(); j++) {
-				temp->set(j, lookup[i]->getAbundance(j), lookup[i]->getGroup());
-			}
 			looktemp.push_back(temp);
 		}
 	
 		/************************ fill lookup in order given by place *********************/
 		//for each bin
-		for (int i = 0; i < looktemp[0]->size(); i++) {														//place
+		for (int i = 0; i < looktemp[0]->getNumBins(); i++) {														//place
 			//fill lookup																					// 2 -> 1
 			for (int j = 0; j < looktemp.size(); j++) {														// 3 -> 2
-				int newAbund = looktemp[j]->getAbundance(i);												// 1 -> 3
-				lookup[j]->set(place[i], newAbund, looktemp[j]->getGroup()); //binNumber, abundance, group
+				int newAbund = looktemp[j]->get(i);												// 1 -> 3
+				lookup[j]->set(place[i], newAbund); //binNumber, abundance, group
+                sortedLabels[place[i]] = currentLabels[i];
 			}
-            sortedLabels[place[i]] = m->currentSharedBinLabels[i];
 		}
 		
-		//delete looktemp -- Sarah look at - this is causing segmentation faults
-		for (int j = 0; j < looktemp.size(); j++) {
-//			delete looktemp[j];
-		}
-		
-		return sortedLabels;
-		
+        return sortedLabels;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "HeatMap", "sortSharedVectors");
@@ -276,7 +263,7 @@ vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundVector*>& lookup){
 	}
 }
 //**********************************************************************************************************************
-map<int, int> HeatMap::orderShared(vector<SharedRAbundVector*>& lookup){
+map<int, int> HeatMap::orderShared(vector<SharedRAbundVector*> lookup){
 	try {
 				
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
@@ -286,11 +273,11 @@ map<int, int> HeatMap::orderShared(vector<SharedRAbundVector*>& lookup){
 		vector<int> uniqueBins;
 		
 		//for each bin
-		for (int i = 0; i < lookup[0]->size(); i++) {	
+		for (int i = 0; i < lookup[0]->getNumBins(); i++) {
 			int count = 0;												
 			
 			//is this bin shared
-			for (int j = 0; j < lookup.size(); j++) {		if (lookup[j]->getAbundance(i) != 0) { count++; }	}
+			for (int j = 0; j < lookup.size(); j++) {		if (lookup[j]->get(i) != 0) { count++; }	}
 			
 			if (count < 2)	{  uniqueBins.push_back(i); }
 			else			{  sharedBins.push_back(i); }
@@ -309,7 +296,7 @@ map<int, int> HeatMap::orderShared(vector<SharedRAbundVector*>& lookup){
 	}
 }
 //**********************************************************************************************************************
-map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundVector*>& lookup){
+map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundVector*> lookup){
 	try {
 				
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
@@ -318,10 +305,10 @@ map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundVector*>& lookup){
 		vector<binCount> totals;
 		
 		//for each bin
-		for (int i = 0; i < lookup[0]->size(); i++) {	
+		for (int i = 0; i < lookup[0]->getNumBins(); i++) {
 			int total = 0;												
 			
-			for (int j = 0; j < lookup.size(); j++) {	total += lookup[j]->getAbundance(i); 	}
+			for (int j = 0; j < lookup.size(); j++) {	total += lookup[j]->get(i); 	}
 			
 			binCount temp(i, total);
 			
@@ -342,7 +329,7 @@ map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundVector*>& lookup){
 	}
 }
 //**********************************************************************************************************************
-map<int, int> HeatMap::orderTopGroup(vector<SharedRAbundVector*>& lookup){
+map<int, int> HeatMap::orderTopGroup(vector<SharedRAbundVector*> lookup){
 	try {
 				
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
@@ -352,9 +339,9 @@ map<int, int> HeatMap::orderTopGroup(vector<SharedRAbundVector*>& lookup){
 		totals.resize(lookup.size());
 		
 		//for each bin
-		for (int i = 0; i < lookup[0]->size(); i++) {	
+		for (int i = 0; i < lookup[0]->getNumBins(); i++) {
 			for (int j = 0; j < lookup.size(); j++) {
-				binCount temp(i, (lookup[j]->getAbundance(i)));
+				binCount temp(i, (lookup[j]->get(i)));
 				totals[j].push_back(temp);
 			}
 		}
@@ -425,17 +412,17 @@ void HeatMap::printLegend(int y, float maxbin) {
 }
 //**********************************************************************************************************************
 
-string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup) {
+string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup, vector<string> groups) {
 	try {
 	
-		int numBinsToDisplay = lookup[0]->size();
+		int numBinsToDisplay = lookup[0]->getNumBins();
 		
 		if (numOTU != 0) { //user want to display a portion of the otus
 			if (numOTU < numBinsToDisplay) {  numBinsToDisplay = numOTU; }
 		}
 		
 		//sort lookup so shared bins are on top
-		vector<string> sortedLabels = m->currentSharedBinLabels;
+        vector<string> sortedLabels = currentLabels;
 		if (sorted != "none") {  sortedLabels = sortSharedVectors(lookup);  }
 		
 		vector<vector<string> > scaleRelAbund;
@@ -443,9 +430,9 @@ string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup) {
 		float superMaxRelAbund = 0;
 		
 		for(int i = 0; i < lookup.size(); i++){
-			for(int j=0; j<lookup[i]->size(); j++){
+			for(int j=0; j<numBinsToDisplay; j++){
 				
-				float relAbund = lookup[i]->getAbundance(j);
+				float relAbund = lookup[i]->get(j);
 				if(relAbund > maxRelAbund[i]){	maxRelAbund[i] = relAbund;	}
 			}
 			if(maxRelAbund[i] > superMaxRelAbund){	superMaxRelAbund = maxRelAbund[i];	}
@@ -455,10 +442,10 @@ string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup) {
 		for(int i=0;i<lookup.size();i++){
 			scaleRelAbund[i].assign(numBinsToDisplay, "");
 			for(int j=0;j<numBinsToDisplay;j++){
-				if (m->control_pressed) {  return "control"; }
-				float relAbund = lookup[i]->getAbundance(j);
+				if (m->getControl_pressed()) {  return "control"; }
+				float relAbund = lookup[i]->get(j);
 				
-				if (lookup[i]->getAbundance(j) != 0) { //don't want log value of 0.
+				if (lookup[i]->get(j) != 0) { //don't want log value of 0.
 					if (scaler == "log10") {
                         if (maxRelAbund[i] == 1) { maxRelAbund[i] -= 0.001; }
                         if (relAbund == 1) { relAbund -= 0.001; }
@@ -477,8 +464,8 @@ string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup) {
 			}
 		}
 
-		string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + ".heatmap.bin.svg";
-		m->openOutputFile(filenamesvg, outsvg);
+		string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + ".heatmap.bin.svg";
+		util.openOutputFile(filenamesvg, outsvg);
         
         int binHeight = 20;
         int labelBump = 100;
@@ -498,7 +485,7 @@ string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup) {
                 string tempLabel = "OTU";
                 outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(labelBump-labelBump/2+1) + "\" y=\"50\">" + tempLabel + "</text>\n";
             }else {
-                outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(((binWidth * h) - 150) - ((int)lookup[h-1]->getGroup().length() / 2)+labelBump/2) + "\" y=\"50\">" + lookup[h-1]->getGroup() + "</text>\n";
+                outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(((binWidth * h) - 150) - ((int)groups[h-1].length() / 2)+labelBump/2) + "\" y=\"50\">" + groups[h-1] + "</text>\n";
             }
 		}
         
@@ -513,7 +500,7 @@ string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup) {
             outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(x) + "\" y=\"" + toString(y) + "\">" + sortedLabels[i] + "</text>\n";
             x += labelBump;
 			for (int j = 0; j < scaleRelAbund.size(); j++) {
-				if (m->control_pressed) { outsvg.close(); return "control"; }
+				if (m->getControl_pressed()) { outsvg.close(); return "control"; }
 				
 				outsvg << "<rect fill=\"#" + scaleRelAbund[j][i] + "\" stroke=\"#" + scaleRelAbund[j][i] + "\" x=\"" + toString(x) + "\" y=\"" + toString(y) + "\" width=\"" + toString(binWidth) +  "\" height=\"" + toString(binHeight) +  "\"/>\n";
 				x += binWidth;
@@ -534,14 +521,14 @@ string HeatMap::getPic(vector<SharedRAbundFloatVector*> lookup) {
 	}
 }
 //**********************************************************************************************************************
-vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundFloatVector*>& lookup){
+vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundFloatVector*> lookup){
 	try {
 				
 		vector<SharedRAbundFloatVector*> looktemp;
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
 		map<int, int>::iterator it;
         
-        vector<string> sortedLabels = m->currentSharedBinLabels;
+        vector<string> sortedLabels; sortedLabels.resize(currentLabels.size(), "");
 		
 		/****************** find order of otus **********************/
 		if (sorted == "shared") {
@@ -556,14 +543,9 @@ vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundFloatVector*>& look
 		/******************* create copy of lookup *********************/
 		//create and initialize looktemp as a copy of lookup
 		for (int i = 0; i < lookup.size(); i++) { 
-			SharedRAbundFloatVector* temp = new SharedRAbundFloatVector(lookup[i]->getNumBins());
+			SharedRAbundFloatVector* temp = new SharedRAbundFloatVector(*lookup[i]);
 			temp->setLabel(lookup[i]->getLabel());
-			temp->setGroup(lookup[i]->getGroup());
-			//copy lookup i's info
-			for (int j = 0; j < lookup[i]->size(); j++) {
-				temp->set(j, lookup[i]->getAbundance(j), lookup[i]->getGroup());
-			}
-			looktemp.push_back(temp);
+            looktemp.push_back(temp);
 		}
 	
 		/************************ fill lookup in order given by place *********************/
@@ -571,17 +553,12 @@ vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundFloatVector*>& look
 		for (int i = 0; i < looktemp[0]->size(); i++) {														//place
 			//fill lookup																					// 2 -> 1
 			for (int j = 0; j < looktemp.size(); j++) {														// 3 -> 2
-				float newAbund = looktemp[j]->getAbundance(i);												// 1 -> 3
-				lookup[j]->set(place[i], newAbund, looktemp[j]->getGroup()); //binNumber, abundance, group
-                sortedLabels[place[i]] = m->currentSharedBinLabels[i];
+				float newAbund = looktemp[j]->get(i);												// 1 -> 3
+				lookup[j]->set(place[i], newAbund); //binNumber, abundance, group
+                sortedLabels[place[i]] = currentLabels[i];
 			}
 		}
 		
-		//delete looktemp -- Sarah look at - this is causing segmentation faults
-		for (int j = 0; j < looktemp.size(); j++) {
-//			delete looktemp[j];
-		}
-		
 		return sortedLabels;
 		
 	}
@@ -591,7 +568,7 @@ vector<string> HeatMap::sortSharedVectors(vector<SharedRAbundFloatVector*>& look
 	}
 }
 //**********************************************************************************************************************
-int HeatMap::sortRabund(RAbundVector*& r){
+int HeatMap::sortRabund(RAbundVector* r){
 	try {
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
 		map<int, int>::iterator it;
@@ -636,7 +613,7 @@ int HeatMap::sortRabund(RAbundVector*& r){
 	}
 }
 //**********************************************************************************************************************
-map<int, int> HeatMap::orderShared(vector<SharedRAbundFloatVector*>& lookup){
+map<int, int> HeatMap::orderShared(vector<SharedRAbundFloatVector*> lookup){
 	try {
 				
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
@@ -646,11 +623,11 @@ map<int, int> HeatMap::orderShared(vector<SharedRAbundFloatVector*>& lookup){
 		vector<int> uniqueBins;
 		
 		//for each bin
-		for (int i = 0; i < lookup[0]->size(); i++) {	
+		for (int i = 0; i < lookup[0]->getNumBins(); i++) {
 			int count = 0;												
 			
 			//is this bin shared
-			for (int j = 0; j < lookup.size(); j++) {		if (lookup[j]->getAbundance(i) != 0) { count++; }	}
+			for (int j = 0; j < lookup.size(); j++) {		if (lookup[j]->get(i) != 0) { count++; }	}
 			
 			if (count < 2)	{  uniqueBins.push_back(i); }
 			else			{  sharedBins.push_back(i); }
@@ -669,7 +646,7 @@ map<int, int> HeatMap::orderShared(vector<SharedRAbundFloatVector*>& lookup){
 	}
 }
 //**********************************************************************************************************************
-map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundFloatVector*>& lookup){
+map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundFloatVector*> lookup){
 	try {
 				
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
@@ -681,7 +658,7 @@ map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundFloatVector*>& lookup){
 		for (int i = 0; i < lookup[0]->size(); i++) {	
 			int total = 0;												
 			
-			for (int j = 0; j < lookup.size(); j++) {	total += lookup[j]->getAbundance(i); 	}
+			for (int j = 0; j < lookup.size(); j++) {	total += lookup[j]->get(i); 	}
 			
 			binCountFloat temp(i, total);
 			
@@ -702,7 +679,7 @@ map<int, int> HeatMap::orderTopOtu(vector<SharedRAbundFloatVector*>& lookup){
 	}
 }
 //**********************************************************************************************************************
-map<int, int> HeatMap::orderTopGroup(vector<SharedRAbundFloatVector*>& lookup){
+map<int, int> HeatMap::orderTopGroup(vector<SharedRAbundFloatVector*> lookup){
 	try {
 				
 		map<int, int> place; //spot in lookup where you insert shared by, ie, 3 -> 2 if they are shared by 3 inset into location 2.
@@ -714,7 +691,7 @@ map<int, int> HeatMap::orderTopGroup(vector<SharedRAbundFloatVector*>& lookup){
 		//for each bin
 		for (int i = 0; i < lookup[0]->size(); i++) {	
 			for (int j = 0; j < lookup.size(); j++) {
-				binCountFloat temp(i, (lookup[j]->getAbundance(i)));
+				binCountFloat temp(i, (lookup[j]->get(i)));
 				totals[j].push_back(temp);
 			}
 		}
