@@ -11,20 +11,23 @@
 #include "ordervector.hpp"
 #include "listvector.hpp"
 #include "rabundvector.hpp"
+#include "sharedrabundvectors.hpp"
 
 /***********************************************************************/
 
-InputData::InputData(string fName, string f) : format(f){
+InputData::InputData(string fName, string f, vector<string> userGroups) : format(f){
 	m = MothurOut::getInstance();
-	m->openInputFile(fName, fileHandle);
+	util.openInputFile(fName, fileHandle);
 	filename = fName;
-	m->saveNextLabel = "";
+	nextDistanceLabel = "";
+    groups = userGroups;
+    otuTag = util.getTag(fName);
 }
 /***********************************************************************/
 
 InputData::~InputData(){
 	fileHandle.close();
-	m->saveNextLabel = "";
+	nextDistanceLabel = "";
 }
 
 /***********************************************************************/
@@ -33,7 +36,7 @@ InputData::InputData(string fName, string orderFileName, string f) : format(f){
 	try {
 		m = MothurOut::getInstance();
 		ifstream ofHandle;
-		m->openInputFile(orderFileName, ofHandle);
+		util.openInputFile(orderFileName, ofHandle);
 		string name;
 
 		int count = 0;
@@ -42,12 +45,13 @@ InputData::InputData(string fName, string orderFileName, string f) : format(f){
 			ofHandle >> name;
 			orderMap[name] = count;
 			count++;
-			m->gobble(ofHandle);
+			util.gobble(ofHandle);
 		}
 		ofHandle.close();
 	
-		m->openInputFile(fName, fileHandle);
-		m->saveNextLabel = "";
+		util.openInputFile(fName, fileHandle);
+		nextDistanceLabel = "";
+        otuTag = util.getTag(fName);
 		
 	}
 	catch(exception& e) {
@@ -61,10 +65,15 @@ ListVector* InputData::getListVector(){
 	try {
 		if(!fileHandle.eof()){
 			if(format == "list") {
-				list = new ListVector(fileHandle);
+				list = new ListVector(fileHandle, nextDistanceLabel, otuTag);
+                if (list != NULL) {
+                    //pass labels to others distances in file
+                    if (currentLabels.size() == 0) { currentLabels = list->getLabels(); }
+                    else { list->setLabels(currentLabels);  }
+                }
 			}else{ list = NULL;  }
 					
-			m->gobble(fileHandle);
+			util.gobble(fileHandle);
 			return list;
 		}
 		else{
@@ -81,24 +90,29 @@ ListVector* InputData::getListVector(){
 ListVector* InputData::getListVector(string label){
 	try {
 		ifstream in;
-		string  thisLabel;
-		m->openInputFile(filename, in);
-        m->saveNextLabel = "";
+		util.openInputFile(filename, in);
+        nextDistanceLabel = "";
 		
 		if(in){
 
 			if (format == "list") {
 			
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					list = new ListVector(in);
-					thisLabel = list->getLabel();
+					list = new ListVector(in, nextDistanceLabel, otuTag);
+					nextDistanceLabel = list->getLabel();
+                    
+                    if (list != NULL) {
+                        //pass labels to others distances in file
+                        if (currentLabels.size() == 0) { currentLabels = list->getLabels(); }
+                        else { list->setLabels(currentLabels);  }
+                    }
 					
 					//if you are at the last label
-					if (thisLabel == label) {  break;  }
+					if (nextDistanceLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete list;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}else{ list = NULL;  }
 			
@@ -117,10 +131,9 @@ ListVector* InputData::getListVector(string label){
 /***********************************************************************/
 ListVector* InputData::getListVector(string label, bool resetFP){
 	try {
-		string  thisLabel;
 		fileHandle.clear();
 		fileHandle.seekg(0);
-        m->saveNextLabel = "";
+        nextDistanceLabel = "";
 		
 		if(fileHandle){
 
@@ -128,11 +141,17 @@ ListVector* InputData::getListVector(string label, bool resetFP){
 			
 				while (fileHandle.eof() != true) {
 					
-					list = new ListVector(fileHandle); m->gobble(fileHandle);
-					thisLabel = list->getLabel();
+					list = new ListVector(fileHandle, nextDistanceLabel, otuTag); util.gobble(fileHandle);
+					nextDistanceLabel = list->getLabel();
+                    
+                     if (list != NULL) {
+                         //pass labels to others distances in file
+                         if (currentLabels.size() == 0) { currentLabels = list->getLabels(); }
+                         else { list->setLabels(currentLabels);  }
+                     }
 					
 					//if you are at the last label
-					if (thisLabel == label) {  break;  }
+					if (nextDistanceLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete list;	}
 				}
@@ -156,10 +175,16 @@ SharedListVector* InputData::getSharedListVector(){
 	try {
 		if(fileHandle){
 			if (format == "shared")  {
-				SharedList = new SharedListVector(fileHandle);
+				SharedList = new SharedListVector(fileHandle, groups, nextDistanceLabel, otuTag);
+                if (SharedList != NULL) {
+                    //pass labels to others distances in file
+                    if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
+                    else { SharedList->setLabels(currentLabels);  }
+                }
+
 			}else{ SharedList = NULL;  }
 					
-			m->gobble(fileHandle);
+			util.gobble(fileHandle);
 			return SharedList;
 		}
 		else{
@@ -177,22 +202,28 @@ SharedListVector* InputData::getSharedListVector(string label){
 	try {
 		ifstream in;
 		string  thisLabel;
-		m->openInputFile(filename, in);
+		util.openInputFile(filename, in);
+        nextDistanceLabel = "";
 		
 		if(in){
 
 			if (format == "shared")  {
 			
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					SharedList = new SharedListVector(in);
+					SharedList = new SharedListVector(in, groups, nextDistanceLabel, otuTag);
 					thisLabel = SharedList->getLabel();
-					
+                    
+                    if (SharedList != NULL) {
+                        //pass labels to others distances in file
+                        if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
+                        else { SharedList->setLabels(currentLabels);  }
+                    }
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete SharedList;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}else{ SharedList = NULL;  }
@@ -218,10 +249,11 @@ SharedOrderVector* InputData::getSharedOrderVector(){
 	try {
 		if(fileHandle){
 			if (format == "sharedfile")  {
-				SharedOrder = new SharedOrderVector(fileHandle);
+				SharedOrder = new SharedOrderVector(fileHandle, groups, nextDistanceLabel);
+                if (SharedOrder->getNumBins() == 0) { delete SharedOrder; SharedOrder =  NULL; } //no valid groups
 			}else{ SharedOrder = NULL;  }
 				
-			m->gobble(fileHandle);
+			util.gobble(fileHandle);
 			return SharedOrder;
 			
 		}else{
@@ -240,23 +272,24 @@ SharedOrderVector* InputData::getSharedOrderVector(string label){
 	try {
 		ifstream in;
 		string  thisLabel;
-		m->openInputFile(filename, in);
-        m->saveNextLabel = "";
+		util.openInputFile(filename, in);
+        nextDistanceLabel = "";
 		
 		if(in){
 
 			if (format == "sharedfile")  {
 			
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					SharedOrder = new SharedOrderVector(in);
+					SharedOrder = new SharedOrderVector(in, groups, nextDistanceLabel);
 					thisLabel = SharedOrder->getLabel();
+                    if (SharedOrder->getNumBins() == 0) { delete SharedOrder; SharedOrder =  NULL; break; } //no valid groups
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete SharedOrder;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}else{ SharedOrder = NULL;  }
@@ -282,10 +315,10 @@ OrderVector* InputData::getOrderVector(){
 	try {
 		if(fileHandle){
 			if((format == "list") || (format == "listorder")) {
-				input = new ListVector(fileHandle);
+				input = new ListVector(fileHandle, nextDistanceLabel, otuTag);
 			}
 			else if (format == "shared")  {
-				input = new SharedListVector(fileHandle);
+				input = new SharedListVector(fileHandle, groups, nextDistanceLabel, otuTag);
 			}
 			else if(format == "rabund"){
 				input = new RAbundVector(fileHandle);
@@ -297,7 +330,7 @@ OrderVector* InputData::getOrderVector(){
 				input = new SAbundVector(fileHandle);
 			}
 						
-			m->gobble(fileHandle);
+			util.gobble(fileHandle);
 			
 			output = new OrderVector();	
 			*output = (input->getOrderVector());
@@ -320,41 +353,42 @@ OrderVector* InputData::getOrderVector(string label){
 	
 		ifstream in;
 		string  thisLabel;
-		m->openInputFile(filename, in);
+		util.openInputFile(filename, in);
+        nextDistanceLabel = "";
 		
 		if(in){
 			if((format == "list") || (format == "listorder")) {
-                m->saveNextLabel = "";
-				while (in.eof() != true) {
+                nextDistanceLabel = "";
+				while (!in.eof()) {
 					
-					input = new ListVector(in);
+					input = new ListVector(in, nextDistanceLabel, otuTag);
 					thisLabel = input->getLabel();
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}
 			else if (format == "shared")  {
-				m->saveNextLabel = "";
-				while (in.eof() != true) {
+				nextDistanceLabel = "";
+				while (!in.eof()) {
 					
-					input = new SharedListVector(in);
+					input = new SharedListVector(in, groups, nextDistanceLabel, otuTag);
 					thisLabel = input->getLabel();
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "rabund"){
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new RAbundVector(in);
 					thisLabel = input->getLabel();
@@ -363,13 +397,13 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "order"){			
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new OrderVector(in);
 					thisLabel = input->getLabel();
@@ -378,13 +412,13 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "sabund"){
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new SAbundVector(in);
 					thisLabel = input->getLabel();
@@ -393,7 +427,7 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 					
 				}
 
@@ -416,73 +450,88 @@ OrderVector* InputData::getOrderVector(string label){
 		exit(1);
 	}
 }
+/***********************************************************************/
+SharedRAbundVectors* InputData::getSharedRAbundVectors(){
+    try {
+        if(fileHandle){
+            if (format == "sharedfile")  {
+                SharedRAbundVectors* shared = new SharedRAbundVectors(fileHandle, groups, nextDistanceLabel, otuTag);
+                if (shared != NULL) {
+                    //pass labels to others distances in file
+                    if (currentLabels.size() == 0) { currentLabels = shared->getOTUNames(); }
+                    else { shared->setOTUNames(currentLabels);  }
+                    if (shared->getNumBins() == 0) { delete shared; shared = NULL; } //no valid groups
+                }
+                return shared;
+            }else if (format == "shared") {
+                SharedList = new SharedListVector(fileHandle, groups, nextDistanceLabel, otuTag);
+                
+                if (SharedList != NULL) {
+                    //pass labels to others distances in file
+                    if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
+                    else { SharedList->setLabels(currentLabels);  }
+
+                    return SharedList->getSharedRAbundVector();
+                }
+            }
+            util.gobble(fileHandle);
+        }
+        
+        //this is created to signal to calling function that the input file is at eof
+        SharedRAbundVectors* null; null = NULL;
+        return null;
+        
+    }
+    catch(exception& e) {
+        m->errorOut(e, "InputData", "getSharedRAbundVectors");
+        exit(1);
+    }
+}
 
 /***********************************************************************/
-//this is used when you don't need the order vector
-vector<SharedRAbundVector*> InputData::getSharedRAbundVectors(){
-	try {
-		if(fileHandle){
-			if (format == "sharedfile")  {
-				SharedRAbundVector* SharedRAbund = new SharedRAbundVector(fileHandle);
-				if (SharedRAbund != NULL) {
-					return SharedRAbund->getSharedRAbundVectors();
-				}
-			}else if (format == "shared") {
-				SharedList = new SharedListVector(fileHandle);
-				
-				if (SharedList != NULL) {
-					return SharedList->getSharedRAbundVector();
-				}
-			}
-			m->gobble(fileHandle);
-		}
-				
-		//this is created to signal to calling function that the input file is at eof
-		vector<SharedRAbundVector*> null;  null.push_back(NULL);
-		return null;
-		
-	}
-	catch(exception& e) {
-		m->errorOut(e, "InputData", "getSharedRAbundVectors");
-		exit(1);
-	}
-}
-/***********************************************************************/
-vector<SharedRAbundVector*> InputData::getSharedRAbundVectors(string label){
+SharedRAbundVectors* InputData::getSharedRAbundVectors(string label){
 	try {
 		ifstream in;
 		string  thisLabel;
 		
-		m->openInputFile(filename, in);
-		m->saveNextLabel = "";
+		util.openInputFile(filename, in);
+		nextDistanceLabel = "";
 	
 		if(in){
 			if (format == "sharedfile")  {
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					SharedRAbundVector* SharedRAbund = new SharedRAbundVector(in);
+					SharedRAbundVectors* SharedRAbund = new SharedRAbundVectors(in, groups, nextDistanceLabel, otuTag);
 					if (SharedRAbund != NULL) {
 						thisLabel = SharedRAbund->getLabel();
-					
+                        
+                        if (SharedRAbund->getNumBins() == 0) { delete SharedRAbund; SharedRAbund = NULL; break; } //no valid groups
+                        
+                        //pass labels to others distances in file
+                        if (currentLabels.size() == 0) { currentLabels = SharedRAbund->getOTUNames(); }
+                        else { SharedRAbund->setOTUNames(currentLabels);  }
+                        
+
 						//if you are at the last label
-						if (thisLabel == label) {  in.close(); return SharedRAbund->getSharedRAbundVectors();  }
+						if (thisLabel == label) {  in.close(); return SharedRAbund;  }
 						else {
-							//so you don't loose this memory
-							vector<SharedRAbundVector*> lookup = SharedRAbund->getSharedRAbundVectors(); 
-							for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
 							delete SharedRAbund;
 						}
 					}else{  break;  }
-					m->gobble(in);
+					util.gobble(in);
 					
 				}
 			}else if (format == "shared") {
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					SharedList = new SharedListVector(in);
+					SharedList = new SharedListVector(in, groups, nextDistanceLabel, otuTag);
 					
 					if (SharedList != NULL) {
 						thisLabel = SharedList->getLabel();
+                        //pass labels to others distances in file
+                        if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
+                        else { SharedList->setLabels(currentLabels);  }
+
 						//if you are at the last label
 						if (thisLabel == label) {  in.close(); return SharedList->getSharedRAbundVector();  }
 						else {
@@ -490,7 +539,7 @@ vector<SharedRAbundVector*> InputData::getSharedRAbundVectors(string label){
 							delete SharedList;
 						}
 					}else{  break;  }
-					m->gobble(in);
+					util.gobble(in);
 					
 				}
 			
@@ -498,7 +547,7 @@ vector<SharedRAbundVector*> InputData::getSharedRAbundVectors(string label){
 		}
 				
 		//this is created to signal to calling function that the input file is at eof
-		vector<SharedRAbundVector*> null;  null.push_back(NULL);
+		SharedRAbundVectors* null;  null = (NULL);
 		in.close();
 		return null;
 	
@@ -511,31 +560,39 @@ vector<SharedRAbundVector*> InputData::getSharedRAbundVectors(string label){
 
 /***********************************************************************/
 //this is used when you don't need the order vector
-vector<SharedRAbundFloatVector*> InputData::getSharedRAbundFloatVectors(){
+SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(){
 	try {
 		if(fileHandle){
 			if (format == "relabund")  {
-				SharedRAbundFloatVector* SharedRelAbund = new SharedRAbundFloatVector(fileHandle);
-				if (SharedRelAbund != NULL) {
-					return SharedRelAbund->getSharedRAbundFloatVectors();
-				}
+				SharedRAbundFloatVectors* SharedRelAbund = new SharedRAbundFloatVectors(fileHandle, groups, nextDistanceLabel, otuTag);
+                if (SharedRelAbund->getNumBins() == 0) { delete SharedRelAbund; SharedRelAbund = NULL;  } //no valid groups
+                else { //pass labels to others distances in file
+                    if (currentLabels.size() == 0) { currentLabels = SharedRelAbund->getOTUNames(); }
+                    else { SharedRelAbund->setOTUNames(currentLabels);  }
+                }
+                return SharedRelAbund;
 			}else if (format == "sharedfile")  {
-				SharedRAbundVector* SharedRAbund = new SharedRAbundVector(fileHandle);
+				SharedRAbundVectors* SharedRAbund = new SharedRAbundVectors(fileHandle, groups, nextDistanceLabel, otuTag);
 				if (SharedRAbund != NULL) {
-					vector<SharedRAbundVector*> lookup = SharedRAbund->getSharedRAbundVectors(); 
-					vector<SharedRAbundFloatVector*> lookupFloat = SharedRAbund->getSharedRAbundFloatVectors(lookup); 
-					for (int i = 0; i < lookup.size(); i++) { delete lookup[i]; } lookup.clear();
-					return lookupFloat;  
+                    //pass labels to others distances in file
+                    if (currentLabels.size() == 0) { currentLabels = SharedRAbund->getOTUNames(); }
+                    else { SharedRAbund->setOTUNames(currentLabels);  }
+
+					vector<SharedRAbundFloatVector*> lookup = SharedRAbund->getSharedRAbundFloatVectors();
+                    SharedRAbundFloatVectors* SharedRelAbund = new SharedRAbundFloatVectors();
+                    SharedRelAbund->setOTUNames(currentLabels);
+                    for (int i = 0; i < lookup.size(); i++) { SharedRelAbund->push_back(lookup[i]); }
+					delete SharedRAbund;
+                    return SharedRelAbund;
 				}
 						
 			}
-			m->gobble(fileHandle);
+			util.gobble(fileHandle);
 		}
 				
 		//this is created to signal to calling function that the input file is at eof
-		vector<SharedRAbundFloatVector*> null;  null.push_back(NULL);
+		SharedRAbundFloatVectors* null;  null = (NULL);
 		return null;
-		
 	}
 	catch(exception& e) {
 		m->errorOut(e, "InputData", "getSharedRAbundFloatVectors");
@@ -543,61 +600,63 @@ vector<SharedRAbundFloatVector*> InputData::getSharedRAbundFloatVectors(){
 	}
 }
 /***********************************************************************/
-vector<SharedRAbundFloatVector*> InputData::getSharedRAbundFloatVectors(string label){
+SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(string label){
 	try {
 		ifstream in;
 		string  thisLabel;
 		
-		m->openInputFile(filename, in);
-		m->saveNextLabel = "";
+		util.openInputFile(filename, in);
+		nextDistanceLabel = "";
 		
 		if(in){
 			if (format == "relabund")  {
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					SharedRAbundFloatVector* SharedRelAbund = new SharedRAbundFloatVector(in);
+					SharedRAbundFloatVectors* SharedRelAbund = new SharedRAbundFloatVectors(in, groups, nextDistanceLabel, otuTag);
 					if (SharedRelAbund != NULL) {
 						thisLabel = SharedRelAbund->getLabel();
+                        
+                        if (SharedRelAbund->getNumBins() == 0) { delete SharedRelAbund; SharedRelAbund = NULL; break;  } //no valid groups
+                        
+                        //pass labels to others distances in file
+                        if (currentLabels.size() == 0) { currentLabels = SharedRelAbund->getOTUNames(); }
+                        else { SharedRelAbund->setOTUNames(currentLabels);  }
 						//if you are at the last label
-						if (thisLabel == label) {  in.close(); return SharedRelAbund->getSharedRAbundFloatVectors();  }
-						else {
-							//so you don't loose this memory
-							vector<SharedRAbundFloatVector*> lookup = SharedRelAbund->getSharedRAbundFloatVectors(); 
-							for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
-							delete SharedRelAbund;
-						}
+						if (thisLabel == label) {  in.close(); return SharedRelAbund;  }
+						else { delete SharedRelAbund; }
 					}else{  break;  }
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}else if (format == "sharedfile")  {
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					SharedRAbundVector* SharedRAbund = new SharedRAbundVector(in);
+					SharedRAbundVectors* SharedRAbund = new SharedRAbundVectors(in, groups, nextDistanceLabel, otuTag);
 					if (SharedRAbund != NULL) {
 						thisLabel = SharedRAbund->getLabel();
+                        
+                        //pass labels to others distances in file
+                        if (currentLabels.size() == 0) { currentLabels = SharedRAbund->getOTUNames(); }
+                        else { SharedRAbund->setOTUNames(currentLabels);  }
 						
 						//if you are at the last label
 						if (thisLabel == label) {  
 							in.close(); 
-							vector<SharedRAbundVector*> lookup = SharedRAbund->getSharedRAbundVectors(); 
-							vector<SharedRAbundFloatVector*> lookupFloat = SharedRAbund->getSharedRAbundFloatVectors(lookup); 
-							for (int i = 0; i < lookup.size(); i++) { delete lookup[i]; } lookup.clear();
-							return lookupFloat;  
-						}else {
-							//so you don't loose this memory
-							vector<SharedRAbundVector*> lookup = SharedRAbund->getSharedRAbundVectors(); 
-							for (int i = 0; i < lookup.size(); i++) { delete lookup[i]; } lookup.clear();
-							delete SharedRAbund;
-						}
+                            vector<SharedRAbundFloatVector*> lookup = SharedRAbund->getSharedRAbundFloatVectors();
+                            SharedRAbundFloatVectors* SharedRelAbund = new SharedRAbundFloatVectors();
+                            SharedRelAbund->setOTUNames(currentLabels);
+                            for (int i = 0; i < lookup.size(); i++) { SharedRelAbund->push_back(lookup[i]); }
+                            delete SharedRAbund;
+                            return SharedRelAbund;
+						}else { delete SharedRAbund; }
 					}else{  break;  }
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}	
 		}
 		
 				
 		//this is created to signal to calling function that the input file is at eof
-		vector<SharedRAbundFloatVector*> null;  null.push_back(NULL);
+		SharedRAbundFloatVectors* null;  null = (NULL);
 		in.close();
 		return null;
 	
@@ -613,10 +672,10 @@ SAbundVector* InputData::getSAbundVector(){
 	try {
 		if(fileHandle){
 			if (format == "list") {
-				input = new ListVector(fileHandle);
+				input = new ListVector(fileHandle, nextDistanceLabel, otuTag);
 			}
 			else if (format == "shared")  {
-				input = new SharedListVector(fileHandle);
+				input = new SharedListVector(fileHandle, groups, nextDistanceLabel, otuTag);
 			}
 			else if(format == "rabund"){
 				input = new RAbundVector(fileHandle);
@@ -627,7 +686,7 @@ SAbundVector* InputData::getSAbundVector(){
 			else if(format == "sabund"){
 				input = new SAbundVector(fileHandle);
 			}					
-			m->gobble(fileHandle);
+			util.gobble(fileHandle);
 
 			sabund = new SAbundVector();
 			*sabund = (input->getSAbundVector());
@@ -649,41 +708,42 @@ SAbundVector* InputData::getSAbundVector(string label){
 	
 		ifstream in;
 		string  thisLabel;
-		m->openInputFile(filename, in);
+		util.openInputFile(filename, in);
+        nextDistanceLabel = "";
 		
 		if(in){
 			if (format == "list") {
-                m->saveNextLabel = "";
-				while (in.eof() != true) {
+                nextDistanceLabel = "";
+				while (!in.eof()) {
 					
-					input = new ListVector(in);
+					input = new ListVector(in, nextDistanceLabel, otuTag);
 					thisLabel = input->getLabel();
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}
 			else if (format == "shared")  {
-				m->saveNextLabel = "";
-				while (in.eof() != true) {
+				nextDistanceLabel = "";
+				while (!in.eof()) {
 					
-					input = new SharedListVector(in);
+					input = new SharedListVector(in, groups, nextDistanceLabel, otuTag);
 					thisLabel = input->getLabel();
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "rabund"){
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new RAbundVector(in);
 					thisLabel = input->getLabel();
@@ -692,13 +752,13 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "order"){			
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new OrderVector(in);
 					thisLabel = input->getLabel();
@@ -707,13 +767,13 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "sabund"){
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new SAbundVector(in);
 					thisLabel = input->getLabel();
@@ -722,7 +782,7 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 					
 				}
 
@@ -751,10 +811,10 @@ RAbundVector* InputData::getRAbundVector(){
 	try {
 		if(fileHandle){
 			if (format == "list") {
-				input = new ListVector(fileHandle);
+				input = new ListVector(fileHandle, nextDistanceLabel, otuTag);
 			}
 			else if (format == "shared")  {
-				input = new SharedListVector(fileHandle);
+				input = new SharedListVector(fileHandle, groups, nextDistanceLabel, otuTag);
 			}
 			else if(format == "rabund"){
 				input = new RAbundVector(fileHandle);
@@ -766,7 +826,7 @@ RAbundVector* InputData::getRAbundVector(){
 				input = new SAbundVector(fileHandle);
 			}
 			
-			m->gobble(fileHandle);
+			util.gobble(fileHandle);
 
 			rabund = new RAbundVector();
 			*rabund = (input->getRAbundVector());
@@ -788,43 +848,44 @@ RAbundVector* InputData::getRAbundVector(string label){
 	
 		ifstream in;
 		string  thisLabel;
-		m->openInputFile(filename, in);
+		util.openInputFile(filename, in);
+        nextDistanceLabel = "";
 		
 		if(in){
 			if (format == "list") {
-                m->saveNextLabel = "";
+                nextDistanceLabel = "";
 			
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					input = new ListVector(in);
+					input = new ListVector(in, nextDistanceLabel, otuTag);
 					thisLabel = input->getLabel();
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 			}
 			else if (format == "shared")  {
-                m->saveNextLabel = "";
+                nextDistanceLabel = "";
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
-					input = new SharedListVector(in);
+					input = new SharedListVector(in, groups, nextDistanceLabel, otuTag);
 					thisLabel = input->getLabel();
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "rabund"){
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new RAbundVector(in);
 					thisLabel = input->getLabel();
@@ -833,13 +894,13 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "order"){			
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new OrderVector(in);
 					thisLabel = input->getLabel();
@@ -848,13 +909,13 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 				}
 
 			}
 			else if(format == "sabund"){
 				
-				while (in.eof() != true) {
+				while (!in.eof()) {
 					
 					input = new SAbundVector(in);
 					thisLabel = input->getLabel();
@@ -863,7 +924,7 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					m->gobble(in);
+					util.gobble(in);
 					
 				}
 
