@@ -10,10 +10,10 @@
 class Rarefact {
 	
 public:
-	Rarefact(OrderVector& o, vector<Display*> disp, int p, set<int> en) :
-			numSeqs(o.getNumSeqs()), order(o), displays(disp), label(o.getLabel()), processors(p), ends(en)  { m = MothurOut::getInstance(); }
-	Rarefact(vector<SharedRAbundVector*> shared, vector<Display*> disp) :
-					 lookup(shared), displays(disp) {  m = MothurOut::getInstance(); }
+	Rarefact(OrderVector& o, vector<Display*> disp, set<int> en) :
+    numSeqs(o.getNumSeqs()), order(o), displays(disp), label(o.getLabel()),  ends(en)  { m = MothurOut::getInstance(); jumble = false; }
+	Rarefact(vector<SharedRAbundVector*> shared, vector<Display*> disp, bool j) :
+					 lookup(shared), displays(disp), jumble(j) {  m = MothurOut::getInstance(); }
 
 	~Rarefact(){};
 	int getCurve(float, int);
@@ -23,14 +23,15 @@ private:
 	
 	OrderVector order;
 	vector<Display*> displays;
-	int numSeqs, numGroupComb, processors;
+	int numSeqs, numGroupComb;
 	string label;
     set<int> ends;
 	void mergeVectors(SharedRAbundVector*, SharedRAbundVector*);
-	vector<SharedRAbundVector*> lookup; 
+	vector<SharedRAbundVector*> lookup;
 	MothurOut* m;
+    bool jumble;
+    Utils util;
 	
-	int createProcesses(vector<int>&, RarefactionCurveData*, int, int);
 	int driver(RarefactionCurveData*, int, int);
 
 };
