@@ -25,13 +25,13 @@ int seqNoise::getSequenceData(string sequenceFileName, vector<string>& sequences
 	try {
 		
 		ifstream sequenceFile;
-		m->openInputFile(sequenceFileName, sequenceFile);
+		util.openInputFile(sequenceFileName, sequenceFile);
 		
 		while(!sequenceFile.eof()){
 			
-			if (m->control_pressed) { break; }
+			if (m->getControl_pressed()) { break; }
 			
-			Sequence temp(sequenceFile); m->gobble(sequenceFile);
+			Sequence temp(sequenceFile); util.gobble(sequenceFile);
 			
 			if (temp.getName() != "") {
 				sequences.push_back(temp.getAligned());
@@ -63,16 +63,16 @@ int seqNoise::getRedundantNames(string namesFileName, vector<string>& uniqueName
 	try {
 		string unique, redundant;
 		ifstream namesFile;
-		m->openInputFile(namesFileName, namesFile);
+		util.openInputFile(namesFileName, namesFile);
 		
 		for(int i=0;i<redundantNames.size();i++){
 			
-			if (m->control_pressed) { break; }
+			if (m->getControl_pressed()) { break; }
 			
-			namesFile >> uniqueNames[i]; m->gobble(namesFile);
-			namesFile >> redundantNames[i]; m->gobble(namesFile);
+			namesFile >> uniqueNames[i]; util.gobble(namesFile);
+			namesFile >> redundantNames[i]; util.gobble(namesFile);
 			
-			seqFreq[i] = m->getNumNames(redundantNames[i]);
+			seqFreq[i] = util.getNumNames(redundantNames[i]);
 		}
 		namesFile.close();
 		
@@ -89,7 +89,7 @@ int seqNoise::addRedundantName(string uniqueName, string redundantName, vector<s
 		
 		uniqueNames.push_back(uniqueName);
 		redundantNames.push_back(redundantName);
-		seqFreq.push_back(m->getNumNames(redundantName));
+		seqFreq.push_back(util.getNumNames(redundantName));
 		
 		return 0;
 	}
@@ -103,7 +103,7 @@ int seqNoise::getDistanceData(string distFileName, vector<double>& distances){
 	try {
 		
 		ifstream distFile;
-		m->openInputFile(distFileName, distFile);
+		util.openInputFile(distFileName, distFile);
 		
 		int numSeqs = 0;
 		string name = "";
@@ -112,7 +112,7 @@ int seqNoise::getDistanceData(string distFileName, vector<double>& distances){
 		
 		for(int i=0;i<numSeqs;i++){
 			
-			if (m->control_pressed) {  break; }
+			if (m->getControl_pressed()) {  break; }
 			
 			distances[i * numSeqs + i] = 0.0000;
 			
@@ -139,14 +139,15 @@ int seqNoise::getListData(string listFileName, double cutOff, vector<int>& otuDa
 	try {
 		
 		ifstream listFile;
-		m->openInputFile(listFileName, listFile);
+		util.openInputFile(listFileName, listFile);
 		
 		bool adjustCutoff = true;
         string lastLabel = "";
+        string readLabels = "";
         
 		while(!listFile.eof()){
             
-            ListVector list(listFile); m->gobble(listFile); //10/18/13 - change to reading with listvector to accomodate changes to the listfiel format. ie. adding header labels.
+            ListVector list(listFile, readLabels, lastLabel); util.gobble(listFile); //10/18/13 - change to reading with listvector to accomodate changes to the listfiel format. ie. adding header labels.
             
             string thisLabel = list.getLabel();
             lastLabel = thisLabel;
@@ -154,7 +155,7 @@ int seqNoise::getListData(string listFileName, double cutOff, vector<int>& otuDa
             if (thisLabel == "unique") {} //skip to next label in listfile
             else {
                 double threshold;
-                m->mothurConvert(thisLabel, threshold);
+                util.mothurConvert(thisLabel, threshold);
                 
                 if(threshold < cutOff){} //skip to next label in listfile
                 else{
@@ -164,7 +165,7 @@ int seqNoise::getListData(string listFileName, double cutOff, vector<int>& otuDa
                     
                     for(int i=0;i<numOTUs;i++){
                         
-                        if (m->control_pressed) { return 0; }
+                        if (m->getControl_pressed()) { return 0; }
                         
                         string otu = list.get(i);
                         int count = 0;
@@ -194,11 +195,11 @@ int seqNoise::getListData(string listFileName, double cutOff, vector<int>& otuDa
                     int numSeqs = otuData.size();
                     
                     for(int i=0;i<numSeqs;i++){
-                        if (m->control_pressed) { return 0; }
+                        if (m->getControl_pressed()) { return 0; }
                         otuBySeqLookUp[otuData[i]].push_back(i);
                     }
                     for(int i=0;i<numOTUs;i++){
-                        if (m->control_pressed) { return 0; }
+                        if (m->getControl_pressed()) { return 0; }
                         for(int j=otuBySeqLookUp[i].size();j<numSeqs;j++){
                             otuBySeqLookUp[i].push_back(0);
                         }
@@ -214,7 +215,7 @@ int seqNoise::getListData(string listFileName, double cutOff, vector<int>& otuDa
 		//the listfile does not contain a threshold greater than the cutoff so use highest value
 		if (adjustCutoff) {
             
-            InputData input(listFileName, "list");
+            InputData input(listFileName, "list", nullVector);
             ListVector* list = input.getListVector(lastLabel);
             
             int numOTUs = list->getNumBins();
@@ -222,7 +223,7 @@ int seqNoise::getListData(string listFileName, double cutOff, vector<int>& otuDa
 			
 			for(int i=0;i<numOTUs;i++){
 				
-				if (m->control_pressed) { return 0; }
+				if (m->getControl_pressed()) { return 0; }
 				
 				string otu = list->get(i);
 				
@@ -253,11 +254,11 @@ int seqNoise::getListData(string listFileName, double cutOff, vector<int>& otuDa
 			int numSeqs = otuData.size();
 			
 			for(int i=0;i<numSeqs;i++){
-				if (m->control_pressed) { return 0; }
+				if (m->getControl_pressed()) { return 0; }
 				otuBySeqLookUp[otuData[i]].push_back(i);
 			}
 			for(int i=0;i<numOTUs;i++){
-				if (m->control_pressed) { return 0; }
+				if (m->getControl_pressed()) { return 0; }
 				for(int j=otuBySeqLookUp[i].size();j<numSeqs;j++){
 					otuBySeqLookUp[i].push_back(0);
 				}
@@ -290,7 +291,7 @@ int seqNoise::updateOTUCountData(vector<int> otuFreq,
 		for(int i=0;i<numOTUs;i++){
 			cumCount[i] = count;
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			for(int j=0;j<otuFreq[i];j++){
 				anP[count] = otuBySeqLookUp[i][j];
@@ -326,7 +327,7 @@ double seqNoise::calcNewWeights(
 		
 		for(int i=0;i<numOTUs;i++){
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			double change = weights[i];
 			
@@ -375,7 +376,7 @@ int seqNoise::calcCentroids(
 		
 		for(int i=0;i<numOTUs;i++){
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			int minFIndex = -1;
 			double minFValue = 1e10;
@@ -446,12 +447,12 @@ int seqNoise::checkCentroids(vector<double>& weights, vector<int> centroids){
 		
 		double minWeight = MIN_WEIGHT;
 		for(int i=0;i<numOTUs;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			if(weights[i] < minWeight){	unique[i] = -1;	}
 		}
 		
 		for(int i=0;i<numOTUs;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			if(unique[i] == 1){
 				for(int j=i+1; j<numOTUs;j++){
 					if(unique[j] == 1){
@@ -485,7 +486,7 @@ int seqNoise::setUpOTUData(vector<int>& otuData, vector<double>& percentage, vec
 		vector<double> bestIndex(numSeqs, -1);
 		
 		for(int i=0;i<numOTUs;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			for(int j=0;j<otuFreq[i];j++){
 				
 				int index1 = cumCount[i] + j;
@@ -500,7 +501,7 @@ int seqNoise::setUpOTUData(vector<int>& otuData, vector<double>& percentage, vec
 		}
 		
 		for(int i=0;i<numSeqs;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			otuData[i] = bestIndex[i];
 			percentage[i] = 1 - bestTau[i];
 		}
@@ -526,7 +527,7 @@ int seqNoise::finishOTUData(vector<int> otuData, vector<int>& otuFreq, vector<in
 		anI.assign(numSeqs, 0);
 		
 		for(int i=0;i<numSeqs;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			int otu = otuData[i];
 			total++;
 			
@@ -550,7 +551,7 @@ int seqNoise::getLastMatch(char direction, vector<vector<char> >& alignMoves, in
 		char nullReturn = -1;
 		
 		while(i>=1 && j>=1){
-			if (m->control_pressed) { return nullReturn; }
+			if (m->getControl_pressed()) { return nullReturn; }
 			if(direction == 'd'){
 				if(seqA[i-1] == seqB[j-1])	{	return seqA[i-1];	}
 				else						{	return nullReturn;	}
@@ -608,25 +609,25 @@ int seqNoise::countDiffs(vector<int> query, vector<int> ref){
 		vector<vector<char> > alignMoves(queryLength + 1);
 		
 		for(int i=0;i<=queryLength;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			alignMatrix[i].resize(refLength + 1, 0);
 			alignMoves[i].resize(refLength + 1, 'x');
 		}
 		
 		for(int i=0;i<=queryLength;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			alignMatrix[i][0] = 15.0 * i;
 			alignMoves[i][0] = 'u';
 		}
 		
 		for(int i=0;i<=refLength;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			alignMatrix[0][i] = 15.0 * i;
 			alignMoves[0][i] = 'l';
 		}
 		
 		for(int i=1;i<=queryLength;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			for(int j=1;j<=refLength;j++){
 				
 				double nogap;		
@@ -700,7 +701,7 @@ int seqNoise::countDiffs(vector<int> query, vector<int> ref){
 		//	string bases = "ACTG";
 		
 		while(i > 0 && j > 0){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			if(alignMoves[i][j] == 'd'){
 				//			alignA = bases[query[i-1]] + alignA;
 				//			alignB = bases[ref[j-1]] + alignB;
@@ -753,7 +754,7 @@ vector<int> seqNoise::convertSeq(string bases){
 		vector<int> numbers(bases.length(), -1);
 		
 		for(int i=0;i<bases.length();i++){
-			if (m->control_pressed) { return numbers; }
+			if (m->getControl_pressed()) { return numbers; }
 			
 			char b = bases[i];
 			
@@ -780,7 +781,7 @@ string seqNoise::degapSeq(string aligned){
 		
 		for(int i=0;i<aligned.length();i++){
 			
-			if (m->control_pressed) { return ""; }
+			if (m->getControl_pressed()) { return ""; }
 			
 			if(aligned[i] != '-' && aligned[i] != '.'){
 				unaligned += aligned[i];
@@ -810,7 +811,7 @@ int seqNoise::writeOutput(string fastaFileName, string namesFileName, string uMa
 		vector<int> maxSequenceIndex(numOTUs, 0);
 		
 		for(int i=0;i<numSeqs;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			if(maxSequenceAbund[otuData[i]] < seqFreq[i]){
 				maxSequenceAbund[otuData[i]] = seqFreq[i];
 				maxSequenceIndex[otuData[i]] = i;
@@ -820,7 +821,7 @@ int seqNoise::writeOutput(string fastaFileName, string namesFileName, string uMa
 		int count = 1;
 		
 		for(int i=0;i<numOTUs;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			if(finalTau[i] > 0){
 				
@@ -855,7 +856,7 @@ int seqNoise::writeOutput(string fastaFileName, string namesFileName, string uMa
 				
 				
 				for(int j=0;j<frequencyData.size();j++){
-					if (m->control_pressed) { return 0; }
+					if (m->getControl_pressed()) { return 0; }
 					redundantSeqs += ',' + redundantNames[frequencyData[j].index];
 					
 					uMapFile << uniqueNames[frequencyData[j].index] << '\t' << seqFreq[frequencyData[j].index] << '\t';
