@@ -33,11 +33,11 @@ vector<string> Venn::getPic(SAbundVector* sabund, vector<Calculator*> vCalcs) {
 		vector<string> outputNames;
 
 		for(int i=0;i<vCalcs.size();i++){
-			string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + "." + sabund->getLabel() + "." + vCalcs[i]->getName() + ".svg";
+			string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + "." + sabund->getLabel() + "." + vCalcs[i]->getName() + ".svg";
 			outputNames.push_back(filenamesvg);
-			m->openOutputFile(filenamesvg, outsvg);
+			util.openOutputFile(filenamesvg, outsvg);
 			
-			if (m->control_pressed) { outsvg.close(); return outputNames; }
+			if (m->getControl_pressed()) { outsvg.close(); return outputNames; }
 
 			vector<double> data = vCalcs[i]->getValues(sabund);
 			
@@ -91,11 +91,11 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 			
 			//make a file for each calculator
 			for(int i=0;i<vCalcs.size();i++){
-				string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + ".svg";
+				string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + ".svg";
 				outputNames.push_back(filenamesvg);
-				m->openOutputFile(filenamesvg, outsvg);
+				util.openOutputFile(filenamesvg, outsvg);
 				
-				if (m->control_pressed) { outsvg.close(); return outputNames; }
+				if (m->getControl_pressed()) { outsvg.close(); return outputNames; }
 				
 				//in essence you want to run it like a single 
 				if (vCalcs[i]->getName() == "sharedsobs") {
@@ -147,12 +147,12 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 			
 			//make a file for each calculator
 			for(int i=0;i<vCalcs.size();i++){
-				string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + ".svg";
+				string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + ".svg";
 
 				outputNames.push_back(filenamesvg);
-				m->openOutputFile(filenamesvg, outsvg);
+				util.openOutputFile(filenamesvg, outsvg);
 				
-				if (m->control_pressed) { outsvg.close(); return outputNames; }
+				if (m->getControl_pressed()) { outsvg.close(); return outputNames; }
 				
 				//get estimates for sharedAB
                 vector<string> labels;
@@ -164,11 +164,11 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                     if (sharedOtus &&  (labels.size() != 0)) {
                         string groupsTag = "";
                         for (int h = 0; h < lookup.size()-1; h++) { groupsTag += lookup[h]->getGroup() + "-"; }  groupsTag += lookup[lookup.size()-1]->getGroup();
-                        string filenameShared = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + groupsTag + ".sharedotus";
+                        string filenameShared = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + groupsTag + ".sharedotus";
                         
                         outputNames.push_back(filenameShared);
                         ofstream outShared;
-                        m->openOutputFile(filenameShared, outShared);
+                        util.openOutputFile(filenameShared, outShared);
                         outShared << "Groups\tNumShared\tOTULabels\n";
                         outShared << lookup[0]->getGroup() + "-" + lookup[1]->getGroup() << '\t' << labels.size() << '\t';
                         for (int k = 0; k < labels.size()-1; k++) {
@@ -186,7 +186,6 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 				if (nseqs) {
 					NSeqs* nseqsCalc = new NSeqs();
 					vector<double> data = nseqsCalc->getValues(lookup);
-					cout << data[0] << '\t' << data[1] << endl;
 					sharedVal = data[0] + data[1];
 					numSeqsA = sabundA->getNumSeqs();
 					numSeqsB = sabundB->getNumSeqs();
@@ -264,12 +263,12 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 			//make a file for each calculator
 			for(int i=0;i<vCalcs.size();i++){
 			
-				string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + "-" + lookup[2]->getGroup() + ".svg";
+				string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + "-" + lookup[2]->getGroup() + ".svg";
 
 				outputNames.push_back(filenamesvg);
-				m->openOutputFile(filenamesvg, outsvg);
+				util.openOutputFile(filenamesvg, outsvg);
 				
-				if (m->control_pressed) { outsvg.close(); return outputNames; }
+				if (m->getControl_pressed()) { outsvg.close(); return outputNames; }
 				
 				int sharedVal, sharedABVal, sharedACVal, sharedBCVal, numSeqsA, numSeqsB, numSeqsC, uniqSeqsToA, uniqSeqsToB, uniqSeqsToC;
 				
@@ -338,9 +337,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 					if (vCalcs[i]->getMultiple() == false) {
 						//merge BC and estimate with shared with A
 						SharedRAbundVector* merge = new SharedRAbundVector();
-						for (int j = 0; j < lookup[1]->size(); j++) {
-							merge->push_back((lookup[1]->getAbundance(j) + lookup[2]->getAbundance(j)), "");
-						}
+						for (int j = 0; j < lookup[1]->size(); j++) {  merge->push_back((lookup[1]->get(j) + lookup[2]->get(j)));  }
 					
 						subset.clear();
 						subset.push_back(lookup[0]); subset.push_back(merge);
@@ -349,9 +346,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 						delete merge;
 						//merge AC and estimate with shared with B
 						merge = new SharedRAbundVector();
-						for (int j = 0; j < lookup[0]->size(); j++) {
-							merge->push_back((lookup[0]->getAbundance(j) + lookup[2]->getAbundance(j)), "");
-						}
+						for (int j = 0; j < lookup[0]->size(); j++) { merge->push_back((lookup[0]->get(j) + lookup[2]->get(j))); }
 					
 						subset.clear();
 						subset.push_back(merge); subset.push_back(lookup[1]);
@@ -360,9 +355,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 						delete merge;
 						//merge AB and estimate with shared with C
 						merge = new SharedRAbundVector();
-						for (int j = 0; j < lookup[0]->size(); j++) {
-							merge->push_back((lookup[0]->getAbundance(j) + lookup[1]->getAbundance(j)), "");
-						}
+						for (int j = 0; j < lookup[0]->size(); j++) { merge->push_back((lookup[0]->get(j) + lookup[1]->get(j))); }
 					
 						subset.clear();
 						subset.push_back(lookup[2]); subset.push_back(merge);
@@ -459,11 +452,11 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs")) {
                         string groupsTag = "";
                         for (int h = 0; h < lookup.size()-1; h++) { groupsTag += lookup[h]->getGroup() + "-"; }  groupsTag += lookup[lookup.size()-1]->getGroup();
-                        string filenameShared = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + groupsTag + ".sharedotus";
+                        string filenameShared = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + groupsTag + ".sharedotus";
                         
                         outputNames.push_back(filenameShared);
                        
-                        m->openOutputFile(filenameShared, outShared);
+                        util.openOutputFile(filenameShared, outShared);
                         outShared << "Groups\tNumShared\tOTULabels\n";
                     }
 					vector<SharedRAbundVector*> subset;
@@ -631,11 +624,11 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 				
 				if ((vCalcs[i]->getName() != "sharedsobs") && (vCalcs[i]->getName() != "sharedchao")) { m->mothurOut(vCalcs[i]->getName() + " is not a valid calculator with four groups.  It will be disregarded. "); m->mothurOutEndLine(); }
 				else{
-					string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + "-" + lookup[2]->getGroup() + "-" + lookup[3]->getGroup() + ".svg";
+					string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + "-" + lookup[2]->getGroup() + "-" + lookup[3]->getGroup() + ".svg";
 					outputNames.push_back(filenamesvg);
-					m->openOutputFile(filenamesvg, outsvg);
+					util.openOutputFile(filenamesvg, outsvg);
 
-					if (m->control_pressed) { outsvg.close(); return outputNames; }
+					if (m->getControl_pressed()) { outsvg.close(); return outputNames; }
 					
 					//in essence you want to run it like a single 
 					if (vCalcs[i]->getName() == "sharedsobs") {
@@ -666,11 +659,11 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs")) {
                         string groupsTag = "";
                         for (int h = 0; h < lookup.size()-1; h++) { groupsTag += lookup[h]->getGroup() + "-"; }  groupsTag += lookup[lookup.size()-1]->getGroup();
-                        string filenameShared = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + groupsTag + ".sharedotus";
+                        string filenameShared = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + vCalcs[i]->getName() + "." + groupsTag + ".sharedotus";
                         
                         outputNames.push_back(filenameShared);
                         
-                        m->openOutputFile(filenameShared, outShared);
+                        util.openOutputFile(filenameShared, outShared);
                         outShared << "Groups\tNumShared\tOTULabels\n";
                     }
 
