@@ -9,11 +9,8 @@
  *
  */
 
-#include "sabundvector.hpp"
-#include "sharedrabundvector.h"
-#include "datavector.hpp"
-#include "calculator.h"
 
+#include "calculator.h"
 
 /***********************************************************************/
 
@@ -32,6 +29,7 @@ private:
 	MothurOut* m;
 	bool nseqs, sharedOtus;
 	int fontSize;
+    Utils util;
 };
 
 /***********************************************************************/
