@@ -48,7 +48,7 @@ VsearchFileParser::VsearchFileParser(string f, string nameOrCount, string forma)
         
         if (format == "name") { namefile = nameOrCount; }
         else if (format == "count") { countfile = nameOrCount; }
-        else {  m->mothurOut("[ERROR]: " + format + " is not a valid file format for the VsearchFileParser, quitting.\n"); m->control_pressed = true;  }
+        else {  m->mothurOut("[ERROR]: " + format + " is not a valid file format for the VsearchFileParser, quitting.\n"); m->setControl_pressed(true);  }
         
     }
     catch(exception& e) {
@@ -59,15 +59,16 @@ VsearchFileParser::VsearchFileParser(string f, string nameOrCount, string forma)
 /***********************************************************************/
 string VsearchFileParser::getVsearchFile() {
     try {
-        if (fastafile == "") { m->mothurOut("[ERROR]: no fasta file given, cannot continue.\n"); m->control_pressed = true;  }
+        Utils util;
+        if (fastafile == "") { m->mothurOut("[ERROR]: no fasta file given, cannot continue.\n"); m->setControl_pressed(true);  }
         
         //Run unique.seqs on the data if a name or count file is not given
-        if ((namefile == "") && (countfile == ""))  {  getNamesFile(fastafile);                }
-        else if (namefile != "")                    {  counts = m->readNames(namefile);        }
+        if ((namefile == "") && (countfile == ""))  {  getNamesFile(fastafile);                  }
+        else if (namefile != "")                    {  counts = util.readNames(namefile);        }
         
         if (countfile != "") { CountTable countTable; countTable.readTable(countfile, false, false);  counts = countTable.getNameMap(); }
         
-        if (m->control_pressed) {  return 0; }
+        if (m->getControl_pressed()) {  return 0; }
         
         //Remove gap characters from each sequence if needed
         //Append the number of sequences that each unique sequence represents to the end of the fasta file name
@@ -86,23 +87,24 @@ string VsearchFileParser::getVsearchFile() {
 
 string VsearchFileParser::createVsearchFasta(string inputFile){
     try {
-        string vsearchFasta = m->getSimpleName(fastafile) + ".sorted.fasta.temp";
+        Utils util;
+        string vsearchFasta = util.getSimpleName(fastafile) + ".sorted.fasta.temp";
         
         vector<seqPriorityNode> seqs;
         map<string, int>::iterator it;
         
         ifstream in;
-        m->openInputFile(inputFile, in);
+        util.openInputFile(inputFile, in);
         
         while (!in.eof()) {
             
-            if (m->control_pressed) { in.close(); return vsearchFasta; }
+            if (m->getControl_pressed()) { in.close(); return vsearchFasta; }
             
-            Sequence seq(in); m->gobble(in);
+            Sequence seq(in); util.gobble(in);
             
             it = counts.find(seq.getName());
             if (it == counts.end()) {
-                m->mothurOut("[ERROR]: " + seq.getName() + " is not in your name or countfile, quitting.\n"); m->control_pressed = true;
+                m->mothurOut("[ERROR]: " + seq.getName() + " is not in your name or countfile, quitting.\n"); m->setControl_pressed(true);
             }else {
                 seqPriorityNode temp(it->second, seq.getUnaligned(), it->first);
                 seqs.push_back(temp);
@@ -111,7 +113,7 @@ string VsearchFileParser::createVsearchFasta(string inputFile){
         }
         in.close();
         
-        m->printVsearchFile(seqs, vsearchFasta, ";size=", ";");
+        util.printVsearchFile(seqs, vsearchFasta, ";size=", ";");
         
         return vsearchFasta;
     }
@@ -125,22 +127,19 @@ string VsearchFileParser::createVsearchFasta(string inputFile){
 string VsearchFileParser::getNamesFile(string& inputFile){
     try {
         
-        m->mothurOutEndLine(); m->mothurOut("No namesfile given, running unique.seqs command to generate one."); m->mothurOutEndLine(); m->mothurOutEndLine();
+        m->mothurOut("\nNo namesfile given, running unique.seqs command to generate one.\n\n");
         
         //use unique.seqs to create new name and fastafile
         string inputString = "fasta=" + inputFile + ", format=count";
-        m->mothurOut("/******************************************/"); m->mothurOutEndLine();
-        m->mothurOut("Running command: unique.seqs(" + inputString + ")"); m->mothurOutEndLine();
-        m->mothurCalling = true;
-        
+        m->mothurOut("/******************************************/\n");
+        m->mothurOut("Running command: unique.seqs(" + inputString + ")\n");
         Command* uniqueCommand = new DeconvoluteCommand(inputString);
         uniqueCommand->execute();
         
         map<string, vector<string> > filenames = uniqueCommand->getOutputFiles();
         
         delete uniqueCommand;
-        m->mothurCalling = false;
-        m->mothurOut("/******************************************/"); m->mothurOutEndLine();
+        m->mothurOut("/******************************************/\n");
         
         countfile = filenames["count"][0];
         fastafile = filenames["fasta"][0];
@@ -156,11 +155,12 @@ string VsearchFileParser::getNamesFile(string& inputFile){
 //S	1	275	*	*	*	*	*	GQY1XT001C44N8/ab=3677/	*
 int VsearchFileParser::createListFile(string inputFile, string listFile, string sabundFile, string rabundFile, int numBins, string label){
     try {
+        Utils util;
         map<string, string>::iterator itName;
-        if (format == "name") { counts.clear(); m->readNames(namefile, nameMap); }
+        if (format == "name") { counts.clear(); util.readNames(namefile, nameMap); }
         
         ifstream in;
-        m->openInputFile(inputFile, in);
+        util.openInputFile(inputFile, in);
         
         ListVector list(numBins); list.setLabel(label);
         
@@ -168,9 +168,9 @@ int VsearchFileParser::createListFile(string inputFile, string listFile, string
         string seqName, recordType, length, percentIdentity, strand, notUsed1, notUsed2, compressedAlignment, repSequence;
         
         while(!in.eof()) {
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            in >> recordType >> clusterNumber >> length >> percentIdentity >> strand >> notUsed1 >> notUsed2 >> compressedAlignment >> seqName >> repSequence; m->gobble(in);
+            in >> recordType >> clusterNumber >> length >> percentIdentity >> strand >> notUsed1 >> notUsed2 >> compressedAlignment >> seqName >> repSequence; util.gobble(in);
             
             if (recordType != "S") {
                 
@@ -178,7 +178,7 @@ int VsearchFileParser::createListFile(string inputFile, string listFile, string
                 
                 if (format == "name") {
                     itName = nameMap.find(seqName);
-                    if (itName == nameMap.end()) {  m->mothurOut("[ERROR]: " + seqName + " is not in your name file. Parsing error???\n"); m->control_pressed = true; }
+                    if (itName == nameMap.end()) {  m->mothurOut("[ERROR]: " + seqName + " is not in your name file. Parsing error???\n"); m->setControl_pressed(true); }
                     else{  seqName = itName->second;  }
                 }
                 
@@ -193,19 +193,17 @@ int VsearchFileParser::createListFile(string inputFile, string listFile, string
         in.close();
         
         ofstream out;
-        m->openOutputFile(listFile,	out);
-        list.printHeaders(out);
+        util.openOutputFile(listFile,	out);
         
-        if (countfile != "") {
-            list.print(out, counts);
-        }else {
+        if (countfile != "") { list.print(out, counts); }
+        else {
             list.print(out);
             
             if ((sabundFile != "") && (rabundFile != "")){
                 //print sabund and rabund
                 ofstream sabund, rabund;
-                m->openOutputFile(sabundFile, sabund);
-                m->openOutputFile(rabundFile, rabund);
+                util.openOutputFile(sabundFile, sabund);
+                util.openOutputFile(rabundFile, rabund);
             
                 list.getRAbundVector().print(rabund);  rabund.close();
                 list.getSAbundVector().print(sabund);  sabund.close();
@@ -243,18 +241,18 @@ int VsearchFileParser::getNumBins(string logfile){
         int numBins = 0;
         
         ifstream in;
-        m->openInputFile(logfile, in);
+        Utils util; util.openInputFile(logfile, in);
         
         string line;
         while(!in.eof()) {
-            if (m->control_pressed) { break; }
+            if (m->getControl_pressed()) { break; }
             
-            line = m->getline(in); m->gobble(in);
+            line = util.getline(in); util.gobble(in);
             
             int pos = line.find("Clusters:");
             if (pos != string::npos) {
-                vector<string> pieces = m->splitWhiteSpace(line);
-                if (pieces.size() > 1) { m->mothurConvert(pieces[1], numBins);  }
+                vector<string> pieces = util.splitWhiteSpace(line);
+                if (pieces.size() > 1) { util.mothurConvert(pieces[1], numBins);  }
                 break;
             }
         }
